/** A Data Extension Schema is the [JSON schema](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/backend-extensions/schema-plugins/the-json-schema) within a [schema plugin extension](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/backend-extensions/schema-plugins/about-schema-plugin-extensions) defining `extendedFields` that are added to a Wix API's service object. */
interface DataExtensionSchema {
    /**
     * Schema ID.
     * @format GUID
     * @readonly
     * @immutable
     */
    _id?: string | null;
    /**
     * FQDN of the entity this schema extends.
     * @immutable
     * @maxLength 255
     */
    fqdn?: string | null;
    /**
     * Namespace for this schema. For example, an app creating schemas might use their app name as a namespace.
     * When a site owner creates a user-defined schema, the namespace is: `_user_fields`.
     * @immutable
     * @maxLength 164
     */
    namespace?: string | null;
    /**
     * Schema definition in [JSON schema format](https://dev.wix.com/docs/build-apps/develop-your-app/extensions/backend-extensions/schema-plugins/the-json-schema) with the following [vocab](https://docs.json-everything.net/schema/vocabs/) extension:
     * ```
     * {
     * "$schema": "https://json-schema.org/draft/2020-12/schema",
     * "$id": "https://wixapis.com/v1/json-schema/extensions",
     * "$vocabulary": {
     * "https://wixapis.com/v1/json-schema/extensions/vocab/data-extensions": true
     * },
     * "$dynamicAnchor": "meta",
     * "title": "Wix' data-extensions vocabulary meta schema",
     * "type": [
     * "object",
     * "boolean"
     * ],
     * "properties": {
     * "x-wix-permissions": {
     * "type": "object",
     * "description": "list of identity types that are allowed reading schema properties",
     * "properties": {
     * "read": {
     * "type": "array",
     * "items": {
     * "type": "string",
     * "enum": [
     * "apps",
     * "owning-app",
     * "users",
     * "users-of-users"
     * ]
     * }
     * },
     * "write": {
     * "type": "array",
     * "items": {
     * "type": "string",
     * "enum": [
     * "apps",
     * "owning-app",
     * "users",
     * "users-of-users"
     * ]
     * }
     * }
     * }
     * },
     * "x-wix-display": {
     * "type": "object",
     * "description": "field display properties",
     * "schema": {
     * "properties": {
     * "placeholder": {
     * "type": "string",
     * "maxLength": 255,
     * "description": "placeholder text for input fields"
     * },
     * "label": {
     * "type": "string",
     * "maxLength": 255,
     * "description": "label of the input fields"
     * },
     * "hint": {
     * "type": "string",
     * "maxLength": 255,
     * "description": "a short explanation that appears next to the input field"
     * }
     * }
     * }
     * }
     * }
     * }
     * ```
     */
    jsonSchema?: Record<string, any> | null;
    /**
     * Date and time the schema was last updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Date and time the schema was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Revision number, which increments by 1 each time the schema is updated. To prevent conflicting changes, the existing revision must be used when updating a schema.
     * @readonly
     */
    revision?: string | null;
    /**
     * Maximum allowed schema size in bytes.
     * @readonly
     */
    maxLimitBytes?: number | null;
    /**
     * Current schema size in bytes.
     * @readonly
     */
    currentSizeBytes?: number | null;
}
declare enum DataExtensionSchemaState {
}
/** @enumType */
type DataExtensionSchemaStateWithLiterals = DataExtensionSchemaState;
interface DomainEvent extends DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
/** @oneof */
interface DomainEventBodyOneOf {
    createdEvent?: EntityCreatedEvent;
    updatedEvent?: EntityUpdatedEvent;
    deletedEvent?: EntityDeletedEvent;
    actionEvent?: ActionEvent;
}
interface EntityCreatedEvent {
    entity?: string;
}
interface RestoreInfo {
    deletedDate?: Date | null;
}
interface EntityUpdatedEvent {
    /**
     * Since platformized APIs only expose PATCH and not PUT we can't assume that the fields sent from the client are the actual diff.
     * This means that to generate a list of changed fields (as opposed to sent fields) one needs to traverse both objects.
     * We don't want to impose this on all developers and so we leave this traversal to the notification recipients which need it.
     */
    currentEntity?: string;
}
interface EntityDeletedEvent {
    /** Entity that was deleted. */
    deletedEntity?: string | null;
}
interface ActionEvent {
    body?: string;
}
interface MessageEnvelope {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
    /** Stringify payload. */
    data?: string;
}
interface IdentificationData extends IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
    /** @readonly */
    identityType?: WebhookIdentityTypeWithLiterals;
}
/** @oneof */
interface IdentificationDataIdOneOf {
    /**
     * ID of a site visitor that has not logged in to the site.
     * @format GUID
     */
    anonymousVisitorId?: string;
    /**
     * ID of a site visitor that has logged in to the site.
     * @format GUID
     */
    memberId?: string;
    /**
     * ID of a Wix user (site owner, contributor, etc.).
     * @format GUID
     */
    wixUserId?: string;
    /**
     * ID of an app.
     * @format GUID
     */
    appId?: string;
}
declare enum WebhookIdentityType {
    UNKNOWN = "UNKNOWN",
    ANONYMOUS_VISITOR = "ANONYMOUS_VISITOR",
    MEMBER = "MEMBER",
    WIX_USER = "WIX_USER",
    APP = "APP"
}
/** @enumType */
type WebhookIdentityTypeWithLiterals = WebhookIdentityType | 'UNKNOWN' | 'ANONYMOUS_VISITOR' | 'MEMBER' | 'WIX_USER' | 'APP';
interface ReindexEvent {
    /**
     * fqdn of the dext schema that needs reindexing
     * @maxLength 255
     */
    fqdn?: string;
    /**
     * List of fields that needs reindexing
     * @maxSize 100
     */
    fields?: ReindexField[];
}
interface ReindexField {
    /**
     * path of field that needs reindexing
     * @maxLength 2000
     */
    fieldPath?: string;
    /** only reindex records updated after this timestamp */
    reindexSince?: Date | null;
}
interface CreateDataExtensionSchemaRequest {
    /** Schema to create. */
    dataExtensionSchema: DataExtensionSchema;
}
interface CreateDataExtensionSchemaResponse {
    /** Created schema. */
    dataExtensionSchema?: DataExtensionSchema;
}
interface UpdateDataExtensionSchemaRequest {
    /** Schema to update. */
    dataExtensionSchema: DataExtensionSchema;
}
interface UpdateDataExtensionSchemaResponse {
    /** Updated schema. */
    dataExtensionSchema?: DataExtensionSchema;
}
interface ListDataExtensionSchemasRequest {
    /**
     * [Fully qualified domain name](https://dev.wix.com/docs/rest/articles/getting-started/fqdns).
     * @maxLength 255
     */
    fqdn: string;
    /**
     * Namespaces within the given entity.
     * @maxSize 100
     * @maxLength 164
     */
    namespaces?: string[];
    /**
     * Additional fields that are hidden by default. For example, fields with `"x-wix-archived": true`.
     * @maxSize 5
     */
    fields?: RequestedFieldWithLiterals[];
    /**
     * Extension points within the given entity.
     * @maxSize 20
     * @maxLength 10
     */
    extensionPoints?: string[];
}
declare enum RequestedField {
    /** Undefined requested field. */
    UNKNOWN_REQUESTED_FIELD = "UNKNOWN_REQUESTED_FIELD",
    /** Returns `x-wix-archived` fields in `DataExtensionSchema.json_schema`. */
    ARCHIVED = "ARCHIVED"
}
/** @enumType */
type RequestedFieldWithLiterals = RequestedField | 'UNKNOWN_REQUESTED_FIELD' | 'ARCHIVED';
interface ListDataExtensionSchemasResponse {
    /** Requested schemas. */
    dataExtensionSchemas?: DataExtensionSchema[];
}
interface DeleteDemoDataExtensionSchemaRequest {
    /**
     * Schema ID.
     * @format GUID
     */
    dataExtensionSchemaId?: string;
}
interface DeleteDemoDataExtensionSchemaResponse {
}
interface DeleteGlobalExtensionSchemaRequest {
    /**
     * fqdn
     * @maxLength 255
     */
    fqdn?: string;
    /**
     * namespace
     * @maxLength 164
     */
    namespace?: string;
    /**
     * extension point
     * @maxLength 20
     */
    extensionPoint?: string;
    /** state */
    state?: DataExtensionSchemaStateWithLiterals;
}
interface DeleteGlobalExtensionSchemaResponse {
}
interface DeleteByWhiteListedMetaSiteRequest {
    /**
     * Meta site id
     * @format GUID
     */
    metaSiteId: string;
}
interface DeleteByWhiteListedMetaSiteResponse {
    /** has more */
    hasMore?: boolean;
}
interface Empty {
}
interface AppRuntimeDataEvent {
    appRuntimeData?: AppRuntimeDataCacheEntity;
    isDraft?: boolean;
}
interface AppRuntimeDataCacheEntity {
    appData?: AppData;
    translatedDataMap?: Record<string, TranslatedData>;
}
interface RuntimeComponentCacheEntity extends RuntimeComponentCacheEntityComponentOneOf {
    componentEntity?: RuntimeComponentCacheEntityComponent;
    componentExperimentEntity?: RuntimeComponentCacheEntityExperiment;
}
/** @oneof */
interface RuntimeComponentCacheEntityComponentOneOf {
    componentEntity?: RuntimeComponentCacheEntityComponent;
    componentExperimentEntity?: RuntimeComponentCacheEntityExperiment;
}
interface RuntimeComponentCacheEntityComponent {
    /**
     * The ID of the component
     * @format GUID
     */
    componentId?: string;
    /** The version of the component */
    version?: number;
    /**
     * Component name
     * @maxLength 200
     */
    name?: string | null;
    /** the type of the component */
    type?: ComponentTypeWithLiterals;
    /** the data of the component */
    data?: ComponentData;
    /** The external id of the component */
    externalId?: string | null;
    /** The additional translated keys of the component */
    additionalTranslatedKeys?: Record<string, string>;
    /** Partial update patch value */
    partialUpdatePatch?: string | null;
}
/** Component type */
declare enum ComponentType {
    NONE = "NONE",
    STUDIO = "STUDIO",
    PLATFORM = "PLATFORM",
    WORKER = "WORKER",
    DASHBOARD = "DASHBOARD",
    WIDGET = "WIDGET",
    PAGE = "PAGE",
    DASHBOARD_PLATFORM = "DASHBOARD_PLATFORM",
    STUDIO_WIDGET = "STUDIO_WIDGET",
    EMBEDDED_SCRIPT = "EMBEDDED_SCRIPT",
    EXTENSION = "EXTENSION",
    SNIPPET_SOLUTION = "SNIPPET_SOLUTION",
    DATA_COMPONENT = "DATA_COMPONENT",
    WEB = "WEB",
    DC_CONFIG = "DC_CONFIG",
    WIDGET_OUT_OF_IFRAME = "WIDGET_OUT_OF_IFRAME",
    PAGE_OUT_OF_IFRAME = "PAGE_OUT_OF_IFRAME",
    STATIC_FILE = "STATIC_FILE",
    APP_CONFIG = "APP_CONFIG",
    MULTIPLE_DASHBOARDS = "MULTIPLE_DASHBOARDS",
    PAYMENTS_GATEWAY = "PAYMENTS_GATEWAY",
    CODE_PACKAGE = "CODE_PACKAGE",
    AUTOMATION_TRIGGER = "AUTOMATION_TRIGGER",
    INVOICES_ACTIONS = "INVOICES_ACTIONS",
    DASHBOARD_APPLICATION = "DASHBOARD_APPLICATION",
    CONTACT_LABELS = "CONTACT_LABELS",
    WIDGET_PLUGIN = "WIDGET_PLUGIN",
    CROSS_SELL = "CROSS_SELL",
    LOCAL_DELIVERY = "LOCAL_DELIVERY",
    PAYMENT_PROVIDER = "PAYMENT_PROVIDER",
    ECOM_MEMBERSHIPS = "ECOM_MEMBERSHIPS",
    ECOM_LINE_ITEMS_ENRICHER = "ECOM_LINE_ITEMS_ENRICHER",
    ECOM_SHIPPING_RATES = "ECOM_SHIPPING_RATES",
    SHIPPING_LABEL_CARRIER = "SHIPPING_LABEL_CARRIER",
    RESTAURANTS_POS = "RESTAURANTS_POS",
    FICTIONAL_SHIPPING_PROVIDER = "FICTIONAL_SHIPPING_PROVIDER",
    ALERT_ENRICHER = "ALERT_ENRICHER",
    DATA_EXTENSIONS = "DATA_EXTENSIONS",
    GENERIC_HOOKS = "GENERIC_HOOKS",
    AUTOMATIONS_ACTION_PROVIDER = "AUTOMATIONS_ACTION_PROVIDER",
    ECOM_CATALOG = "ECOM_CATALOG",
    BACK_OFFICE_EXTENSION_CONTAINER = "BACK_OFFICE_EXTENSION_CONTAINER",
    BACK_OFFICE_EXTENSION = "BACK_OFFICE_EXTENSION",
    AUTOMATIONS_TRIGGER_PROVIDER = "AUTOMATIONS_TRIGGER_PROVIDER",
    IDENTITY_PRE_REGISTRATION = "IDENTITY_PRE_REGISTRATION",
    PREMIUM_PRODUCTS_PATHS = "PREMIUM_PRODUCTS_PATHS",
    ECOM_CUSTOM_SCOPE = "ECOM_CUSTOM_SCOPE",
    GIFT_CARDS_PROVIDER = "GIFT_CARDS_PROVIDER",
    DEALER_EXTERNAL_FILTER_PROVIDER = "DEALER_EXTERNAL_FILTER_PROVIDER",
    ECOM_DROPSHIPPING_PROVIDER = "ECOM_DROPSHIPPING_PROVIDER",
    INVOICES_PROVIDER = "INVOICES_PROVIDER",
    SEO_KEYWORDS_SUGGESTIONS = "SEO_KEYWORDS_SUGGESTIONS",
    ECOM_DISCOUNTS_TRIGGER = "ECOM_DISCOUNTS_TRIGGER",
    MULTILINGUAL_CONTENT_PROVIDER = "MULTILINGUAL_CONTENT_PROVIDER",
    APPLICATION_AUTOMATION = "APPLICATION_AUTOMATION",
    BACK_OFFICE_SIDEBAR_CATEGORY = "BACK_OFFICE_SIDEBAR_CATEGORY",
    BACK_OFFICE_PAGE = "BACK_OFFICE_PAGE",
    ECOM_ADDITIONAL_FEES = "ECOM_ADDITIONAL_FEES",
    PING_USER_NOTIFICATION = "PING_USER_NOTIFICATION",
    ECOM_RECOMMENDATIONS_PROVIDER = "ECOM_RECOMMENDATIONS_PROVIDER",
    BOOKINGS_PRICING_PROVIDER = "BOOKINGS_PRICING_PROVIDER",
    IDENTITY_AUTHENTICATOR = "IDENTITY_AUTHENTICATOR",
    IDENTITY_IDP_CONNECTOR = "IDENTITY_IDP_CONNECTOR",
    ITEMS_SELECTION_PROVIDER = "ITEMS_SELECTION_PROVIDER",
    PORTFOLIO_SYNCED_PROJECTS_PROVIDER = "PORTFOLIO_SYNCED_PROJECTS_PROVIDER",
    COMMUNICATION_CHANNEL = "COMMUNICATION_CHANNEL",
    IDENTITY_POST_LOGIN = "IDENTITY_POST_LOGIN",
    BACK_OFFICE_WIDGET = "BACK_OFFICE_WIDGET",
    SOCIAL_MARKETING_DESIGN = "SOCIAL_MARKETING_DESIGN",
    FORMS_SUBMISSIONS_PROVIDER = "FORMS_SUBMISSIONS_PROVIDER",
    WIX_OFFERING = "WIX_OFFERING",
    DEV_CENTER_TESTING_COMPONENT = "DEV_CENTER_TESTING_COMPONENT",
    COMPONENTS_VALIDATOR_PROVIDER = "COMPONENTS_VALIDATOR_PROVIDER",
    COMPONENTS_TRANSLATIONS_ADDITIONAL_FIELDS_PROVIDER = "COMPONENTS_TRANSLATIONS_ADDITIONAL_FIELDS_PROVIDER",
    FORMS_SCHEMA_PROVIDER = "FORMS_SCHEMA_PROVIDER",
    BOOKINGS_EXTERNAL_CALENDAR_PROVIDER = "BOOKINGS_EXTERNAL_CALENDAR_PROVIDER",
    ECOM_DEFAULT_TAXATION_CATEGORY = "ECOM_DEFAULT_TAXATION_CATEGORY",
    VIEWER_DYNAMIC_SITE_STRUCTURE_PROVIDER = "VIEWER_DYNAMIC_SITE_STRUCTURE_PROVIDER",
    PING_UOU_NOTIFICATION = "PING_UOU_NOTIFICATION",
    HEADLESS_OAUTH = "HEADLESS_OAUTH",
    ECOM_TAX_CALCULATOR_SPI = "ECOM_TAX_CALCULATOR_SPI",
    COMMENTS_MODERATION_PROVIDER = "COMMENTS_MODERATION_PROVIDER",
    GRID_APP_FILES_TRANSFORMER = "GRID_APP_FILES_TRANSFORMER",
    BENEFIT_PROGRAMS_POLICY_PROVIDER = "BENEFIT_PROGRAMS_POLICY_PROVIDER",
    PREMIUM_CUSTOM_CHARGES = "PREMIUM_CUSTOM_CHARGES",
    ECOM_VALIDATIONS = "ECOM_VALIDATIONS",
    COMPONENT_REFERENCE_DATA_PROVIDER = "COMPONENT_REFERENCE_DATA_PROVIDER",
    WIX_REVIEWS_PRODUCT_CATALOG = "WIX_REVIEWS_PRODUCT_CATALOG",
    SOCIAL_MARKETING_DESIGNS_PROVIDER = "SOCIAL_MARKETING_DESIGNS_PROVIDER",
    GOOGLE_BUSINESS_PROFILE_FEATURE_PROVIDER = "GOOGLE_BUSINESS_PROFILE_FEATURE_PROVIDER",
    COMMENTS_FILTER_PROVIDER = "COMMENTS_FILTER_PROVIDER",
    BILLING_TAX_ID_VALIDATOR = "BILLING_TAX_ID_VALIDATOR",
    PING_SETTINGS_GROUP = "PING_SETTINGS_GROUP",
    FORMS_SPAM_SUBMISSIONS_PROVIDER = "FORMS_SPAM_SUBMISSIONS_PROVIDER",
    EDITOR_ADDON = "EDITOR_ADDON",
    EXTERNAL_DATABASE_PROVIDER = "EXTERNAL_DATABASE_PROVIDER",
    ECOM_PAYMENT_SETTINGS = "ECOM_PAYMENT_SETTINGS",
    NOTIFICATION_TOPIC = "NOTIFICATION_TOPIC",
    NOTIFICATION_PREFERENCES_FILTER_PROVIDER = "NOTIFICATION_PREFERENCES_FILTER_PROVIDER",
    BOOKINGS_RESOURCE_TYPES_PROVIDER = "BOOKINGS_RESOURCE_TYPES_PROVIDER",
    PRICING_PLANS_FORM_CONFIGURATION = "PRICING_PLANS_FORM_CONFIGURATION",
    USER_NOTIFICATION = "USER_NOTIFICATION",
    CONTACT_NOTIFICATION = "CONTACT_NOTIFICATION",
    UNIFIED_PAGE = "UNIFIED_PAGE",
    AVAILABILITY_TIME_SLOTS_CONFIGURATION_PROVIDER = "AVAILABILITY_TIME_SLOTS_CONFIGURATION_PROVIDER",
    PROPOSAL_EDITOR_PROVIDER = "PROPOSAL_EDITOR_PROVIDER",
    CUSTOM_TABLE_RESERVATIONS_PROVIDER = "CUSTOM_TABLE_RESERVATIONS_PROVIDER",
    COMMENTS_CONTEXT_PROVIDER = "COMMENTS_CONTEXT_PROVIDER",
    FORMS_SPAM_SUBMISSION_REPORTS_PROVIDER = "FORMS_SPAM_SUBMISSION_REPORTS_PROVIDER",
    AUTOMATIONS_VELO_ACTION_PROVIDER = "AUTOMATIONS_VELO_ACTION_PROVIDER",
    CALENDAR_EVENT_TYPE_PROVIDER = "CALENDAR_EVENT_TYPE_PROVIDER",
    /** Reserved - previously was `SERVICE_AVAILABILITY_POLICY_PROVIDER` */
    RESERVED = "RESERVED",
    SMS_ACTION_MESSAGE = "SMS_ACTION_MESSAGE",
    BOOKING_POLICY_PROVIDER = "BOOKING_POLICY_PROVIDER",
    MULTI_SERVICE_BOOKING_POLICY_PROVIDER = "MULTI_SERVICE_BOOKING_POLICY_PROVIDER",
    AI_ASSISTANT = "AI_ASSISTANT",
    FORMS_SUBMISSIONS_EXTENSION_PROVIDER = "FORMS_SUBMISSIONS_EXTENSION_PROVIDER",
    MULTILINGUAL_TRANSLATION_SCHEMA = "MULTILINGUAL_TRANSLATION_SCHEMA",
    TAX_CALCULATION_PROVIDER = "TAX_CALCULATION_PROVIDER",
    TAX_GROUPS_PROVIDER = "TAX_GROUPS_PROVIDER",
    BACK_OFFICE_MODAL = "BACK_OFFICE_MODAL",
    DEPLOYMENT_PIPELINE_PROVIDER = "DEPLOYMENT_PIPELINE_PROVIDER",
    CUSTOM_ELEMENT_WIDGET = "CUSTOM_ELEMENT_WIDGET",
    BACK_OFFICE_EXTENSION_WIDGET = "BACK_OFFICE_EXTENSION_WIDGET",
    BACK_OFFICE_EXTENSION_MENU_ITEM = "BACK_OFFICE_EXTENSION_MENU_ITEM",
    FORM_TEMPLATE = "FORM_TEMPLATE",
    NOTIFICATION_CONTENT = "NOTIFICATION_CONTENT",
    BROADCAST_LIST = "BROADCAST_LIST",
    PARTNERS_PAYOUTS = "PARTNERS_PAYOUTS",
    WIX_REVIEWS_ENTITY_CATALOG = "WIX_REVIEWS_ENTITY_CATALOG",
    VELO_PUBLISH_PIPELINE_TASK_PROVIDER = "VELO_PUBLISH_PIPELINE_TASK_PROVIDER",
    FUNCTIONS_SHOP_PRICE_PROVIDER = "FUNCTIONS_SHOP_PRICE_PROVIDER",
    FUNCTION = "FUNCTION",
    ECOM_CHECKOUT_CONTENT = "ECOM_CHECKOUT_CONTENT",
    COMMUNICATION_CHANNEL_PROVIDER = "COMMUNICATION_CHANNEL_PROVIDER",
    WEBHOOK = "WEBHOOK",
    TOPOLOGY = "TOPOLOGY",
    LOYALTY_CUSTOM_REWARDS = "LOYALTY_CUSTOM_REWARDS",
    FUNCTION_RECIPE = "FUNCTION_RECIPE",
    BACK_OFFICE_EXTERNAL_URL = "BACK_OFFICE_EXTERNAL_URL",
    IDENTITY_FACTOR = "IDENTITY_FACTOR",
    ECOM_DISCOUNTS = "ECOM_DISCOUNTS",
    VELO_CUSTOM_CSS = "VELO_CUSTOM_CSS",
    DEALER_ADAPTIVE_COMPONENT_PROVIDER = "DEALER_ADAPTIVE_COMPONENT_PROVIDER",
    AI_ASSISTANT_ACTION = "AI_ASSISTANT_ACTION",
    ECOM_INVENTORY = "ECOM_INVENTORY",
    MONITORING = "MONITORING",
    PAPI_PROVIDER = "PAPI_PROVIDER",
    UNIFIED_LIGHTBOX = "UNIFIED_LIGHTBOX",
    FORMS_EXTENSION_PROVIDER = "FORMS_EXTENSION_PROVIDER",
    MULTILINGUAL_TRANSLATION_SCHEMA_GROUP = "MULTILINGUAL_TRANSLATION_SCHEMA_GROUP",
    PANEL = "PANEL",
    PREMIUM_PURCHASE_VALIDATIONS = "PREMIUM_PURCHASE_VALIDATIONS",
    BROWSER_STORAGE = "BROWSER_STORAGE",
    SDK_DEFINITION = "SDK_DEFINITION",
    SITE_WIDGET_SLOT = "SITE_WIDGET_SLOT",
    CALENDAR_EVENT_VALIDATION_PROVIDER = "CALENDAR_EVENT_VALIDATION_PROVIDER",
    CLIENT_SIDE_SERVICE = "CLIENT_SIDE_SERVICE",
    BILLING_SETTINGS = "BILLING_SETTINGS",
    PATTERNS_WIZARD = "PATTERNS_WIZARD",
    APPLICATION_PROFILE = "APPLICATION_PROFILE",
    TEXT_TO_SPEECH_ACTION_MESSAGE = "TEXT_TO_SPEECH_ACTION_MESSAGE",
    AUDIENCE_PROVIDER = "AUDIENCE_PROVIDER",
    PRICING_PLANS_PRICE = "PRICING_PLANS_PRICE",
    PRICING_PLAN_START_DATE_LIMITS = "PRICING_PLAN_START_DATE_LIMITS",
    PRICING_PLAN_START_DATE_RULES = "PRICING_PLAN_START_DATE_RULES",
    EVENTS_TICKET_RESERVATIONS = "EVENTS_TICKET_RESERVATIONS",
    PAYMENTS_DISPUTE_SERVICE_PLUGIN = "PAYMENTS_DISPUTE_SERVICE_PLUGIN",
    PRICING_PLANS_FEES = "PRICING_PLANS_FEES",
    EDITOR_REACT_COMPONENT = "EDITOR_REACT_COMPONENT",
    SUPPLIERS_HUB_MARKETPLACE = "SUPPLIERS_HUB_MARKETPLACE",
    FORM_SCHEMA_DYNAMIC_VALUES = "FORM_SCHEMA_DYNAMIC_VALUES",
    BLOG_PAYWALL_PROVIDER = "BLOG_PAYWALL_PROVIDER",
    LOYALTY_CUSTOM_REWARDS_V2 = "LOYALTY_CUSTOM_REWARDS_V2",
    STORES_PRODUCT_RESTRICTIONS = "STORES_PRODUCT_RESTRICTIONS",
    FORM_SUBMISSION_MODERATION = "FORM_SUBMISSION_MODERATION",
    EVENTS_EVENT_BADGES = "EVENTS_EVENT_BADGES",
    BILLING_OPERATION = "BILLING_OPERATION",
    BACK_OFFICE_CUSTOMIZATION = "BACK_OFFICE_CUSTOMIZATION",
    COMPONENT_ENRICHER_PROVIDER = "COMPONENT_ENRICHER_PROVIDER",
    BACK_OFFICE_RESTRICTED_CUSTOMIZATION = "BACK_OFFICE_RESTRICTED_CUSTOMIZATION",
    EDITOR_APP_PREVIEWS_POC = "EDITOR_APP_PREVIEWS_POC",
    LEGENDS_PERSONA_CONFIGURATION = "LEGENDS_PERSONA_CONFIGURATION",
    WIX_HOSTING_APP_DEPLOYMENT_PROVIDER = "WIX_HOSTING_APP_DEPLOYMENT_PROVIDER",
    BACKEND_WORKER = "BACKEND_WORKER",
    EVENT_TIME_SLOTS_CONFIGURATION_PROVIDER = "EVENT_TIME_SLOTS_CONFIGURATION_PROVIDER",
    WIX_HOSTING_APP_ENVIRONMENT_PROVIDER = "WIX_HOSTING_APP_ENVIRONMENT_PROVIDER",
    SDK_EXPORTS = "SDK_EXPORTS"
}
/** @enumType */
type ComponentTypeWithLiterals = ComponentType | 'NONE' | 'STUDIO' | 'PLATFORM' | 'WORKER' | 'DASHBOARD' | 'WIDGET' | 'PAGE' | 'DASHBOARD_PLATFORM' | 'STUDIO_WIDGET' | 'EMBEDDED_SCRIPT' | 'EXTENSION' | 'SNIPPET_SOLUTION' | 'DATA_COMPONENT' | 'WEB' | 'DC_CONFIG' | 'WIDGET_OUT_OF_IFRAME' | 'PAGE_OUT_OF_IFRAME' | 'STATIC_FILE' | 'APP_CONFIG' | 'MULTIPLE_DASHBOARDS' | 'PAYMENTS_GATEWAY' | 'CODE_PACKAGE' | 'AUTOMATION_TRIGGER' | 'INVOICES_ACTIONS' | 'DASHBOARD_APPLICATION' | 'CONTACT_LABELS' | 'WIDGET_PLUGIN' | 'CROSS_SELL' | 'LOCAL_DELIVERY' | 'PAYMENT_PROVIDER' | 'ECOM_MEMBERSHIPS' | 'ECOM_LINE_ITEMS_ENRICHER' | 'ECOM_SHIPPING_RATES' | 'SHIPPING_LABEL_CARRIER' | 'RESTAURANTS_POS' | 'FICTIONAL_SHIPPING_PROVIDER' | 'ALERT_ENRICHER' | 'DATA_EXTENSIONS' | 'GENERIC_HOOKS' | 'AUTOMATIONS_ACTION_PROVIDER' | 'ECOM_CATALOG' | 'BACK_OFFICE_EXTENSION_CONTAINER' | 'BACK_OFFICE_EXTENSION' | 'AUTOMATIONS_TRIGGER_PROVIDER' | 'IDENTITY_PRE_REGISTRATION' | 'PREMIUM_PRODUCTS_PATHS' | 'ECOM_CUSTOM_SCOPE' | 'GIFT_CARDS_PROVIDER' | 'DEALER_EXTERNAL_FILTER_PROVIDER' | 'ECOM_DROPSHIPPING_PROVIDER' | 'INVOICES_PROVIDER' | 'SEO_KEYWORDS_SUGGESTIONS' | 'ECOM_DISCOUNTS_TRIGGER' | 'MULTILINGUAL_CONTENT_PROVIDER' | 'APPLICATION_AUTOMATION' | 'BACK_OFFICE_SIDEBAR_CATEGORY' | 'BACK_OFFICE_PAGE' | 'ECOM_ADDITIONAL_FEES' | 'PING_USER_NOTIFICATION' | 'ECOM_RECOMMENDATIONS_PROVIDER' | 'BOOKINGS_PRICING_PROVIDER' | 'IDENTITY_AUTHENTICATOR' | 'IDENTITY_IDP_CONNECTOR' | 'ITEMS_SELECTION_PROVIDER' | 'PORTFOLIO_SYNCED_PROJECTS_PROVIDER' | 'COMMUNICATION_CHANNEL' | 'IDENTITY_POST_LOGIN' | 'BACK_OFFICE_WIDGET' | 'SOCIAL_MARKETING_DESIGN' | 'FORMS_SUBMISSIONS_PROVIDER' | 'WIX_OFFERING' | 'DEV_CENTER_TESTING_COMPONENT' | 'COMPONENTS_VALIDATOR_PROVIDER' | 'COMPONENTS_TRANSLATIONS_ADDITIONAL_FIELDS_PROVIDER' | 'FORMS_SCHEMA_PROVIDER' | 'BOOKINGS_EXTERNAL_CALENDAR_PROVIDER' | 'ECOM_DEFAULT_TAXATION_CATEGORY' | 'VIEWER_DYNAMIC_SITE_STRUCTURE_PROVIDER' | 'PING_UOU_NOTIFICATION' | 'HEADLESS_OAUTH' | 'ECOM_TAX_CALCULATOR_SPI' | 'COMMENTS_MODERATION_PROVIDER' | 'GRID_APP_FILES_TRANSFORMER' | 'BENEFIT_PROGRAMS_POLICY_PROVIDER' | 'PREMIUM_CUSTOM_CHARGES' | 'ECOM_VALIDATIONS' | 'COMPONENT_REFERENCE_DATA_PROVIDER' | 'WIX_REVIEWS_PRODUCT_CATALOG' | 'SOCIAL_MARKETING_DESIGNS_PROVIDER' | 'GOOGLE_BUSINESS_PROFILE_FEATURE_PROVIDER' | 'COMMENTS_FILTER_PROVIDER' | 'BILLING_TAX_ID_VALIDATOR' | 'PING_SETTINGS_GROUP' | 'FORMS_SPAM_SUBMISSIONS_PROVIDER' | 'EDITOR_ADDON' | 'EXTERNAL_DATABASE_PROVIDER' | 'ECOM_PAYMENT_SETTINGS' | 'NOTIFICATION_TOPIC' | 'NOTIFICATION_PREFERENCES_FILTER_PROVIDER' | 'BOOKINGS_RESOURCE_TYPES_PROVIDER' | 'PRICING_PLANS_FORM_CONFIGURATION' | 'USER_NOTIFICATION' | 'CONTACT_NOTIFICATION' | 'UNIFIED_PAGE' | 'AVAILABILITY_TIME_SLOTS_CONFIGURATION_PROVIDER' | 'PROPOSAL_EDITOR_PROVIDER' | 'CUSTOM_TABLE_RESERVATIONS_PROVIDER' | 'COMMENTS_CONTEXT_PROVIDER' | 'FORMS_SPAM_SUBMISSION_REPORTS_PROVIDER' | 'AUTOMATIONS_VELO_ACTION_PROVIDER' | 'CALENDAR_EVENT_TYPE_PROVIDER' | 'RESERVED' | 'SMS_ACTION_MESSAGE' | 'BOOKING_POLICY_PROVIDER' | 'MULTI_SERVICE_BOOKING_POLICY_PROVIDER' | 'AI_ASSISTANT' | 'FORMS_SUBMISSIONS_EXTENSION_PROVIDER' | 'MULTILINGUAL_TRANSLATION_SCHEMA' | 'TAX_CALCULATION_PROVIDER' | 'TAX_GROUPS_PROVIDER' | 'BACK_OFFICE_MODAL' | 'DEPLOYMENT_PIPELINE_PROVIDER' | 'CUSTOM_ELEMENT_WIDGET' | 'BACK_OFFICE_EXTENSION_WIDGET' | 'BACK_OFFICE_EXTENSION_MENU_ITEM' | 'FORM_TEMPLATE' | 'NOTIFICATION_CONTENT' | 'BROADCAST_LIST' | 'PARTNERS_PAYOUTS' | 'WIX_REVIEWS_ENTITY_CATALOG' | 'VELO_PUBLISH_PIPELINE_TASK_PROVIDER' | 'FUNCTIONS_SHOP_PRICE_PROVIDER' | 'FUNCTION' | 'ECOM_CHECKOUT_CONTENT' | 'COMMUNICATION_CHANNEL_PROVIDER' | 'WEBHOOK' | 'TOPOLOGY' | 'LOYALTY_CUSTOM_REWARDS' | 'FUNCTION_RECIPE' | 'BACK_OFFICE_EXTERNAL_URL' | 'IDENTITY_FACTOR' | 'ECOM_DISCOUNTS' | 'VELO_CUSTOM_CSS' | 'DEALER_ADAPTIVE_COMPONENT_PROVIDER' | 'AI_ASSISTANT_ACTION' | 'ECOM_INVENTORY' | 'MONITORING' | 'PAPI_PROVIDER' | 'UNIFIED_LIGHTBOX' | 'FORMS_EXTENSION_PROVIDER' | 'MULTILINGUAL_TRANSLATION_SCHEMA_GROUP' | 'PANEL' | 'PREMIUM_PURCHASE_VALIDATIONS' | 'BROWSER_STORAGE' | 'SDK_DEFINITION' | 'SITE_WIDGET_SLOT' | 'CALENDAR_EVENT_VALIDATION_PROVIDER' | 'CLIENT_SIDE_SERVICE' | 'BILLING_SETTINGS' | 'PATTERNS_WIZARD' | 'APPLICATION_PROFILE' | 'TEXT_TO_SPEECH_ACTION_MESSAGE' | 'AUDIENCE_PROVIDER' | 'PRICING_PLANS_PRICE' | 'PRICING_PLAN_START_DATE_LIMITS' | 'PRICING_PLAN_START_DATE_RULES' | 'EVENTS_TICKET_RESERVATIONS' | 'PAYMENTS_DISPUTE_SERVICE_PLUGIN' | 'PRICING_PLANS_FEES' | 'EDITOR_REACT_COMPONENT' | 'SUPPLIERS_HUB_MARKETPLACE' | 'FORM_SCHEMA_DYNAMIC_VALUES' | 'BLOG_PAYWALL_PROVIDER' | 'LOYALTY_CUSTOM_REWARDS_V2' | 'STORES_PRODUCT_RESTRICTIONS' | 'FORM_SUBMISSION_MODERATION' | 'EVENTS_EVENT_BADGES' | 'BILLING_OPERATION' | 'BACK_OFFICE_CUSTOMIZATION' | 'COMPONENT_ENRICHER_PROVIDER' | 'BACK_OFFICE_RESTRICTED_CUSTOMIZATION' | 'EDITOR_APP_PREVIEWS_POC' | 'LEGENDS_PERSONA_CONFIGURATION' | 'WIX_HOSTING_APP_DEPLOYMENT_PROVIDER' | 'BACKEND_WORKER' | 'EVENT_TIME_SLOTS_CONFIGURATION_PROVIDER' | 'WIX_HOSTING_APP_ENVIRONMENT_PROVIDER' | 'SDK_EXPORTS';
/** Component data */
interface ComponentData extends ComponentDataDataOneOf {
    /**
     * Create a widget iframe that users can display on their site. We recommend submitting a proposal before using iframes in your app.
     * Learn More: https://devforum.wix.com/en/article/widget-components
     */
    widgetComponentData?: WidgetComponentData;
    /**
     * Display an iframe as a page on a user's site.
     * Learn More: https://dev.wix.com/docs/build-apps/developer-tools/extensions/iframes/guide-to-page-extensions
     */
    pageComponentData?: PageComponentData;
    /**
     * Open an iframe in the Dashboard, or add a link to a page on your platform.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/dashboard-extensions/external-links/about-external-link-extensions
     */
    dashboardComponentData?: DashboardComponentData;
    /**
     * Use an invisible iframe to track activity. It’s added to every page on the site (max. 1).
     * Learn More: https://devforum.wix.com/en/article/worker-components
     */
    workerComponentData?: WorkerComponentData;
    /**
     * Inject a script into a site’s HTML code.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/embedded-scripts/about-embedded-scripts
     */
    embeddedScriptComponentData?: EmbeddedScriptComponentData;
    /**
     * Display a widget that fits into a predefined slot in a Wix app.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-plugins/about-site-plugin-extensions
     */
    widgetPlugin?: WidgetPluginComponentData;
    /**
     * Displays the options from your Shipping Rates service plugin in a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/shipping-rates-integration-service-plugin/introduction
     */
    ecomShippingRates?: ShippingRatesConfig;
    /** Extend a Wix entity with custom fields for your app */
    dataExtensions?: DataExtensionsComponentData;
    /**
     * eCommerce Catalog Service Plugin | Become a Wix catalog provider and integrate any external repository of sellable items with the Wix eCommerce platform.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/catalog-service-plugin/introduction
     */
    ecomCatalog?: CatalogSPIConfig;
    /**
     * Gift Card SPI for Ecom Platform
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/gift-cards-service-plugin/introduction
     */
    giftCardsProvider?: GiftCardProviderConfig;
    /**
     * Provide SEO keyword suggestions to site collaborators, report quota usage, and provide a page where users can upgrade their plan.
     * Learn More: https://dev.wix.com/docs/rest/api-reference/marketing/seo-keywords-suggestions-v-1/introduction
     */
    seoKeywordsSuggestions?: SeoKeywordsSuggestionsSPIConfig;
    /**
     * Configure a page for your app that will be embedded in the Wix Dashboard.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/dashboard-extensions/dashboard-pages/about-dashboard-page-extensions
     */
    backOfficePage?: BackOfficePage;
    /**
     * Displays the fees from your Additional Fees service plugin in a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/additional-fees-service-plugin/introduction
     */
    ecomAdditionalFees?: AdditionalFeesSPIConfig;
    /**
     * Premium Custom Charges Config
     * Learn More: https://dev.wix.com/docs/rest/api-reference/app-management/apps/custom-charges-spi/introduction
     */
    premiumCustomCharges?: CustomChargesConfig;
    /**
     * Performs Validations for a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/api-reference/wix-e-commerce/validations-integration-spi/introduction
     */
    ecomValidations?: ValidationsSPIConfig;
    /**
     * Build a tool that adds functionality to the Wix editors.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/editor-extensions/about-editor-extensions
     */
    editorAddon?: EditorAddon;
    /** External Database component */
    externalDatabaseProvider?: ExternalDatabaseSpiConfig;
    /**
     * Ecom Payment Settings Service Plugin Config
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/payment-settings-integration-service-plugin/introduction
     */
    ecomPaymentSettings?: PaymentSettingsSPIConfig;
    /**
     * Add a site page that displays selected widgets.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-pages/about-site-page-extensions
     */
    unifiedPage?: UnifiedPage;
    /** Create a reusable modal that can be utilized across multiple pages within your app and in other applications. */
    backOfficeModal?: BackOfficeModal;
    /**
     * Display a draggable widget on a site using a self-hosted custom element.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-widgets/about-site-widget-extensions
     */
    customElementWidget?: CustomElementWidget;
    /**
     * Restriction service plugin for editing products managed by third-party fulfillment apps, such as dropshipping or print-on-demand services
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/stores/service-plugins/product-restrictions-v3/introduction
     */
    storesProductRestrictions?: ProductRestrictionsConfig;
}
/** @oneof */
interface ComponentDataDataOneOf {
    /**
     * Create a widget iframe that users can display on their site. We recommend submitting a proposal before using iframes in your app.
     * Learn More: https://devforum.wix.com/en/article/widget-components
     */
    widgetComponentData?: WidgetComponentData;
    /**
     * Display an iframe as a page on a user's site.
     * Learn More: https://dev.wix.com/docs/build-apps/developer-tools/extensions/iframes/guide-to-page-extensions
     */
    pageComponentData?: PageComponentData;
    /**
     * Open an iframe in the Dashboard, or add a link to a page on your platform.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/dashboard-extensions/external-links/about-external-link-extensions
     */
    dashboardComponentData?: DashboardComponentData;
    /**
     * Use an invisible iframe to track activity. It’s added to every page on the site (max. 1).
     * Learn More: https://devforum.wix.com/en/article/worker-components
     */
    workerComponentData?: WorkerComponentData;
    /**
     * Inject a script into a site’s HTML code.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/embedded-scripts/about-embedded-scripts
     */
    embeddedScriptComponentData?: EmbeddedScriptComponentData;
    /**
     * Display a widget that fits into a predefined slot in a Wix app.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-plugins/about-site-plugin-extensions
     */
    widgetPlugin?: WidgetPluginComponentData;
    /**
     * Displays the options from your Shipping Rates service plugin in a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/shipping-rates-integration-service-plugin/introduction
     */
    ecomShippingRates?: ShippingRatesConfig;
    /** Extend a Wix entity with custom fields for your app */
    dataExtensions?: DataExtensionsComponentData;
    /**
     * eCommerce Catalog Service Plugin | Become a Wix catalog provider and integrate any external repository of sellable items with the Wix eCommerce platform.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/catalog-service-plugin/introduction
     */
    ecomCatalog?: CatalogSPIConfig;
    /**
     * Gift Card SPI for Ecom Platform
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/gift-cards-service-plugin/introduction
     */
    giftCardsProvider?: GiftCardProviderConfig;
    /**
     * Provide SEO keyword suggestions to site collaborators, report quota usage, and provide a page where users can upgrade their plan.
     * Learn More: https://dev.wix.com/docs/rest/api-reference/marketing/seo-keywords-suggestions-v-1/introduction
     */
    seoKeywordsSuggestions?: SeoKeywordsSuggestionsSPIConfig;
    /**
     * Configure a page for your app that will be embedded in the Wix Dashboard.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/dashboard-extensions/dashboard-pages/about-dashboard-page-extensions
     */
    backOfficePage?: BackOfficePage;
    /**
     * Displays the fees from your Additional Fees service plugin in a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/additional-fees-service-plugin/introduction
     */
    ecomAdditionalFees?: AdditionalFeesSPIConfig;
    /**
     * Premium Custom Charges Config
     * Learn More: https://dev.wix.com/docs/rest/api-reference/app-management/apps/custom-charges-spi/introduction
     */
    premiumCustomCharges?: CustomChargesConfig;
    /**
     * Performs Validations for a site's cart and checkout.
     * Learn More: https://dev.wix.com/docs/rest/api-reference/wix-e-commerce/validations-integration-spi/introduction
     */
    ecomValidations?: ValidationsSPIConfig;
    /**
     * Build a tool that adds functionality to the Wix editors.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/editor-extensions/about-editor-extensions
     */
    editorAddon?: EditorAddon;
    /** External Database component */
    externalDatabaseProvider?: ExternalDatabaseSpiConfig;
    /**
     * Ecom Payment Settings Service Plugin Config
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/e-commerce/service-plugins/payment-settings-integration-service-plugin/introduction
     */
    ecomPaymentSettings?: PaymentSettingsSPIConfig;
    /**
     * Add a site page that displays selected widgets.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-pages/about-site-page-extensions
     */
    unifiedPage?: UnifiedPage;
    /** Create a reusable modal that can be utilized across multiple pages within your app and in other applications. */
    backOfficeModal?: BackOfficeModal;
    /**
     * Display a draggable widget on a site using a self-hosted custom element.
     * Learn More: https://dev.wix.com/docs/build-apps/develop-your-app/extensions/site-extensions/site-widgets/about-site-widget-extensions
     */
    customElementWidget?: CustomElementWidget;
    /**
     * Restriction service plugin for editing products managed by third-party fulfillment apps, such as dropshipping or print-on-demand services
     * Learn More: https://dev.wix.com/docs/rest/business-solutions/stores/service-plugins/product-restrictions-v3/introduction
     */
    storesProductRestrictions?: ProductRestrictionsConfig;
}
/** An iframe to be displayed on the user’s site */
interface WidgetComponentData {
    /** Allow users to resize and move the widget, or pin it to a specific position on all pages of the site. */
    fixedPositionOption?: FixedPositionOptions;
    /** Widget will automatically be stretched to this width after installing it */
    widgetWidthType?: WidgetWidthTypeWithLiterals;
    /**
     * Widget width size
     * @max 9999
     */
    width?: number | null;
    /**
     * Widget width height
     * @max 9999
     */
    height?: number | null;
    /**
     * A public link to the widget endpoint
     * @format WEB_URL
     */
    widgetEndpointUrl?: string | null;
    /** A public link to the mobile endpoint */
    widgetMobileEndpointUrl?: string | null;
    /** A public link to the settings endpoint */
    settingsEndpointUrl?: string | null;
    /** A public link to the SEO endpoint */
    seoEndpointUrl?: string | null;
    /** Product display data for this component */
    widgetDisplay?: WidgetDisplay;
    /** When true, this is the default component */
    default?: boolean;
    /** When this is turned on, this page will be added to the site when installing the app, regardless of whether it's the default component or not */
    essential?: boolean;
    /** Published state for this widget */
    published?: boolean;
    /** When true, allow this widget to be added only once */
    addOnlyOnce?: boolean;
    /**
     * This ID is used to identify your widget endpoint in a Wix site. You can use this ID when using methods of the Wix SDK
     * @readonly
     */
    tpaWidgetId?: string;
    /** Where this should be rendered */
    position?: Position;
    /** Article id in settings panel */
    helpId?: string | null;
    /** Default Mobile Height */
    defaultMobileHeight?: number | null;
    /** Min Mobile Height */
    minMobileHeight?: number | null;
    /** Mobile Settings Enabled */
    mobileSettingsEnabled?: boolean;
    /** Mobile article id in settings panel */
    mobileHelpId?: string | null;
    /**
     * Editor setting version. optional values: 1 (old - deprecated) or 2 (new). default value is 2
     * @min 1
     * @max 2
     */
    settingsVersion?: number | null;
    /** If setting version is 1, this will be the public link to the settings endpoint */
    settingsEndpointUrlV1?: string | null;
    /** A public link to the settings endpoint on ADI editor */
    onBoardingSettingsEndpointUrl?: string | null;
    /** The sub pages list for this component to be rendered in */
    subPages?: SubPage[];
    /** If this component should be stretched in relation to a form factor (desktop, tablet, mobile) */
    isStretched?: IsStretched;
    /** Any margins this page should have in relation to a form factor (desktop, tablet, mobile) */
    margins?: Margins;
    /** Any docking this page (horizontal / vertical) should have in relation to a form factor (desktop, tablet, mobile) */
    docking?: Docking;
    /** The height of this page in relation to a form factor (desktop, tablet, mobile) */
    heightBreakPoints?: Height;
    /** The width of this page in relation to a form factor (desktop, tablet, mobile) */
    widthBreakPoints?: ApiWidth;
    /** Keep default and let users stretch widget to full width (GFPP) */
    addStretchButton?: boolean;
    /** toggle to mark whether the editor should revoke an app that contains this component. */
    excludeFromAutoRevoke?: boolean;
    /** should be <%=serviceUrl('your_artifact_id', '<resource-path>')%>, this field will later be used to trasform the settings url field in both the component and the **derived widget** */
    settingsEndpointUrlTemplate?: string | null;
    /** should be <%=serviceUrl('your_artifact_id', '<resource-path>')%>, this field will later be used to trasform the settings url field in both the component and the **derived widget** */
    settingsEndpointUrlV1Template?: string | null;
}
/** Allow users to resize and move the widget, or pin it to a specific position on all pages of the site. */
interface FixedPositionOptions {
    /** Vertical widget position in the browser window */
    widgetVertical?: WidgetVerticalWithLiterals;
    /** Horizontal widget position in the browser window */
    widgetHorizontal?: WidgetHorizontalWithLiterals;
}
/** Vertical widget position in the browser window */
declare enum WidgetVertical {
    NONE_VERTICAL = "NONE_VERTICAL",
    TOP = "TOP",
    CENTER_VERTICAL = "CENTER_VERTICAL",
    BOTTOM = "BOTTOM"
}
/** @enumType */
type WidgetVerticalWithLiterals = WidgetVertical | 'NONE_VERTICAL' | 'TOP' | 'CENTER_VERTICAL' | 'BOTTOM';
/** Horizontal widget position in the browser window */
declare enum WidgetHorizontal {
    NONE_HORIZONTAL = "NONE_HORIZONTAL",
    LEFT = "LEFT",
    CENTER_HORIZONTAL = "CENTER_HORIZONTAL",
    RIGHT = "RIGHT"
}
/** @enumType */
type WidgetHorizontalWithLiterals = WidgetHorizontal | 'NONE_HORIZONTAL' | 'LEFT' | 'CENTER_HORIZONTAL' | 'RIGHT';
/** Widget will automatically be stretched to this width after installing it */
declare enum WidgetWidthType {
    NONE_TYPE = "NONE_TYPE",
    /** A custom width for the widget */
    CUSTOM = "CUSTOM",
    /** Full width of the browser window */
    FULL = "FULL"
}
/** @enumType */
type WidgetWidthTypeWithLiterals = WidgetWidthType | 'NONE_TYPE' | 'CUSTOM' | 'FULL';
interface WidgetDisplay {
    name?: string;
    /**
     * short description about the widget
     * @maxLength 300
     */
    shortDescription?: string | null;
    /** images showing off how the widget looks */
    images?: string[];
    /** optional, if no order exist for all components, will be decided by order in array (non-deterministic) */
    order?: number | null;
    price?: number | null;
    variationId?: string | null;
}
interface Position {
    region?: RegionWithLiterals;
}
declare enum Region {
    no_region = "no_region",
    header = "header",
    pageContainer = "pageContainer",
    footer = "footer"
}
/** @enumType */
type RegionWithLiterals = Region | 'no_region' | 'header' | 'pageContainer' | 'footer';
interface SubPage {
    /** The path of the subpage */
    key?: string;
    /** If it's sub entities are enumerable for querying (for example, a search endpoint is not enumerable) */
    enumerable?: boolean;
    /** Should hide inner routes of this sub page from floating dynamic pages navigation bar */
    hideFromFloatingNavBar?: boolean;
    /** Should hide this sub page from selections in link panel */
    hideFromLinkPanel?: boolean;
}
interface IsStretched {
    desktop?: boolean | null;
    tablet?: boolean | null;
    mobile?: boolean | null;
}
interface Margins {
    desktop?: DisplayProperties;
    tablet?: DisplayProperties;
    mobile?: DisplayProperties;
}
interface DisplayProperties {
    top?: DisplayValue;
    right?: DisplayValue;
    bottom?: DisplayValue;
    left?: DisplayValue;
}
interface DisplayValue {
    type?: UnitTypeWithLiterals;
    value?: number | null;
}
declare enum UnitType {
    NO_UNIT = "NO_UNIT",
    AUTO = "AUTO",
    PX = "PX",
    VH = "VH",
    VW = "VW",
    PERCENTAGE = "PERCENTAGE"
}
/** @enumType */
type UnitTypeWithLiterals = UnitType | 'NO_UNIT' | 'AUTO' | 'PX' | 'VH' | 'VW' | 'PERCENTAGE';
interface Docking {
    desktop?: DockingProperties;
    tablet?: DockingProperties;
    mobile?: DockingProperties;
}
interface DockingProperties {
    horizontal?: HorizontalDockingWithLiterals;
    vertical?: VerticalDockingWithLiterals;
}
declare enum HorizontalDocking {
    NO_HDOCKING = "NO_HDOCKING",
    LEFT_DOCKING = "LEFT_DOCKING",
    HCENTER = "HCENTER",
    RIGHT_DOCKING = "RIGHT_DOCKING"
}
/** @enumType */
type HorizontalDockingWithLiterals = HorizontalDocking | 'NO_HDOCKING' | 'LEFT_DOCKING' | 'HCENTER' | 'RIGHT_DOCKING';
declare enum VerticalDocking {
    NO_VDOCKING = "NO_VDOCKING",
    TOP_DOCKING = "TOP_DOCKING",
    VCENTER = "VCENTER",
    BOTTOM_DOCKING = "BOTTOM_DOCKING"
}
/** @enumType */
type VerticalDockingWithLiterals = VerticalDocking | 'NO_VDOCKING' | 'TOP_DOCKING' | 'VCENTER' | 'BOTTOM_DOCKING';
interface Height {
    desktop?: DisplayValue;
    tablet?: DisplayValue;
    mobile?: DisplayValue;
}
interface ApiWidth {
    desktop?: DisplayValue;
    tablet?: DisplayValue;
    mobile?: DisplayValue;
}
/** An iframe to be displayed as a full page on the user’s site */
interface PageComponentData {
    /** Hide this page from the user’s site menu */
    isHidden?: boolean;
    /** Show in pages menu */
    showInPanel?: boolean | null;
    /** Set page to full width */
    isFullWidth?: boolean;
    /** Keep default and let users stretch page to full width (GFPP) */
    addStrechButton?: boolean;
    /**
     * A public link to the page endpoint
     * @format WEB_URL
     */
    pageEndpointUrl?: string | null;
    /** A public link to the mobile endpoint */
    pageMobileEndpointUrl?: string | null;
    /** A public link to the settings endpoint */
    settingsEndpointUrl?: string | null;
    /** A public link to the SEO endpoint */
    seoEndpointUrl?: string | null;
    /**
     * When true, this is the default component
     * Main visual component. One components must be default (no more than 1 component)
     */
    default?: boolean;
    /**
     * Second visual component
     * When this is turned on, this page will be added to the site when installing the app, regardless of whether it's the default component or not
     */
    essential?: boolean;
    /** Published state for this page */
    published?: boolean;
    /**
     * This ID is used to identify your page endpoint in a Wix site. You can use this ID when using methods of the Wix SDK
     * @readonly
     */
    tpaWidgetId?: string;
    /** Article id in settings panel */
    helpId?: string | null;
    /** Default Mobile Height */
    defaultMobileHeight?: number | null;
    /** Min Mobile Height */
    minMobileHeight?: number | null;
    /** Mobile Settings Enabled */
    mobileSettingsEnabled?: boolean;
    /** Mobile article id in settings panel */
    mobileHelpId?: string | null;
    /**
     * Editor setting version. optional values: 1 (old - deprecated) or 2 (new). default value is 2
     * @min 1
     * @max 2
     */
    settingsVersion?: number | null;
    /** If setting version is 1, this will be the public link to the settings endpoint */
    settingsEndpointUrlV1?: string | null;
    /** A public link to the settings endpoint on ADI editor */
    onBoardingSettingsEndpointUrl?: string | null;
    /** The padding to use in different views */
    padding?: Padding;
    /** The sub pages list for this component to be rendered in */
    subPages?: SubPage[];
    /** toggle to mark whether the editor should revoke an app that contains this component. */
    excludeFromAutoRevoke?: boolean;
    /** Options to mark whether this page is replacing other page or is replaced by other page. */
    pageReplaceOptions?: PageReplaceOptions;
    /** Elements in the editor can be linked to this page (a button for example) */
    linkable?: boolean | null;
    /** Should add the page to site menu. defaults to true (will add the page to site menu) */
    addToSiteMenu?: boolean | null;
    /** Should allow multiple instances of the page (allow duplicate the page). defaults to false (will not allow multiple instances of the page) */
    multiInstanceEnabled?: boolean;
}
interface Padding {
    desktop?: DisplayProperties;
    tablet?: DisplayProperties;
    mobile?: DisplayProperties;
}
interface PageReplaceOptions extends PageReplaceOptionsOptionsOneOf {
    replacingOptions?: ReplacingOptions;
    replaceableOptions?: ReplaceableOptions;
    type?: ReplacementTypeWithLiterals;
}
/** @oneof */
interface PageReplaceOptionsOptionsOneOf {
    replacingOptions?: ReplacingOptions;
    replaceableOptions?: ReplaceableOptions;
}
interface PageReplace {
    /**
     * The app id of the page the app can replace
     * @format GUID
     */
    appId?: string;
    /**
     * The page id the app can replace
     * @format GUID
     */
    pageId?: string;
}
declare enum ReplacementType {
    UNKNOWN_REPLACEMENT = "UNKNOWN_REPLACEMENT",
    REPLACING = "REPLACING",
    REPLACEABLE = "REPLACEABLE"
}
/** @enumType */
type ReplacementTypeWithLiterals = ReplacementType | 'UNKNOWN_REPLACEMENT' | 'REPLACING' | 'REPLACEABLE';
interface ReplacingOptions {
    /** describe the page and application id that this page will replace. */
    pageReplace?: PageReplace;
}
interface ReplaceableOptions {
    /** toggle to mark whether this page can be replaced by other page or app. */
    isReplaceable?: boolean;
}
/** A widget out of iframe component that loads directly in the Editor DOM */
interface WidgetOutOfIframeComponentData {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    componentUrl?: string;
    /**
     * Iframe controller URL.
     * @format WEB_URL
     */
    controllerUrl?: string | null;
    /** Information about the widget. */
    widgetData?: WidgetComponentData;
    /**
     * Out of iframe SSR URL.
     * @format WEB_URL
     */
    ssrComponentUrl?: string | null;
    /** Format: `<%=serviceUrl('your_artifact_id', 'component_url_bundle_file')%>`. */
    componentUrlTemplate?: string | null;
    /** Format: `<%=serviceUrl('your_artifact_id', 'controller_url_bundle_file')%>`. */
    controllerUrlTemplate?: string | null;
    /** Out of iframe widget data. */
    outOfIframeData?: OutOfIframeData;
    /** Format: `<%=serviceUrl('your_artifact_id', 'no_css_component_url_bundle_file')%>`. */
    noCssComponentUrlTemplate?: string | null;
    /**
     * Out of iframe no css component URL.
     * @format WEB_URL
     */
    noCssComponentUrl?: string | null;
    /** Whether to support different style param values for different breakpoints. */
    cssPerBreakpoint?: boolean | null;
    /**
     * builderConfig static url.
     * @format WEB_URL
     */
    builderConfigUrl?: string | null;
}
/** Out Of Iframes additional info */
interface OutOfIframeData {
    /** The setting URLs for the app */
    settingsUrls?: SettingsUrl[];
    /** Automatically installed on app installation */
    autoInstall?: boolean;
    /** The info about how to report errors for the App */
    errorReporting?: ErrorReporting;
    /** The list of slots available */
    slots?: ApiSlot[];
    /** if true, ssr will not cache pages that contain this widget */
    ssrCacheExcluded?: boolean;
    /** Should use loadable-components */
    isLoadable?: boolean;
}
/** An editor settings configuration */
interface SettingsUrl {
    /**
     * The URL for the setting panel
     * @format WEB_URL
     */
    url?: string;
    /** What type of editor this is */
    editorType?: string;
    /** How this view is rendered (mobile, tablet, etc) */
    viewType?: string;
    /** should be <%=serviceUrl('your_artifact_id', '<resource-path>')%>, this field will later be used to trasform the settings url field in both the component and the **derived widget** */
    urlTemplate?: string | null;
}
/** Error reporting configuration for the App */
interface ErrorReporting {
    /** An error reporting URL to be used by our infra (Example: A sentry DSN url) */
    url?: string;
    /** Optional: Data about the artifact that reports the error. */
    artifact?: ErrorReportingArtifact;
}
/** Data of the artifact that reports an error. */
interface ErrorReportingArtifact {
    /**
     * The full artifact id of the project which errors are associated with (Example: com.wixpress.my-artifact)
     * @minLength 1
     * @maxLength 255
     */
    fullArtifactId?: string;
    /**
     * The project version which errors are associated with (Example: Falcon fingerprint)
     * @minLength 1
     * @maxLength 255
     */
    version?: string;
}
/** Definition of slot */
interface ApiSlot {
    /** Role of the slot component (uniquely identifies slot within parent comp; used by Velo) - former "slotName" */
    slotRole?: string;
    /** The list of interfaces that should be implemented by a plugin in order to fit the slot */
    pluginInterfaces?: PluginInterfaceWithLiterals[];
    /** Id of the slot component (a.k.a. Velo role) */
    slotId?: string;
}
/** The types of public APIs exposed by the Plugin */
declare enum PluginInterface {
    /** No public APIs exposed */
    NONE_INTERFACE = "NONE_INTERFACE",
    /** The slot requires the REVIEWS interface to be implemented by the plugin. The plugin specifies the implementation of the REVIEWS interface */
    REVIEWS = "REVIEWS",
    /** The slot requires the RATINGS_SUMMARY interface to be implemented by the plugin. The plugin specifies the implementation of the RATINGS_SUMMARY interface */
    RATINGS_SUMMARY = "RATINGS_SUMMARY",
    /** The slot requires the RATINGS_SUMMARY_OOI_LIST interface to be implemented by the plugin. The plugin specifies the implementation of the RATINGS_SUMMARY_OOI_LIST interface */
    RATINGS_SUMMARY_OOI_LIST = "RATINGS_SUMMARY_OOI_LIST",
    /** The slot requires the BOOKINGS_SERVICE interface to be implemented by the plugin. The plugin specifies the implementation of the BOOKINGS_SERVICE interface */
    BOOKINGS_SERVICE = "BOOKINGS_SERVICE",
    /** The slot requires the BOOKINGS_FORM interface to be implemented by the plugin. The plugin specifies the implementation of the BOOKINGS_FORM interface */
    BOOKINGS_FORM = "BOOKINGS_FORM",
    /** The slot requires the BASE interface to be implemented by the plugin. The plugin specifies the implementation of the BASE interface */
    BASE = "BASE",
    /** The slot requires the EVENT interface to be implemented by the plugin. The plugin specifies the implementation of the EVENT interface */
    EVENT = "EVENT",
    /** The slot requires the PRODUCT interface to be implemented by the plugin. The plugin specifies the implementation of the PRODUCT interface */
    PRODUCT = "PRODUCT",
    /** The slot requires the CHECKOUT interface to be implemented by the plugin. The plugin specifies the implementation of the CHECKOUT interface */
    CHECKOUT = "CHECKOUT",
    /** The slot requires the CATEGORY interface to be implemented by the plugin. The plugin specifies the implementation of the CATEGORY interface */
    CATEGORY = "CATEGORY",
    /** The slot requires the BOOKINGS_CALENDAR interface to be implemented by the plugin. The plugin specifies the implementation of the BOOKINGS_CALENDAR interface */
    BOOKINGS_CALENDAR = "BOOKINGS_CALENDAR",
    /** The slot requires the CART interface to be implemented by the plugin. The plugin specifies the implementation of the CART interface */
    CART = "CART"
}
/** @enumType */
type PluginInterfaceWithLiterals = PluginInterface | 'NONE_INTERFACE' | 'REVIEWS' | 'RATINGS_SUMMARY' | 'RATINGS_SUMMARY_OOI_LIST' | 'BOOKINGS_SERVICE' | 'BOOKINGS_FORM' | 'BASE' | 'EVENT' | 'PRODUCT' | 'CHECKOUT' | 'CATEGORY' | 'BOOKINGS_CALENDAR' | 'CART';
interface ExtensionExposure {
    /** Determines if the component is production ready */
    maturity?: MaturityWithLiterals;
}
declare enum Exposure {
    /** Unexposed. to be used by dev team only */
    PRIVATE = "PRIVATE",
    /** Exposed internally */
    INTERNAL = "INTERNAL",
    /** Exposed to the world */
    PUBLIC = "PUBLIC"
}
declare enum Maturity {
    /** Immature. subject to breaking changes */
    ALPHA = "ALPHA",
    /** Ready for integration. 2 weeks notice before breaking changes are applied */
    BETA = "BETA",
    /** Matured. breaking changes are not acceptable. 3 month notice before sunset */
    GA = "GA",
    /** Not yet implemented */
    NOT_IMPLEMENTED = "NOT_IMPLEMENTED"
}
/** @enumType */
type MaturityWithLiterals = Maturity | 'ALPHA' | 'BETA' | 'GA' | 'NOT_IMPLEMENTED';
/** A page out of iframe component that loads directly in the Editor DOM */
interface PageOutOfIframeComponentData {
    /**
     * Out of iframe component URL.
     * @format WEB_URL
     */
    componentUrl?: string;
    /**
     * Out of iframe controller URL.
     * @format WEB_URL
     */
    controllerUrl?: string | null;
    /** Page data. */
    pageData?: PageComponentData;
    /**
     * Out of iframe SSR URL.
     * @format WEB_URL
     */
    ssrComponentUrl?: string | null;
    /** Component URL template. `<%=serviceUrl('your_artifact_id', 'component_url_bundle_file')%>` */
    componentUrlTemplate?: string | null;
    /** Controller URL template. `<%=serviceUrl('your_artifact_id', 'controller_url_bundle_file')%>` */
    controllerUrlTemplate?: string | null;
    /** Data about the out of iframe page. */
    outOfIframeData?: OutOfIframeData;
    /** Setting endpoint URL template. `<%=serviceUrl('your_artifact_id', '<resource-path>')%>`. Used to transform the settings URL field in both the component and the **derived widget**. */
    settingsEndpointUrlTemplate?: string | null;
    /** Setting endpoint URL v1 template. `<%=serviceUrl('your_artifact_id', '<resource-path>')%>`.  Used to transform the settings URL field in both the component and the **derived widget**. */
    settingsEndpointUrlV1Template?: string | null;
    /** No css component URL template. `<%=serviceUrl('your_artifact_id', 'no_css_component_url_bundle_file')%>`. */
    noCssComponentUrlTemplate?: string | null;
    /**
     * URL for the out of iframe no CSS component URL.
     * @format WEB_URL
     */
    noCssComponentUrl?: string | null;
    /** Whether to enable support for different style param values for different breakpoints. */
    cssPerBreakpoint?: boolean | null;
    /**
     * builderConfig static url.
     * @format WEB_URL
     */
    builderConfigUrl?: string | null;
}
/** Create a collection of native Editor components that loads directly in the Editor DOM */
interface PlatfromComponentData {
    /**
     * Path to a Javascript file that Editor runs on app install
     * @format WEB_URL
     */
    editorScriptUrl?: string | null;
    /** Path to a Javascript file that viewer runs for page components / widgets and applicative business logic */
    viewerScriptUrl?: string | null;
    /** If true, components of the app wont be added to the editor (only run editor scripts) */
    platformOnly?: boolean;
    /** If the viewer script should run in the Editor */
    enableInEditor?: boolean;
    /** URL to get complex routing decisions at runtime from a platform app. Some spec can be seen here: https://docs.google.com/document/d/1t_3bl9vVMoPVm_I9Sx59LsVUPXi07gihGIg3-F7z8Q0/edit?ts=595512f6#heading=h.9ca9859ng5d */
    routerServiceUrl?: string | null;
    /**
     * Path to a Javascript file that viewer runs for page components / widgets and applicative business logic. Includes verbose logs for Wix runtime.
     * @format WEB_URL
     */
    viewerVerboseScriptUrl?: string | null;
    /** A map of string descriptor the app understands to a versioned URL topology value, can be an API or statics data. Example: `storesCartAPI: https://stores.com/api/v2/cart/ */
    baseUrls?: Record<string, string>;
    /** Used by DAC (gradual roll-out). A map of string descriptor the app understands to a template versioned URL topology value, Example: `storeCSSStuff: https://static.pararstorage.com/services/stores-css-stuff/<%=serviceVersion('your_artifact_id')%>/main.css */
    baseUrlsTemplate?: Record<string, string>;
    /** should be <%=serviceUrl('your_artifact_id', 'viewer_script_url_bundle_file')%> */
    viewerScriptUrlTemplate?: string | null;
    /** If this component should be stretched in relation to a form factor (desktop, tablet, mobile) */
    isStretched?: IsStretched;
    /** Any margins this page should have in relation to a form factor (desktop, tablet, mobile) */
    margins?: Margins;
    /** Any docking this page (horizontal / vertical) should have in relation to a form factor (desktop, tablet, mobile) */
    docking?: Docking;
    /** The height of this page in relation to a form factor (desktop, tablet, mobile) */
    height?: Height;
    /** The width of this page in relation to a form factor (desktop, tablet, mobile) */
    width?: ApiWidth;
    /**
     * Support adding application pages with preset data
     * Vertical endpoint that clones the data
     * https://docs.google.com/document/d/1pUp-d9vVMCTjDdQffBuwh1mBvQacQZy0n6nm2amCMV4/edit
     * @format WEB_URL
     */
    cloneAppDataUrl?: string | null;
    /**
     * False by default
     * If false, data is cloned per app
     * If true, the data is cloned per add component on component addition
     */
    shouldCloneDataPerComponent?: boolean;
    /**
     * Error reporting URL used to report errors at platform level,
     * and as fallback for pageOOI and widgetOOI error reporting
     */
    errorReporting?: ErrorReporting;
    /**
     * A concrete versioned URL of the translation template, contains `{language}` parameter in the path
     * @format WEB_URL
     */
    editorTranslationUrl?: string | null;
    /** A version templated URL of the translation template, contains a <%=serviceVersion('your_artifact_id')%> template and a `{language}` template */
    editorTranslationUrlTemplate?: string | null;
    excludeFromAutoRevoke?: boolean;
    /** dictates if the app has migrated to the new platform API */
    migratedToNewPlatformApi?: boolean;
    /** The HTTP Verb used to call the router, if not set will be POST */
    routerHttpMethod?: HTTPMethodWithLiterals;
}
/** Add interim support for HTTP methods before a bigger rewrite for Routers as a component */
declare enum HTTPMethod {
    UNKNOWN_METHOD = "UNKNOWN_METHOD",
    GET = "GET",
    POST = "POST"
}
/** @enumType */
type HTTPMethodWithLiterals = HTTPMethod | 'UNKNOWN_METHOD' | 'GET' | 'POST';
/**
 * An iframe that opens in the user’s Wix Dashboard,
 * or add a link to open the page directly in your platform.
 */
interface DashboardComponentData {
    /**
     * The dashboard url.
     * @format WEB_URL
     */
    url?: string;
    /**
     * External or Internal dashboard.
     * The user’s Wix Dashboard (recommended) or your platform or site
     */
    embedded?: boolean;
    /**
     * A settings page for users to customize your dashboard
     * @maxLength 300
     */
    settingsPageUrl?: string | null;
    /** @maxLength 300 */
    checkStatusUrl?: string | null;
    published?: boolean | null;
    hideWixSideMenu?: boolean | null;
}
/** An invisible iframe to track site activity. It’ll be added to every page on the user’s site */
interface WorkerComponentData {
    /**
     * A public link to the worker endpoint
     * @format WEB_URL
     */
    workerEndpointUrl?: string;
}
/**
 * An extension to platform used by Wix Blocks UI
 * The main component in the Wix Blocks.
 * no manual adding. auto-created only from Wix Blocks
 */
interface StudioComponentData {
    /** Path to a Javascript file that Editor runs on app install */
    editorScriptUrl?: string;
    /** Path to a Javascript file that viewer runs for page components / widgets and applicative business logic */
    viewerScriptUrl?: string;
    /** If true, components of the app wont be added to the editor (only run editor scripts) */
    platformOnly?: boolean;
    /** If the viewer script should run in the Editor */
    enableInEditor?: boolean;
    /** URL to get complex routing decisions at runtime from a platform app. Some spec can be seen here: https://docs.google.com/document/d/1t_3bl9vVMoPVm_I9Sx59LsVUPXi07gihGIg3-F7z8Q0/edit?ts=595512f6#heading=h.9ca9859ng5d */
    routerServiceUrl?: string;
    /** Path to a Javascript file that viewer runs for page components / widgets and applicative business logic. Includes verbose logs for Wix runtime. */
    viewerVerboseScriptUrl?: string;
    /**
     * Instance id of wixCode in the original dev site. used in order to access the widgets code
     * @format GUID
     */
    wixCodeInstanceId?: string;
    /**
     * Id of the grid in wixCode FS where the widgets code is located. used in order to access the widgets code
     * @format GUID
     */
    wixCodeGridId?: string;
    /** Path to a json which contains metaData of the devSite */
    siteHeaderUrl?: string;
    /** A map of string descriptor the app understands to a versioned URL topology value, can be an API or statics data. This may have some values which are NOT URL since Studio computes some values on the fly. */
    baseUrls?: Record<string, string>;
    /** If true, not shown in add panel and apps panel when it is installed */
    hideInAddPanel?: boolean;
    /** if true, this studio component enforce permissions */
    permissionsEnforced?: boolean;
}
/** A widget component in the Wix Blocks. */
interface StudioWidgetComponentData {
    /** Id of the widget */
    studioWidgetId?: string;
    /** Path to a json which contains the widget data and structure */
    pageJsonFilename?: string;
    /** variationId -> widget variation data */
    variations?: Record<string, StudioWidgetVariation>;
    /** Product display data for this component */
    widgetDisplay?: WidgetDisplay;
    /** If it is required to be installed as part of the app */
    essential?: boolean;
    /** The version of blocks used to build this widget */
    blocksVersion?: string;
    /** If this component should be stretched in relation to a form factor (desktop, tablet, mobile) */
    isStretched?: IsStretched;
    /** Any margins this page should have in relation to a form factor (desktop, tablet, mobile) */
    margins?: Margins;
    /** Any docking this page (horizontal / vertical) should have in relation to a form factor (desktop, tablet, mobile) */
    docking?: Docking;
    /** The height of this page in relation to a form factor (desktop, tablet, mobile) */
    height?: Height;
    /** The width of this page in relation to a form factor (desktop, tablet, mobile) */
    width?: ApiWidth;
    /** Properties of installed custom elements */
    customElement?: CustomElement;
    /** ids of nested widgets in this widget */
    nestedWidgets?: NestedWidgets;
    /** Properties of widget's presets */
    presetsInfo?: PresetInfo[];
    /** Widget properties that affect the way it behaves during installation in a site. */
    installationSettings?: InstallationSettings;
    /** Properties that affect the widget's presence in the editor. */
    editorPresence?: EditorPresence;
    /** Base info of component by shared logic of unified components */
    base?: BaseInfo;
    /** Unified widget installation settings */
    installation?: WidgetInstallationSettings;
    /**
     * Optional: The URL of the widget's code bundle
     * @format WEB_URL
     */
    widgetBundleUrl?: string | null;
}
/** A variation of a blocks widget */
interface StudioWidgetVariation {
    /** Id of the widget variation */
    _id?: string;
    /** Display name of the variation */
    name?: string;
    /** Path to a json which contains the widget variation data and structure */
    pageJsonFilename?: string;
}
interface CustomElement extends CustomElementConsentCategoryOneOf {
    essential?: boolean;
    /** Related to performance and other functional measurements. */
    functional?: boolean;
    /** Related to analytics about how the site is used in order to improve it. */
    analytics?: boolean;
    /** Related to allowing better customization of the experience to a current visitor. */
    advertising?: boolean;
    /** Boolean to make custom element in this widget be available for free sites */
    allowedForFreeSite?: boolean;
    /** CCPA compliance flag. */
    dataToThirdParty?: boolean;
}
/** @oneof */
interface CustomElementConsentCategoryOneOf {
    essential?: boolean;
    /** Related to performance and other functional measurements. */
    functional?: boolean;
    /** Related to analytics about how the site is used in order to improve it. */
    analytics?: boolean;
    /** Related to allowing better customization of the experience to a current visitor. */
    advertising?: boolean;
}
/** Nested widgets */
interface NestedWidgets {
    /**
     * ids of all recursively nested widgets from the same Blocks app
     * @format GUID
     */
    internal?: string[];
}
/** Preset Info */
interface PresetInfo {
    /** Id of the widget's preset */
    presetId?: string;
    /** Display name of the widget's preset */
    presetName?: string;
    /** The default size used when the preset is added to the stage */
    defaultSize?: PresetSize;
}
/** Preset Size */
interface PresetSize {
    /** The width of the preset when it's added to the stage */
    width?: DisplayValue;
    /** The height of the preset when it's added to the stage */
    height?: DisplayValue;
}
/** Settings to control the behavour of widgets when installed in a wix site. */
interface InstallationSettings extends InstallationSettingsOptionsOneOf {
    /** Extra options needed when `install_page` is set to `PAGE`. */
    pageOptions?: PageOptions;
    /** Extra options needed when `install_page` is set to `LIGHTBOX`. */
    lightboxOptions?: LightboxOptions;
    /** How to add the widget automatically to the site. Options could be `NO_PAGE`, `CURRENT`, `PAGE` or `LIGHTBOX`. */
    installPage?: InstallPageWithLiterals;
    /** Controls whether to show or hide the widget in the add panel. */
    showInAddPanel?: boolean | null;
    /** Defines the main preset per breakpoint for the widget. */
    mainPresets?: MainPresets;
}
/** @oneof */
interface InstallationSettingsOptionsOneOf {
    /** Extra options needed when `install_page` is set to `PAGE`. */
    pageOptions?: PageOptions;
    /** Extra options needed when `install_page` is set to `LIGHTBOX`. */
    lightboxOptions?: LightboxOptions;
}
/** The page to which a new widget can be added */
declare enum InstallPage {
    /** Don't add widget to a page */
    NO_PAGE = "NO_PAGE",
    /** Add widget to the current page in the editor */
    CURRENT = "CURRENT",
    /** Add widget to a new page in the editor */
    PAGE = "PAGE",
    /** Add widget to a new lightbox in the editor */
    LIGHTBOX = "LIGHTBOX"
}
/** @enumType */
type InstallPageWithLiterals = InstallPage | 'NO_PAGE' | 'CURRENT' | 'PAGE' | 'LIGHTBOX';
/** Defines the main preset per breakpoint for the widget. */
interface MainPresets {
    /** The main desktop preset. */
    desktopPresetId?: string;
    /** The main tablet preset. */
    tabletPresetId?: string;
    /** The main mobile preset. */
    mobilePresetId?: string;
}
/** Options for widgets that are added as a page during installation */
interface PageOptions {
    /** Display name of the page that will be shown in the page menu. */
    pageName?: string;
    /** The page ID used for navigation purposes. Once set cannot be changed. */
    pageId?: string;
}
interface LightboxOptions {
    /** Display name of the lightbox that will be shown in the lightbox menu. */
    lightboxName?: string;
    /** The lightbox ID used for navigation purposes. Once set cannot be changed. */
    lightboxId?: string;
}
interface EditorPresence {
    /** Properties that describe the presence of each of the widget's presets */
    presetsEditorPresence?: PresetEditorPresence[];
}
interface PresetEditorPresence {
    /** Id of the widget's preset */
    presetId?: string;
    /** Controls whether to show or hide the preset in the Add Panel */
    showInAddPanel?: boolean;
    /** Controls whether to show or hide the preset in the Presets Panel */
    showInPresetsPanel?: boolean;
    /** Optional image to show as the preset's thumbnail in the editor, if left empty an automatic snapshot of the preset will be used */
    wixMediaThumbnail?: string;
    /** Another preset id that is a mobile variation of this preset */
    mobilePresetId?: string;
}
interface FocalPoint {
    /** X-coordinate of the focal point. */
    x?: number;
    /** Y-coordinate of the focal point. */
    y?: number;
    /** crop by height */
    height?: number | null;
    /** crop by width */
    width?: number | null;
}
interface BaseInfo {
    /**
     * The name of the component
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /** The internal id of the component by the own app */
    _id?: string;
    /**
     * The description of the component by the own app
     * @maxLength 130
     */
    description?: string;
    /** Reference to help articles about the widget */
    helpResources?: HelpResources;
}
interface HelpResources {
    /**
     * The Wix Answers' article related to the component (chosen by own app)
     * @format GUID
     */
    articleId?: string;
}
interface WidgetInstallationSettings extends WidgetInstallationSettingsTargetContainerOneOf {
    /** Which static container should the widget be installed at */
    staticContainer?: StaticContainerWithLiterals;
    /**
     * Deprecated, autoAdd should be mapped to static_container HOMEPAGE, essential should be mapped to container. Shared installation settings for unified components
     * @deprecated Deprecated, autoAdd should be mapped to static_container HOMEPAGE, essential should be mapped to container. Shared installation settings for unified components
     * @replacedBy static_container
     * @targetRemovalDate 2026-02-26
     */
    base?: BaseInstallation;
    /**
     * Deprecated, default_preset should be mapped to presets, region is not relevant. Widget installation settings for unified components
     * @deprecated Deprecated, default_preset should be mapped to presets, region is not relevant. Widget installation settings for unified components
     * @replacedBy presets
     * @targetRemovalDate 2026-02-26
     */
    widget?: WidgetInstallation;
    /** Default presets per breakpoint with which the widget should be installed */
    presets?: DefaultPresets;
}
/** @oneof */
interface WidgetInstallationSettingsTargetContainerOneOf {
    /** Which static container should the widget be installed at */
    staticContainer?: StaticContainerWithLiterals;
}
interface BaseInstallation {
    /** Auto add component to stage */
    autoAdd?: boolean;
    /** Mark component as essential for the existence of the app (force to delete the whole app) */
    essential?: boolean;
    /** Max instances of the component that can be on site */
    maxInstances?: number | null;
}
interface WidgetInstallation {
    /** Preset should be selected defaultly with installation */
    defaultPreset?: MainPresets;
    /** Region of widget */
    region?: RegionTypeWithLiterals;
}
declare enum RegionType {
    HEADER = "HEADER",
    BODY = "BODY",
    FOOTER = "FOOTER"
}
/** @enumType */
type RegionTypeWithLiterals = RegionType | 'HEADER' | 'BODY' | 'FOOTER';
interface DefaultPresets {
    /**
     * Default preset ID in small (mobile) breakpoint
     * @minLength 1
     * @maxLength 50
     */
    small?: string | null;
    /**
     * Default preset ID in large (desktop) breakpoint
     * @minLength 1
     * @maxLength 50
     */
    large?: string | null;
}
declare enum StaticContainer {
    UNKNOWN_CONTAINER = "UNKNOWN_CONTAINER",
    /** Widget should be installed in the homepage */
    HOMEPAGE = "HOMEPAGE"
}
/** @enumType */
type StaticContainerWithLiterals = StaticContainer | 'UNKNOWN_CONTAINER' | 'HOMEPAGE';
interface ComponentModel {
    /** The component type of the builder component. */
    componentType?: string;
    /**
     * The component URL of the builder component
     * @format WEB_URL
     */
    componentUrl?: string;
}
/** A component that indicates the existence of an importable code package in a Wix Blocks application. */
interface CodePackageComponentData {
    /**
     * The GUID to access the package code in the Velo/Wix Code system
     * @format GUID
     */
    gridId?: string;
    /** Name of the package for display */
    displayName?: string;
    /** Name of the package for import */
    importName?: string;
    /** An optional description of this package and what it does */
    description?: string | null;
}
/** A collection of native components that load directly in the Business Manager */
interface DashboardPlatfromComponentData {
    /**
     * Path to a Javascript file that Dashboard runs on app install
     * @format WEB_URL
     */
    scriptUrl?: string;
}
/** Inject third party scripts into the user’s site */
interface EmbeddedScriptComponentData {
    /** The script */
    template?: string;
    /** A name that’s unique to this component. Names can include letters and the hyphen (-) character only */
    name?: string;
    /** What category of pages this will be embedded on (single, many, none) */
    pages?: EmbeddedScriptPagesWithLiterals;
    /** Where in the HTML this should be embedded */
    placement?: EmbeddedScriptPlacementWithLiterals;
    /** An article explaining how to activate the script */
    connectArticleUrl?: string;
    /** Type of script you are injecting. This will be used for GDPR and cookie consent purposes */
    embedCategory?: EmbedCategoryWithLiterals;
    /**
     * if the script should be loaded once - default and only supported value is true
     * @readonly
     */
    loadOnce?: boolean;
    /** allow developers to decide if their app script can be install on free sites */
    allowedForFreeSite?: boolean;
    /**
     * The runtime dependencies array to declare the widget packages.
     * @maxSize 50
     */
    dependencies?: WixDependency[];
}
/** Category of pages this will be embedded on (single, many, none) */
declare enum EmbeddedScriptPages {
    /** It will not be embedded */
    NONE_PAGES = "NONE_PAGES",
    /** It will be embedded once */
    ONCE = "ONCE",
    /** It will be embedded multiple times on specific pages */
    SPECIFIC_PAGES = "SPECIFIC_PAGES"
}
/** @enumType */
type EmbeddedScriptPagesWithLiterals = EmbeddedScriptPages | 'NONE_PAGES' | 'ONCE' | 'SPECIFIC_PAGES';
/** Where that embed will be rendered */
declare enum EmbeddedScriptPlacement {
    /** It will not be rendered */
    NONE_PLACEMENT = "NONE_PLACEMENT",
    /** In the document head */
    HEAD = "HEAD",
    /** Prepended before all children already rendered in the body tag */
    BODY_START = "BODY_START",
    /** Appended after the last child already rendered in the body tag */
    BODY_END = "BODY_END"
}
/** @enumType */
type EmbeddedScriptPlacementWithLiterals = EmbeddedScriptPlacement | 'NONE_PLACEMENT' | 'HEAD' | 'BODY_START' | 'BODY_END';
/** Embed category defined for Privacy regulation compliance in EU and CCPA in the US */
declare enum EmbedCategory {
    /** Not categorized yet */
    UNKNOWN = "UNKNOWN",
    /** Must load regardless of policy */
    ESSENTIAL = "ESSENTIAL",
    /** Adds optional functionality to the site */
    FUNCTIONAL = "FUNCTIONAL",
    /** Adds analytics abilities to the site */
    ANALYTICS = "ANALYTICS",
    /** Adds advertising content or advertising tracking to the site */
    ADVERTISING = "ADVERTISING"
}
/** @enumType */
type EmbedCategoryWithLiterals = EmbedCategory | 'UNKNOWN' | 'ESSENTIAL' | 'FUNCTIONAL' | 'ANALYTICS' | 'ADVERTISING';
interface WixDependency {
    /**
     * The fully qualified package name from npm, example: @wix/frontend-location
     * @minLength 2
     * @maxLength 100
     */
    packageName?: string;
    /** The major version of the package (this may be a detail included in the package name, but is conventional in NPM with semver semantics */
    version?: number;
}
/** A draggable custom element. Add your custom script and generate ui directly in the viewer */
interface WebComponentData {
    /** A link to a preview image we can render in the editor in place of your component */
    imagePreview?: string;
    /** Web component size */
    size?: Size;
    /**
     * This script url should render temp empty state
     * @format WEB_URL
     */
    scriptTag?: string;
    /** Unique tag name to use in order to connect your JS script to your web component */
    tagName?: string;
    /**
     * The settings panel URL for this component
     * @format WEB_URL
     */
    settingsUrl?: string | null;
    /** The editor modal that the user will see */
    modalTitle?: string;
    /** Settings CTA label */
    connectLabel?: string;
    /** Dynamic settings(Graphic Floating Properties Panel settings) */
    gfppSettings?: Settings;
    /** Custom element type PAGE / WIDGET */
    type?: WebComponentDataElementTypeWithLiterals;
    /** Boolean to make this component be available for free sites */
    allowedForFreeSite?: boolean;
    /**
     * A public link to the SEO endpoint
     * @format WEB_URL
     */
    seoUrl?: string | null;
    /** For case that the widget will be used as page */
    slug?: string | null;
    /** For case that the widget will be used as page */
    showPageInMenu?: boolean;
    /** The details of the selected widget to add */
    widget?: WidgetDetails;
    /** Give the option to change the script type */
    scriptType?: ScriptTypeWithLiterals;
    /** Web component default mobile height */
    defaultMobileHeight?: number | null;
    /** Prevent the deletion of the widget when set to true. */
    essential?: boolean;
    /** Toggle to mark whether the editor should revoke an app that contains this component. */
    excludeFromAutoRevoke?: boolean;
    /** defines the widget's behaviour in editor page */
    widgetBehavior?: WidgetBehavior;
}
/** Web component size */
interface Size {
    /**
     * Height in pixels
     * @max 9999
     */
    height?: number;
    /**
     * Width in pixels
     * @max 9999
     */
    width?: number;
}
/** Graphic Floating Properties Panel settings */
interface Settings {
    activeTab?: string;
    /** @format WEB_URL */
    fetchInitialData?: string | null;
    tabs?: Tab[];
}
/** Setting tab definition */
interface Tab {
    label?: string;
    items?: Container[];
    /** hidden tab will not be visible in editor and dev center preview */
    hidden?: boolean;
}
/** UI Container in page */
interface Container extends ContainerDataOneOf {
    /** containers */
    main?: Main;
    section?: Section;
    drillInListItem?: DrillInListItem;
    /** items */
    thumbnails?: Thumbnails;
    sliderLabeled?: SliderLabeled;
    dropDownLabeled?: DropDownLabeled;
    toggleLabeled?: ToggleLabeled;
    barAlignment?: BarAlignment;
    textInputLabeled?: TextInputLabeled;
    resetButton?: ResetButton;
    fontFamilyWithColorPicker?: FontFamilyWithColorPicker;
    radioButtonLabeled?: RadioButtonLabeled;
    colorSelectLabeled?: ColorSelectLabeled;
    textStyle?: TextStyle;
}
/** @oneof */
interface ContainerDataOneOf {
    /** containers */
    main?: Main;
    section?: Section;
    drillInListItem?: DrillInListItem;
    /** items */
    thumbnails?: Thumbnails;
    sliderLabeled?: SliderLabeled;
    dropDownLabeled?: DropDownLabeled;
    toggleLabeled?: ToggleLabeled;
    barAlignment?: BarAlignment;
    textInputLabeled?: TextInputLabeled;
    resetButton?: ResetButton;
    fontFamilyWithColorPicker?: FontFamilyWithColorPicker;
    radioButtonLabeled?: RadioButtonLabeled;
    colorSelectLabeled?: ColorSelectLabeled;
    textStyle?: TextStyle;
}
/** Main 1 */
interface Main {
    items?: MainPropsData[];
}
/** MainPropsData */
interface MainPropsData {
    dashboardButton?: DashboardButton;
    richTextWithIllustrationVertical?: RichTextWithIllustrationVertical;
}
/** DashboardButton main 2 */
interface DashboardButton {
    title?: string;
    label?: string;
}
/** RichTextWithIllustrationVertical main 1 */
interface RichTextWithIllustrationVertical {
    key?: string;
    label?: string;
    text?: string;
}
/** Section 2 */
interface Section {
    label?: string;
}
/** DrillInListItem 3 */
interface DrillInListItem {
    items?: DrillItem[];
    label?: string;
}
/** DrillItem */
interface DrillItem extends DrillItemDataOneOf {
    /** containers */
    section?: Section;
    /** items */
    radioButtonLabeled?: RadioButtonLabeled;
    colorSelectLabeled?: ColorSelectLabeled;
    thumbnails?: Thumbnails;
    sliderLabeled?: SliderLabeled;
    dropDownLabeled?: DropDownLabeled;
    toggleLabeled?: ToggleLabeled;
    barAlignment?: BarAlignment;
    textInputLabeled?: TextInputLabeled;
    fontFamilyWithColorPicker?: FontFamilyWithColorPicker;
    textStyle?: TextStyle;
}
/** @oneof */
interface DrillItemDataOneOf {
    /** containers */
    section?: Section;
    /** items */
    radioButtonLabeled?: RadioButtonLabeled;
    colorSelectLabeled?: ColorSelectLabeled;
    thumbnails?: Thumbnails;
    sliderLabeled?: SliderLabeled;
    dropDownLabeled?: DropDownLabeled;
    toggleLabeled?: ToggleLabeled;
    barAlignment?: BarAlignment;
    textInputLabeled?: TextInputLabeled;
    fontFamilyWithColorPicker?: FontFamilyWithColorPicker;
    textStyle?: TextStyle;
}
/** RadioButtonLabeled 12 */
interface RadioButtonLabeled {
    key?: string;
    title?: string;
    value?: string;
    options?: string[];
    description?: string;
    conditions?: Condition[];
}
interface Condition {
    value?: string;
    state?: SingleKeyCondition[];
}
interface SingleKeyCondition {
    key?: string;
    value?: string;
    visible?: boolean;
}
/** ColorSelectLabeled 13 */
interface ColorSelectLabeled extends ColorSelectLabeledDataOneOf {
    customColor?: ColorDefinition;
    templateColor?: TemplateDefaultColorWithLiterals;
    title?: string;
    key?: string;
    /** @deprecated */
    color?: string;
    defaultData?: ColorDefinition;
    description?: string;
}
/** @oneof */
interface ColorSelectLabeledDataOneOf {
    customColor?: ColorDefinition;
    templateColor?: TemplateDefaultColorWithLiterals;
}
interface ColorDefinition {
    value?: string;
    opacity?: string;
}
declare enum TemplateDefaultColor {
    BACKGROUND = "BACKGROUND",
    SECONDARY_TEXTS = "SECONDARY_TEXTS",
    MAIN_TEXT_AND_ICONS = "MAIN_TEXT_AND_ICONS",
    BORDERS_AND_DIVIDERS = "BORDERS_AND_DIVIDERS",
    BUTTONS_AND_LINKS = "BUTTONS_AND_LINKS"
}
/** @enumType */
type TemplateDefaultColorWithLiterals = TemplateDefaultColor | 'BACKGROUND' | 'SECONDARY_TEXTS' | 'MAIN_TEXT_AND_ICONS' | 'BORDERS_AND_DIVIDERS' | 'BUTTONS_AND_LINKS';
/** Thumbnails 4 */
interface Thumbnails {
    key?: string;
    title?: string;
    value?: string;
    options?: ThumbnailData[];
    size?: ThumbnailsSizeWithLiterals;
    description?: string;
    conditions?: Condition[];
}
/** Structure for thumbnail */
interface ThumbnailData {
    value?: string;
    /** @format WEB_URL */
    src?: string | null;
    /** @format WEB_URL */
    selectedSrc?: string | null;
    /** @format WEB_URL */
    onHoverSrc?: string | null;
    label?: string;
}
declare enum ThumbnailsSize {
    SMALL = "SMALL",
    MEDIUM = "MEDIUM",
    LARGE = "LARGE",
    XLARGE = "XLARGE"
}
/** @enumType */
type ThumbnailsSizeWithLiterals = ThumbnailsSize | 'SMALL' | 'MEDIUM' | 'LARGE' | 'XLARGE';
/** SliderLabeled 5 */
interface SliderLabeled {
    key?: string;
    title?: string;
    size?: string;
    placeholder?: string;
    description?: string;
    minSize?: number;
    maxSize?: number;
}
/** DropDownLabeled 6 */
interface DropDownLabeled {
    key?: string;
    title?: string;
    value?: string;
    options?: string[];
    description?: string;
    conditions?: Condition[];
}
/** ToggleLabeled 7 */
interface ToggleLabeled {
    key?: string;
    title?: string;
    value?: boolean;
    description?: string;
    conditions?: Condition[];
}
/**
 * Elements =========
 * BarAlignment 8
 */
interface BarAlignment {
    /** @deprecated */
    selected?: BarAlignmentSelectedWithLiterals;
    key?: string;
    title?: string;
    description?: string;
    value?: BarAlignmentSelectedWithLiterals;
    conditions?: Condition[];
}
/** Bar alignment selected value */
declare enum BarAlignmentSelected {
    ALIGN_LEFT = "ALIGN_LEFT",
    ALIGN_CENTER = "ALIGN_CENTER",
    ALIGN_RIGHT = "ALIGN_RIGHT"
}
/** @enumType */
type BarAlignmentSelectedWithLiterals = BarAlignmentSelected | 'ALIGN_LEFT' | 'ALIGN_CENTER' | 'ALIGN_RIGHT';
/** TextInputLabeled 9 */
interface TextInputLabeled {
    key?: string;
    title?: string;
    placeholder?: string;
    value?: string;
    description?: string;
}
/** 11 */
interface FontFamilyWithColorPicker {
    key?: string;
    title?: string;
    description?: string;
    value?: FontDefinition;
    defaultValue?: FontDefinition;
}
/** defintion and enums */
interface FontDefinition {
    font?: string;
    color?: ColorDefinition;
}
/** TextStyle 14 */
interface TextStyle extends TextStyleDefaultColorOneOf {
    customColor?: ColorDefinition;
    templateColor?: TemplateDefaultColorWithLiterals;
    key?: string;
    title?: string;
    description?: string;
    defaultTextStyle?: DefaultTextStyleWithLiterals;
}
/** @oneof */
interface TextStyleDefaultColorOneOf {
    customColor?: ColorDefinition;
    templateColor?: TemplateDefaultColorWithLiterals;
}
declare enum DefaultTextStyle {
    TITLE = "TITLE",
    PARAGRAPH = "PARAGRAPH",
    LOWER_HIERARCHY_TEXTS = "LOWER_HIERARCHY_TEXTS"
}
/** @enumType */
type DefaultTextStyleWithLiterals = DefaultTextStyle | 'TITLE' | 'PARAGRAPH' | 'LOWER_HIERARCHY_TEXTS';
/** 10 */
interface ResetButton {
    label?: string;
}
declare enum WebComponentDataElementType {
    WIDGET = "WIDGET",
    PAGE = "PAGE"
}
/** @enumType */
type WebComponentDataElementTypeWithLiterals = WebComponentDataElementType | 'WIDGET' | 'PAGE';
interface WidgetDetails {
    name?: string | null;
    icon?: string | null;
    description?: string | null;
}
declare enum ScriptType {
    NO_SCRIPT_TYPE = "NO_SCRIPT_TYPE",
    MODULE = "MODULE"
}
/** @enumType */
type ScriptTypeWithLiterals = ScriptType | 'NO_SCRIPT_TYPE' | 'MODULE';
interface WidgetBehavior {
    /** Toggle whether the widget is removable from the page. */
    removable?: boolean;
    /** Toggle whether the widget is duplicatable from the page. */
    duplicatable?: boolean;
}
interface ExtensionData {
    data?: string;
    extensionType?: ExtensionTypeWithLiterals;
}
declare enum ExtensionType {
    NONE_EXTENSION = "NONE_EXTENSION",
    PAYMENTS_GATEWAY_EXTENSION = "PAYMENTS_GATEWAY_EXTENSION",
    COUPONS_EXTENSION = "COUPONS_EXTENSION",
    DROPSHIPPING_EXTENSION = "DROPSHIPPING_EXTENSION",
    FULFILMENT_EXTENSION = "FULFILMENT_EXTENSION",
    DROPSHIPPING_SUPPLIER_EXTENSION = "DROPSHIPPING_SUPPLIER_EXTENSION",
    FULFILLMENT_CENTER_EXTENSION = "FULFILLMENT_CENTER_EXTENSION",
    RESTAURANTS_POS_EXTENSION = "RESTAURANTS_POS_EXTENSION",
    ART_STORE_EXTENSION = "ART_STORE_EXTENSION",
    ASCEND_AUTOMATION_EXTENSION = "ASCEND_AUTOMATION_EXTENSION",
    CONTACT_LABELS_EXTENSION = "CONTACT_LABELS_EXTENSION"
}
/** @enumType */
type ExtensionTypeWithLiterals = ExtensionType | 'NONE_EXTENSION' | 'PAYMENTS_GATEWAY_EXTENSION' | 'COUPONS_EXTENSION' | 'DROPSHIPPING_EXTENSION' | 'FULFILMENT_EXTENSION' | 'DROPSHIPPING_SUPPLIER_EXTENSION' | 'FULFILLMENT_CENTER_EXTENSION' | 'RESTAURANTS_POS_EXTENSION' | 'ART_STORE_EXTENSION' | 'ASCEND_AUTOMATION_EXTENSION' | 'CONTACT_LABELS_EXTENSION';
interface SnippetSolutionData {
    code?: string;
    instructions?: string;
}
/** A component which represents collections that will be installed as part of the app */
interface DataComponent {
}
interface DCConfigData {
    isVisualApp?: boolean;
}
interface StaticFileComponentData {
    /** @format WEB_URL */
    url?: string;
}
interface AppConfig {
    siteConfig?: SiteConfig;
    namespace?: string;
}
interface SiteConfig {
    /**
     * todo: WEB_URL
     * @maxLength 1000
     */
    siteStructureApi?: string | null;
}
/**
 * Business Manager sidebar category that contains sidebar links.
 * each link in the category opens in the business manager in an iframe.
 */
interface MultipleDashboardsComponentData {
    /** items inside the category */
    items?: DashboardItem[];
}
/**
 * a single dashboard page,
 * represented in Business Manager as sidebar link that opens in an iframe
 */
interface DashboardItem {
    /** name of the sidebar link of the page */
    label?: string;
    /** data about the current page */
    dashboardData?: DashboardComponentData;
    /** permission to check for this page. */
    permissionId?: string | null;
}
/** Test component extension */
interface PaymentsGatewayComponentData {
    /**
     * The shop url
     * @format WEB_URL
     */
    shopUrl?: string;
}
interface AutomationTrigger {
    /**
     * The name that will be passed with trigger report event to activate an Automation.
     * @maxLength 80
     */
    name?: string;
    /**
     * The name displayed to the user.
     * @maxLength 80
     */
    displayName?: string;
    /** The schema of the payload that will be passed with trigger when activating an Automation. */
    schemaConfig?: SchemaConfig;
    deploymentUri?: string;
    revision?: number;
}
interface SchemaConfig {
    /** The fields of the payload as sent in the report event */
    fields?: SchemaField[];
    /**
     * Dynamic schema service URL.
     * Dynamic schema is used when user needs to choose specific entities from site to activate the Automation.
     * For example form name, purchased product, etc.
     * @format WEB_URL
     */
    dynamicSchemaUrl?: string | null;
}
interface SchemaField {
    /** The key as it appears on the report event payload. */
    key?: string;
    /** The name displayed to the user. */
    displayName?: string;
    /** The field type */
    fieldType?: SchemaFieldType;
    /** Sample values, values that could show up in the payload of a trigger. */
    sampleValues?: string[];
    /** The field exposure */
    exposure?: SchemaFieldExposureWithLiterals;
}
declare enum PrimitiveType {
    UNKNOWN_PRIMITIVE_TYPE = "UNKNOWN_PRIMITIVE_TYPE",
    TEXT = "TEXT",
    BOOLEAN = "BOOLEAN",
    NUMBER = "NUMBER"
}
/** @enumType */
type PrimitiveTypeWithLiterals = PrimitiveType | 'UNKNOWN_PRIMITIVE_TYPE' | 'TEXT' | 'BOOLEAN' | 'NUMBER';
declare enum SimpleType {
    UNKNOWN_SIMPLE_TYPE = "UNKNOWN_SIMPLE_TYPE",
    MONEY = "MONEY",
    LINK = "LINK",
    BACKOFFICE_LINK = "BACKOFFICE_LINK",
    LIVESITE_LINK = "LIVESITE_LINK",
    MULTILINGUAL = "MULTILINGUAL",
    IMAGE_LINK = "IMAGE_LINK",
    GUID = "GUID",
    EMAIL = "EMAIL",
    PHONE = "PHONE",
    CONTACT_ID = "CONTACT_ID"
}
/** @enumType */
type SimpleTypeWithLiterals = SimpleType | 'UNKNOWN_SIMPLE_TYPE' | 'MONEY' | 'LINK' | 'BACKOFFICE_LINK' | 'LIVESITE_LINK' | 'MULTILINGUAL' | 'IMAGE_LINK' | 'GUID' | 'EMAIL' | 'PHONE' | 'CONTACT_ID';
interface Primitive {
    primitiveType?: PrimitiveTypeWithLiterals;
}
interface Simple {
    simpleType?: SimpleTypeWithLiterals;
}
interface _Date {
    /** Default: false, set this to true if the date is normally a future date, like: Invoice expiration date, Membership renewal date */
    allowNegativeOffset?: boolean | null;
}
interface SchemaFieldType extends SchemaFieldTypeFieldTypeOneOf {
    primitive?: Primitive;
    simple?: Simple;
    /**
     * The field value must conform to the following JSON structure { "timestamp": string, "timeZone": string }, where the timestamp is ISO format UTC, and the time zone is the full name
     * Example: { "timestamp": "2021-03-22T11:41:47.992Z", timeZone: "Asia/Jerusalem" }
     */
    date?: _Date;
}
/** @oneof */
interface SchemaFieldTypeFieldTypeOneOf {
    primitive?: Primitive;
    simple?: Simple;
    /**
     * The field value must conform to the following JSON structure { "timestamp": string, "timeZone": string }, where the timestamp is ISO format UTC, and the time zone is the full name
     * Example: { "timestamp": "2021-03-22T11:41:47.992Z", timeZone: "Asia/Jerusalem" }
     */
    date?: _Date;
}
declare enum SchemaFieldExposure {
    UNKNOWN_EXPOSURE = "UNKNOWN_EXPOSURE",
    /** Not sent to the action provider */
    SETUP = "SETUP",
    /** Sent to the action provider and usually hidden from user */
    HIDDEN = "HIDDEN",
    /** Sent to the action provider and usually shown to user */
    EXPOSED = "EXPOSED"
}
/** @enumType */
type SchemaFieldExposureWithLiterals = SchemaFieldExposure | 'UNKNOWN_EXPOSURE' | 'SETUP' | 'HIDDEN' | 'EXPOSED';
/** represents Invoices integration policies */
interface InvoicesActionsComponentData {
    /** partial payment restriction on invoice */
    partialPayment?: PartialPaymentRestrictionWithLiterals;
}
/** Possible Partial Payment Policy Values */
declare enum PartialPaymentRestriction {
    UNDEFINED = "UNDEFINED",
    /** Allow Partial Payment */
    ALLOW = "ALLOW",
    /** Disallow Partial Payment */
    DISALLOW = "DISALLOW"
}
/** @enumType */
type PartialPaymentRestrictionWithLiterals = PartialPaymentRestriction | 'UNDEFINED' | 'ALLOW' | 'DISALLOW';
/** Experimental-WIP: Specifies the app module configuration of business manager module */
interface DashboardApplicationData {
    /**
     * List of bundles to be loaded for your module
     * @minSize 1
     */
    bundles?: Bundle[];
    /**
     * Your module id as defined in business-manager-api
     * @minLength 2
     * @maxLength 64
     */
    _id?: string | null;
    /** List of available page components that your module is registering */
    pageComponents?: PageDashboardApplicationComponent[];
    /** The default component to load when another app navigates to your module */
    defaultPageComponentId?: string | null;
    /** Config section that will be provided to your lazy component and component along with all other properties from business-manager, if your config object will contain topology parameter, you'll be able to benefit from statics override machanism */
    config?: AppConfiguration;
    /** Allows an application to declare that when it's opened inside the business-manager without a deeplink the business-manager home should be shown. It currently only affects opening the app from Editor/ADI */
    useHomeAsLandingPage?: boolean | null;
    /** If there are some experiments that define if this page should be enabled, list of experiment lists with OR relationship between them, experiments should be in business manager scope */
    enabledByExperiments?: ExperimentGroupWrapper[];
    /** If this module should load in absence of any pages, by default this won't run */
    loadWithoutPages?: boolean | null;
    /** List of hosted component of the application */
    components?: HostedComponent[];
}
/** Specifes business manager module file bundle */
interface Bundle {
    /**
     * The JavaScript file to load
     * @format WEB_URL
     */
    file?: string;
    /** If there are some experiments that define if this page should be enabled, list of experiment lists with OR relationship between them, experiments should be in business manager scope */
    enabledByExperiments?: ExperimentGroupWrapper[];
    /**
     * A alternative debug file for debugging issues
     * @format WEB_URL
     */
    debugFile?: string | null;
}
/** Specifies a list of experiments that have AND relationship between them, and OR relationship between each list */
interface ExperimentGroupWrapper {
    /**
     * list of experiments with AND relationship between them, for false value use ! before experiment spec
     * @minSize 1
     */
    experimentsGroup?: string[];
}
/** Specifies page components for a business manager module */
interface PageDashboardApplicationComponent {
    /**
     * The id of the page
     * @minLength 1
     */
    _id?: string;
    /**
     * The route of the page, the part of the url after /dashboard/{msid}/ (must be unique in the specific application)
     * @minLength 1
     */
    route?: string;
    /**
     * The name you used to register this component to the ModuleRegistry (must be unique across apps)
     * @minLength 1
     */
    name?: string;
    /** If there are some experiments that define if this page should be enabled, list of experiment lists with OR relationship between them, experiments should be in business manager scope. */
    enabledByExperiments?: ExperimentGroupWrapper[];
    /** Additional routes to the page */
    routeAliases?: string[];
}
/** Specifies config for topology and config data */
interface AppConfiguration {
    /** A map of topology key to template url */
    topology?: Record<string, string>;
    /** Config section that will be provided to your lazy component and component along with all other properties from business-manager, if your config object will contain topology parameter */
    configData?: Record<string, string>;
}
/** Specifes business hosted component configuration */
interface HostedComponent {
    /**
     * A unique id for the component, maps between the host and name
     * @minLength 1
     */
    _id?: string;
    /**
     * The component name used in registerComponentWithModuleParams components can be shared by using the same name but a unique id
     * @minLength 1
     */
    name?: string;
    /** Permissions required for the component, this is not strictly enforced */
    requiredPermission?: string;
    /** Represents the collection of components where the component will be hosted, get this value from the host provider. */
    hostContainerId?: HostContainerIdWithLiterals;
    /** If there are some experiments that define if this page should be enabled, list of experiment lists with OR relationship between them, experiments should be in business manager scope */
    enabledByExperiments?: ExperimentGroupWrapper[];
    /** A URI used to send component error events */
    errorReporting?: ErrorReporting;
}
declare enum HostContainerId {
    BUSINESS_MANAGER = "BUSINESS_MANAGER",
    BUSINESS_DASHBOARD_HOST = "BUSINESS_DASHBOARD_HOST",
    SIDEBAR_FOOTER = "SIDEBAR_FOOTER"
}
/** @enumType */
type HostContainerIdWithLiterals = HostContainerId | 'BUSINESS_MANAGER' | 'BUSINESS_DASHBOARD_HOST' | 'SIDEBAR_FOOTER';
/** Contact Labels Extensions */
interface ContactLabelsComponentData {
    /** Whether apps can create labels in this namespace. */
    allowAppDefinedLabels?: boolean | null;
    /**
     * Required permissions to manage app-defined labels.
     * Only apps with these permission will be able to create labels in this namespace.
     * Relevant if `allow_app_defined_labels` is `true`.
     */
    permission?: string | null;
    /** Predefined labels that exist on all sites that install the app. */
    predefinedLabels?: PredefinedLabel[];
}
interface PredefinedLabel {
    /**
     * Unique key. Can contain letters, dashes, or underscores.
     * For example, `"secondary-hobby"`.
     * @minLength 1
     * @maxLength 50
     */
    key?: string;
    /**
     * Display name.
     * For example, `"Secondary Hobby"`.
     * @minLength 1
     * @maxLength 180
     */
    displayName?: string;
}
/** A component to be rendered within Widget Slots */
interface WidgetPluginComponentData {
    /**
     * ID of the widget used for the plugin component.
     * @format GUID
     */
    referenceComponentId?: string;
    /** APIs implemented by the Plugin's widget. */
    pluginInterfaces?: PluginInterfaceWithLiterals[];
    /** Marketing information about the plugin. */
    marketData?: PluginMarketData;
    /** List of placements where the plugin is allowed to be installed. */
    placements?: PluginPlacement[];
    /** Widget plugin installation settings. */
    installation?: PluginInstallationSettings;
}
/** Marketing information about the plugin. */
interface PluginMarketData {
    /**
     * Plugin name.
     * @minLength 1
     * @maxLength 50
     */
    name?: string;
    /**
     * Plugin description.
     * @maxLength 130
     */
    description?: string;
    /**
     * Plugin logo. 35x35px in JPG or PNG format.
     * @format WEB_URL
     */
    logoUrl?: string | null;
}
/** Combination of IDs that uniquely identify a slot in the app component. */
interface PluginPlacement {
    /**
     * Slot app definition ID.
     * @format GUID
     */
    appDefinitionId?: string;
    /**
     * Slot app component ID.
     * @format GUID
     */
    widgetId?: string;
    /**
     * Slot ID.
     * @minLength 1
     */
    slotId?: string;
}
interface PluginInstallationSettings {
    /** Shared installation settings for unified components */
    base?: BaseInstallation;
}
interface CrossSellConfig {
    /** uri for call implementor, could be one of `grpc://<artifact-name>`, `velo://`, `https://` */
    baseUri?: string;
}
/** Local Delivery component */
interface LocalDeliveryComponentData {
    /**
     * URL for the Delivery provider registration web page.
     * The App Instance and Account Id query parameters are attached to the registration URL
     * so that you can identify your account when accessing the vendor api. [learn more](https://devforum.wix.com/en/article/app-instance)
     * @format WEB_URL
     */
    registrationUrl?: string;
    /**
     * The base URL for all the local delivery api calls.
     * Description of end points and schema can be find in the local delivery documentation.
     */
    apiBaseUri?: string;
}
/** Configuration for the payment service SPI implementor */
interface PaymentServiceProviderConfig {
    /**
     * Payment service provider to display on Accept payments tab in Business manager
     * @minLength 1
     */
    title?: string;
    /** SPI base url */
    baseUrl?: string;
    /** Available payment methods */
    paymentMethods?: PaymentMethod[];
    /** Provider authentication methods */
    credentialsFields?: PaymentServiceProviderCredentialsField[];
}
interface PaymentMethod extends PaymentMethodMethodOneOf {
    /** Information about hosted page payment method */
    hostedPage?: HostedPage;
}
/** @oneof */
interface PaymentMethodMethodOneOf {
    /** Information about hosted page payment method */
    hostedPage?: HostedPage;
}
interface HostedPage {
    /**
     * The payment method title to be will be displayed on accept payments tab in business manager as well as on the checkout
     * @minLength 1
     */
    title?: string;
    /** Url to images in different formats and colors */
    logos?: Logos;
    /** Billing address fields that buyer needs to fill in order to process payment with the specified payment method */
    billingAddressMandatoryFields?: MandatoryFieldWithLiterals[];
}
interface Logos {
    /** white theme logos */
    white?: Color;
    /** colored theme logos */
    colored?: Color;
}
interface Color {
    /**
     * URL to SVG image
     * @format WEB_URL
     */
    svg?: string;
    /**
     * URL to PNG image
     * @format WEB_URL
     */
    png?: string;
}
declare enum MandatoryField {
    ZIPCODE = "ZIPCODE",
    CITY = "CITY",
    STATE = "STATE",
    ADDRESS = "ADDRESS",
    COUNTRY_CODE = "COUNTRY_CODE",
    EMAIL = "EMAIL",
    PHONE = "PHONE",
    FIRST_NAME = "FIRST_NAME",
    LAST_NAME = "LAST_NAME",
    STREET = "STREET",
    HOUSE_NUMBER = "HOUSE_NUMBER",
    TAX_IDENTIFIER = "TAX_IDENTIFIER"
}
/** @enumType */
type MandatoryFieldWithLiterals = MandatoryField | 'ZIPCODE' | 'CITY' | 'STATE' | 'ADDRESS' | 'COUNTRY_CODE' | 'EMAIL' | 'PHONE' | 'FIRST_NAME' | 'LAST_NAME' | 'STREET' | 'HOUSE_NUMBER' | 'TAX_IDENTIFIER';
interface PaymentServiceProviderCredentialsField extends PaymentServiceProviderCredentialsFieldFieldOneOf {
    /** text field */
    simpleField?: SimpleField;
    /** checkbox field */
    checkboxField?: CheckboxField;
    /** dropdown field */
    dropdownField?: DropdownField;
}
/** @oneof */
interface PaymentServiceProviderCredentialsFieldFieldOneOf {
    /** text field */
    simpleField?: SimpleField;
    /** checkbox field */
    checkboxField?: CheckboxField;
    /** dropdown field */
    dropdownField?: DropdownField;
}
interface SimpleField {
    /**
     * field name
     * @minLength 1
     */
    name?: string;
    /**
     * field label
     * @minLength 1
     */
    label?: string;
}
interface CheckboxField {
    /**
     * field name
     * @minLength 1
     */
    name?: string;
    /**
     * field label
     * @minLength 1
     */
    label?: string;
    /** field tooltip */
    tooltip?: string | null;
}
interface DropdownField {
    /**
     * field name
     * @minLength 1
     */
    name?: string;
    /**
     * field label
     * @minLength 1
     */
    label?: string;
    /** specific options */
    options?: DropdownFieldOption[];
}
interface DropdownFieldOption {
    /**
     * option key
     * @minLength 1
     */
    key?: string;
    /**
     * option value
     * @minLength 1
     */
    value?: string;
}
interface MembershipsSPIConfig {
    /** The URL of the SPI implementation */
    deploymentUri?: string;
    /**
     * @minSize 1
     * @maxSize 300
     */
    catalogAppDefIds?: string[];
}
interface LineItemsEnricherConfig {
    /** the base URI where all the methods are deployed. */
    baseUri?: string;
}
interface ShippingRatesConfig {
    /**
     * Base URI where the endpoints are called.
     * Wix eCommerce appends the endpoint path to the base URI.
     * For example, to call the Get Shipping Rates endpoint at `https://my-shipping-provider.com/v1/getRates`,
     * the base URI you provide here is `https://my-shipping-provider.com/`.
     * @minLength 1
     */
    deploymentUri?: string;
    /**
     * Human-readable name of the shipping provider.
     * @minLength 1
     * @maxLength 64
     */
    name?: string;
    /**
     * Description of the shipping provider.
     * @maxLength 200
     */
    description?: string | null;
    /**
     * URL to more info about the shipping provider.
     * @maxLength 200
     */
    learnMoreUrl?: string | null;
    /**
     * URL to reach the shipping provider app's dashboard.
     * @minLength 1
     * @maxLength 2048
     * @format WEB_URL
     */
    dashboardUrl?: string | null;
    /** Whether to require the site owner to define a fallback/default rate. Set to `true` if you do not provide rates as part of the integration. */
    fallbackDefinitionMandatory?: boolean;
    /**
     * Thumbnail image of the shipping rates provider. Displayed in the shipping settings section in the Dashboard.
     * The URL must be of an image uploaded to the [Wix Media Manager](https://support.wix.com/en/article/wix-media-uploading-media-to-the-media-manager).
     * @format WEB_URL
     */
    thumbnailUrl?: string | null;
}
interface ShippingLabelCarrierSpiConfig {
    /** the base URI where all the methods are deployed */
    baseUri?: string;
    /**
     * the countries supported to send from
     * @format COUNTRY
     * @minSize 1
     * @maxSize 300
     */
    originCountries?: string[];
    /**
     * the countries supported to send to
     * @format COUNTRY
     * @minSize 1
     * @maxSize 300
     */
    destinationCountries?: string[];
    /**
     * the currency of the labels
     * @format CURRENCY
     */
    currency?: string;
    /** the measurement system of he labels (Metric or Imperial) */
    measurementSystem?: MeasurementSystemWithLiterals;
    /** does carrier support insurance */
    isInsuranceSupported?: boolean;
    /**
     * preset carrier packages
     * @minSize 1
     * @maxSize 20
     */
    packageTypes?: PackageType[];
}
declare enum MeasurementSystem {
    Metric = "Metric",
    Imperial = "Imperial"
}
/** @enumType */
type MeasurementSystemWithLiterals = MeasurementSystem | 'Metric' | 'Imperial';
interface PackageType {
    /**
     * carrier id that can be used to get quotes and purchase
     * @maxLength 30
     */
    _id?: string;
    /**
     * display name of the package (translated)
     * @maxLength 100
     */
    name?: string;
    /**
     * description (translated)
     * @maxLength 200
     */
    description?: string;
    /** the dimensions of the package */
    dimension?: PackageDimension;
    /** image of the package (Optional) */
    image?: Image;
}
interface PackageDimension {
    /**
     * width of the package
     * @max 120
     */
    width?: number;
    /**
     * length of the package
     * @max 120
     */
    length?: number;
    /**
     * height of the package (Optional)
     * @max 120
     */
    height?: number | null;
}
interface Image {
    /** WixMedia image ID. */
    _id?: string;
    /** Image URL. */
    url?: string;
    /**
     * Original image height.
     * @readonly
     */
    height?: number;
    /**
     * Original image width.
     * @readonly
     */
    width?: number;
    /** Image alt text. Optional. */
    altText?: string | null;
    /** Image filename. Optional. */
    filename?: string | null;
}
/** Restaurants POS component */
interface RestaurantsPOSComponentData {
    /**
     * URL for the Restaurants POS registration web page.
     * The app instance and account ID query parameters are appended to the registration URL so that you can identify an account when accessing the vendor api.
     * [Learn more](https://devforum.wix.com/en/article/app-instance).
     * @format WEB_URL
     */
    registrationUrl?: string;
    /** Base URL for all the Restaurants POS API calls. */
    apiBaseUri?: string;
    /** Configuration parameters defining the behavoiur of the catalog sync. */
    catalogSyncConfiguration?: CatalogSyncConfiguration;
}
interface CatalogSyncConfiguration {
    /** If menu, section, or dish availability will be updated on the POS side or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    entityAvailabilityUpdated?: DefaultWithLiterals;
    /** Whether fulfillment methods will be defined on the POS side or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    fulfillmentMethodsDefinition?: DefaultWithLiterals;
    /** If dish images will be updated on the POS side or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    dishImagesUpdated?: DefaultWithLiterals;
    /** If sorting (Menu/Category/Dish/Options) will be done on the POS side (API order) or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    entitySortingControl?: DefaultWithLiterals;
    /** If labels will be updated on the POS side or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    dishLabelsUpdated?: DefaultWithLiterals;
    /** If min/max amount of choices is to be set on the POS side or on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    dishOptionsMinMaxUpdated?: DefaultWithLiterals;
    /** If dish in/out of stock will be retrieved from POS or updated on [Wix Menus](https://dev.wix.com/docs/rest/business-solutions/restaurants/menus/menus/introduction). */
    dishInStockUpdated?: DefaultWithLiterals;
}
declare enum Default {
    WIX = "WIX",
    POS = "POS"
}
/** @enumType */
type DefaultWithLiterals = Default | 'WIX' | 'POS';
interface ShippingProviderConfig {
    /** URI configuration of the deployment */
    deploymentUri?: SpiBaseUri;
    /** User-friendly name of the shipping provider */
    shippingCompanyName?: string;
    /** Cost of making a shipment */
    shippingPrice?: number;
}
interface SpiBaseUri {
    /**
     * Base URI where the methods are called. Wix appends the path to the `baseUri`.
     * For example, to call the Get Shipping Rates method at `https://my-shipping-provider.com/v1/getRates`, the base URI you provide here is `https://my-shipping-provider.com/`.
     * @minLength 6
     * @maxLength 2048
     */
    baseUri?: string;
    /** Alternate, custom URIs to replace the default URIs for specific service plugin methods. */
    alternativeUris?: AlternativeUri[];
}
interface AlternativeUri {
    /**
     * Name of the method to create a custom URI for.
     *
     * For `methodName`, use the name of the method in PascalCase.
     * For example, for Get Shipping Rates use `GetShippingRates`.
     * @minLength 3
     * @maxLength 128
     */
    methodName?: string;
    /**
     * Custom URI that Wix uses to call your server for this method. The path-suffix documented in the method will not be appended to this URI.
     * Must be a secured endpoint beginning with `https://`. For example, `https://www.my-shipping-provider.com/my-shipping-rates`.
     * @minLength 6
     * @maxLength 2048
     */
    absoluteUri?: string;
}
interface AlertEnricherSpiConfiguration {
    deploymentUri?: string;
}
/** A component holding schema of Data Extensions */
interface DataExtensionsComponentData {
    /** FQDN of the entity that the application extends */
    fqdn?: string;
    /** Schema of the extended fields in JSON Schema compatible format */
    schema?: Record<string, any> | null;
    /**
     * Extension point for this schema. empty string or "ROOT" means regular top level schema
     * @maxLength 20
     */
    extensionPoint?: string;
}
interface GenericHooksConfig {
    /**
     * Hook definitions
     * @maxSize 100
     */
    hooks?: GenericHookConfig[];
}
declare enum HookType {
    UNDEFINED = "UNDEFINED",
    BEFORE_BLOCKING = "BEFORE_BLOCKING",
    BEFORE = "BEFORE",
    AFTER = "AFTER"
}
/** @enumType */
type HookTypeWithLiterals = HookType | 'UNDEFINED' | 'BEFORE_BLOCKING' | 'BEFORE' | 'AFTER';
interface GenericHookConfig {
    /** FQN of proto service */
    serviceFqn?: string;
    /** Name of RPC inside given proto service */
    methodName?: string;
    /**
     * An URI, which uniquely identifies the hook for invocation
     * @format WEB_URL
     */
    uri?: string;
    /** Type of hook */
    hookType?: HookTypeWithLiterals;
}
interface ActionProviderSPIConfig {
    /** URL to action provider service for this action */
    baseUri?: string;
    /** Action service plugin configuration */
    actionConfig?: ActionSPIConfig;
}
interface ActionSPIConfig {
    /**
     * Identifier for this action - human-readable action key - unique per app def ID
     * @minLength 5
     * @maxLength 50
     */
    actionKey?: string;
    /**
     * The action expects the following input
     * The schema is described according to the JSON Schema standard: https://json-schema.org/
     *
     * Example - Add Label to Contact Action input schema:
     * {
     * "$schema": "https://json-schema.org/draft/2020-12/schema",
     * "type": "object",
     * "title": "Add label to contact input schema",
     * "description": "The schema of the JSON that is sent when invoking this add label to contact action",
     * "default": {},
     * "examples": [
     * {
     * "contactId": "a647eb32-c5f4-11ec-9d64-0242ac120002",
     * "labelId": "1e8b5e5e-dba2-11ec-9d64-0242ac120002"
     * }
     * ],
     * "required": [
     * "contactId",
     * "labelId"
     * ],
     * "properties": {
     * "contactId": {
     * "$id": "#/properties/contactId",
     * "type": "string",
     * "format": "uuid",
     * "title": "Contact Id",
     * "description": "The ID of the contact to apply the label to",
     * "default": "",
     * "identityType": "contact" // can be contact/visitor/user, limited to 1 type per identity.
     * },
     * "labelId": {
     * "$id": "#/properties/labelId",
     * "type": "string",
     * "format": "uuid",
     * "title": "Label Id",
     * "description": "The ID of the label to apply",
     * "default": "",
     * }
     * }
     * }
     */
    inputSchema?: Record<string, any> | null;
    /**
     * The output of the action, which will be added to the payload after execution.
     * The schema is described according to the JSON Schema standard: https://json-schema.org/
     *
     * Example - Output of create task action
     * {
     * "$schema": "https://json-schema.org/draft/2020-12/schema",
     * "type": "object",
     * "title": "Create task action schema",
     * "description": "The schema of the JSON that is sent when invoking this create task action",
     * "default": {},
     * "examples": [
     * {
     * "taskId": "a647eb32-c5f4-11ec-9d64-0242ac120002",
     * }
     * ],
     * "required": [
     * "taskId"
     * ],
     * "properties": {
     * "taskId": {
     * "$id": "#/properties/taskId",
     * "type": "string",
     * "format": "uuid",
     * "title": "Contact Id",
     * "description": "The ID of the task created",
     * "default": "",
     * }
     * }
     * }
     */
    outputSchema?: Record<string, any> | null;
    /**
     * Actions display name - human-readable field. Ex. - "Send SMS"
     * @minLength 5
     * @maxLength 80
     */
    displayName?: string | null;
    description?: string | null;
    /** Specifies which optional methods were implemented */
    implementedMethods?: ActionSPIConfigImplementedMethods;
    /**
     * Indicates whether we should wait for the action to complete before executing the next actions or finish and
     * expect a callback in the actionCompleted method
     */
    executionType?: ExecutionTypeWithLiterals;
    /** Chosen interface for action */
    interfaceConfiguration?: ActionSPIConfigInterfaceConfiguration;
    /** Icon representing the action in the UI */
    icon?: string;
    /** The action configuration source information */
    source?: Source;
    /**
     * action id
     * @format GUID
     */
    _id?: string | null;
}
declare enum ActionSPIConfigInterfaceConfigurationType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    WIDGET_COMPONENT = "WIDGET_COMPONENT",
    GENERIC = "GENERIC"
}
/** @enumType */
type ActionSPIConfigInterfaceConfigurationTypeWithLiterals = ActionSPIConfigInterfaceConfigurationType | 'UNKNOWN_TYPE' | 'WIDGET_COMPONENT' | 'GENERIC';
interface WidgetComponentOptions {
    /**
     * Name of provided component
     * @minLength 1
     * @maxLength 80
     */
    componentName?: string;
}
interface GenericOptions {
    /** UI schema */
    uiSchema?: Record<string, any> | null;
}
declare enum SourceType {
    UNKNOWN_SOURCE_TYPE = "UNKNOWN_SOURCE_TYPE",
    /** The input/output schemas are constructed by developers in Dev Center using the self-service flow */
    DEV_CENTER = "DEV_CENTER",
    /** The input/output schemas are derived from an existing Wix API through the API-to-Action feature */
    WIX_API = "WIX_API"
}
/** @enumType */
type SourceTypeWithLiterals = SourceType | 'UNKNOWN_SOURCE_TYPE' | 'DEV_CENTER' | 'WIX_API';
interface WixApiOptions {
    /**
     * Service entity fqdn
     * @minLength 1
     * @maxLength 100
     */
    serviceEntityFqdn?: string;
    /**
     * The service providing the API
     * @minLength 1
     * @maxLength 200
     */
    serviceName?: string;
    /**
     * The method name
     * @minLength 1
     * @maxLength 200
     */
    methodName?: string;
}
interface ActionSPIConfigImplementedMethods {
    /** Implements ValidateConfiguration */
    validateConfiguration?: boolean;
    /** Implements DuplicateInputMapping */
    duplicateInputMapping?: boolean;
    /** Implements GenerateApplicationAutomationInputMapping */
    generateApplicationAutomationInputMapping?: boolean;
    /** Implements GetQuotaInfo */
    getQuotaInfo?: boolean;
    /** Implements OnBeforeSave */
    onBeforeSave?: boolean;
    /** Implements OnReset */
    onReset?: boolean;
    /** implements generateActionInputMappingFromTemplate */
    generateActionInputMappingFromTemplate?: boolean;
    /** implements OnRemove */
    onRemove?: boolean;
    /** Implements GetDynamicInputSchema */
    getDynamicInputSchema?: boolean;
    /** Implements MergeInputMappings */
    mergeInputMappings?: boolean;
    /** Implements GetDynamicOutputSchema */
    getDynamicOutputSchema?: boolean;
}
declare enum ExecutionType {
    UNKNOWN_EXECUTION_TYPE = "UNKNOWN_EXECUTION_TYPE",
    SYNC = "SYNC",
    ASYNC = "ASYNC"
}
/** @enumType */
type ExecutionTypeWithLiterals = ExecutionType | 'UNKNOWN_EXECUTION_TYPE' | 'SYNC' | 'ASYNC';
interface Metadata {
    /** Show action only to advanced mode users (Wix staff) */
    hidden?: boolean;
}
interface ActionSPIConfigInterfaceConfiguration extends ActionSPIConfigInterfaceConfigurationOptionsOneOf {
    widgetComponentOptions?: WidgetComponentOptions;
    genericOptions?: GenericOptions;
    /** Type of chosen interface */
    type?: ActionSPIConfigInterfaceConfigurationTypeWithLiterals;
}
/** @oneof */
interface ActionSPIConfigInterfaceConfigurationOptionsOneOf {
    widgetComponentOptions?: WidgetComponentOptions;
    genericOptions?: GenericOptions;
}
interface Source extends SourceOptionsOneOf {
    /** Wix API options */
    wixApiOptions?: WixApiOptions;
    /** the source type */
    type?: SourceTypeWithLiterals;
}
/** @oneof */
interface SourceOptionsOneOf {
    /** Wix API options */
    wixApiOptions?: WixApiOptions;
}
interface CatalogSPIConfig {
    /** Base URI which Wix eCommerce will call to access Catalog service plugin endpoints. For example, to call the Get Catalog Items endpoint at `https://my-external-catalog.com/get-catalog-items`, the base URI you provide here is `https://my-external-catalog.com`. */
    deploymentUri?: string;
    /** Configuration details for discounts applied to all items in the catalog. */
    allItemsDiscount?: DiscountConfig;
    /** Configuration details for discounts applied to specific items in the catalog. */
    specificItemsDiscount?: DiscountConfig;
}
interface DiscountConfig {
    /**
     * Whether the discount is enabled.
     *
     * Default: `false`.
     */
    enabled?: boolean;
    /**
     * Translation key for text to display to the site owner.
     * @minLength 5
     * @maxLength 100
     */
    translationKey?: string;
}
/** A container (slot) that can be extended by other applications (e.g. widget slot or context menu slot) */
interface BackOfficeExtensionContainer {
    /** Information about the type of slot. */
    extendable?: Extendable;
    /**
     * Default route for the container.
     * @maxLength 400
     */
    defaultRoute?: string | null;
    /** A container (slot) common properties. */
    slotData?: SlotData;
}
/** Extensibility properties used by containers (slots) */
interface Extendable {
    /** Type of component that this slot accepts. */
    extendedBy?: ExtendingComponentTypeWithLiterals;
}
/** Which component types can be extended in containers */
declare enum ExtendingComponentType {
    INVALID = "INVALID",
    BACK_OFFICE_MENU_ITEM = "BACK_OFFICE_MENU_ITEM",
    BACK_OFFICE_EXTENSION_WIDGET = "BACK_OFFICE_EXTENSION_WIDGET"
}
/** @enumType */
type ExtendingComponentTypeWithLiterals = ExtendingComponentType | 'INVALID' | 'BACK_OFFICE_MENU_ITEM' | 'BACK_OFFICE_EXTENSION_WIDGET';
/** List of back-office hosting platforms */
declare enum BackOfficeHostingPlatforms {
    NO_HOSTING_PLATFORM = "NO_HOSTING_PLATFORM",
    /** Site Dashboard (The Wix Dashboard) */
    BUSINESS_MANAGER = "BUSINESS_MANAGER",
    /** User Account Dashboard */
    ACCOUNT_MANAGER = "ACCOUNT_MANAGER",
    /** Internal: Dev center */
    DEV_CENTER = "DEV_CENTER",
    /** Enterprise dashboard (available to enterprise accounts only) */
    ENTERPRISE = "ENTERPRISE",
    /** Partners dashboard (available to partners accounts only) */
    PARTNERS_DASHBOARD = "PARTNERS_DASHBOARD",
    /** Employee only financial support dashboard */
    FINANCIALS_INTERNAL_BO = "FINANCIALS_INTERNAL_BO",
    /** FED Guild POC dashboard */
    FED_GUILD_POC = "FED_GUILD_POC",
    /** Studio dashboard */
    STUDIO_DASHBOARD = "STUDIO_DASHBOARD",
    /** Channels dashboard (available to channels accounts only) */
    CHANNELS = "CHANNELS",
    /** Wix internal dashboard for data tools (proffesional data consumers, i.e Business Analysts, Data Engineers...) */
    DATA_TOOLS = "DATA_TOOLS",
    /** Internal back-office for payment service provider management */
    PSP_BACKOFFICE = "PSP_BACKOFFICE",
    /** Rise.ai account dashboard */
    RISE_PLATFORM_ACCOUNT_DASHBOARD = "RISE_PLATFORM_ACCOUNT_DASHBOARD",
    /** Enterprise demo dashboard (available to possible enterprise accounts for demo purposes) */
    DEMO_DASHBOARD_ENTERPRISE = "DEMO_DASHBOARD_ENTERPRISE",
    /** A new AI scheduling assistant product dashboard (codename: "Nownia") */
    AI_SCHEDULING_ASSISTANT_DASHBOARD = "AI_SCHEDULING_ASSISTANT_DASHBOARD",
    /** Employee only getting paid cluster dashboard */
    GETTING_PAID = "GETTING_PAID",
    /** Wix internal dashboard for data (non proffesional data consumers, i.e any Wix Employee that has a need for BI data) */
    DATA = "DATA",
    /** Dashboard for viral forms/lite events/etc */
    LITE_DASHBOARD = "LITE_DASHBOARD",
    /** Picasso AI application POC */
    PICASSO_EDITOR = "PICASSO_EDITOR"
}
/** @enumType */
type BackOfficeHostingPlatformsWithLiterals = BackOfficeHostingPlatforms | 'NO_HOSTING_PLATFORM' | 'BUSINESS_MANAGER' | 'ACCOUNT_MANAGER' | 'DEV_CENTER' | 'ENTERPRISE' | 'PARTNERS_DASHBOARD' | 'FINANCIALS_INTERNAL_BO' | 'FED_GUILD_POC' | 'STUDIO_DASHBOARD' | 'CHANNELS' | 'DATA_TOOLS' | 'PSP_BACKOFFICE' | 'RISE_PLATFORM_ACCOUNT_DASHBOARD' | 'DEMO_DASHBOARD_ENTERPRISE' | 'AI_SCHEDULING_ASSISTANT_DASHBOARD' | 'GETTING_PAID' | 'DATA' | 'LITE_DASHBOARD' | 'PICASSO_EDITOR';
/** Definitions of common slots properties */
interface SlotData extends SlotDataSlotTypeOneOf {
    /** Widget-specific slot. */
    widgetOptions?: WidgetSlot;
    /** Menu-specific slot. */
    menuOptions?: MenuSlot;
    /**
     * Slot display name.
     * @maxLength 400
     */
    displayName?: string | null;
    /**
     * Slot description.
     * @maxLength 400
     */
    description?: string | null;
    /** Parameters for the slot. */
    slotParams?: SlotParams;
    /**
     * HTTP links to a markdown files.
     * @maxSize 100
     * @format WEB_URL
     */
    mdHttpLinks?: string[];
    type?: SlotDataTypeWithLiterals;
}
/** @oneof */
interface SlotDataSlotTypeOneOf {
    /** Widget-specific slot. */
    widgetOptions?: WidgetSlot;
    /** Menu-specific slot. */
    menuOptions?: MenuSlot;
}
interface DtsDefinitionReference extends DtsDefinitionReferenceDtsDefinitionOneOf {
    dtsHttpLinkOptions?: DtsHttpLink;
    dtsContentOptions?: DtsContent;
    type?: DtsDefinitionTypeWithLiterals;
}
/** @oneof */
interface DtsDefinitionReferenceDtsDefinitionOneOf {
    dtsHttpLinkOptions?: DtsHttpLink;
    dtsContentOptions?: DtsContent;
}
declare enum DtsDefinitionType {
    UNKNOWN = "UNKNOWN",
    DTS_HTTP_LINK = "DTS_HTTP_LINK",
    DTS_CONTENT = "DTS_CONTENT"
}
/** @enumType */
type DtsDefinitionTypeWithLiterals = DtsDefinitionType | 'UNKNOWN' | 'DTS_HTTP_LINK' | 'DTS_CONTENT';
interface DtsHttpLink {
    /**
     * HTTP link to the bundled d.ts file.
     * @maxLength 400
     */
    bundledDtsHttpLink?: string;
}
interface DtsContent {
    /**
     * d.ts file content.
     * @maxLength 2000
     */
    bundledDtsContent?: string;
}
interface BlocksData {
    /** Maximum allowed dimensions. */
    maxDimensionsPixels?: Dimension;
    /** Minimum allowed dimensions. */
    minDimensionsPixels?: Dimension;
    /**
     * Slot placeholder component ID in the document.
     * @maxLength 50
     */
    compRefId?: string | null;
}
interface Dimension {
    /**
     * Width of the component (max: 9999).
     * @max 9999
     */
    width?: number | null;
    /**
     * Height of the component (max: 9999).
     * @max 9999
     */
    height?: number | null;
}
interface SlotParams {
    /** DTS reference for the slot parameters. */
    slotParamsDtsReference?: DtsDefinitionReference;
    /**
     * Named export to use.
     * @maxLength 400
     */
    namedExport?: string | null;
}
declare enum SlotDataType {
    UNKNOWN = "UNKNOWN",
    WIDGET = "WIDGET",
    MENU = "MENU"
}
/** @enumType */
type SlotDataTypeWithLiterals = SlotDataType | 'UNKNOWN' | 'WIDGET' | 'MENU';
interface WidgetSlot {
    /** Blocks specific data. */
    blocksData?: BlocksData;
}
interface MenuSlot {
}
/**
 * A component that enables extending Wix Dashboard Functionality, as defined by ExtendingComponentType.
 * Currently this supports extending menus and extending widget slots (for Wix apps that expose such menus and slots)
 */
interface BackOfficeExtension extends BackOfficeExtensionExtensionOneOf {
    /** Information about a widget extension. */
    widget?: LegacyBackOfficeExtensionWidget;
    /** Information about a menu item extension. */
    menuItem?: LegacyBackOfficeMenuItem;
    /**
     * ID of the slot that hosts the extension.
     * @format GUID
     */
    extends?: string;
    /** Extension title. This is how the extension is referred to in the Wix Dev Center. */
    title?: string;
    /** Extension description. This is how the extension is described in the Wix Dev Center. */
    description?: string | null;
    /** Type of extension. */
    extensionType?: ExtendingComponentTypeWithLiterals;
    /**
     * Platform that hosts the extension.
     *
     * Must be `"BUSINESS_MANAGER"`.
     */
    hostingPlatform?: BackOfficeHostingPlatformsWithLiterals;
}
/** @oneof */
interface BackOfficeExtensionExtensionOneOf {
    /** Information about a widget extension. */
    widget?: LegacyBackOfficeExtensionWidget;
    /** Information about a menu item extension. */
    menuItem?: LegacyBackOfficeMenuItem;
}
/** The schema of a widget extending a slot exposed in a page in the Wix Dashboard */
interface LegacyBackOfficeExtensionWidget extends LegacyBackOfficeExtensionWidgetAssetOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
    /**
     * Initial width of the widget while loading, in pixels.
     * Width may be adjusted dynamically based on the content of the widget or limited by the size of the widget's container.
     * @max 9999
     */
    width?: number | null;
    /**
     * Initial height of the widget while loading, in pixels.
     * Height may be adjusted dynamically based on the content of the widget or limited by the size of the widget's container.
     * @max 9999
     */
    height?: number | null;
}
/** @oneof */
interface LegacyBackOfficeExtensionWidgetAssetOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
}
/** Internal: Specifications for loading an asset via JS in the back office */
interface BackOfficeScriptAsset {
    /**
     * The JavaScript file to load
     * @format WEB_URL
     */
    url?: string;
    /**
     * Namespacing of the component in the Webpack Module Federation registry
     * @minLength 1
     */
    containerId?: string;
    /**
     * Key name for the retrieval of the component
     * @minLength 1
     */
    exportedName?: string;
    /** Optional: What type should by used on <script> tag. */
    scriptType?: BackOfficeScriptAssetTypeWithLiterals;
}
/** Type attribute for the script tag */
declare enum BackOfficeScriptAssetType {
    /** Script will be loaded without a type attribute */
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    /** Use "module" as the script type */
    MODULE = "MODULE"
}
/** @enumType */
type BackOfficeScriptAssetTypeWithLiterals = BackOfficeScriptAssetType | 'UNKNOWN_TYPE' | 'MODULE';
/** The schema of a menu extension of a slot exposed in a page in the Wix Dashboard */
interface LegacyBackOfficeMenuItem {
    /**
     * [Wix Design System icon key](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full-size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
    /** Action that takes places when the menu item is clicked. */
    action?: LegacyBackOfficeMenuItemAction;
    /**
     * Menu item subtitle.
     * @maxLength 200
     */
    subtitle?: string | null;
}
/** View modes for how to open a component. */
declare enum ViewMode {
    /** Opens a page in place of the current page. */
    PAGE = "PAGE",
    /** Opens as a modal on the current page. */
    MODAL = "MODAL"
}
/** @enumType */
type ViewModeWithLiterals = ViewMode | 'PAGE' | 'MODAL';
/** the schema of the data needed to open a component from menu extensions */
interface OpenComponent {
    /**
     * ID of the component to open.
     * @format GUID
     */
    componentId?: string;
    /** How the component is opened. */
    viewMode?: ViewModeWithLiterals;
    /** Parameters to navigate to a page or as props for a modal. */
    componentParams?: Record<string, string>;
}
/** The schema of an action that is onvoked from menu extensions */
interface LegacyBackOfficeMenuItemAction {
    /** Component that opens when the menu item is clicked. */
    openComponent?: OpenComponent;
}
interface TriggerProviderSPIConfig {
    /**
     * The trigger configuration
     *
     * example of a trigger:
     *
     * {
     * appId: "56cc7843-fdfc-417f-a660-d4af9a2eafe3",
     * triggerKey: "form_submit",
     * displayName: "Visitor submits a form",
     * payloadDataSchema: {
     * "$schema": "http://json-schema.org/draft-07/schema",
     * "type": "object",
     * "title": "Visitor submits a form Payload Schema",
     * "description": "The schema of the payload that is part of the triggered event",
     * "default": {},
     * "examples": [
     * {
     * "formId": "60d2cd50-1047-4164-884d-8c24fbda84bb",
     * "formName": "My Cool Form
     * }
     * ],
     * "properties": {
     * "formId": {
     * "$id": "#/properties/formId",
     * "type": "string",
     * "format": "uuid",
     * "title": "Form ID",
     * "description": "The form identifier",
     * "default": "",
     * "examples": [
     * "60d2cd50-1047-4164-884d-8c24fbda84bb"
     * ]
     * },
     * "formName": {
     * "$id": "#/properties/formName",
     * "type": "string",
     * "title": "Form Name",
     * "description": "The form display name",
     * "default": "",
     * "examples": [
     * "My Form"
     * ]
     * },
     * "contactId": {
     * "$id": "#/properties/contactId",
     * "type": "string",
     * "format": "uuid",
     * "title": "Contact Id",
     * "description": "The Id of the contact which submitted the form",
     * "default": "",
     * "identityType": "contact", // can be contact, visitor, user limited to 1 type per identity,
     * "name": "contact" // friendly name to be used later on, in order to user that person's data "contact.firstName"
     * }
     * },
     * "required": [
     * "formId",
     * "formName",
     * "contactId"
     * ],
     * "additionalProperties": false
     * }
     * }
     */
    triggerConfig?: Record<string, any> | null;
    /** URL to the trigger provider service */
    baseUri?: string;
}
interface PreRegisterConfig {
    /** the base URI where all the methods are deployed. */
    baseUri?: string;
}
interface ProductsPathsConfig {
    /** implementer's deployment uri */
    deploymentUri?: string;
}
interface CustomScopeConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
}
interface GiftCardProviderConfig {
    /** The URL of the SPI implementation */
    deploymentUri?: string;
}
interface ExternalFilterProviderConfig {
    /** the base URI where all the methods are deployed. E.g */
    baseUri?: string;
}
interface RecommendationsProviderConfig {
    /** URI where the application implementing the SPI is deployed. */
    deploymentUri?: string;
    /**
     * App IDs of catalogs for which recommended items can be found.
     * @minSize 1
     * @maxSize 100
     * @minLength 1
     * @maxLength 36
     */
    catalogAppIds?: string[];
    /**
     * The algorithms that this application can use to calculate item recommendations.
     * @minSize 1
     * @maxSize 100
     */
    supportedAlgorithms?: AlgorithmConfig[];
}
interface AlgorithmConfig {
    /**
     * Algorithm name. This value is not translatable.
     * @minLength 1
     * @maxLength 50
     */
    name?: string;
    /**
     * Algorithm description. This describes how the algorithm works and if it has any limitations regarding site content, number of items in the catalog, site traffic, and so on. This value is not translatable.
     * @minLength 1
     * @maxLength 500
     */
    description?: string;
    /**
     * A supplemental `description`. It can be used to help break up and organize information. You can, for example, display this information as a tooltip or as an additional section that is collapsed by default.
     * @minLength 1
     * @maxLength 300
     */
    additionalInfo?: string | null;
    /**
     * Algorithms may have the following types:
     * * `RELATED_ITEMS` - This type of algorithm provides recommendations based on 1 or more other provided items. For example, when an item is added to a cart, the algorithm can suggest other items frequently bought together with that item.
     * * `GLOBAL` - This type of algorithm provides general recommendations based on site or project statistics. For example, bestsellers or new arrivals.
     */
    algorithmType?: AlgorithmTypeWithLiterals;
    /**
     * Algorithm ID. This must be unique for a specific app but does not have to be unique across all apps on the site or in the project.
     * @format GUID
     */
    algorithmId?: string;
}
declare enum AlgorithmType {
    UNSPECIFIED = "UNSPECIFIED",
    RELATED_ITEMS = "RELATED_ITEMS",
    GLOBAL = "GLOBAL"
}
/** @enumType */
type AlgorithmTypeWithLiterals = AlgorithmType | 'UNSPECIFIED' | 'RELATED_ITEMS' | 'GLOBAL';
interface DropshippingProviderSPIConfig {
    /** name of the dropshipping provider was it appears in relevant screens/mails in eComm Platform */
    name?: string;
    /** The URL of the SPI implementation - not needed in this case */
    deploymentUri?: string;
    /**
     * URI for the thumbnail page
     * @format WEB_URL
     */
    thumbnailUri?: string;
    /**
     * URI of the dashboard page
     * @format WEB_URL
     */
    dashboardUri?: string;
    /** if duplication operation for product is locked */
    duplicateProduct?: LockableOperationWithLiterals;
    /** whether there is a warning or not when price is changed */
    changePrice?: RestrictedOperationWithLiterals;
    /** whether the chagne inventory operations are locked */
    changeInventory?: LockableOperationWithLiterals;
    /** where there is a warning of not when changing options */
    manageOptions?: RestrictedOperationWithLiterals;
}
declare enum LockableOperation {
    /** When operation lockability is not specified */
    UNSPECIFIED_LOCKABLE = "UNSPECIFIED_LOCKABLE",
    /** Operation is locked */
    LOCKED = "LOCKED",
    /** Operation is unlocked */
    UNLOCKED = "UNLOCKED"
}
/** @enumType */
type LockableOperationWithLiterals = LockableOperation | 'UNSPECIFIED_LOCKABLE' | 'LOCKED' | 'UNLOCKED';
declare enum RestrictedOperation {
    UNSPECIFIED_RESTRICTED = "UNSPECIFIED_RESTRICTED",
    ALLOW = "ALLOW",
    WARN = "WARN"
}
/** @enumType */
type RestrictedOperationWithLiterals = RestrictedOperation | 'UNSPECIFIED_RESTRICTED' | 'ALLOW' | 'WARN';
interface InvoicesConfig {
    /** Base URI of spi provider */
    baseUri?: string;
}
interface SeoKeywordsSuggestionsSPIConfig {
    /**
     * Base URL of your SEO implementation. Wix sends API requests to endpoints implemented using this URL.
     * @minLength 1
     */
    baseUri?: string;
    /**
     * URL of the page where users can purchase a paid plan. Wix offers a link to this page when you respond with a value of `false` in quota's `paidPlan` property.
     * @format WEB_URL
     */
    upgradeUrl?: string | null;
    /**
     * List of countries you support for SEO analysis.
     * 2-letter country code in [ISO-3166 alpha-2](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements) format.
     * @format COUNTRY
     * @minSize 1
     * @maxSize 250
     */
    supportedCountryCodes?: string[];
    /** Whether there is a quota limit in the service. When `true`, the response includes the quota object. */
    quotaEnabled?: boolean | null;
    /**
     * Your website's landing page.
     * @format WEB_URL
     */
    landingPageUrl?: string;
}
interface CustomTriggerConfig {
    /**
     * Required. Base URI where the endpoints are called. Wix appends the endpoint path to the base URI.
     * For example, to call the Get Eligible Triggers endpoint at `https://my-discount-app.com/v1/get-eligible-triggers`, the base URI you provide here is `https://my-discount-app.com/`.
     */
    deploymentUri?: string;
}
interface ContentProviderConfig {
    /** base uri for each implementer */
    deploymentUri?: string;
    /**
     * a human readable name of the provider
     * @maxLength 64
     */
    providerName?: string;
    /** the maximum items allowed to read and update in a single request */
    maximumReadingBulkSize?: number | null;
}
/** Automation Component data that is stored in dev center */
interface ApplicationAutomationComponent {
    /** A rule that contains a trigger & some actions */
    rule?: Rule;
    /**
     * Automation name
     * @maxLength 500
     */
    name?: string | null;
    /**
     * Automation description
     * @maxLength 2000
     */
    description?: string | null;
    /** Automation metadata */
    metadata?: AutomationMetadata;
    /** Automation status */
    status?: StatusWithLiterals;
    /** Optional origin that indicates the source of the automation */
    origin?: OriginInfo;
    /**
     * Automation id - points to a V3 Builder automation id
     * @format GUID
     */
    automationId?: string | null;
    /**
     * trigger app id - used for reading easily for cache - v3
     * @format GUID
     */
    triggerAppId?: string | null;
    /**
     * trigger key - used for reading easily for cache - v3
     * @minLength 1
     * @maxLength 100
     */
    triggerKey?: string | null;
}
interface Rule {
    /** an event triggered by visitors on a site, or by a site manager (owner & team). */
    trigger?: Trigger;
    /**
     * the actions responding to the trigger happening
     * @maxSize 100
     */
    actions?: ServiceAction[];
}
interface Trigger {
    /**
     * the id of the app defining the trigger
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this trigger - human readable action key
     * @maxLength 100
     */
    triggerKey?: string;
    /**
     * optional list of filters on schema fields
     * @maxSize 5
     */
    filters?: TriggerFilter[];
    /**
     * optional - allows to define a trigger whose following actions will be executed only if the same event for the same resource has not in the last X seconds.
     * for example, if the trigger is "session booked", the resource is a contact and the timeframe is 3600 seconds (contact hasn't booked another session in the last hour),
     * then the actions will be executed only if the same event (session booked for that contact) has not happened in the last hour.
     * resource id is sent in runtime via the externalEntityId parameter, ReportEvent method.
     */
    debounce?: Debounce;
}
interface TriggerFilter {
    /**
     * the filter identifier
     * @format GUID
     */
    _id?: string | null;
    /**
     * the field key from the schema, for example "formId"
     * @minLength 1
     * @maxLength 50
     */
    fieldKey?: string;
    /** filter expression that evaluates to a boolean, for example - {{ contains(["guid1","guid2"];formId) }} */
    filterExpression?: string;
}
interface Debounce {
    /**
     * Amount of time in seconds to wait for any additional events to occur before triggering the actions.
     * If no additional events occur within the specified time, the actions will be triggered.
     * If additional events occur within the specified time, the timer will be reset.
     * @min 1
     */
    timeFrameInSeconds?: number;
    /**
     * The field key in the event payload, which indicates the identifier of the entity/event to debounce on
     * For example: if the trigger is "user logged in", the resource is a contact and the resource key is "contactId",
     * Another example: if the trigger is "visitor logged in", the resource is a visitor and the resource key is "visitorId".
     * @maxLength 100
     */
    fieldKey?: string;
}
interface ServiceAction {
    /**
     * the id of the action for delayed events
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * the id of the app defining the action
     * @format GUID
     */
    appId?: string;
    /**
     * Identifier for this action - human readable action key - unique per app def id
     * @maxLength 80
     */
    actionKey?: string;
    /**
     * input mapping expression for the action inputs
     * for example:
     * `{  "subject": "Thanks for reaching out!"
     * "message": "Hi {{contact.name.first}}, thanks for contacting our business"
     * }`
     * where the value for "contact.name.first" comes from the trigger's payload
     * @maxLength 5000
     */
    actionConfig?: string;
    /**
     * output mapping expression for the action output
     * for example in get-contact action:
     * `{ "author": "{{$}}" }`
     * This will map the entire entity of contact under `author` namespace
     * @maxLength 3000
     */
    outputActionConfig?: string | null;
    /** Optional delay configuration for the action */
    delay?: Delay;
    /** allows you define an activation policy - like number of activations in a time frame, or limit by some identifier, like contact (e.g. send email to user only at first login) */
    rateLimit?: RateLimit;
    /**
     * allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @deprecated allows the user to define a condition for the action to be executed, if the condition fails the action (and following actions) will not be executed
     * @replacedBy conditions
     * @targetRemovalDate 2023-08-01
     */
    condition?: ActionCondition;
    conditions?: Conditions;
    /**
     * allows the user to define a namespace for the action output
     * @minLength 1
     * @maxLength 100
     */
    namespace?: string | null;
}
declare enum BlockType {
    UNKNOWN = "UNKNOWN",
    OR = "OR",
    AND = "AND"
}
/** @enumType */
type BlockTypeWithLiterals = BlockType | 'UNKNOWN' | 'OR' | 'AND';
interface ConditionBlock {
    type?: BlockTypeWithLiterals;
    /**
     * @minSize 1
     * @maxSize 20
     */
    lineExpressions?: string[];
}
interface Offset extends OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** @oneof */
interface OffsetValueOneOf {
    /** A delay in seconds */
    seconds?: number;
    /** The key of the field in the trigger payload which contains a delay, in seconds. */
    delayFieldKey?: string;
}
/** calculated as date + delay */
interface Until {
    /** The key of the field in the trigger payload which contains the date to delay until */
    dateFieldKey?: string;
    /** Optional: a delay to add together with the date described in the payload */
    offset?: Offset;
}
interface Delay extends DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
/** @oneof */
interface DelayTypeOneOf {
    /** A delay which is calculated based on the immediate time when the action is triggered. */
    for?: Offset;
    /** A delay which is calculated based on a date field in the trigger payload. May also be used together with an Offset delay. */
    until?: Until;
}
interface RateLimit {
    /**
     * time frame in minutes
     * @min 1
     */
    timeFrame?: number | null;
    /**
     * number of activations allowed in the given time frame
     * @min 1
     */
    activations?: number;
    /**
     * limit the activation by an entity, for example activate once per contact. example: {{contact.id}}
     * @minLength 1
     * @maxLength 300
     */
    uniqueIdentifierExpression?: string | null;
}
interface ActionCondition {
    /**
     * entity object is deprecated due to the new approach to conditions
     * the condition expression, for example - {{and(gt(price;10);lt(price;100))}}
     * @minLength 1
     * @maxLength 2000
     */
    conditionExpression?: string;
}
interface Conditions {
    /**
     * condition evaluates to `true` if either of the blocks evaluate to `true` (aka OR between all)
     * @minSize 1
     * @maxSize 10
     */
    conditionBlocks?: ConditionBlock[];
}
interface AutomationMetadata {
    /** Is this Automation hidden on a site? */
    hidden?: boolean;
    /** Can this Automation be deactivated on a site? */
    alwaysActive?: boolean;
    /** Is this Automation's scheduling modification is disabled on a site? */
    schedulingModificationDisabled?: boolean;
    /** Is the removal of this Automation's actions disabled? */
    actionRemovalDisabled?: boolean;
    /** Is conditions editing for this Automation allowed on a site? */
    actionConditionsEditingDisabled?: boolean;
}
declare enum Domain {
    /** User domain (default) */
    USER = "USER",
    /** Wix domain */
    WIX = "WIX"
}
declare enum Status {
    ACTIVE = "ACTIVE",
    INACTIVE = "INACTIVE"
}
/** @enumType */
type StatusWithLiterals = Status | 'ACTIVE' | 'INACTIVE';
interface OriginInfo {
    /**
     * The id of the original automation used to create the preinstalled automation (v3/Builder only)
     * @format GUID
     */
    siteAutomationId?: string;
    /**
     * The site which the automation was originally created in (v3/Builder only)
     * @format GUID
     */
    metaSiteId?: string;
}
/** Back-office sidebar categories */
interface BackOfficeSidebarCategory {
    /**
     * Category title.
     * @minLength 1
     */
    title?: string;
    /** Sidebar order within the app */
    priority?: number;
}
/** A page in one of the back-office platforms */
interface BackOfficePage extends BackOfficePageAssetOneOf {
    /** @format WEB_URL */
    iframeUrl?: string;
    /** The route of the page, must be a valid URL path, relative to the app namespace or app id */
    routePath?: string;
    /** Routes that redirect to this page, these paths should include the original path including the namespace or app id */
    previousRoutePaths?: string[];
    /**
     * Page title, also used as sidebar entry label
     * @minLength 1
     */
    title?: string;
    /** False by default, if true, sidebar will be hidden when loading the page */
    fullPage?: boolean;
    /**
     * Optional: category this page belongs to
     * @format GUID
     */
    pageCategoryId?: string | null;
    /** Should the page be shown or hidden in the sidebar, by default a link to the page will be shown */
    hideInSidebar?: boolean;
    /** Sidebar order within the category and app, lower priority means the page is earlier, by default priority is 0, meaning newer pages will appear first */
    priority?: number;
    /**
     * Which page is active in sidebar when this page is loaded
     * @format GUID
     */
    activeSidebarPageId?: string | null;
    /** general component data */
    metaData?: ComponentMetaData;
    /**
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
    /**
     * Anchors for direct navigation to specific sections of the page
     * @maxSize 50
     */
    pageAnchors?: PageAnchor[];
}
/** @oneof */
interface BackOfficePageAssetOneOf {
    /** @format WEB_URL */
    iframeUrl?: string;
}
interface ComponentMetaData {
    /**
     * @minLength 1
     * @maxLength 200
     */
    title?: string | null;
    /**
     * @minLength 1
     * @maxLength 200
     */
    description?: string | null;
    /**
     * Searchable keywords
     * @maxSize 100
     */
    keywords?: Keywords[];
    /** Is searchable */
    searchable?: boolean;
}
interface Keywords {
    /** Keyword ID */
    _id?: string;
    /**
     * @minLength 1
     * @maxLength 200
     */
    value?: string;
}
interface PageAnchor {
    /**
     * A URL path relative to the page route for direct navigation to a specific section
     * @minLength 1
     * @maxLength 100
     */
    relativeUrl?: string;
    /**
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
    /** metadata for the page anchor */
    metaData?: AnchorMetaData;
    /**
     * anchor ID
     * @maxLength 50
     */
    _id?: string;
}
interface AnchorMetaData {
    /**
     * @minLength 1
     * @maxLength 200
     */
    title?: string | null;
    /**
     * @minLength 1
     * @maxLength 200
     */
    description?: string | null;
    /**
     * anchor keywords
     * @maxSize 100
     */
    keywords?: Keywords[];
}
interface UrlParam {
    /**
     * The name of the parameter
     * @minLength 1
     * @maxLength 100
     */
    name?: string;
    /**
     * The description of the parameter
     * @minLength 1
     * @maxLength 200
     */
    description?: string;
}
interface AdditionalFeesSPIConfig {
    /**
     * Base URI where the endpoints are called.
     * Wix eCommerce appends the endpoint path to the base URI.
     * For example, to call the Calculate Additional Fees endpoint at `https://my-additional-fees.com/v1/calculateAdditionalFees`,
     * the base URI you provide here is `https://my-additional-fees.com/`.
     */
    deploymentUri?: string;
}
/** Describes a notification that can be sent to users */
interface PingNotificationComponentData {
}
interface BookingsPricingProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /** User-friendly name of the pricing provider */
    pricingProviderName?: string;
}
interface AuthenticatorConfig {
    /** the base URI where all the methods are deployed. */
    baseUri?: string;
    /** Is the enrolment step required (eg. for saving the password, public key, etc.) */
    requireUserEnroll?: boolean;
    /** Information required during the enrollment and authentication processes */
    expectedInputs?: ExpectedInputs;
}
interface ExpectedInputs {
    /** Inputs that will be expected from the user at the start of the process of trying to enroll or authenticate */
    expectedStartInputs?: PredefinedExpectedInput[];
    /** Inputs that may be required during a second step of enroll/authenticate, specified at runtime by sending a Verify response */
    expectedVerifyInputs?: PredefinedExpectedInput[];
}
/**
 * Specifies an expected input that can be fully configured by the SPI implementor, perhaps with overrides by the admin, _before_ runtime.
 * Notably, this does not include WebAuthn, as that input requires a unique, random challenge to be generated and persisted per request (ie at runtime)
 * in order to be implemented correctly.
 */
interface PredefinedExpectedInput {
    /** The key used to identify the value entered into the input in the user_start_inputs or user_verify_inputs map */
    key?: string;
    /** The name of the input as it should be indicated to the user */
    displayName?: string;
    /** The configuration for the input */
    configuration?: PredefinedExpectedInputConfiguration;
}
interface PredefinedExpectedInputConfiguration extends PredefinedExpectedInputConfigurationTypeOneOf {
    textInput?: AdminConfigurableTextInput;
}
/** @oneof */
interface PredefinedExpectedInputConfigurationTypeOneOf {
    textInput?: AdminConfigurableTextInput;
}
interface AdminConfigurableTextInput {
    /** The default settings for the text input */
    defaultSettings?: TextInputSettings;
    /**
     * Settings that must be have non-null values.
     * This must be a subset of admin_configurable_settings.
     */
    requiredSettings?: string[];
    /**
     * Settings that the admin may override.
     * This must be a valid FieldMask with respect to TextFieldSettings as the root object.
     */
    adminConfigurableSettings?: string[];
}
interface TextInputSettings {
    /** The minimum length required for the user to enter */
    minLength?: number | null;
    /** The maximum length allowed for the user to enter */
    maxLength?: number | null;
    /** A regex that the text entered by the user must match */
    regex?: string | null;
    /** How should the field be displayed to the end user */
    displayType?: TextInputDisplayTypeWithLiterals;
}
declare enum TextInputDisplayType {
    /** A regular text field */
    TEXT = "TEXT",
    /** A password field (where the text is hidden visually) */
    PASSWORD = "PASSWORD",
    /** A field optimized for one time codes */
    CODE = "CODE"
}
/** @enumType */
type TextInputDisplayTypeWithLiterals = TextInputDisplayType | 'TEXT' | 'PASSWORD' | 'CODE';
interface IDPConnectionConfig {
    /** the base URI where all the methods are deployed. */
    baseUri?: string;
    /** Information required from the admin when he will install the app; */
    requiredConfig?: Record<string, string>;
}
interface ItemsSelectionProviderConfig {
    /**
     * Base URI which Wix calls to retrieve the selected items. For example, `"deploymentUri": "https://my-items.com"`.
     * @minLength 1
     */
    deploymentUri?: string;
    /**
     * A unique identifier for the provider.
     * @minLength 3
     * @maxLength 250
     */
    key?: string;
    /** Supported search parameters. */
    searchParams?: SearchParams;
    /** Display data such as provider name and icon. */
    contentData?: ContentData;
    /**
     * An array of strings representing the Wix UI pages supported by your SPI implementation. If no tags are listed, Wix assumes that the implementation supports all eligible pages.
     * @maxSize 50
     */
    supportedTags?: TagWithLiterals[];
    /** Configuration settings for how the thumbnail is displayed. */
    itemThumbnail?: ItemThumbnail;
    /** Pagination Mode */
    paginationMode?: PaginationModeWithLiterals;
}
interface LearnMore {
    /**
     * The url of the learn more link. If you want a dynamic url according to the user locale, you can add {{locale}} variable within the string.
     * @maxLength 2048
     */
    url?: string;
    /**
     * Optional link label.
     * @maxLength 500
     */
    label?: string | null;
}
declare enum ThumbnailType {
    UNKNOWN_THUMBNAIL_TYPE = "UNKNOWN_THUMBNAIL_TYPE",
    IMAGE = "IMAGE",
    AVATAR = "AVATAR"
}
/** @enumType */
type ThumbnailTypeWithLiterals = ThumbnailType | 'UNKNOWN_THUMBNAIL_TYPE' | 'IMAGE' | 'AVATAR';
interface ImageConfig {
    shape?: ImageShapeWithLiterals;
}
declare enum ImageShape {
    UNKNOWN_SHAPE = "UNKNOWN_SHAPE",
    /** Circle */
    CIRCLE = "CIRCLE",
    /** Square */
    SQUARE = "SQUARE",
    /** Rectangle */
    RECTANGLE = "RECTANGLE"
}
/** @enumType */
type ImageShapeWithLiterals = ImageShape | 'UNKNOWN_SHAPE' | 'CIRCLE' | 'SQUARE' | 'RECTANGLE';
interface AvatarConfig {
    shape?: AvatarShapeWithLiterals;
}
declare enum AvatarShape {
    UNKNOWN_SHAPE = "UNKNOWN_SHAPE",
    /** Circle */
    CIRCLE = "CIRCLE",
    /** Square */
    SQUARE = "SQUARE"
}
/** @enumType */
type AvatarShapeWithLiterals = AvatarShape | 'UNKNOWN_SHAPE' | 'CIRCLE' | 'SQUARE';
interface SearchField {
    /** Supported searchable fields. */
    key?: string;
    /**
     * Item description.
     * @minLength 1
     * @maxLength 100
     */
    description?: string;
}
interface FilterInfo extends FilterInfoOptionsOneOf {
    /** Static hardcoded options */
    staticOptions?: StaticFilterOptions;
    /** The filter options are items of another provider */
    providerOptions?: ProviderFilterOptions;
    /**
     * Key of the filter
     * @minLength 1
     * @maxLength 100
     */
    key?: string;
    /** Optional filter will be shown only for consumers with this tag. Only one filter is allowed per tag. */
    tag?: TagWithLiterals;
    /** The filter selection type. */
    selectionType?: FilterSelectionTypeWithLiterals;
    /** Filter options type. For now only static options are supported */
    optionsType?: FilterOptionsTypeWithLiterals;
    /**
     * Optional placeholder text to display on the filter
     * @maxLength 500
     */
    placeholder?: string | null;
}
/** @oneof */
interface FilterInfoOptionsOneOf {
    /** Static hardcoded options */
    staticOptions?: StaticFilterOptions;
    /** The filter options are items of another provider */
    providerOptions?: ProviderFilterOptions;
}
declare enum Tag {
    UNKNOWN_TAG = "UNKNOWN_TAG",
    EMBEDDABLE = "EMBEDDABLE",
    ECOM_EDIT_ORDER = "ECOM_EDIT_ORDER",
    ECOM_CREATE_ORDER = "ECOM_CREATE_ORDER",
    INBOX = "INBOX",
    ECOM_CREATE_PAY_LINK = "ECOM_CREATE_PAY_LINK",
    ECOM_DELIVERY_PROFILES = "ECOM_DELIVERY_PROFILES",
    ADD_TO_CATEGORY = "ADD_TO_CATEGORY"
}
/** @enumType */
type TagWithLiterals = Tag | 'UNKNOWN_TAG' | 'EMBEDDABLE' | 'ECOM_EDIT_ORDER' | 'ECOM_CREATE_ORDER' | 'INBOX' | 'ECOM_CREATE_PAY_LINK' | 'ECOM_DELIVERY_PROFILES' | 'ADD_TO_CATEGORY';
declare enum FilterSelectionType {
    UNKNOWN_SELECTION = "UNKNOWN_SELECTION",
    /** Allow to select only a single item */
    SINGLE_SELECTION = "SINGLE_SELECTION",
    /** Allow to select multiple items */
    MULTIPLE_SELECTION = "MULTIPLE_SELECTION"
}
/** @enumType */
type FilterSelectionTypeWithLiterals = FilterSelectionType | 'UNKNOWN_SELECTION' | 'SINGLE_SELECTION' | 'MULTIPLE_SELECTION';
declare enum FilterOptionsType {
    UNKNOWN_FILTER_OPTIONS = "UNKNOWN_FILTER_OPTIONS",
    /** Static hardcoded options */
    STATIC = "STATIC",
    PROVIDER = "PROVIDER"
}
/** @enumType */
type FilterOptionsTypeWithLiterals = FilterOptionsType | 'UNKNOWN_FILTER_OPTIONS' | 'STATIC' | 'PROVIDER';
interface StaticFilterOptions {
    /**
     * List of hardcoded options for a filter
     * @maxSize 50
     */
    data?: StaticFilterOption[];
}
interface StaticFilterOption {
    /**
     * Title of a filter option
     * @minLength 1
     * @maxLength 500
     */
    label?: string;
    /**
     * Value of a filter option
     * @minLength 1
     * @maxLength 100
     */
    value?: string;
}
interface ProviderFilterOptions {
    /**
     * Provider identifier for fetching filter options
     * @minLength 3
     * @maxLength 250
     */
    key?: string;
}
interface SearchParams {
    /**
     * Supported search parameters.
     * @maxSize 50
     */
    fields?: SearchField[];
    /**
     * Filters for viewing only part of the items. Maximum one filter per tag.
     * @maxSize 100
     */
    filters?: FilterInfo[];
}
interface ContentData {
    /**
     * Provider icon. Choose an icon name from the [Wix Design System](https://www.wixdesignsystem.com/).
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
    /**
     * Provider name.
     * @minLength 1
     * @maxLength 100
     */
    providerName?: string;
    /**
     * Item title.
     * @minLength 1
     * @maxLength 100
     */
    title?: string;
    /**
     * Button label.
     * @minLength 1
     * @maxLength 50
     */
    button?: string;
    /**
     * Item description.
     * @minLength 1
     * @maxLength 100
     */
    subtitle?: string | null;
    /** Learn more link. */
    learnMore?: LearnMore;
}
interface AdditionalStepInfo {
    /** ID of the widget associated with the step. */
    widgetId?: string;
    /**
     * Title of the additional step.
     * @minLength 1
     * @maxLength 100
     */
    title?: string;
    /**
     * Subtitle of the additional step.
     * @maxLength 100
     */
    subtitle?: string | null;
    /** Hide item note if exists when showing selected item on additional step header, default: false. */
    hideItemNote?: boolean | null;
}
interface CreateNewItemInfo {
    /** ID of the widget associated with the new item modal. */
    widgetId?: string;
    /**
     * Button label for creating a new item
     * @minLength 1
     * @maxLength 50
     */
    buttonText?: string | null;
}
interface ItemThumbnail extends ItemThumbnailOptionsOneOf {
    /** Configuration specific to images. */
    imageConfig?: ImageConfig;
    /** Configuration specific to avatars. */
    avatarConfig?: AvatarConfig;
    /** Thumbnail type */
    type?: ThumbnailTypeWithLiterals;
    /** Whether the thumbnail is hidden from the UI. */
    hidden?: boolean | null;
}
/** @oneof */
interface ItemThumbnailOptionsOneOf {
    /** Configuration specific to images. */
    imageConfig?: ImageConfig;
    /** Configuration specific to avatars. */
    avatarConfig?: AvatarConfig;
}
declare enum PaginationMode {
    UNKNOWN_PAGINATION_MODE = "UNKNOWN_PAGINATION_MODE",
    CURSOR = "CURSOR",
    OFFSET = "OFFSET"
}
/** @enumType */
type PaginationModeWithLiterals = PaginationMode | 'UNKNOWN_PAGINATION_MODE' | 'CURSOR' | 'OFFSET';
interface SyncedProjectsProviderConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: string;
    /**
     * The Provider Name
     * @maxLength 200
     */
    providerName?: string;
    /** which project's fields are synced by the provider, and therefore will not be editable through wix portfolio project page. */
    projectSyncedFields?: string[];
}
interface CommunicationChannelConfiguration {
    deploymentUri?: string;
    config?: ChannelConfiguration;
}
interface ChannelConfiguration extends ChannelConfigurationMessagingConfigOneOf {
    directMessageConfig?: DirectMessageConfig;
    emailMessageConfig?: EmailMessageConfig;
    smsMessageConfig?: SmsMessageConfig;
    /** The type of the communication channel */
    type?: ChannelTypeWithLiterals;
    /** Specific provider branding parameters for the channel */
    branding?: ChannelBranding;
    /** Conversation initiation definition */
    conversationLimitations?: ConversationLimitations;
}
/** @oneof */
interface ChannelConfigurationMessagingConfigOneOf {
    directMessageConfig?: DirectMessageConfig;
    emailMessageConfig?: EmailMessageConfig;
    smsMessageConfig?: SmsMessageConfig;
}
/** The type of the communication channel */
declare enum ChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    DIRECT_MESSAGING = "DIRECT_MESSAGING",
    EMAIL = "EMAIL",
    SMS = "SMS"
}
/** @enumType */
type ChannelTypeWithLiterals = ChannelType | 'UNKNOWN_CHANNEL_TYPE' | 'DIRECT_MESSAGING' | 'EMAIL' | 'SMS';
interface DirectMessageConfig {
    /** When marked as true, there's no need to list the supported types explicitly */
    acceptAllMessageTypes?: boolean;
    /**
     * Direct message types accepted by the provider. only those types will be sent from Wix
     * If all are excepted this field can be left empty and there's no need to explicitly state types
     */
    acceptedMessageTypes?: AcceptedDirectMessageTypeWithLiterals[];
    /** Elaborates what media types (mime types) and sizes are supported */
    mediaCapabilities?: MediaCapabilities;
}
declare enum AcceptedDirectMessageType {
    TEXT = "TEXT",
    MEDIA = "MEDIA",
    CARD = "CARD",
    ANNOUNCEMENT = "ANNOUNCEMENT",
    FORM = "FORM"
}
/** @enumType */
type AcceptedDirectMessageTypeWithLiterals = AcceptedDirectMessageType | 'TEXT' | 'MEDIA' | 'CARD' | 'ANNOUNCEMENT' | 'FORM';
interface MediaCapabilities {
    /** When marked as true, there's no need to list the supported types explicitly */
    allMediaTypes?: boolean;
    /**
     * List for supported media types
     * If all are excepted this field can be left empty and there's no need to explicitly state types
     * @maxSize 50
     */
    supportedMediaTypes?: MediaMimeTypeWithLiterals[];
    /** Maximum file size in bytes of a single file in a message */
    maxFileSizeInBytes?: number | null;
}
/** Mime type for relevant media entities in channels */
declare enum MediaMimeType {
    UNKNOWN_MIME_TYPE = "UNKNOWN_MIME_TYPE",
    IMAGE_JPEG = "IMAGE_JPEG",
    IMAGE_PNG = "IMAGE_PNG",
    IMAGE_WEBP = "IMAGE_WEBP",
    VIDEO_MPEG = "VIDEO_MPEG",
    VIDEO_MP4 = "VIDEO_MP4",
    VIDEO_3GP = "VIDEO_3GP",
    AUDIO_AAC = "AUDIO_AAC",
    AUDIO_MP4 = "AUDIO_MP4",
    AUDIO_MPEG = "AUDIO_MPEG",
    AUDIO_OGG = "AUDIO_OGG",
    AUDIO_OPUS = "AUDIO_OPUS",
    APPLICATION_PDF = "APPLICATION_PDF",
    APPLICATION_OCTET_STREAM = "APPLICATION_OCTET_STREAM"
}
/** @enumType */
type MediaMimeTypeWithLiterals = MediaMimeType | 'UNKNOWN_MIME_TYPE' | 'IMAGE_JPEG' | 'IMAGE_PNG' | 'IMAGE_WEBP' | 'VIDEO_MPEG' | 'VIDEO_MP4' | 'VIDEO_3GP' | 'AUDIO_AAC' | 'AUDIO_MP4' | 'AUDIO_MPEG' | 'AUDIO_OGG' | 'AUDIO_OPUS' | 'APPLICATION_PDF' | 'APPLICATION_OCTET_STREAM';
interface EmailMessageConfig {
    /** Media (Attachment) types accepted by the provider */
    mediaCapabilities?: MediaCapabilities;
    /** Maximum size in bytes of total media items in a message. */
    maxTotalFilesSizeInBytes?: number | null;
}
interface SmsMessageConfig {
    /** When marked as true, there's no need to list the supported types explicitly */
    acceptAllMessageTypes?: boolean;
    /** SMS message types accepted by the provider. only those types will be sent from Wix */
    acceptedMessageTypes?: AcceptedSmsMessageTypeWithLiterals[];
    /** Elaborates what media types (mime types) and sizes are supported */
    mediaCapabilities?: MediaCapabilities;
}
declare enum AcceptedSmsMessageType {
    SMS = "SMS",
    MMS = "MMS"
}
/** @enumType */
type AcceptedSmsMessageTypeWithLiterals = AcceptedSmsMessageType | 'SMS' | 'MMS';
interface ChannelBranding {
    /** The name of the channel, e.g. `Facebook` / `SMS` */
    displayName?: string;
    /** Name of the channel provider (Wix, Meta, Google) */
    providerName?: string | null;
    /** Relevant brand icons, used when the channel is integrated */
    brandIcons?: BrandIcons;
}
/**
 * Brand icons required for correct channel integration
 * todo: 1. which ones are required ?
 * todo: 2. we may need to specify Icons specs (i.e. format and sizes)
 */
interface BrandIcons {
    default?: ChannelIcon;
    vector?: ChannelIcon;
    bwOutlineVector?: ChannelIcon;
}
interface ChannelIcon {
    /** Specific Icon url */
    url?: string | null;
}
interface ConversationLimitations {
    /**
     * Defines who can initiate conversation in this channel.
     * If, `CUSTOMER` is selected, this means that only inbound
     * messages can start a conversation (aka business can only reply and not initiate the first communication).
     */
    initDirection?: InitDirectionWithLiterals;
}
declare enum InitDirection {
    UNKNOWN_INIT_DIRECTION = "UNKNOWN_INIT_DIRECTION",
    BUSINESS = "BUSINESS",
    CUSTOMER = "CUSTOMER",
    BOTH = "BOTH"
}
/** @enumType */
type InitDirectionWithLiterals = InitDirection | 'UNKNOWN_INIT_DIRECTION' | 'BUSINESS' | 'CUSTOMER' | 'BOTH';
interface PostLoginConfig {
    /** the base URI where all the methods are deployed. */
    baseUri?: string;
}
/** A general widget in one of the back-office platforms */
interface BackOfficeWidget extends BackOfficeWidgetContentOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
    /**
     * Widget title.
     * @minLength 1
     */
    title?: string;
    /**
     * Initial width of the widget while loading, in pixels.
     * Width may be adjusted dynamically based on the content of the widget or limited by the size of the widget's container.
     * @max 9999
     */
    width?: number | null;
    /**
     * Initial height of the widget while loading, in pixels.
     * Height may be adjusted dynamically based on the content of the widget or limited by the size of the widget's container.
     * @max 9999
     */
    height?: number | null;
}
/** @oneof */
interface BackOfficeWidgetContentOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
}
interface SocialMarketingDesignSPIConfig {
    /** The URL of the SPI implementation */
    baseUri?: string;
    /** ID of the provider */
    _id?: string;
    /** Name of the provider */
    name?: string;
    /**
     * URL of the editor
     * @format WEB_URL
     */
    editorUrl?: string;
    /**
     * URL of the templates page
     * @format WEB_URL
     */
    templatesPageUrl?: string;
    /**
     * Provider's icon, to be displayed in UI
     * @format WEB_URL
     */
    iconUrl?: string;
}
interface FormSubmissionSpiConfig {
    /**
     * URI where the SPI Implementer is deployed
     * @maxLength 500
     */
    deploymentUri?: string;
    /**
     * Configuration of namespaces known by implementer
     * @maxSize 3
     */
    namespaceConfigs?: FormsSubmissionsNamespaceConfig[];
}
interface FormsSubmissionsNamespaceConfig {
    /**
     * Namespace name.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /** Permissions associated with this namespace. */
    permissions?: FormsPermissions;
    /** Mark new submission as pending by default. */
    pendingByDefault?: boolean;
    /**
     * Allows to disable automatic contact insert/update on contact mapping provided.
     * On manual contact mapping enabled, the implementer is responsible for mapping the submission to a contact.
     * Out of the box GDPR support is not available for unmapped submissions with contact PII fields.
     */
    manualContactMapping?: boolean;
    /**
     * Delete a PENDING submission after X days.
     * @min 1
     */
    deletePendingAfterDays?: number | null;
}
interface FormsPermissions {
    /**
     * Create permission name
     * @maxLength 60
     */
    create?: string;
    /**
     * Delete permission name
     * @maxLength 60
     */
    delete?: string;
    /**
     * Update permission name
     * @maxLength 60
     */
    update?: string;
    /**
     * Read permission name
     * @maxLength 60
     */
    read?: string;
}
/** Redirects to either a page component in the Business Manager or to a wix answers article */
interface WixOfferingComponentData extends WixOfferingComponentDataOfferingOneOf {
    /** Redirects to a page in the Business Manager. */
    businessManagerPage?: BusinessManagerPage;
    /**
     * Redirects to an article with this ID.
     * @format GUID
     */
    articleGuid?: string;
}
/** @oneof */
interface WixOfferingComponentDataOfferingOneOf {
    /** Redirects to a page in the Business Manager. */
    businessManagerPage?: BusinessManagerPage;
    /**
     * Redirects to an article with this ID.
     * @format GUID
     */
    articleGuid?: string;
}
interface BusinessManagerPage {
    /** ID of the page component to redirect to. */
    componentId?: string;
    /** Redirects to this app state. */
    appState?: string | null;
    /** Whether to show the regular app page in the App Market instead of redirecting to the Business Manager page. */
    showRegularAppPage?: boolean;
}
/** A component used for testing dev center functionality */
interface DevCenterTestingComponentData extends DevCenterTestingComponentDataTranslatableOneOfOneOf {
    translatableString?: string;
    translatableOptionalString?: string | null;
    translatableMessageInOneOf?: MessageContainingTranslatables;
    /** Non translatable field */
    nonTranslatable?: string;
    name?: string;
    /** @maxLength 500 */
    description?: string | null;
    translationsMap?: Record<string, string>;
    translatableMessage?: MessageContainingTranslatables;
    /** @maxSize 500 */
    mapOfTranslatableMessages?: Record<string, MessageContainingTranslatables>;
    baseUri?: string;
    /** @format GUID */
    referenceId?: string | null;
    referenceData?: CustomRefData;
    priceMultiplier?: number;
    responsePrefix?: string;
    /** @maxSize 500 */
    translatedMessagesWithUniqueField?: TranslatedMessageWithUniqueFieldRepeated[];
    /** @maxSize 500 */
    translatedMessagesWithIdField?: TranslatedMessageWithIdRepeated[];
    componentMetadata?: DiscoveryMetaData;
    /** @maxSize 500 */
    repeatedComponentMetadata?: DiscoveryMetaData[];
    /** @maxSize 500 */
    repeatedInternalComponentMetadata?: InternalComponentMetadata[];
    translatableRichContent?: RichContent;
    nonTranslatableRichContent?: RichContent;
    richContentMap?: Record<string, RichContent>;
    exposure?: ExtensionExposure;
    /**
     * @maxSize 500
     * @maxLength 500
     */
    referencedEntity?: string[];
}
/** @oneof */
interface DevCenterTestingComponentDataTranslatableOneOfOneOf {
    translatableString?: string;
    translatableOptionalString?: string | null;
    translatableMessageInOneOf?: MessageContainingTranslatables;
}
interface MessageContainingTranslatables {
    messageName?: string;
    messageDescription?: string | null;
    messageTranslationsMap?: Record<string, string>;
    innerTranslatableRichContent?: RichContent;
}
interface RichContent {
    /** Node objects representing a rich content document. */
    nodes?: Node[];
    /** Object metadata. */
    metadata?: V1Metadata;
    /** Global styling for header, paragraph, block quote, and code block nodes in the object. */
    documentStyle?: DocumentStyle;
}
interface Node extends NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
    /** Node type. Use `APP_EMBED` for nodes that embed content from other Wix apps. Use `EMBED` to embed content in [oEmbed](https://oembed.com/) format. */
    type?: NodeTypeWithLiterals;
    /** Node ID. */
    id?: string;
    /** A list of child nodes. */
    nodes?: Node[];
    /** Padding and background color styling for the node. */
    style?: NodeStyle;
}
/** @oneof */
interface NodeDataOneOf {
    /** Data for a button node. */
    buttonData?: ButtonData;
    /** Data for a code block node. */
    codeBlockData?: CodeBlockData;
    /** Data for a divider node. */
    dividerData?: DividerData;
    /** Data for a file node. */
    fileData?: FileData;
    /** Data for a gallery node. */
    galleryData?: GalleryData;
    /** Data for a GIF node. */
    gifData?: GIFData;
    /** Data for a heading node. */
    headingData?: HeadingData;
    /** Data for an embedded HTML node. */
    htmlData?: HTMLData;
    /** Data for an image node. */
    imageData?: ImageData;
    /** Data for a link preview node. */
    linkPreviewData?: LinkPreviewData;
    /** @deprecated */
    mapData?: MapData;
    /** Data for a paragraph node. */
    paragraphData?: ParagraphData;
    /** Data for a poll node. */
    pollData?: PollData;
    /** Data for a text node. Used to apply decorations to text. */
    textData?: TextData;
    /** Data for an app embed node. */
    appEmbedData?: AppEmbedData;
    /** Data for a video node. */
    videoData?: VideoData;
    /** Data for an oEmbed node. */
    embedData?: EmbedData;
    /** Data for a collapsible list node. */
    collapsibleListData?: CollapsibleListData;
    /** Data for a table node. */
    tableData?: TableData;
    /** Data for a table cell node. */
    tableCellData?: TableCellData;
    /** Data for a custom external node. */
    externalData?: Record<string, any> | null;
    /** Data for an audio node. */
    audioData?: AudioData;
    /** Data for an ordered list node. */
    orderedListData?: OrderedListData;
    /** Data for a bulleted list node. */
    bulletedListData?: BulletedListData;
    /** Data for a block quote node. */
    blockquoteData?: BlockquoteData;
    /** Data for a caption node. */
    captionData?: CaptionData;
    /** LayoutData layout_data = 31; // Data for a layout node. Reserved for future use. */
    layoutCellData?: LayoutCellData;
}
declare enum NodeType {
    PARAGRAPH = "PARAGRAPH",
    TEXT = "TEXT",
    HEADING = "HEADING",
    BULLETED_LIST = "BULLETED_LIST",
    ORDERED_LIST = "ORDERED_LIST",
    LIST_ITEM = "LIST_ITEM",
    BLOCKQUOTE = "BLOCKQUOTE",
    CODE_BLOCK = "CODE_BLOCK",
    VIDEO = "VIDEO",
    DIVIDER = "DIVIDER",
    FILE = "FILE",
    GALLERY = "GALLERY",
    GIF = "GIF",
    HTML = "HTML",
    IMAGE = "IMAGE",
    LINK_PREVIEW = "LINK_PREVIEW",
    /** @deprecated */
    MAP = "MAP",
    POLL = "POLL",
    APP_EMBED = "APP_EMBED",
    BUTTON = "BUTTON",
    COLLAPSIBLE_LIST = "COLLAPSIBLE_LIST",
    TABLE = "TABLE",
    EMBED = "EMBED",
    COLLAPSIBLE_ITEM = "COLLAPSIBLE_ITEM",
    COLLAPSIBLE_ITEM_TITLE = "COLLAPSIBLE_ITEM_TITLE",
    COLLAPSIBLE_ITEM_BODY = "COLLAPSIBLE_ITEM_BODY",
    TABLE_CELL = "TABLE_CELL",
    TABLE_ROW = "TABLE_ROW",
    EXTERNAL = "EXTERNAL",
    AUDIO = "AUDIO",
    CAPTION = "CAPTION",
    LAYOUT = "LAYOUT",
    LAYOUT_CELL = "LAYOUT_CELL"
}
/** @enumType */
type NodeTypeWithLiterals = NodeType | 'PARAGRAPH' | 'TEXT' | 'HEADING' | 'BULLETED_LIST' | 'ORDERED_LIST' | 'LIST_ITEM' | 'BLOCKQUOTE' | 'CODE_BLOCK' | 'VIDEO' | 'DIVIDER' | 'FILE' | 'GALLERY' | 'GIF' | 'HTML' | 'IMAGE' | 'LINK_PREVIEW' | 'MAP' | 'POLL' | 'APP_EMBED' | 'BUTTON' | 'COLLAPSIBLE_LIST' | 'TABLE' | 'EMBED' | 'COLLAPSIBLE_ITEM' | 'COLLAPSIBLE_ITEM_TITLE' | 'COLLAPSIBLE_ITEM_BODY' | 'TABLE_CELL' | 'TABLE_ROW' | 'EXTERNAL' | 'AUDIO' | 'CAPTION' | 'LAYOUT' | 'LAYOUT_CELL';
interface NodeStyle {
    /** The top padding value in pixels. */
    paddingTop?: string | null;
    /** The bottom padding value in pixels. */
    paddingBottom?: string | null;
    /** The background color as a hexadecimal value. */
    backgroundColor?: string | null;
}
interface ButtonData {
    /** Styling for the button's container. */
    containerData?: PluginContainerData;
    /** The button type. */
    type?: ButtonDataTypeWithLiterals;
    /** Styling for the button. */
    styles?: Styles;
    /** The text to display on the button. */
    text?: string | null;
    /** Button link details. */
    link?: V1Link;
}
interface Border {
    /**
     * Deprecated: Use `borderWidth` in `styles` instead.
     * @deprecated
     */
    width?: number | null;
    /**
     * Deprecated: Use `borderRadius` in `styles` instead.
     * @deprecated
     */
    radius?: number | null;
}
interface Colors {
    /**
     * Deprecated: Use `textColor` in `styles` instead.
     * @deprecated
     */
    text?: string | null;
    /**
     * Deprecated: Use `borderColor` in `styles` instead.
     * @deprecated
     */
    border?: string | null;
    /**
     * Deprecated: Use `backgroundColor` in `styles` instead.
     * @deprecated
     */
    background?: string | null;
}
interface PluginContainerData {
    /** The width of the node when it's displayed. */
    width?: PluginContainerDataWidth;
    /** The node's alignment within its container. */
    alignment?: PluginContainerDataAlignmentWithLiterals;
    /** Spoiler cover settings for the node. */
    spoiler?: Spoiler;
    /** The height of the node when it's displayed. */
    height?: PluginContainerDataHeight;
    /** Sets whether text should wrap around this node when it's displayed. If `textWrap` is `false`, the node takes up the width of its container. Defaults to `true` for all node types except 'DIVIVDER' where it defaults to `false`. */
    textWrap?: boolean | null;
}
declare enum WidthType {
    /** Width matches the content width */
    CONTENT = "CONTENT",
    /** Small Width */
    SMALL = "SMALL",
    /** Width will match the original asset width */
    ORIGINAL = "ORIGINAL",
    /** coast-to-coast display */
    FULL_WIDTH = "FULL_WIDTH"
}
/** @enumType */
type WidthTypeWithLiterals = WidthType | 'CONTENT' | 'SMALL' | 'ORIGINAL' | 'FULL_WIDTH';
interface PluginContainerDataWidth extends PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
/** @oneof */
interface PluginContainerDataWidthDataOneOf {
    /**
     * One of the following predefined width options:
     * `CONTENT`: The width of the container matches the content width.
     * `SMALL`: A small width.
     * `ORIGINAL`: For `imageData` containers only. The width of the container matches the original image width.
     * `FULL_WIDTH`: For `imageData` containers only. The image container takes up the full width of the screen.
     */
    size?: WidthTypeWithLiterals;
    /** A custom width value in pixels. */
    custom?: string | null;
}
declare enum PluginContainerDataAlignment {
    /** Center Alignment */
    CENTER = "CENTER",
    /** Left Alignment */
    LEFT = "LEFT",
    /** Right Alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type PluginContainerDataAlignmentWithLiterals = PluginContainerDataAlignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface Spoiler {
    /** Sets whether the spoiler cover is enabled for this node. Defaults to `false`. */
    enabled?: boolean | null;
    /** The description displayed on top of the spoiler cover. */
    description?: string | null;
    /** The text for the button used to remove the spoiler cover. */
    buttonText?: string | null;
}
interface PluginContainerDataHeight {
    /** A custom height value in pixels. */
    custom?: string | null;
}
declare enum ButtonDataType {
    /** Regular link button */
    LINK = "LINK",
    /** Triggers custom action that is defined in plugin configuration by the consumer */
    ACTION = "ACTION"
}
/** @enumType */
type ButtonDataTypeWithLiterals = ButtonDataType | 'LINK' | 'ACTION';
interface Styles {
    /**
     * Deprecated: Use `borderWidth` and `borderRadius` instead.
     * @deprecated
     */
    border?: Border;
    /**
     * Deprecated: Use `textColor`, `borderColor` and `backgroundColor` instead.
     * @deprecated
     */
    colors?: Colors;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /**
     * Deprecated: Use `borderWidth` for normal/hover states instead.
     * @deprecated
     */
    borderWidthHover?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /**
     * Border color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    borderColorHover?: string | null;
    /**
     * Text color as a hexadecimal value.
     * @format COLOR_HEX
     */
    textColor?: string | null;
    /**
     * Text color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    textColorHover?: string | null;
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Background color as a hexadecimal value (hover state).
     * @format COLOR_HEX
     */
    backgroundColorHover?: string | null;
    /** Button size option, one of `SMALL`, `MEDIUM` or `LARGE`. Defaults to `MEDIUM`. */
    buttonSize?: string | null;
}
interface V1Link extends V1LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
    /**
     * he HTML `target` attribute value for the link. This property defines where the linked document opens as follows:
     * `SELF` - Default. Opens the linked document in the same frame as the link.
     * `BLANK` - Opens the linked document in a new browser tab or window.
     * `PARENT` - Opens the linked document in the link's parent frame.
     * `TOP` - Opens the linked document in the full body of the link's browser tab or window.
     */
    target?: LinkTargetWithLiterals;
    /** The HTML `rel` attribute value for the link. This object specifies the relationship between the current document and the linked document. */
    rel?: Rel;
    /** A serialized object used for a custom or external link panel. */
    customData?: string | null;
}
/** @oneof */
interface V1LinkDataOneOf {
    /** The absolute URL for the linked document. */
    url?: string;
    /** The target node's ID. Used for linking to another node in this object. */
    anchor?: string;
}
declare enum LinkTarget {
    /** Opens the linked document in the same frame as it was clicked (this is default) */
    SELF = "SELF",
    /** Opens the linked document in a new window or tab */
    BLANK = "BLANK",
    /** Opens the linked document in the parent frame */
    PARENT = "PARENT",
    /** Opens the linked document in the full body of the window */
    TOP = "TOP"
}
/** @enumType */
type LinkTargetWithLiterals = LinkTarget | 'SELF' | 'BLANK' | 'PARENT' | 'TOP';
interface Rel {
    /** Indicates to search engine crawlers not to follow the link. Defaults to `false`. */
    nofollow?: boolean | null;
    /** Indicates to search engine crawlers that the link is a paid placement such as sponsored content or an advertisement. Defaults to `false`. */
    sponsored?: boolean | null;
    /** Indicates that this link is user-generated content and isn't necessarily trusted or endorsed by the page’s author. For example, a link in a fourm post. Defaults to `false`. */
    ugc?: boolean | null;
    /** Indicates that this link protect referral information from being passed to the target website. */
    noreferrer?: boolean | null;
}
interface CodeBlockData {
    /** Styling for the code block's text. */
    textStyle?: V1TextStyle;
}
interface V1TextStyle {
    /** Text alignment. Defaults to `AUTO`. */
    textAlignment?: TextAlignmentWithLiterals;
    /** A CSS `line-height` value for the text expressed as a ratio relative to the font size. For example, if the font size is 20px, a `lineHeight` value of `'1.5'`` results in a line height of 30px. */
    lineHeight?: string | null;
}
declare enum TextAlignment {
    /** browser default, eqivalent to `initial` */
    AUTO = "AUTO",
    /** Left align */
    LEFT = "LEFT",
    /** Right align */
    RIGHT = "RIGHT",
    /** Center align */
    CENTER = "CENTER",
    /** Text is spaced to line up its left and right edges to the left and right edges of the line box, except for the last line */
    JUSTIFY = "JUSTIFY"
}
/** @enumType */
type TextAlignmentWithLiterals = TextAlignment | 'AUTO' | 'LEFT' | 'RIGHT' | 'CENTER' | 'JUSTIFY';
interface DividerData {
    /** Styling for the divider's container. */
    containerData?: PluginContainerData;
    /** Divider line style. */
    lineStyle?: LineStyleWithLiterals;
    /** Divider width. */
    width?: DividerDataWidthWithLiterals;
    /** Divider alignment. */
    alignment?: AlignmentWithLiterals;
}
declare enum LineStyle {
    /** Single Line */
    SINGLE = "SINGLE",
    /** Double Line */
    DOUBLE = "DOUBLE",
    /** Dashed Line */
    DASHED = "DASHED",
    /** Dotted Line */
    DOTTED = "DOTTED"
}
/** @enumType */
type LineStyleWithLiterals = LineStyle | 'SINGLE' | 'DOUBLE' | 'DASHED' | 'DOTTED';
declare enum DividerDataWidth {
    /** Large line */
    LARGE = "LARGE",
    /** Medium line */
    MEDIUM = "MEDIUM",
    /** Small line */
    SMALL = "SMALL"
}
/** @enumType */
type DividerDataWidthWithLiterals = DividerDataWidth | 'LARGE' | 'MEDIUM' | 'SMALL';
declare enum Alignment {
    /** Center alignment */
    CENTER = "CENTER",
    /** Left alignment */
    LEFT = "LEFT",
    /** Right alignment */
    RIGHT = "RIGHT"
}
/** @enumType */
type AlignmentWithLiterals = Alignment | 'CENTER' | 'LEFT' | 'RIGHT';
interface FileData {
    /** Styling for the file's container. */
    containerData?: PluginContainerData;
    /** The source for the file's data. */
    src?: FileSource;
    /** File name. */
    name?: string | null;
    /** File type. */
    type?: string | null;
    /**
     * Use `sizeInKb` instead.
     * @deprecated
     */
    size?: number | null;
    /** Settings for PDF files. */
    pdfSettings?: PDFSettings;
    /** File MIME type. */
    mimeType?: string | null;
    /** File path. */
    path?: string | null;
    /** File size in KB. */
    sizeInKb?: string | null;
}
declare enum PDFSettingsViewMode {
    /** No PDF view */
    NONE = "NONE",
    /** Full PDF view */
    FULL = "FULL",
    /** Mini PDF view */
    MINI = "MINI"
}
/** @enumType */
type PDFSettingsViewModeWithLiterals = PDFSettingsViewMode | 'NONE' | 'FULL' | 'MINI';
interface FileSource extends FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
    /** Indicates whether the file's source is private. Defaults to `false`. */
    private?: boolean | null;
}
/** @oneof */
interface FileSourceDataOneOf {
    /** The absolute URL for the file's source. */
    url?: string | null;
    /**
     * Custom ID. Use `id` instead.
     * @deprecated
     */
    custom?: string | null;
    /** An ID that's resolved to a URL by a resolver function. */
    id?: string | null;
}
interface PDFSettings {
    /**
     * PDF view mode. One of the following:
     * `NONE` : The PDF isn't displayed.
     * `FULL` : A full page view of the PDF is displayed.
     * `MINI` : A mini view of the PDF is displayed.
     */
    viewMode?: PDFSettingsViewModeWithLiterals;
    /** Sets whether the PDF download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the PDF print button is disabled. Defaults to `false`. */
    disablePrint?: boolean | null;
}
interface GalleryData {
    /** Styling for the gallery's container. */
    containerData?: PluginContainerData;
    /** The items in the gallery. */
    items?: Item[];
    /** Options for defining the gallery's appearance. */
    options?: GalleryOptions;
    /** Sets whether the gallery's expand button is disabled. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Sets whether the gallery's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
}
interface Media {
    /** The source for the media's data. */
    src?: FileSource;
    /** Media width in pixels. */
    width?: number | null;
    /** Media height in pixels. */
    height?: number | null;
    /** Media duration in seconds. Only relevant for audio and video files. */
    duration?: number | null;
}
interface ItemImage {
    /** Image file details. */
    media?: Media;
    /** Link details for images that are links. */
    link?: V1Link;
}
interface Video {
    /** Video file details. */
    media?: Media;
    /** Video thumbnail file details. */
    thumbnail?: Media;
}
interface Item extends ItemDataOneOf {
    /** An image item. */
    image?: ItemImage;
    /** A video item. */
    video?: Video;
    /** Item title. */
    title?: string | null;
    /** Item's alternative text. */
    altText?: string | null;
}
/** @oneof */
interface ItemDataOneOf {
    /** An image item. */
    image?: ItemImage;
    /** A video item. */
    video?: Video;
}
interface GalleryOptions {
    /** Gallery layout. */
    layout?: Layout;
    /** Styling for gallery items. */
    item?: ItemStyle;
    /** Styling for gallery thumbnail images. */
    thumbnails?: GalleryOptionsThumbnails;
}
declare enum LayoutType {
    /** Collage type */
    COLLAGE = "COLLAGE",
    /** Masonry type */
    MASONRY = "MASONRY",
    /** Grid type */
    GRID = "GRID",
    /** Thumbnail type */
    THUMBNAIL = "THUMBNAIL",
    /** Slider type */
    SLIDER = "SLIDER",
    /** Slideshow type */
    SLIDESHOW = "SLIDESHOW",
    /** Panorama type */
    PANORAMA = "PANORAMA",
    /** Column type */
    COLUMN = "COLUMN",
    /** Magic type */
    MAGIC = "MAGIC",
    /** Fullsize images type */
    FULLSIZE = "FULLSIZE"
}
/** @enumType */
type LayoutTypeWithLiterals = LayoutType | 'COLLAGE' | 'MASONRY' | 'GRID' | 'THUMBNAIL' | 'SLIDER' | 'SLIDESHOW' | 'PANORAMA' | 'COLUMN' | 'MAGIC' | 'FULLSIZE';
declare enum Orientation {
    /** Rows Orientation */
    ROWS = "ROWS",
    /** Columns Orientation */
    COLUMNS = "COLUMNS"
}
/** @enumType */
type OrientationWithLiterals = Orientation | 'ROWS' | 'COLUMNS';
declare enum Crop {
    /** Crop to fill */
    FILL = "FILL",
    /** Crop to fit */
    FIT = "FIT"
}
/** @enumType */
type CropWithLiterals = Crop | 'FILL' | 'FIT';
declare enum ThumbnailsAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Right alignment */
    RIGHT = "RIGHT",
    /** Bottom alignment */
    BOTTOM = "BOTTOM",
    /** Left alignment */
    LEFT = "LEFT",
    /** No thumbnail */
    NONE = "NONE"
}
/** @enumType */
type ThumbnailsAlignmentWithLiterals = ThumbnailsAlignment | 'TOP' | 'RIGHT' | 'BOTTOM' | 'LEFT' | 'NONE';
interface Layout {
    /** Gallery layout type. */
    type?: LayoutTypeWithLiterals;
    /** Sets whether horizontal scroll is enabled. Defaults to `true` unless the layout `type` is set to `GRID` or `COLLAGE`. */
    horizontalScroll?: boolean | null;
    /** Gallery orientation. */
    orientation?: OrientationWithLiterals;
    /** The number of columns to display on full size screens. */
    numberOfColumns?: number | null;
    /** The number of columns to display on mobile screens. */
    mobileNumberOfColumns?: number | null;
}
interface ItemStyle {
    /** Desirable dimension for each item in pixels (behvaior changes according to gallery type) */
    targetSize?: number | null;
    /** Item ratio */
    ratio?: number | null;
    /** Sets how item images are cropped. */
    crop?: CropWithLiterals;
    /** The spacing between items in pixels. */
    spacing?: number | null;
}
interface GalleryOptionsThumbnails {
    /** Thumbnail alignment. */
    placement?: ThumbnailsAlignmentWithLiterals;
    /** Spacing between thumbnails in pixels. */
    spacing?: number | null;
}
interface GIFData {
    /** Styling for the GIF's container. */
    containerData?: PluginContainerData;
    /** The source of the full size GIF. */
    original?: GIF;
    /** The source of the downsized GIF. */
    downsized?: GIF;
    /** Height in pixels. */
    height?: number;
    /** Width in pixels. */
    width?: number;
    /** Type of GIF (Sticker or NORMAL). Defaults to `NORMAL`. */
    gifType?: GIFTypeWithLiterals;
}
interface GIF {
    /**
     * GIF format URL.
     * @format WEB_URL
     */
    gif?: string | null;
    /**
     * MP4 format URL.
     * @format WEB_URL
     */
    mp4?: string | null;
    /**
     * Thumbnail URL.
     * @format WEB_URL
     */
    still?: string | null;
}
declare enum GIFType {
    NORMAL = "NORMAL",
    STICKER = "STICKER"
}
/** @enumType */
type GIFTypeWithLiterals = GIFType | 'NORMAL' | 'STICKER';
interface HeadingData {
    /** Heading level from 1-6. */
    level?: number;
    /** Styling for the heading text. */
    textStyle?: V1TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
}
interface HTMLData extends HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
    /** Styling for the HTML node's container. Height property is irrelevant for HTML embeds when autoHeight is set to `true`. */
    containerData?: PluginContainerData;
    /** The type of HTML code. */
    source?: HTMLDataSourceWithLiterals;
    /** If container height is aligned with its content height. Defaults to `true`. */
    autoHeight?: boolean | null;
}
/** @oneof */
interface HTMLDataDataOneOf {
    /** The URL for the HTML code for the node. */
    url?: string;
    /** The HTML code for the node. */
    html?: string;
    /**
     * Whether this is an AdSense element. Use `source` instead.
     * @deprecated
     */
    isAdsense?: boolean | null;
}
declare enum HTMLDataSource {
    HTML = "HTML",
    ADSENSE = "ADSENSE"
}
/** @enumType */
type HTMLDataSourceWithLiterals = HTMLDataSource | 'HTML' | 'ADSENSE';
interface ImageData {
    /** Styling for the image's container. */
    containerData?: PluginContainerData;
    /** Image file details. */
    image?: Media;
    /** Link details for images that are links. */
    link?: V1Link;
    /** Sets whether the image expands to full screen when clicked. Defaults to `false`. */
    disableExpand?: boolean | null;
    /** Image's alternative text. */
    altText?: string | null;
    /**
     * Deprecated: use Caption node instead.
     * @deprecated
     */
    caption?: string | null;
    /** Sets whether the image's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Sets whether the image is decorative and does not need an explanation. Defaults to `false`. */
    decorative?: boolean | null;
    /** Styling for the image. */
    styles?: ImageDataStyles;
}
interface StylesBorder {
    /** Border width in pixels. */
    width?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** Border radius in pixels. */
    radius?: number | null;
}
interface ImageDataStyles {
    /** Border attributes. */
    border?: StylesBorder;
}
interface LinkPreviewData {
    /** Styling for the link preview's container. */
    containerData?: PluginContainerData;
    /** Link details. */
    link?: V1Link;
    /** Preview title. */
    title?: string | null;
    /** Preview thumbnail URL. */
    thumbnailUrl?: string | null;
    /** Preview description. */
    description?: string | null;
    /** The preview content as HTML. */
    html?: string | null;
    /** Styling for the link preview. */
    styles?: LinkPreviewDataStyles;
}
declare enum StylesPosition {
    /** Thumbnail positioned at the start (left in LTR layouts, right in RTL layouts) */
    START = "START",
    /** Thumbnail positioned at the end (right in LTR layouts, left in RTL layouts) */
    END = "END",
    /** Thumbnail positioned at the top */
    TOP = "TOP",
    /** Thumbnail hidden and not displayed */
    HIDDEN = "HIDDEN"
}
/** @enumType */
type StylesPositionWithLiterals = StylesPosition | 'START' | 'END' | 'TOP' | 'HIDDEN';
interface LinkPreviewDataStyles {
    /**
     * Background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
    /**
     * Title color as a hexadecimal value.
     * @format COLOR_HEX
     */
    titleColor?: string | null;
    /**
     * Subtitle color as a hexadecimal value.
     * @format COLOR_HEX
     */
    subtitleColor?: string | null;
    /**
     * Link color as a hexadecimal value.
     * @format COLOR_HEX
     */
    linkColor?: string | null;
    /** Border width in pixels. */
    borderWidth?: number | null;
    /** Border radius in pixels. */
    borderRadius?: number | null;
    /**
     * Border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    borderColor?: string | null;
    /** Position of thumbnail. Defaults to `START`. */
    thumbnailPosition?: StylesPositionWithLiterals;
}
interface MapData {
    /** Styling for the map's container. */
    containerData?: PluginContainerData;
    /** Map settings. */
    mapSettings?: MapSettings;
}
interface MapSettings {
    /** The address to display on the map. */
    address?: string | null;
    /** Sets whether the map is draggable. */
    draggable?: boolean | null;
    /** Sets whether the location marker is visible. */
    marker?: boolean | null;
    /** Sets whether street view control is enabled. */
    streetViewControl?: boolean | null;
    /** Sets whether zoom control is enabled. */
    zoomControl?: boolean | null;
    /** Location latitude. */
    lat?: number | null;
    /** Location longitude. */
    lng?: number | null;
    /** Location name. */
    locationName?: string | null;
    /** Sets whether view mode control is enabled. */
    viewModeControl?: boolean | null;
    /** Initial zoom value. */
    initialZoom?: number | null;
    /** Map type. `HYBRID` is a combination of the `ROADMAP` and `SATELLITE` map types. */
    mapType?: MapTypeWithLiterals;
}
declare enum MapType {
    /** Roadmap map type */
    ROADMAP = "ROADMAP",
    /** Satellite map type */
    SATELITE = "SATELITE",
    /** Hybrid map type */
    HYBRID = "HYBRID",
    /** Terrain map type */
    TERRAIN = "TERRAIN"
}
/** @enumType */
type MapTypeWithLiterals = MapType | 'ROADMAP' | 'SATELITE' | 'HYBRID' | 'TERRAIN';
interface ParagraphData {
    /** Styling for the paragraph text. */
    textStyle?: V1TextStyle;
    /** Indentation level from 1-4. */
    indentation?: number | null;
    /** Paragraph level */
    level?: number | null;
}
interface PollData {
    /** Styling for the poll's container. */
    containerData?: PluginContainerData;
    /** Poll data. */
    poll?: Poll;
    /** Layout settings for the poll and voting options. */
    layout?: PollDataLayout;
    /** Styling for the poll and voting options. */
    design?: Design;
}
declare enum ViewRole {
    /** Only Poll creator can view the results */
    CREATOR = "CREATOR",
    /** Anyone who voted can see the results */
    VOTERS = "VOTERS",
    /** Anyone can see the results, even if one didn't vote */
    EVERYONE = "EVERYONE"
}
/** @enumType */
type ViewRoleWithLiterals = ViewRole | 'CREATOR' | 'VOTERS' | 'EVERYONE';
declare enum VoteRole {
    /** Logged in member */
    SITE_MEMBERS = "SITE_MEMBERS",
    /** Anyone */
    ALL = "ALL"
}
/** @enumType */
type VoteRoleWithLiterals = VoteRole | 'SITE_MEMBERS' | 'ALL';
interface SettingsPermissions {
    /** Sets who can view the poll results. */
    view?: ViewRoleWithLiterals;
    /** Sets who can vote. */
    vote?: VoteRoleWithLiterals;
    /** Sets whether one voter can vote multiple times. Defaults to `false`. */
    allowMultipleVotes?: boolean | null;
}
interface PollOption {
    /** Option ID. */
    id?: string | null;
    /** Option title. */
    title?: string | null;
    /** The image displayed with the option. */
    image?: Media;
}
interface PollSettings {
    /** Permissions settings for voting. */
    permissions?: SettingsPermissions;
    /** Sets whether voters are displayed in the vote results. Defaults to `true`. */
    showVoters?: boolean | null;
    /** Sets whether the vote count is displayed. Defaults to `true`. */
    showVotesCount?: boolean | null;
}
declare enum PollLayoutType {
    /** List */
    LIST = "LIST",
    /** Grid */
    GRID = "GRID"
}
/** @enumType */
type PollLayoutTypeWithLiterals = PollLayoutType | 'LIST' | 'GRID';
declare enum PollLayoutDirection {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type PollLayoutDirectionWithLiterals = PollLayoutDirection | 'LTR' | 'RTL';
interface PollLayout {
    /** The layout for displaying the voting options. */
    type?: PollLayoutTypeWithLiterals;
    /** The direction of the text displayed in the voting options. Text can be displayed either right-to-left or left-to-right. */
    direction?: PollLayoutDirectionWithLiterals;
    /** Sets whether to display the main poll image. Defaults to `false`. */
    enableImage?: boolean | null;
}
interface OptionLayout {
    /** Sets whether to display option images. Defaults to `false`. */
    enableImage?: boolean | null;
}
declare enum BackgroundType {
    /** Color background type */
    COLOR = "COLOR",
    /** Image background type */
    IMAGE = "IMAGE",
    /** Gradiant background type */
    GRADIENT = "GRADIENT"
}
/** @enumType */
type BackgroundTypeWithLiterals = BackgroundType | 'COLOR' | 'IMAGE' | 'GRADIENT';
interface Gradient {
    /** The gradient angle in degrees. */
    angle?: number | null;
    /**
     * The start color as a hexademical value.
     * @format COLOR_HEX
     */
    startColor?: string | null;
    /**
     * The end color as a hexademical value.
     * @format COLOR_HEX
     */
    lastColor?: string | null;
}
interface Background extends BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
    /** Background type. For each option, include the relevant details. */
    type?: BackgroundTypeWithLiterals;
}
/** @oneof */
interface BackgroundBackgroundOneOf {
    /**
     * The background color as a hexademical value.
     * @format COLOR_HEX
     */
    color?: string | null;
    /** An image to use for the background. */
    image?: Media;
    /** Details for a gradient background. */
    gradient?: Gradient;
}
interface PollDesign {
    /** Background styling. */
    background?: Background;
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface OptionDesign {
    /** Border radius in pixels. */
    borderRadius?: number | null;
}
interface Poll {
    /** Poll ID. */
    id?: string | null;
    /** Poll title. */
    title?: string | null;
    /** Poll creator ID. */
    creatorId?: string | null;
    /** Main poll image. */
    image?: Media;
    /** Voting options. */
    options?: PollOption[];
    /** The poll's permissions and display settings. */
    settings?: PollSettings;
}
interface PollDataLayout {
    /** Poll layout settings. */
    poll?: PollLayout;
    /** Voting otpions layout settings. */
    options?: OptionLayout;
}
interface Design {
    /** Styling for the poll. */
    poll?: PollDesign;
    /** Styling for voting options. */
    options?: OptionDesign;
}
interface TextData {
    /** The text to apply decorations to. */
    text?: string;
    /** The decorations to apply. */
    decorations?: Decoration[];
}
/** Adds appearence changes to text */
interface Decoration extends DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
    /** The type of decoration to apply. */
    type?: DecorationTypeWithLiterals;
}
/** @oneof */
interface DecorationDataOneOf {
    /** Data for an anchor link decoration. */
    anchorData?: AnchorData;
    /** Data for a color decoration. */
    colorData?: ColorData;
    /** Data for an external link decoration. */
    linkData?: LinkData;
    /** Data for a mention decoration. */
    mentionData?: MentionData;
    /** Data for a font size decoration. */
    fontSizeData?: FontSizeData;
    /** Font weight for a bold decoration. */
    fontWeightValue?: number | null;
    /** Data for an italic decoration. Defaults to `true`. */
    italicData?: boolean | null;
    /** Data for an underline decoration. Defaults to `true`. */
    underlineData?: boolean | null;
    /** Data for a spoiler decoration. */
    spoilerData?: SpoilerData;
    /** Data for a strikethrough decoration. Defaults to `true`. */
    strikethroughData?: boolean | null;
}
declare enum DecorationType {
    BOLD = "BOLD",
    ITALIC = "ITALIC",
    UNDERLINE = "UNDERLINE",
    SPOILER = "SPOILER",
    ANCHOR = "ANCHOR",
    MENTION = "MENTION",
    LINK = "LINK",
    COLOR = "COLOR",
    FONT_SIZE = "FONT_SIZE",
    EXTERNAL = "EXTERNAL",
    STRIKETHROUGH = "STRIKETHROUGH"
}
/** @enumType */
type DecorationTypeWithLiterals = DecorationType | 'BOLD' | 'ITALIC' | 'UNDERLINE' | 'SPOILER' | 'ANCHOR' | 'MENTION' | 'LINK' | 'COLOR' | 'FONT_SIZE' | 'EXTERNAL' | 'STRIKETHROUGH';
interface AnchorData {
    /** The target node's ID. */
    anchor?: string;
}
interface ColorData {
    /** The text's background color as a hexadecimal value. */
    background?: string | null;
    /** The text's foreground color as a hexadecimal value. */
    foreground?: string | null;
}
interface LinkData {
    /** Link details. */
    link?: V1Link;
}
interface MentionData {
    /** The mentioned user's name. */
    name?: string;
    /** The version of the user's name that appears after the `@` character in the mention. */
    slug?: string;
    /** Mentioned user's ID. */
    id?: string | null;
}
interface FontSizeData {
    /** The units used for the font size. */
    unit?: FontTypeWithLiterals;
    /** Font size value. */
    value?: number | null;
}
declare enum FontType {
    PX = "PX",
    EM = "EM"
}
/** @enumType */
type FontTypeWithLiterals = FontType | 'PX' | 'EM';
interface SpoilerData {
    /** Spoiler ID. */
    id?: string | null;
}
interface AppEmbedData extends AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
    /** The type of Wix App content being embedded. */
    type?: AppTypeWithLiterals;
    /** The ID of the embedded content. */
    itemId?: string | null;
    /** The name of the embedded content. */
    name?: string | null;
    /**
     * Deprecated: Use `image` instead.
     * @deprecated
     */
    imageSrc?: string | null;
    /** The URL for the embedded content. */
    url?: string | null;
    /** An image for the embedded content. */
    image?: Media;
}
/** @oneof */
interface AppEmbedDataAppDataOneOf {
    /** Data for embedded Wix Bookings content. */
    bookingData?: BookingData;
    /** Data for embedded Wix Events content. */
    eventData?: EventData;
}
declare enum AppType {
    PRODUCT = "PRODUCT",
    EVENT = "EVENT",
    BOOKING = "BOOKING"
}
/** @enumType */
type AppTypeWithLiterals = AppType | 'PRODUCT' | 'EVENT' | 'BOOKING';
interface BookingData {
    /** Booking duration in minutes. */
    durations?: string | null;
}
interface EventData {
    /** Event schedule. */
    scheduling?: string | null;
    /** Event location. */
    location?: string | null;
}
interface VideoData {
    /** Styling for the video's container. */
    containerData?: PluginContainerData;
    /** Video details. */
    video?: Media;
    /** Video thumbnail details. */
    thumbnail?: Media;
    /** Sets whether the video's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Video title. */
    title?: string | null;
    /** Video options. */
    options?: PlaybackOptions;
}
interface PlaybackOptions {
    /** Sets whether the media will automatically start playing. */
    autoPlay?: boolean | null;
    /** Sets whether media's will be looped. */
    playInLoop?: boolean | null;
    /** Sets whether media's controls will be shown. */
    showControls?: boolean | null;
}
interface EmbedData {
    /** Styling for the oEmbed node's container. */
    containerData?: PluginContainerData;
    /** An [oEmbed](https://www.oembed.com) object. */
    oembed?: Oembed;
    /** Origin asset source. */
    src?: string | null;
}
interface Oembed {
    /** The resource type. */
    type?: string | null;
    /** The width of the resource specified in the `url` property in pixels. */
    width?: number | null;
    /** The height of the resource specified in the `url` property in pixels. */
    height?: number | null;
    /** Resource title. */
    title?: string | null;
    /** The source URL for the resource. */
    url?: string | null;
    /** HTML for embedding a video player. The HTML should have no padding or margins. */
    html?: string | null;
    /** The name of the author or owner of the resource. */
    authorName?: string | null;
    /** The URL for the author or owner of the resource. */
    authorUrl?: string | null;
    /** The name of the resource provider. */
    providerName?: string | null;
    /** The URL for the resource provider. */
    providerUrl?: string | null;
    /** The URL for a thumbnail image for the resource. If this property is defined, `thumbnailWidth` and `thumbnailHeight` must also be defined. */
    thumbnailUrl?: string | null;
    /** The width of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailHeight` must also be defined. */
    thumbnailWidth?: string | null;
    /** The height of the resource's thumbnail image. If this property is defined, `thumbnailUrl` and `thumbnailWidth`must also be defined. */
    thumbnailHeight?: string | null;
    /** The URL for an embedded viedo. */
    videoUrl?: string | null;
    /** The oEmbed version number.  This value must be `1.0`. */
    version?: string | null;
}
interface CollapsibleListData {
    /** Styling for the collapsible list's container. */
    containerData?: PluginContainerData;
    /** If `true`, only one item can be expanded at a time. Defaults to `false`. */
    expandOnlyOne?: boolean | null;
    /** Sets which items are expanded when the page loads. */
    initialExpandedItems?: InitialExpandedItemsWithLiterals;
    /** The direction of the text in the list. Either left-to-right or right-to-left. */
    direction?: DirectionWithLiterals;
    /** If `true`, The collapsible item will appear in search results as an FAQ. */
    isQapageData?: boolean | null;
}
declare enum InitialExpandedItems {
    /** First item will be expended initally */
    FIRST = "FIRST",
    /** All items will expended initally */
    ALL = "ALL",
    /** All items collapsed initally */
    NONE = "NONE"
}
/** @enumType */
type InitialExpandedItemsWithLiterals = InitialExpandedItems | 'FIRST' | 'ALL' | 'NONE';
declare enum Direction {
    /** Left-to-right */
    LTR = "LTR",
    /** Right-to-left */
    RTL = "RTL"
}
/** @enumType */
type DirectionWithLiterals = Direction | 'LTR' | 'RTL';
interface TableData {
    /** Styling for the table's container. */
    containerData?: PluginContainerData;
    /** The table's dimensions. */
    dimensions?: Dimensions;
    /**
     * Deprecated: Use `rowHeader` and `columnHeader` instead.
     * @deprecated
     */
    header?: boolean | null;
    /** Sets whether the table's first row is a header. Defaults to `false`. */
    rowHeader?: boolean | null;
    /** Sets whether the table's first column is a header. Defaults to `false`. */
    columnHeader?: boolean | null;
}
interface Dimensions {
    /** An array representing relative width of each column in relation to the other columns. */
    colsWidthRatio?: number[];
    /** An array representing the height of each row in pixels. */
    rowsHeight?: number[];
    /** An array representing the minimum width of each column in pixels. */
    colsMinWidth?: number[];
}
interface TableCellData {
    /** Styling for the cell's background color and text alignment. */
    cellStyle?: CellStyle;
    /** The cell's border colors. */
    borderColors?: BorderColors;
}
declare enum VerticalAlignment {
    /** Top alignment */
    TOP = "TOP",
    /** Middle alignment */
    MIDDLE = "MIDDLE",
    /** Bottom alignment */
    BOTTOM = "BOTTOM"
}
/** @enumType */
type VerticalAlignmentWithLiterals = VerticalAlignment | 'TOP' | 'MIDDLE' | 'BOTTOM';
interface CellStyle {
    /** Vertical alignment for the cell's text. */
    verticalAlignment?: VerticalAlignmentWithLiterals;
    /**
     * Cell background color as a hexadecimal value.
     * @format COLOR_HEX
     */
    backgroundColor?: string | null;
}
interface BorderColors {
    /**
     * Left border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    left?: string | null;
    /**
     * Right border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    right?: string | null;
    /**
     * Top border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    top?: string | null;
    /**
     * Bottom border color as a hexadecimal value.
     * @format COLOR_HEX
     */
    bottom?: string | null;
}
/**
 * `NullValue` is a singleton enumeration to represent the null value for the
 * `Value` type union.
 *
 * The JSON representation for `NullValue` is JSON `null`.
 */
declare enum NullValue {
    /** Null value. */
    NULL_VALUE = "NULL_VALUE"
}
/**
 * `ListValue` is a wrapper around a repeated field of values.
 *
 * The JSON representation for `ListValue` is JSON array.
 */
interface ListValue {
    /** Repeated field of dynamically typed values. */
    values?: any[];
}
interface AudioData {
    /** Styling for the audio node's container. */
    containerData?: PluginContainerData;
    /** Audio file details. */
    audio?: Media;
    /** Sets whether the audio node's download button is disabled. Defaults to `false`. */
    disableDownload?: boolean | null;
    /** Cover image. */
    coverImage?: Media;
    /** Track name. */
    name?: string | null;
    /** Author name. */
    authorName?: string | null;
    /** An HTML version of the audio node. */
    html?: string | null;
}
interface OrderedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
    /** List start number. */
    start?: number | null;
}
interface BulletedListData {
    /** Indentation level from 0-4. */
    indentation?: number;
    /** Offset level from 0-4. */
    offset?: number | null;
}
interface BlockquoteData {
    /** Indentation level from 1-4. */
    indentation?: number;
}
interface CaptionData {
    textStyle?: V1TextStyle;
}
interface LayoutCellData {
    /** Size of the cell in 12 columns grid. */
    colSpan?: number | null;
}
interface V1Metadata {
    /** Schema version. */
    version?: number;
    /**
     * When the object was created.
     * @readonly
     * @deprecated
     */
    createdTimestamp?: Date | null;
    /**
     * When the object was most recently updated.
     * @deprecated
     */
    updatedTimestamp?: Date | null;
    /** Object ID. */
    _id?: string | null;
}
interface DocumentStyle {
    /** Styling for H1 nodes. */
    headerOne?: TextNodeStyle;
    /** Styling for H2 nodes. */
    headerTwo?: TextNodeStyle;
    /** Styling for H3 nodes. */
    headerThree?: TextNodeStyle;
    /** Styling for H4 nodes. */
    headerFour?: TextNodeStyle;
    /** Styling for H5 nodes. */
    headerFive?: TextNodeStyle;
    /** Styling for H6 nodes. */
    headerSix?: TextNodeStyle;
    /** Styling for paragraph nodes. */
    paragraph?: TextNodeStyle;
    /** Styling for block quote nodes. */
    blockquote?: TextNodeStyle;
    /** Styling for code block nodes. */
    codeBlock?: TextNodeStyle;
}
interface TextNodeStyle {
    /** The decorations to apply to the node. */
    decorations?: Decoration[];
    /** Padding and background color for the node. */
    nodeStyle?: NodeStyle;
    /** Line height for text in the node. */
    lineHeight?: string | null;
}
interface CustomRefData {
    title?: string;
    anotherTitle?: string;
}
interface TranslatedMessageWithUniqueFieldRepeated {
    uniqueField?: string;
    message?: string;
}
interface TranslatedMessageWithIdRepeated {
    _id?: string;
    message?: string;
}
interface DiscoveryMetaData {
    /**
     * @minLength 1
     * @maxLength 200
     */
    title?: string | null;
    /**
     * @minLength 1
     * @maxLength 200
     */
    description?: string | null;
    /**
     * Searchable keywords
     * @maxSize 100
     */
    keywords?: Keywords[];
    /** Is searchable */
    searchable?: boolean;
}
interface InternalComponentMetadata {
    componentMetadata?: DiscoveryMetaData;
    /** @maxSize 500 */
    repeatedComponentMetadata?: DiscoveryMetaData[];
}
/** SPI config - defines the relation between implementer URL and which types it is validates */
interface ComponentsValidatorConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /**
     * Component types that will be validated
     * @minSize 1
     * @maxSize 100
     */
    componentValidationTypes?: ComponentTypeWithLiterals[];
    /** Indicates whether the validation should affect real production */
    testMode?: boolean;
}
interface ComponentTranslationAdditionalFieldsConfig {
    deploymentUri?: string;
}
interface FormSchemaSpiConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /**
     * Configuration of namespaces known by implementer
     * @maxSize 3
     */
    namespaceConfigs?: FormsSchemaNamespaceConfig[];
}
interface FormsSchemaNamespaceConfig {
    /**
     * Namespace name.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /** Permissions associated with this namespace. */
    permissions?: FormsPermissions;
    /** Enable client specific form validation for the namespace, more info in ValidateFormSchema. */
    schemaValidationEnabled?: boolean;
    /** Restrictions associated with this namespace. */
    restrictions?: Restrictions;
    /** Enable translations with multilingual */
    multilingualEnabled?: boolean;
    /** Attempt to select unique name for form */
    uniqueName?: boolean;
}
interface Restrictions {
    /**
     * Maximum amount of forms allowed per namespace.
     * @max 15000
     */
    maxFormsAmount?: number;
    /**
     * Maximum amount of fields allowed per form.
     * @max 200
     */
    maxFieldsAmount?: number;
}
interface ProviderConfig {
    /**
     * The name of the calendar provider.
     * @minLength 1
     */
    name?: string;
    /** The base URI in which all methods are deployed. */
    baseUri?: string;
    /** The provided calendar type. */
    calendarType?: CalendarTypeWithLiterals;
    /**
     * Connect methods used to connect to the calendar.
     * @minSize 1
     */
    connectMethods?: ConnectMethodWithLiterals[];
    /** Whether the sync configuration can be updated. */
    canUpdateSyncConfig?: boolean;
    /** Whether events can be listed from the external calendar to the Wix calendar. */
    listEventFromCalendars?: ListEventFromCalendarsWithLiterals;
    /** Whether Wix calendar sessions can be synced to the external calendar. */
    syncToCalendar?: SyncToCalendarWithLiterals;
}
declare enum CalendarType {
    UNDEFINED = "UNDEFINED",
    GOOGLE = "GOOGLE",
    I_CAL = "I_CAL",
    MICROSOFT = "MICROSOFT",
    OTHER = "OTHER"
}
/** @enumType */
type CalendarTypeWithLiterals = CalendarType | 'UNDEFINED' | 'GOOGLE' | 'I_CAL' | 'MICROSOFT' | 'OTHER';
declare enum ConnectMethod {
    OAUTH = "OAUTH",
    CREDENTIALS = "CREDENTIALS"
}
/** @enumType */
type ConnectMethodWithLiterals = ConnectMethod | 'OAUTH' | 'CREDENTIALS';
declare enum ListEventFromCalendars {
    /** Listing events from the external calendar is not supported. */
    LIST_NOT_SUPPORTED = "LIST_NOT_SUPPORTED",
    /** Listing events from the primary external calendar only. */
    LIST_FROM_PRIMARY_CALENDAR_ONLY = "LIST_FROM_PRIMARY_CALENDAR_ONLY",
    /**
     * Listing events from specific external calendars.
     * The external calendars can be listed using the `ExternalCalendarProvider.ListCalendars` API.
     */
    LIST_FROM_SPECIFIC_CALENDARS = "LIST_FROM_SPECIFIC_CALENDARS"
}
/** @enumType */
type ListEventFromCalendarsWithLiterals = ListEventFromCalendars | 'LIST_NOT_SUPPORTED' | 'LIST_FROM_PRIMARY_CALENDAR_ONLY' | 'LIST_FROM_SPECIFIC_CALENDARS';
declare enum SyncToCalendar {
    /** Syncing Wix calendar sessions to the external calendar is not supported. */
    SYNC_NOT_SUPPORTED = "SYNC_NOT_SUPPORTED",
    /** Syncing Wix calendar sessions to the primary external calendar only. */
    SYNC_TO_PRIMARY_CALENDAR_ONLY = "SYNC_TO_PRIMARY_CALENDAR_ONLY",
    /** Syncing Wix calendar sessions to a new external calendar. */
    SYNC_TO_DEDICATED_CALENDAR = "SYNC_TO_DEDICATED_CALENDAR"
}
/** @enumType */
type SyncToCalendarWithLiterals = SyncToCalendar | 'SYNC_NOT_SUPPORTED' | 'SYNC_TO_PRIMARY_CALENDAR_ONLY' | 'SYNC_TO_DEDICATED_CALENDAR';
interface DefaultTaxGroupProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /** User-friendly name of the tax category */
    taxationCategory?: string;
    additionalCategories?: Record<string, TaxationCategoryProvider>;
}
interface TaxationCategoryProvider {
    taxationCategory?: string;
    /**
     * must be a unique GUID for the category
     * @format GUID
     */
    taxationCategoryUuid?: string;
}
interface DynamicSiteStructureProviderConfig {
    /** URL to dynamic site structure provider service */
    deploymentUri?: string;
}
interface HeadlessOAuth {
    /**
     * ID of the site that uses the component.
     * @format GUID
     */
    siteId?: string;
    /** Allowlist of domains that can be redirected to after a login. */
    allowedDomains?: string[];
    /** Component description. */
    description?: string | null;
    /**
     * Login URL to automatically redirect users to from Wix pages.
     * @format WEB_URL
     */
    loginUrl?: string | null;
    /**
     * Array of URIs that can be redirected to after oAuth2 authorization.
     * @maxLength 2048
     */
    allowedRedirectUris?: string[];
    /** Whether a user can resolve the [app secret](https://dev.wix.com/docs/rest/internal-only/dev-center-platform/app-service/introduction). */
    blockSecretGeneration?: boolean;
    /**
     * Logout URL that is invoked when users logout from wix pages.
     * @format WEB_URL
     */
    logoutUrl?: string | null;
    /** OAuth application type. */
    applicationType?: OAuthAppTypeWithLiterals;
    /** OAuth technology used by the application. */
    technology?: OAuthTechnologiesWithLiterals;
    /**
     * List of domain mappings from external domains to Wix domains.
     *
     * When a user accesses a non-Wix domain, they can be automatically forwarded to the corresponding
     * Wix domain based on these mappings. This enables domain-level redirection from
     * external domains to Wix-hosted pages.
     * @maxSize 10
     */
    wixPagesDomainsMappings?: WixPagesDomainMapping[];
}
/** Types of OAuth application. */
declare enum OAuthAppType {
    /** OAuth app type is not specified. */
    OAUTH_APP_TYPE_UNSPECIFIED = "OAUTH_APP_TYPE_UNSPECIFIED",
    /** OAuth app type is a web application. */
    WEB_APP = "WEB_APP",
    /** OAuth app type is a mobile application. */
    MOBILE = "MOBILE",
    /** OAuth app type is some other type of application. */
    OTHER = "OTHER"
}
/** @enumType */
type OAuthAppTypeWithLiterals = OAuthAppType | 'OAUTH_APP_TYPE_UNSPECIFIED' | 'WEB_APP' | 'MOBILE' | 'OTHER';
/** OAuth technology used by the oauth application. */
declare enum OAuthTechnologies {
    /** The OAuth technology is not specified. */
    OAUTH_TECHNOLOGY_UNSPECIFIED = "OAUTH_TECHNOLOGY_UNSPECIFIED",
    /** OAuth technology using JavaScript. */
    JAVASCRIPT = "JAVASCRIPT",
    /** OAuth technology using Angular. */
    ANGULAR = "ANGULAR",
    /** OAuth technology using Vue.js. */
    VUE = "VUE",
    /** OAuth technology using React. */
    REACT = "REACT",
    /** OAuth technology using React Native. */
    REACT_NATIVE = "REACT_NATIVE",
    /** OAuth technology using iOS. */
    IOS = "IOS",
    /** OAuth technology using Android. */
    ANDROID = "ANDROID",
    /** OAuth technology using some other kind of technology. */
    OTHER_TECHNOLOGY = "OTHER_TECHNOLOGY"
}
/** @enumType */
type OAuthTechnologiesWithLiterals = OAuthTechnologies | 'OAUTH_TECHNOLOGY_UNSPECIFIED' | 'JAVASCRIPT' | 'ANGULAR' | 'VUE' | 'REACT' | 'REACT_NATIVE' | 'IOS' | 'ANDROID' | 'OTHER_TECHNOLOGY';
interface WixPagesDomainMapping {
    /** @maxLength 2048 */
    origin?: string;
    /** @maxLength 2048 */
    destination?: string;
}
interface TaxCalculatorSpiConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /** User-friendly name of the tax calculator */
    calculatorDisplayName?: string;
    /** list of countries and boolean represents if its a white list or black list (supported or unsupported countries) */
    taxCountriesConfig?: TaxCountriesConfig;
}
interface TaxCountriesConfig {
    /**
     * list of countries
     * @format COUNTRY
     */
    countries?: string[];
    /** represents if the calculator supports tax in those countries or not */
    isSupported?: boolean;
}
interface CommentModerationProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: string;
    /** List of app ids which moderation implementation supports */
    supportedAppIds?: string[];
}
interface GridAppFilesTransformerConfig {
    /** URI where the SPI Implementer is deployed */
    uriConfig?: SpiBaseUri;
    /**
     * Transformation layout which should match to value from
     * [GridAppLayout](https://github.com/wix-private/wix-code/blob/master/editor/wix-code-ide-server-ng/proto/wix/velo/ide/v1/grid_app_layout.proto) enum.
     * The new values should be added via PR.
     */
    layout?: string;
    /**
     * List of paths which requires content transformation to GridApp format
     * @maxSize 10
     */
    filesContentToTransformToGridApp?: string[];
    /**
     * List of paths which requires content transformation to Layout format
     * @maxSize 10
     */
    filesContentToTransformToLayout?: string[];
}
interface PolicyConfig {
    /** URI where the SPI Implementer is deployed */
    uriConfig?: SpiBaseUri;
}
interface CustomChargesConfig {
    /**
     * Base URI where the endpoints are called. Wix appends the endpoint path to the base URI.
     *
     * For example, to call the Premium Custom Charges endpoint at `https://custom-charges.com/v1/premium-custom-charges`, the base URI you provide here is `https://custom-charges.com/`.
     */
    baseUri?: SpiBaseUri;
}
interface ValidationsSPIConfig {
    /** Whether to validate the cart page in addition to the checkout page. Default: `false` */
    validateInCart?: boolean;
    /**
     * Required. Base URI where the endpoints are called. Wix appends the endpoint path to the base URI.
     * For example, to call the Get Validation Violations endpoint at `https://my-validations.com/v1/get-violations`, the base URI you provide here is `https://my-validations.com`.
     * @minLength 1
     */
    deploymentUri?: string;
}
/** SPI config - defines the relation between implementer URL and which types it saves */
interface ComponentReferenceDataConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /**
     * Component types that contains external (reference) data that is NOT saved in DevCenter.
     * @minSize 1
     * @maxSize 100
     */
    supportedComponentTypes?: ComponentTypeWithLiterals[];
}
/** Configuration for ReviewsProductCatalogProvider */
interface ReviewsProductCatalogProviderConfig {
    /** URI where the SPI Implementer is deployed */
    uriConfig?: SpiBaseUri;
    /** Namespace of catalog provider */
    namespace?: string;
    /** Flag that indicates if verified reviews are enabled */
    isVerifiedReviewsEnabled?: boolean;
}
interface SocialMarketingDesignsProviderConfig {
    /**
     * The URL of the SPI implementation
     * @minLength 1
     * @maxLength 1024
     */
    baseUri?: string;
    /**
     * Name of the provider
     * @minLength 1
     * @maxLength 1024
     */
    name?: string;
    /**
     * Component id (from dev center) of the editor
     * @format GUID
     */
    editorComponentId?: string;
    /**
     * Provider's icon, to be displayed in UI
     * @format WEB_URL
     */
    iconUrl?: string;
    /** How the Prover should be opened */
    navigationType?: NavigationTypeWithLiterals;
    /** Is delete design implemented by the provider */
    deleteDesignEnabled?: boolean;
    /** If the provider manages designs */
    manageDesigns?: boolean;
}
declare enum NavigationType {
    NAVIGATE = "NAVIGATE",
    MODAL = "MODAL"
}
/** @enumType */
type NavigationTypeWithLiterals = NavigationType | 'NAVIGATE' | 'MODAL';
interface GbpFeatureConfig {
    baseUri?: SpiBaseUri;
}
interface CommentFilterProviderConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /** List of app ids for which FilterComment should be invoked */
    supportedAppIds?: string[];
}
interface TaxIdValidatorConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /** User-friendly name of the tax id validator */
    validationProvider?: string;
    /** Configuration of supported tax types */
    taxTypesConfig?: TaxTypesConfig;
}
interface TaxTypesConfig {
    /** List of supported tax types, as provided in ValidateTaxIdRequest and persisted in TaxIdValidationService */
    supportedTaxTypes?: string[];
}
/** Describes a setting group of a notification */
interface PingSettingsGroupComponentData {
    title?: string;
    /** the description of the setting group */
    description?: string | null;
    /** the default state of the setting group */
    state?: PingSettingsGroupComponentDataStateWithLiterals;
}
declare enum PingSettingsGroupComponentDataState {
    UNKNOWN_STATE = "UNKNOWN_STATE",
    DEFAULT_ON = "DEFAULT_ON",
    DEFAULT_OFF = "DEFAULT_OFF"
}
/** @enumType */
type PingSettingsGroupComponentDataStateWithLiterals = PingSettingsGroupComponentDataState | 'UNKNOWN_STATE' | 'DEFAULT_ON' | 'DEFAULT_OFF';
interface FormSpamSubmissionSpiConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /**
     * Configuration of namespaces known by implementer
     * @maxSize 3
     */
    namespaceConfigs?: FormsSpamSubmissionsNamespaceConfig[];
}
interface FormsSpamSubmissionsNamespaceConfig {
    /**
     * Namespace name.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /** Permissions associated with this namespace. */
    permissions?: SpamSubmissionPermissions;
    /**
     * Disables Wix spam submissions filter.
     * Spam submissions are persisted in spam submissions storage to support marking submissions as not spam.
     */
    wixSpamFilterDisabled?: boolean;
}
interface SpamSubmissionPermissions {
    /**
     * Create permission name
     * @maxLength 50
     */
    create?: string;
    /**
     * Delete permission name
     * @maxLength 50
     */
    delete?: string;
    /**
     * Update permission name
     * @maxLength 50
     */
    update?: string;
    /**
     * Read permission name
     * @maxLength 50
     */
    read?: string;
    /**
     * Report as not spam permission name
     * @maxLength 50
     */
    reportNotSpam?: string;
}
/** Editor Add-on component */
interface EditorAddon {
    /**
     * Deprecated, use editor_script
     * @format WEB_URL
     * @deprecated Deprecated, use editor_script
     * @replacedBy editor_script
     * @targetRemovalDate 2025-06-01
     */
    editorScriptUrl?: string;
    /** Tool panel configuration. */
    toolPanelConfig?: ToolPanelConfig;
    /** Information to display in the addons market. */
    marketData?: AddonMarketData;
    /**
     * Optional, path to a Javascript file that will run in Editor environment
     * @format WEB_URL
     */
    editorScript?: string | null;
    /** Toggle to mark whether the editor should revoke an app that contains this component. */
    excludeFromAutoRevoke?: boolean;
}
interface InitialPosition {
    /** Offset from the left. For example, `"50px"`. */
    x?: string;
    /** Offset from the top. For example, `"50px"`. */
    y?: string;
}
interface ToolPanelConfig {
    /**
     * Iframe URL that hosts the add-on tool panel's content.
     * @format WEB_URL
     */
    url?: string;
    /** Addon tool panel width. */
    width?: string;
    /** Addon tool panel height. */
    height?: string;
    /**
     * Initial position of the opened panel.
     * Offset from top left corner of the container.
     */
    initialPosition?: InitialPosition;
}
interface AddonMarketData {
    /**
     * Addon name.
     * @minLength 5
     */
    name?: string;
    /**
     * Deprecated, use teaser
     * @minLength 10
     * @deprecated
     * @replacedBy teaser
     * @targetRemovalDate 2025-06-01
     */
    description?: string;
    /**
     * URL source of the addon's icon. Must be 36px x 36px in JPG or PNG format.
     * @format WEB_URL
     */
    iconUrl?: string | null;
    /** Author's name. */
    author?: string;
    /**
     * Addon teaser.
     * @minLength 10
     * @maxLength 60
     */
    teaser?: string | null;
}
interface ExternalDatabaseSpiConfig {
    /** The URI where the service provider is deployed. */
    uriConfig?: SpiBaseUri;
    /** The namespace of the external database. This can be used to access collections within the database, for example `namespace/collectionId`. */
    namespace?: string;
}
interface PaymentSettingsSPIConfig {
    /**
     * Base URI where the endpoints are called. Wix eCommerce appends the endpoint path to the base URI.
     * For example, to call the Get Payment Settings endpoint at `https://my-payment-settings.com/v1/payment-settings`, the base URI you provide here is `https://my-payment-settings.com/`.
     */
    deploymentUri?: string;
    /**
     * The fallback value that is used for [`requires3dSecure`](https://support.wix.com/en/article/about-3d-secure-3ds-payments-with-third-party-payment-providers) if the service plugin call fails.
     *
     * Default: `false`
     */
    fallbackValueForRequires3dSecure?: boolean;
}
/** Describes topic of a notification */
interface NotificationTopic {
    /** the description of the topic */
    description?: string | null;
    /** the default state of the topic */
    state?: NotificationTopicStateWithLiterals;
    /** the type of the topic */
    type?: NotificationTopicTypeWithLiterals;
    /**
     * The recipients' types indicate that this topic is relevant.
     * @maxSize 10
     */
    supportedRecipientTypes?: RecipientTypeWithLiterals[];
}
declare enum NotificationTopicState {
    UNKNOWN_STATE = "UNKNOWN_STATE",
    DEFAULT_ON = "DEFAULT_ON",
    DEFAULT_OFF = "DEFAULT_OFF"
}
/** @enumType */
type NotificationTopicStateWithLiterals = NotificationTopicState | 'UNKNOWN_STATE' | 'DEFAULT_ON' | 'DEFAULT_OFF';
declare enum NotificationTopicType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    PROMOTIONAL = "PROMOTIONAL",
    TRANSACTIONAL = "TRANSACTIONAL"
}
/** @enumType */
type NotificationTopicTypeWithLiterals = NotificationTopicType | 'UNKNOWN_TYPE' | 'PROMOTIONAL' | 'TRANSACTIONAL';
/** Recipient type */
declare enum RecipientType {
    /** Wix User */
    WIX_USER = "WIX_USER",
    /** Contact */
    CONTACT = "CONTACT"
}
/** @enumType */
type RecipientTypeWithLiterals = RecipientType | 'WIX_USER' | 'CONTACT';
interface NotificationPreferencesFilterConfig {
    /** the base URI where all the methods are deployed. E.g. "https://golden-coupons.com/wix-provider" */
    baseUri?: SpiBaseUri;
}
/** This config provides details of the resource types that are managed by an app implementing this component SPI. */
interface BookingsResourceTypesProviderConfig {
    /**
     * References of the resource types that are managed by the app that implements this component SPI.
     * @maxSize 10
     */
    bookingsResourceTypes?: BookingsResourceType[];
}
interface BookingsResourceType {
    /**
     * The ID of the resource type. Must be a GUID that is unique within the app.
     * @format GUID
     */
    _id?: string | null;
    /**
     * The name of the resource type. This can be any string, such as 'staff' or 'table'.
     * @minLength 1
     * @maxLength 40
     */
    name?: string | null;
}
interface PricingPlansFormConfiguration {
    /** *Plan preview** section configuration. */
    planPreview?: PlanFormPreviewSection;
    /** *Plan info** section configuration. */
    infoSection?: PlanFormInfoSection;
    /** *Settings** section configuration. */
    settingsSection?: PlanFormPlanSettingsSection;
    /** *Benefits** section configuration. */
    benefitsSection?: PlanFormBenefitsSection;
    /** *Pricing options** section configuration. */
    pricingAndDurationSection?: PlanFormPricingAndDurationSection;
    /**
     * Custom sections for the form.
     * @maxSize 99
     */
    customSections?: PlanFormCustomSection[];
    /**
     * Order in which sections will be rendered. Can include default section IDs or custom section component IDs.
     * Visible sections that don't exist in this array are displayed below others in default oder.
     * @maxSize 99
     */
    sectionOrder?: PlanFormSection[];
    /** Custom plan form metadata. */
    metadata?: PlanFormTypeMetadata;
    /** *Page permissions** section configuration. */
    pagePermissions?: PlanFormPagePermissionsSection;
    /** Initial plan data for form defaults. */
    initialPlanValue?: PlanFormInitialValue;
    /**
     * Unique custom form name.
     * @minLength 1
     * @maxLength 100
     */
    formName?: string;
}
interface TextWithTooltip {
    /** Displayed text. */
    text?: string;
    /** Tooltip to show next to text. */
    tooltip?: TooltipSuffix;
}
interface TooltipSuffix {
    /** Tooltip content. */
    text?: string;
}
interface TextWithSuffix extends TextWithSuffixSuffixOneOf {
    /** Tooltip to show next to the text. */
    suffixTooltip?: TooltipSuffix;
    /** Link to show next to the text. */
    suffixLink?: LinkSuffix;
    /** Whether to hide the element. */
    hide?: boolean;
    /** Displayed text. */
    text?: string;
}
/** @oneof */
interface TextWithSuffixSuffixOneOf {
    /** Tooltip to show next to the text. */
    suffixTooltip?: TooltipSuffix;
    /** Link to show next to the text. */
    suffixLink?: LinkSuffix;
}
interface LinkSuffix {
    /** Whether to hide the element. */
    hide?: boolean;
    /** Link text. */
    text?: string;
    /** External URL to open on link click. */
    url?: string;
    /** Text that is passed to click BI event as `referral_info` field. */
    referralInfo?: string;
}
interface PreviewCardPlaceholders {
    /** Placeholder plan name for preview. */
    name?: string;
}
interface InputWithPlaceholder {
    /** Input label. */
    label?: TextWithTooltip;
    /** Input placeholder. */
    placeholder?: string;
}
interface CoverImageConfiguration {
    /** Whether to hide the cover image input. */
    hide?: boolean;
    /** Cover image input label. */
    label?: TextWithTooltip;
}
interface PerksConfiguration {
    /** Whether to hide the **Perks** subsection. */
    hide?: boolean;
    /** *Perks** subsection title. */
    title?: TextWithTooltip;
    /** Perks input placeholder. */
    placeholder?: string;
}
interface CheckboxConfiguration {
    /** Policy agreement checkbox input label. */
    label?: string;
    /** Policy checkbox toggle configuration. */
    acceptRequiredToggle?: TextWithTooltip;
    /** Checked by default toggle configuration. */
    acceptedByDefaultToggle?: TextWithTooltip;
}
interface PreviewConfiguration {
    /** Preview card title. */
    title?: string;
    /** Preview card subtitle. */
    subtitle?: string;
    /** Label for checkbox in preview. */
    checkboxLabel?: string;
    /** Text for **Buy now** in preview. */
    buttonText?: string;
}
interface TermsModalConfiguration {
    /** Modal title. */
    title?: string;
    /** Modal subtitle. */
    subtitle?: string;
    /** Save button text. */
    primaryButtonText?: string;
    /** Cancel button text. */
    secondaryButtonText?: string;
    /** Terms and conditions input configuration. */
    input?: InputWithPlaceholder;
    /** Policy agreement checkbox input configuration. */
    checkbox?: CheckboxConfiguration;
    /** Terms and conditions preview configuration. */
    preview?: PreviewConfiguration;
    /** Modal footer text. */
    footer?: string;
}
interface ThankYouPageInputConfig {
    /** Whether to hide input. */
    hide?: boolean;
    /** Label config. */
    label?: TextWithTooltip;
}
interface ThankYouPageRedirectsConfiguration {
    /** Whether to hide redirects. */
    hide?: boolean;
    /** Redirects field label. */
    label?: TextWithTooltip;
    /** Home Page option label. */
    homePageOption?: string;
    /** Other Page option label. */
    redirectUrlOption?: string;
}
interface ThankYouPagePreviewConfiguration {
    /** Preview card title. */
    title?: string;
    /** Preview card subtitle. */
    subtitle?: string;
}
interface ThankYouPageModalConfiguration {
    /** Modal title. */
    title?: string;
    /** Modal subtitle. */
    subtitle?: TextWithSuffix;
    /** Save button text. */
    primaryButtonText?: string;
    /** Cancel button text. */
    secondaryButtonText?: string;
    /** Reset default button text. */
    resetButtonText?: string;
    /** Thank you page title input configuration. */
    titleInput?: ThankYouPageInputConfig;
    /** Thank you page content input configuration. */
    messageInput?: ThankYouPageInputConfig;
    /** Thank you page button text input configuration. */
    buttonTextInput?: ThankYouPageInputConfig;
    /** Thank you page button action field configuration. */
    redirects?: ThankYouPageRedirectsConfiguration;
    /** Thank you page preview configuration. */
    preview?: ThankYouPagePreviewConfiguration;
}
interface PlanSettingsRowConfiguration {
    /** Whether to hide the row. */
    hide?: boolean;
    /** Row title. */
    title?: TextWithTooltip;
    /** Row subtitle. */
    subtitle?: TextWithTooltip;
}
interface TermsAndConditionsConfiguration {
    /** Whether to hide the row. */
    hide?: boolean;
    /** Row title. */
    title?: TextWithTooltip;
    /** Row subtitle. */
    subtitle?: TextWithTooltip;
    /** "Plan policies" modal configuration. */
    modal?: TermsModalConfiguration;
}
interface ThankYouPageConfiguration {
    /** Whether to hide the row. */
    hide?: boolean;
    /** Row title. */
    title?: TextWithTooltip;
    /** Row subtitle. */
    subtitle?: TextWithTooltip;
    /** "\Thank you page modal configuration. */
    modal?: ThankYouPageModalConfiguration;
}
interface DurationInputConfiguration {
    /** Duration dropdown label. */
    label?: TextWithTooltip;
    /** Duration dropdown placeholder. */
    placeholder?: string;
    /** Labels for duration dropdown options. */
    renameOptions?: DurationRenameOptions;
}
interface DurationRenameOptions {
    /** Text for "Forever" duration option. */
    forever?: string;
    /** Text for "Custom" duration option. */
    custom?: string;
}
interface InputConfiguration {
    /** Input label. */
    label?: TextWithTooltip;
}
interface SetupFeeConfiguration {
    /** Hide **Setup fee** toggle. */
    hide?: boolean;
    /** Setup fee toggle label. */
    label?: TextWithTooltip;
    /** Setup fee amount input configuration. */
    amount?: InputWithPlaceholder;
    /** Setup fee name input configuration. */
    name?: InputWithPlaceholder;
}
interface FreeTrialConfiguration {
    /** Whether to hide the **Free trial** toggle. */
    hide?: boolean;
    /** Free trial toggle label. */
    label?: TextWithTooltip;
    /** Free trial duration dropdown configuration. */
    duration?: InputConfiguration;
}
interface FreeOptionConfiguration {
    /** Whether to hide the **Free** option. */
    hide?: boolean;
    /** Option title. */
    title?: string;
    /** Option subtitle. */
    subtitle?: string;
    /** Plan duration dropdown configuration. */
    duration?: DurationInputConfiguration;
    /** Custom duration period dropdown configuration. */
    customDurationPeriod?: InputConfiguration;
    /** Custom  duration input configuration. */
    customDurationInput?: InputConfiguration;
}
interface OneTimeOptionConfiguration {
    /** Whether to hide the One-time payment option. */
    hide?: boolean;
    /** Option title. */
    title?: string;
    /** Option subtitle. */
    subtitle?: string;
    /** Plan duration dropdown configuration. */
    duration?: DurationInputConfiguration;
    /** Custom duration period dropdown configuration. */
    customDurationPeriod?: InputConfiguration;
    /** Custom  duration input configuration. */
    customDurationInput?: InputConfiguration;
    /** Price input configuration. */
    price?: InputWithPlaceholder;
    /** Setup fee field configuration. */
    setupFee?: SetupFeeConfiguration;
}
interface RecurringOptionConfiguration {
    /** Whether to hide the "recurring" option. */
    hide?: boolean;
    /** Option title. */
    title?: string;
    /** Option subtitle. */
    subtitle?: string;
    /** Plan duration dropdown configuration. */
    duration?: DurationInputConfiguration;
    /** Price input configuration. */
    price?: InputWithPlaceholder;
    /** Setup fee field configuration. */
    setupFee?: SetupFeeConfiguration;
    /** Free trial field configuration. */
    freeTrial?: FreeTrialConfiguration;
    /** Frequency dropdown configuration. */
    frequency?: InputConfiguration;
    /** Custom frequency input configuration. */
    customFrequency?: InputConfiguration;
}
declare enum PlanFormPricingOption {
    FREE = "FREE",
    ONE_TIME = "ONE_TIME",
    RECURRING = "RECURRING"
}
/** @enumType */
type PlanFormPricingOptionWithLiterals = PlanFormPricingOption | 'FREE' | 'ONE_TIME' | 'RECURRING';
declare enum PlanFormDefaultSection {
    INFO = "INFO",
    BENEFITS = "BENEFITS",
    PAGE_PERMISSIONS = "PAGE_PERMISSIONS",
    PRICING_AND_DURATION = "PRICING_AND_DURATION",
    ADVANCED_SETTINGS = "ADVANCED_SETTINGS"
}
/** @enumType */
type PlanFormDefaultSectionWithLiterals = PlanFormDefaultSection | 'INFO' | 'BENEFITS' | 'PAGE_PERMISSIONS' | 'PRICING_AND_DURATION' | 'ADVANCED_SETTINGS';
interface Illustration extends IllustrationIllustrationOneOf {
    /**
     * Custom exported component ID to be rendered as an illustration.
     * @format GUID
     */
    componentId?: string;
    /** 96x96px image. Used in type choice modal. */
    src?: string;
}
/** @oneof */
interface IllustrationIllustrationOneOf {
    /**
     * Custom exported component ID to be rendered as an illustration.
     * @format GUID
     */
    componentId?: string;
    /** 96x96px image. Used in type choice modal. */
    src?: string;
}
interface PlanDuration {
    /** Amount of a duration `unit` in a single payment cycle. */
    count?: number;
    /** Unit of time for the cycle duration. */
    unit?: PlanPeriodUnitWithLiterals;
}
/** Pedefined basic time unit. */
declare enum PlanPeriodUnit {
    DAY = "DAY",
    WEEK = "WEEK",
    MONTH = "MONTH",
    YEAR = "YEAR"
}
/** @enumType */
type PlanPeriodUnitWithLiterals = PlanPeriodUnit | 'DAY' | 'WEEK' | 'MONTH' | 'YEAR';
interface PlanPriceData {
    /** Monetary amount. Decimal string with a period as a decimal separator. For example, `3.99`. */
    value?: string;
    /** Currency code. Must be valid ISO 4217 currency code. For example, USD. */
    currency?: string;
}
interface PricingRecurring {
    /** Length of one payment cycle. */
    cycleDuration?: PlanDuration;
    /**
     * Amount of payment cycles this subscription is valid for.
     *
     * `0` indicates unlimited or until it is canceled.
     */
    cycleCount?: number;
}
interface PerkValues {
    /**
     * List of perks.
     * @maxSize 99
     */
    values?: string[];
}
interface PlanPricing extends PlanPricingPricingModelOneOf {
    /** Plan has recurring payments. */
    subscription?: PricingRecurring;
    /** One time payment. Plan is valid for the specified duration. */
    singlePaymentForDuration?: PlanDuration;
    /** One time payment. Plan is valid until it is canceled. */
    singlePaymentUnlimited?: boolean;
    /** Amount for a single payment. */
    price?: PlanPriceData;
}
/** @oneof */
interface PlanPricingPricingModelOneOf {
    /** Plan has recurring payments. */
    subscription?: PricingRecurring;
    /** One time payment. Plan is valid for the specified duration. */
    singlePaymentForDuration?: PlanDuration;
    /** One time payment. Plan is valid until it is canceled. */
    singlePaymentUnlimited?: boolean;
}
interface PlanFormPreviewSection {
    /** Whether to hide the **Preview** section. */
    hide?: boolean;
    /** Preview card title. */
    title?: TextWithTooltip;
    /** Preview card subtitle. */
    subtitle?: TextWithSuffix;
    /** Placeholders for previewed plan. */
    placeholders?: PreviewCardPlaceholders;
    /** Stick **Preview** section to the right while scrolling. As a result, all other sections will be narrower. */
    isSticky?: boolean | null;
}
interface PlanFormInfoSection {
    /** Whether to hide the **Info** section. If `true`, remaining fields are ignored. */
    hide?: boolean;
    /** Tooltip title. */
    title?: TextWithTooltip;
    /** Tooltip subtitle. */
    subtitle?: TextWithSuffix;
    /** Plan name input configuration. */
    name?: InputWithPlaceholder;
    /** Plan tagline input configuration. */
    tagline?: InputWithPlaceholder;
    /** Cover image configuration. */
    coverImage?: CoverImageConfiguration;
    /** Plan perks configuration. */
    perks?: PerksConfiguration;
}
interface PlanFormPlanSettingsSection {
    /** Whether to hide the **Advanced settings** section. */
    hide?: boolean;
    /** Section title configuration. */
    title?: TextWithTooltip;
    /** Section subtitle configuration. */
    subtitle?: TextWithSuffix;
    /** Configuration for "Limit to 1 purchase per person" plan setting. */
    singlePurchase?: PlanSettingsRowConfiguration;
    /** Configuration for "Allow plan cancellation" plan setting. */
    allowCancellation?: PlanSettingsRowConfiguration;
    /** Configuration for "Let people set start date" plan setting. */
    customStartDate?: PlanSettingsRowConfiguration;
    /** Configuration for "Add a policy" plan setting. */
    termsAndConditions?: TermsAndConditionsConfiguration;
    /** Configuration for "Collect additional info" plan setting. */
    customForms?: PlanSettingsRowConfiguration;
    /** Configuration for "Customize a Thank You page" plan setting. */
    thankYouPage?: ThankYouPageConfiguration;
}
interface PlanFormBenefitsSection {
    /** Hide **Benefits** section. */
    hide?: boolean;
    /** *Benefits** section title. */
    title?: TextWithTooltip;
    /** *Benefits** section subtitle. */
    subtitle?: TextWithSuffix;
    /** Suffix link configuration. Rendered at the right side of section header. */
    suffix?: LinkSuffix;
    /**
     * Hide specific benefits from the section.
     * @maxSize 99
     */
    hiddenBenefits?: string[];
}
interface PlanFormPricingAndDurationSection {
    /** Whether to hide **Pricing and Duration** section. */
    hide?: boolean;
    /** Section title. */
    title?: TextWithTooltip;
    /** Section subtitle. */
    subtitle?: TextWithSuffix;
    /** Free pricing option configuration. */
    freePricingOption?: FreeOptionConfiguration;
    /** One-time payment pricing option configuration. */
    oneTimeOption?: OneTimeOptionConfiguration;
    /** Recurring pricing option configuration. */
    recurringOption?: RecurringOptionConfiguration;
    /**
     * Order in which pricing options should be displayed.
     * @maxSize 99
     */
    pricingOptionOrder?: PlanFormPricingOptionWithLiterals[];
}
interface PlanFormCustomSection {
    /**
     * ID of dashboard extension component.
     * Extensions should have the following container ID: `fb869315-532f-4057-9049-e316f94e192f`
     * @format GUID
     */
    componentId?: string;
}
interface PlanFormSection extends PlanFormSectionSectionOneOf {
    /** Extension component ID. */
    componentId?: string;
    /** Default section name. */
    sectionName?: PlanFormDefaultSectionWithLiterals;
}
/** @oneof */
interface PlanFormSectionSectionOneOf {
    /** Extension component ID. */
    componentId?: string;
    /** Default section name. */
    sectionName?: PlanFormDefaultSectionWithLiterals;
}
interface PlanFormTypeMetadata {
    /** Configuration name. */
    title?: string;
    /** Plan type subtitle. Used in type choice modal. */
    subtitle?: string;
    /** Plan type description. Used in type choice modal. */
    description?: string;
    /** Plan type illustration. Used in type choice modal. */
    illustration?: Illustration;
    /** Your business manager module ID. */
    moduleId?: string;
}
interface PlanFormPagePermissionsSection {
    /** Whether to hide the **Page permissions** section. */
    hide?: boolean;
}
interface PlanFormInitialValue {
    /** Plan name. */
    name?: string | null;
    /** Plan description. */
    description?: string | null;
    /** What is included with this plan. */
    perks?: PerkValues;
    /** Plan price, payment schedule, and expiration. */
    pricing?: PlanPricing;
    /** Whether the plan is public. */
    public?: boolean | null;
    /**
     * Number of times the same buyer can purchase the plan.
     *
     * Supported values:
     * - `null | 0`: No limitation.
     * - `1`: Limit of one purchase per buyer.
     */
    maxPurchasesPerBuyer?: number | null;
    /** Whether the buyer can start the plan at a future date. */
    allowFutureStartDate?: boolean | null;
    /** Whether the buyer is allowed to cancel their plan. */
    buyerCanCancel?: boolean | null;
    /**
     * Any terms and conditions that apply to the plan. This information will be displayed during checkout.
     * @maxLength 3000
     */
    termsAndConditions?: string | null;
    /** Additional plan data. */
    clientData?: Record<string, string>;
}
/** Describes user notifications */
interface UserNotification {
    referenceData?: UserNotificationData;
}
interface UserNotificationData {
    /** description */
    description?: string | null;
    /**
     * topic id
     * @minLength 1
     * @format GUID
     */
    topicId?: string | null;
    /** channels */
    channels?: NotificationChannels;
    /** icon */
    icon?: Icon;
    /** intent */
    intent?: IntentWithLiterals;
    /** limiter field */
    limiterField?: LimiterField;
    /** recipient filter */
    recipientFilter?: UserNotificationDataRecipientFilter;
    /** initiator */
    initiator?: UserNotificationDataInitiator;
    /** single deeplink */
    singleDeeplink?: UserNotificationDataDeeplink;
    /** grouped deeplink */
    groupedDeeplink?: UserNotificationDataDeeplink;
    /** context */
    context?: UserNotificationDataContext;
    /** type */
    type?: UserNotificationDataTypeWithLiterals;
}
interface TypedDynamicParam {
    /**
     * name
     * @minLength 1
     */
    name?: string;
    /** dynamic param type */
    dynamicParamType?: TypedDynamicParamTypeWithLiterals;
}
declare enum TypedDynamicParamType {
    STRING = "STRING",
    ARRAY = "ARRAY"
}
/** @enumType */
type TypedDynamicParamTypeWithLiterals = TypedDynamicParamType | 'STRING' | 'ARRAY';
declare enum UserNotificationDataRecipientFilterType {
    WIX_USERS = "WIX_USERS",
    SITE_CONTRIBUTORS = "SITE_CONTRIBUTORS"
}
/** @enumType */
type UserNotificationDataRecipientFilterTypeWithLiterals = UserNotificationDataRecipientFilterType | 'WIX_USERS' | 'SITE_CONTRIBUTORS';
interface WixUsersData {
    /** id */
    _id?: TypedDynamicParam;
}
interface SiteContributorsData {
    /** @minSize 1 */
    permissions?: string[];
}
declare enum InitiatorType {
    WIX_USER = "WIX_USER",
    WIX_APP = "WIX_APP"
}
/** @enumType */
type InitiatorTypeWithLiterals = InitiatorType | 'WIX_USER' | 'WIX_APP';
interface WixUserData {
    /**
     * dynamic param name
     * @minLength 1
     */
    dynamicParamName?: string;
}
interface ConstOrDynamicParam extends ConstOrDynamicParamValueOneOf {
    /**
     * dynamic param name
     * @minLength 1
     */
    dynamicParamName?: string;
    /**
     * constant
     * @minLength 1
     */
    constant?: string;
}
/** @oneof */
interface ConstOrDynamicParamValueOneOf {
    /**
     * dynamic param name
     * @minLength 1
     */
    dynamicParamName?: string;
    /**
     * constant
     * @minLength 1
     */
    constant?: string;
}
interface Url {
    constOrDynamicParam?: ConstOrDynamicParam;
}
interface BackofficeActionDeeplink {
    /**
     * app ID
     * @minLength 1
     */
    appId?: string;
    /** params */
    params?: Record<string, ConstOrDynamicParam>;
}
declare enum Level {
    ACCOUNT = "ACCOUNT",
    SITE = "SITE"
}
/** @enumType */
type LevelWithLiterals = Level | 'ACCOUNT' | 'SITE';
interface OrderValue {
    /** can be const/dynamicParamName */
    value?: ConstOrDynamicParam;
    /**
     * order
     * @min 1
     */
    order?: number;
}
interface NotificationChannels {
    /** email */
    email?: EmailChannel;
    /** feed */
    feed?: FeedChannels;
    /** mobile push */
    mobilePush?: MobilePushChannel;
    /** voice */
    voice?: VoiceChannel;
    /** sms */
    sms?: SmsChannel;
    /** browser push */
    browserPush?: BrowserPushChannel;
    contentMap?: Record<string, string>;
}
interface ResponsysEmail {
    /**
     * responsys email
     * @minLength 1
     */
    responsysTemplate?: string;
}
interface VelocityEmail {
    /**
     * velocity module name
     * @minLength 1
     */
    velocityModuleName?: string;
    /**
     * template file
     * @minLength 1
     */
    templateFile?: string;
}
interface ShoutoutEmail {
    /**
     * template ID
     * @minLength 1
     */
    templateId?: string;
    /**
     * stream by
     * @minLength 1
     */
    streamBy?: string;
    /**
     * template msid
     * @minLength 1
     */
    templateMsid?: string;
}
interface EmailTemplateConfig extends EmailTemplateConfigProviderOneOf {
    /** responsys email */
    responsysEmail?: ResponsysEmail;
}
/** @oneof */
interface EmailTemplateConfigProviderOneOf {
    /** responsys email */
    responsysEmail?: ResponsysEmail;
}
interface WebFeedContentKeys {
    /** title */
    title?: string | null;
    /** message */
    message?: string | null;
    /** action */
    action?: string | null;
    /** group of two message */
    groupOfTwoMessage?: string | null;
    /** group of many message */
    groupOfManyMessage?: string | null;
    /** group of many action */
    groupOfManyAction?: string | null;
}
interface MobileFeedContentKeys {
    /** title */
    title?: string | null;
    /** message */
    message?: string | null;
    /** action */
    action?: string | null;
    /** group of two message */
    groupOfTwoMessage?: string | null;
    /** group of many message */
    groupOfManyMessage?: string | null;
    /** group of many action */
    groupOfManyAction?: string | null;
}
interface FeedAggregation {
    /**
     * group key
     * @minLength 1
     */
    groupKey?: string;
    /**
     * window
     * @minLength 1
     */
    window?: string;
    /** icon */
    icon?: Icon;
}
interface Icon extends IconDataOneOf {
    /** url data */
    urlData?: UrlData;
    /** icon type */
    type?: IconTypeWithLiterals;
}
/** @oneof */
interface IconDataOneOf {
    /** url data */
    urlData?: UrlData;
}
declare enum IconType {
    URL = "URL",
    SPOUT = "SPOUT",
    INITIATOR = "INITIATOR"
}
/** @enumType */
type IconTypeWithLiterals = IconType | 'URL' | 'SPOUT' | 'INITIATOR';
interface UrlData {
    /**
     * actual url
     * @format WEB_URL
     */
    url?: string;
}
interface WebFeedChannel {
    /** content_keys */
    contentKeys?: WebFeedContentKeys;
}
interface MobileFeedChannel {
    /** content keys */
    contentKeys?: MobileFeedContentKeys;
}
interface FeedChannelsConfig {
    /** aggregation */
    aggregation?: FeedAggregation;
}
interface SharedPlatformMobilePushConfig {
    /** sound */
    sound?: string;
    /** group key */
    groupKey?: string | null;
    /** ttl */
    ttl?: number | null;
    /** target application */
    targetApplication?: MobileApplicationWithLiterals;
}
declare enum MobileApplication {
    UNKNOWN_MOBILE_APPLICATION = "UNKNOWN_MOBILE_APPLICATION",
    OWNER = "OWNER",
    SPACES = "SPACES",
    DINE = "DINE",
    FITNESS = "FITNESS",
    WIX_LIFE = "WIX_LIFE",
    WIX_PARTNERS = "WIX_PARTNERS",
    BRANDED = "BRANDED",
    WIX_STUDIO = "WIX_STUDIO",
    NO_SPECIFIC_TARGET_APP = "NO_SPECIFIC_TARGET_APP"
}
/** @enumType */
type MobileApplicationWithLiterals = MobileApplication | 'UNKNOWN_MOBILE_APPLICATION' | 'OWNER' | 'SPACES' | 'DINE' | 'FITNESS' | 'WIX_LIFE' | 'WIX_PARTNERS' | 'BRANDED' | 'WIX_STUDIO' | 'NO_SPECIFIC_TARGET_APP';
interface AndroidMobilePushConfig {
    /** sub group key */
    subGroupKey?: string | null;
    /** style */
    style?: AndroidStyleWithLiterals;
    /** grouped deeplink pattern */
    groupedDeeplinkPattern?: string | null;
}
declare enum AndroidStyle {
    BIG_TEXT = "BIG_TEXT",
    MESSAGING = "MESSAGING",
    INBOX = "INBOX"
}
/** @enumType */
type AndroidStyleWithLiterals = AndroidStyle | 'BIG_TEXT' | 'MESSAGING' | 'INBOX';
interface MobilePushChannelConfig {
    /** shared */
    shared?: SharedPlatformMobilePushConfig;
    /** android */
    android?: AndroidMobilePushConfig;
}
interface MobilePushContentKeys {
    /** title */
    title?: string | null;
    /** message */
    message?: string | null;
    /** group of many title */
    groupOfManyTitle?: string | null;
    /** group of many message */
    groupOfManyMessage?: string | null;
    /** master group name override */
    masterGroupNameOverride?: string | null;
}
interface ExposureRule extends ExposureRuleRuleOneOf {
    /** boolean experiment exposure rule */
    booleanExperimentExposureRule?: BooleanExperimentExposureRule;
    /** custom experiment exposure rule */
    customExperimentExposureRule?: CustomExperimentExposureRule;
    /** type */
    type?: ExposureRuleTypeWithLiterals;
}
/** @oneof */
interface ExposureRuleRuleOneOf {
    /** boolean experiment exposure rule */
    booleanExperimentExposureRule?: BooleanExperimentExposureRule;
    /** custom experiment exposure rule */
    customExperimentExposureRule?: CustomExperimentExposureRule;
}
declare enum ExposureRuleType {
    OPEN_TO_ALL = "OPEN_TO_ALL",
    OPEN_TO_NONE = "OPEN_TO_NONE",
    BOOLEAN_EXPERIMENT = "BOOLEAN_EXPERIMENT",
    CUSTOM_EXPERIMENT = "CUSTOM_EXPERIMENT"
}
/** @enumType */
type ExposureRuleTypeWithLiterals = ExposureRuleType | 'OPEN_TO_ALL' | 'OPEN_TO_NONE' | 'BOOLEAN_EXPERIMENT' | 'CUSTOM_EXPERIMENT';
interface BooleanExperimentExposureRule {
    /** spec */
    spec?: string;
}
interface CustomExperimentExposureRule {
    /** spec */
    spec?: string;
    /** default value */
    defaultValue?: string;
    /** expected value */
    expectedValue?: string;
}
interface VoiceContentKeys {
    /** message */
    message?: string | null;
}
interface SmsContentKeys {
    /** message */
    message?: string | null;
}
interface BrowserPushContentKeys {
    /** title */
    title?: string | null;
    /** message */
    message?: string | null;
}
interface EmailChannel {
    /** config */
    config?: EmailTemplateConfig;
}
interface FeedChannels {
    /** web feed */
    webFeed?: WebFeedChannel;
    /** mobile feed */
    mobileFeed?: MobileFeedChannel;
    /** config */
    config?: FeedChannelsConfig;
}
interface MobilePushChannel {
    /** config */
    config?: MobilePushChannelConfig;
    /** content_keys */
    contentKeys?: MobilePushContentKeys;
}
interface VoiceChannel {
    /** content keys */
    contentKeys?: VoiceContentKeys;
}
interface SmsChannel {
    /** content_keys */
    contentKeys?: SmsContentKeys;
}
interface BrowserPushChannel {
    /** content_keys */
    contentKeys?: BrowserPushContentKeys;
}
declare enum Intent {
    MARKETING = "MARKETING",
    TRANSACTIONAL = "TRANSACTIONAL"
}
/** @enumType */
type IntentWithLiterals = Intent | 'MARKETING' | 'TRANSACTIONAL';
interface LimiterField {
    /** dynamic param name */
    dynamicParamName?: string;
}
interface UserNotificationDataRecipientFilter extends UserNotificationDataRecipientFilterDataOneOf {
    /** wix users data */
    wixUsersData?: WixUsersData;
    /** site contributors data */
    siteContributorsData?: SiteContributorsData;
    /** recipient filter type */
    type?: UserNotificationDataRecipientFilterTypeWithLiterals;
}
/** @oneof */
interface UserNotificationDataRecipientFilterDataOneOf {
    /** wix users data */
    wixUsersData?: WixUsersData;
    /** site contributors data */
    siteContributorsData?: SiteContributorsData;
}
interface UserNotificationDataInitiator extends UserNotificationDataInitiatorDataOneOf {
    /** wix user data */
    wixUserData?: WixUserData;
    /** initiator type */
    type?: InitiatorTypeWithLiterals;
}
/** @oneof */
interface UserNotificationDataInitiatorDataOneOf {
    /** wix user data */
    wixUserData?: WixUserData;
}
interface UserNotificationDataDeeplink extends UserNotificationDataDeeplinkOfOneOf {
    /** url */
    url?: Url;
}
/** @oneof */
interface UserNotificationDataDeeplinkOfOneOf {
    /** url */
    url?: Url;
}
interface UserNotificationDataContext {
    level?: LevelWithLiterals;
    /** params */
    params?: Record<string, OrderValue>;
}
declare enum UserNotificationDataType {
    REGULAR = "REGULAR",
    ALERT_WARNING = "ALERT_WARNING",
    ALERT_INFO = "ALERT_INFO"
}
/** @enumType */
type UserNotificationDataTypeWithLiterals = UserNotificationDataType | 'REGULAR' | 'ALERT_WARNING' | 'ALERT_INFO';
/** Describes contact notifications */
interface ContactNotification {
    /** @format GUID */
    referenceId?: string | null;
    referenceData?: ContactsNotificationData;
}
interface ContactsNotificationData {
    /**
     * name
     * @minLength 1
     */
    name?: string | null;
    /** description */
    description?: string | null;
    /**
     * topic id
     * @minLength 1
     */
    topicId?: string | null;
    /** channels */
    channels?: NotificationChannels;
    /** icon */
    icon?: Icon;
    /** limiter field */
    limiterField?: LimiterField;
    /** recipient filter */
    recipientFilter?: RecipientFilter;
    /** initiator */
    initiator?: Initiator;
    /** single deeplink */
    singleDeeplink?: Deeplink;
    /** grouped deeplink */
    groupedDeeplink?: Deeplink;
    /** context */
    context?: Context;
}
declare enum RecipientFilterType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    CONTACTS = "CONTACTS"
}
/** @enumType */
type RecipientFilterTypeWithLiterals = RecipientFilterType | 'UNKNOWN_TYPE' | 'CONTACTS';
interface ContactsData {
    /** id */
    _id?: TypedDynamicParam;
}
declare enum Type {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    CONTACT = "CONTACT",
    SITE_MEMBER = "SITE_MEMBER"
}
/** @enumType */
type TypeWithLiterals = Type | 'UNKNOWN_TYPE' | 'CONTACT' | 'SITE_MEMBER';
interface ContactData {
    /**
     * dynamic param name
     * @minLength 1
     */
    dynamicParamName?: string;
}
interface SiteMemberData {
    /**
     * dynamic param name
     * @minLength 1
     */
    dynamicParamName?: string;
}
interface LiveSiteActionDeeplink {
    /** app page ID */
    appPageId?: string | null;
    /** path */
    path?: string | null;
    /** language */
    language?: ConstOrDynamicParam;
    /** hash fragment */
    hashFragment?: ConstOrDynamicParam;
    /** query params */
    queryParams?: Record<string, ConstOrDynamicParam>;
}
interface RecipientFilter extends RecipientFilterDataOneOf {
    /** contacts data */
    contactsData?: ContactsData;
    /** recipient filter type */
    type?: RecipientFilterTypeWithLiterals;
}
/** @oneof */
interface RecipientFilterDataOneOf {
    /** contacts data */
    contactsData?: ContactsData;
}
interface Initiator extends InitiatorDataOneOf {
    /** contact data */
    contactData?: ContactData;
    /** site member data */
    siteMemberData?: SiteMemberData;
    /** initiator type */
    type?: TypeWithLiterals;
}
/** @oneof */
interface InitiatorDataOneOf {
    /** contact data */
    contactData?: ContactData;
    /** site member data */
    siteMemberData?: SiteMemberData;
}
interface Deeplink extends DeeplinkOfOneOf {
    /** url */
    url?: Url;
}
/** @oneof */
interface DeeplinkOfOneOf {
    /** url */
    url?: Url;
}
interface Context {
    /** params */
    params?: Record<string, OrderValue>;
}
interface UnifiedPage {
    /** Base info of component by shared logic of unified components */
    base?: BaseInfo;
    /**
     * Page installation settings
     * @deprecated Page installation settings
     * @replacedBy editor_settings
     * @targetRemovalDate 2026-02-26
     */
    installation?: PageInstallationSettings;
    /** Page replacing options (replacer \ replacing \ none) */
    pageReplace?: PageReplaceOptions;
    /** Content of page */
    content?: PageContent;
    /** Settings for how the page integrates with the editor */
    editorSettings?: UnifiedPageEditorSettings;
}
interface PageInstallationSettings {
    /** Shared installation settings for unified components */
    base?: BaseInstallation;
    /** Page installation settings for unified components */
    page?: PageInstallation;
}
interface PageInstallation {
    /**
     * slug of the page (last part of url that point to the page)
     * @minLength 1
     * @maxLength 200
     */
    slug?: string;
    /** Should add page to site menu */
    addToSiteMenu?: boolean;
    /** Can page be linked through link panel */
    linkable?: boolean;
}
interface PageContent {
    /** Widgets to add as content in page */
    widgets?: WidgetAsContent[];
}
interface WidgetAsContent {
    /**
     * GUID of widget to use as content of page
     * @format GUID
     */
    widgetGuid?: string;
    /** The preset should be used */
    preset?: MainPresets;
    /** Mark widget as essential for the existence of the app (force to delete the whole app) */
    essential?: boolean | null;
}
interface UnifiedPageEditorSettings {
    /** Basic editor settings that are relevant to all page types */
    base?: PageEditorSettings;
    /**
     * slug of the page (last part of url that point to the page)
     * @minLength 1
     * @maxLength 200
     */
    slug?: string | null;
}
interface PageEditorSettings {
    /** Add the page to the site menu */
    addToSiteMenu?: boolean | null;
    /** Can a page be linked through the link panel */
    linkable?: boolean | null;
    /** Can a page be duplicated in the editor (if no essential widget is added in the container) */
    duplicatable?: boolean | null;
}
interface AvailabilityTimeSlotsProviderConfig {
    /** URI where the SPI Implementer is deployed. */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of the provider.
     * @maxLength 100
     */
    providerName?: string | null;
}
interface ProposalEditorProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of ProposalEditor provider
     * @maxLength 100
     */
    providerName?: string;
}
interface CustomReservationsApprovalConfig {
    /** URI where the SPI Implementer is deployed */
    uriConfig?: SpiBaseUri;
    /** @minLength 2 */
    name?: string;
}
interface CommentsContextProviderConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /** Comments Environment */
    environment?: EnvironmentWithLiterals;
    /** Feature toggle to indicate if method GetCommentContextResources is implemented */
    toggleResourceProviderEnabled?: boolean;
}
declare enum Environment {
    LIVE_SITE = "LIVE_SITE",
    BUSINESS_MANAGER = "BUSINESS_MANAGER"
}
/** @enumType */
type EnvironmentWithLiterals = Environment | 'LIVE_SITE' | 'BUSINESS_MANAGER';
interface FormSpamSubmissionReportSpiConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /**
     * Configuration of namespaces known by implementer
     * @maxSize 3
     */
    namespaceConfigs?: FormSpamSubmissionReportsNamespaceConfig[];
}
interface FormSpamSubmissionReportsNamespaceConfig {
    /**
     * Namespace name.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /** Permissions associated with this namespace. */
    permissions?: FormSpamSubmissionReportPermissions;
}
interface FormSpamSubmissionReportPermissions {
    /**
     * Create permission name
     * @maxLength 60
     */
    create?: string;
    /**
     * Delete permission name
     * @maxLength 60
     */
    delete?: string;
    /**
     * Update permission name
     * @maxLength 60
     */
    update?: string;
    /**
     * Read permission name
     * @maxLength 60
     */
    read?: string;
    /**
     * Report as not spam permission name
     * @maxLength 60
     */
    reportNotSpam?: string;
    /**
     * Report as not spam permission name
     * @maxLength 60
     */
    checkForSpam?: string;
}
interface VeloActionConfig {
    baseUri?: SpiBaseUri;
}
interface EventTypeProviderConfig {
    /**
     * The name of the event type.
     * Must be globally unique.
     */
    eventTypeName?: string;
    /**
     * Whether the events of this type should be hidden from query results if no type filter is provided.
     * Default is false.
     */
    eventTypeHiddenFromQuery?: boolean;
}
interface ServiceAvailabilityPolicyProviderConfig {
    /** URI where the SPI Implementer is deployed. */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of the provider.
     * @maxLength 100
     */
    providerName?: string | null;
}
/** a translated sms text sent to UOU */
interface SmsActionMessage {
    /**
     * sms text
     * @minLength 1
     */
    body?: string;
}
interface BookingPolicyProviderConfig {
    /** URI where the SPI Implementer is deployed. */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of the provider.
     * @maxLength 100
     */
    providerName?: string | null;
}
interface MultiServiceBookingPolicyProviderConfig {
    /** URI where the SPI Implementer is deployed. */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of the provider.
     * @maxLength 100
     */
    providerName?: string | null;
}
interface FormSubmissionSpiExtensionConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * Namespace names.
     * @maxSize 10
     */
    namespaceConfigs?: FormsSubmissionsExtensionNamespaceConfig[];
}
interface FormsSubmissionsExtensionNamespaceConfig {
    /**
     * Targeted namespace, with what submissions should trigger defined methods.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /**
     * The ID of the specific form that will trigger the defined methods when a submission is made.
     * This field is optional. If not provided, submissions from all forms will trigger the methods.
     * @format GUID
     */
    formId?: string | null;
    /** Enable submission validation. */
    submissionValidationEnabled?: boolean;
}
interface AssistantSpiConfig {
    /**
     * The deployment uri of the assistant
     * @maxLength 1000
     */
    deploymentUri?: string;
    /**
     * The name of the assistant
     * @minLength 1
     * @maxLength 100
     */
    assistantName?: string;
    /** The expose_benchmark_tests of the assistant */
    exposeBenchmarkTests?: boolean;
    /** The expose_dynamic_knowledge of the assistant */
    exposeDynamicKnowledge?: boolean;
}
interface MultilingualTranslationSchema {
}
interface Schema {
    /**
     * Translation schema ID.
     * @readonly
     * @format GUID
     */
    _id?: string | null;
    /** Translation schema unique key identifier. */
    key?: SchemaKey;
    /**
     * List of fields for the translation schema. This property uses a string to map to a `SchemaField` (`Map<string, SchemaField>`). The string serves as a key, which you'll need to access each field in the schema and when adding translation content.
     * @minSize 1
     * @maxSize 1000
     */
    fields?: Record<string, V1SchemaField>;
    /** Fields displayed in content previews. For example, a product name for a product translation schema. */
    previewFields?: PreviewFields;
    /**
     * Whether the translation schema is hidden from the site.
     *
     * Default: `false`
     */
    hidden?: boolean | null;
    /**
     * Translation schema name displayed in the [Translation Manager](https://support.wix.com/en/article/wix-multilingual-using-the-translation-manager).
     * @maxLength 100
     */
    displayName?: string | null;
    /**
     * A reference to the parent schema. For example, if the schema is for a menu item, this property would contain the schema ID of the menu it belongs to.
     * @format GUID
     */
    parentId?: string | null;
    /**
     * Revision number, which increments by 1 each time the schema is updated. To prevent conflicting changes, the existing `revision` must be used when updating a schema.
     * @readonly
     */
    revision?: string | null;
    /**
     * Date and time the translation schema was created.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the translation schema was updated.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Whether to duplicate the translated content when a site containing the translation schema and content is duplicated.
     *
     * Default: `false`
     */
    duplicateContent?: boolean | null;
}
interface SchemaKey {
    /**
     * ID of the app that created the schema.
     * @format GUID
     * @readonly
     */
    appId?: string;
    /**
     * A unique name defined by the app developer to differentiate translation schemas for various entities within their app. For example, if an app developer is creating a translation schema for blog posts, the `entityType` can be `'blog-posts'`.
     * @minLength 1
     * @maxLength 80
     * @immutable
     */
    entityType?: string;
    /**
     * Scope of the translation schema.
     * Supported values:
     * + `GLOBAL`: A global schema for all sites.
     * + `SITE`: A custom schema for a specific site.
     * @immutable
     */
    scope?: SchemaScopeWithLiterals;
}
declare enum SchemaScope {
    UNKNOWN_SCOPE = "UNKNOWN_SCOPE",
    /** Global schema for all sites. */
    GLOBAL = "GLOBAL",
    /** Custom schema for a specific site. */
    SITE = "SITE"
}
/** @enumType */
type SchemaScopeWithLiterals = SchemaScope | 'UNKNOWN_SCOPE' | 'GLOBAL' | 'SITE';
interface V1SchemaField {
    /**
     * Field ID. Validated according to Regex `^[A-Za-z0-9-_)(]+$`. Field IDs may contain parentheses to reference repeated items, such as images. These parentheses can't be nested and each opening parenthesis must be followed by a closing one. For example, `title()()` is valid, while `title)(` and `title(())` aren't valid. The value inside the parenthesis is validated according to Regex `^[^)(\\]\\[\\.]+$`.
     * @minLength 1
     * @maxLength 1000
     * @readonly
     */
    _id?: string;
    /** **Required.** Field type. */
    type?: SchemaFieldFieldTypeWithLiterals;
    /**
     * Field name displayed in the [Translation Manager](https://support.wix.com/en/article/wix-multilingual-using-the-translation-manager).
     * @maxLength 1000
     */
    displayName?: string | null;
    /**
     * Field group name.
     * @maxLength 1000
     */
    groupName?: string | null;
    /**
     * Field minimum text length.
     * @min 1
     */
    minLength?: number | null;
    /**
     * Field maximum text length.
     * @min 1
     */
    maxLength?: number | null;
    /**
     * Field format. Content is validated based on the format set here in the field schema. For example, if the format is `EMAIL`, then the content for this field must be a valid email address.
     * @minLength 2
     * @maxLength 20
     */
    format?: string | null;
    /** Whether the field is hidden from the site. Hidden fields are still validated. */
    hidden?: boolean;
    /** Whether the field is read-only, and not intended to be translated. For example, an image. Use this field when you want an image to remain in the [Translation Manager](https://support.wix.com/en/article/wix-multilingual-using-the-translation-manager) for context, but without being translated. */
    displayOnly?: boolean;
    /** Field index. Use for cases where the order of the fields are relevant. */
    index?: number | null;
}
declare enum SchemaFieldFieldType {
    /** Undefined field type */
    UNDEFINED_TYPE = "UNDEFINED_TYPE",
    /** Short plain text displayed as a single line in the UI. */
    SHORT_TEXT = "SHORT_TEXT",
    /** Long plain text displayed as multiple lines in the UI. */
    LONG_TEXT = "LONG_TEXT",
    /** Long text including styles, images, and links. */
    HTML = "HTML",
    /** Rich-Content using the Wix Ricos format. */
    RICH_CONTENT = "RICH_CONTENT",
    /** Wix Media Manager image. */
    IMAGE = "IMAGE",
    /** Image URL without metadata. */
    IMAGE_LINK = "IMAGE_LINK",
    /** Wix Media Manager video. */
    VIDEO = "VIDEO",
    /** Wix Media Manager document. */
    DOCUMENT = "DOCUMENT"
}
/** @enumType */
type SchemaFieldFieldTypeWithLiterals = SchemaFieldFieldType | 'UNDEFINED_TYPE' | 'SHORT_TEXT' | 'LONG_TEXT' | 'HTML' | 'RICH_CONTENT' | 'IMAGE' | 'IMAGE_LINK' | 'VIDEO' | 'DOCUMENT';
interface PreviewFields {
    /**
     * ID of the field representing the schema's title.
     * @maxLength 1000
     */
    titleFieldId?: string | null;
    /**
     * ID of the field representing the schema's image.
     * @maxLength 1000
     */
    imageFieldId?: string | null;
}
interface TaxGroupsProviderConfig {
    /** Base URI of the service plugin implementation. Since no endpoint is calling this path, it may be left blank. */
    deploymentUri?: SpiBaseUri;
    /**
     * Name of the default tax group for this app. All products retrieved from this app will be categorized, by default, with this group name.
     * The `id` for this tax group is the app's ID.
     * @maxLength 100
     */
    defaultTaxGroup?: string;
    /**
     * Additional tax groups to be added to a site's tax settings when the app is installed.
     * Each `additionalTaxGroup` must include an `id` and a `name`.
     */
    additionalTaxGroups?: Record<string, AdditionalTaxGroup>;
}
interface AdditionalTaxGroup {
    /**
     * Tax group name.
     * @maxLength 100
     */
    name?: string;
    /**
     * Unique tax group ID.
     * @format GUID
     */
    _id?: string;
}
interface TaxCalculationConfig {
    /**
     * Base URI where the endpoints are called. Wix appends the endpoint path to the base URI.
     *
     * For example, to call the Calculate Tax endpoint at https://my-tax-calc.com/v1/calculate-tax, the base URI you provide here is `"https://my-tax-calc.com/"`.
     */
    deploymentUri?: SpiBaseUri;
    /**
     * Display name of the tax calculator.
     * @minLength 1
     * @maxLength 200
     */
    calculatorDisplayName?: string;
    /**
     * List of countries, in [ISO-3166 alpha-1](https://en.wikipedia.org/wiki/ISO_3166-1_alpha-2#Officially_assigned_code_elements) format, that the calculator does not support.
     * @format COUNTRY
     * @maxSize 195
     */
    unsupportedCountries?: string[];
}
/** A modal in one of the back-office platforms */
interface BackOfficeModal extends BackOfficeModalContentOneOf {
    /**
     * Iframe URL that hosts the modal's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
    /**
     * Platform that hosts the modal.
     *
     * Must be `"BUSINESS_MANAGER"`.
     */
    hostingPlatform?: BackOfficeHostingPlatformsWithLiterals;
    /**
     * Modal title.
     * @minLength 1
     */
    title?: string;
    /**
     * Initial width of the modal while loading, in pixels.
     * Width may be adjusted dynamically based on the content of the modal or limited by the size of the modal's container.
     * @max 9999
     */
    width?: number | null;
    /**
     * Initial height of the modal while loading, in pixels.
     * Height may be adjusted dynamically based on the content of the modal or limited by the size of the modal's container.
     * @max 9999
     */
    height?: number | null;
    /** general component data */
    metaData?: ComponentMetaData;
    /**
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
}
/** @oneof */
interface BackOfficeModalContentOneOf {
    /**
     * Iframe URL that hosts the modal's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
}
interface ModalParams {
    /**
     * Named export to use.
     * @maxLength 400
     */
    namedExport?: string | null;
}
interface DeploymentPipelineProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentPipelineUri?: SpiBaseUri;
    /**
     * The deployment pipeline implementer id
     * @format GUID
     */
    deploymentPipelineId?: string;
}
interface CustomElementWidget {
    /** Base info of component by shared logic of unified components */
    base?: BaseInfo;
    /** Unified widget installation settings */
    installation?: WidgetInstallationSettings;
    /** The extension data for this component */
    widgetData?: WidgetData;
    /** The widget's editor behaviors */
    behaviors?: EditorBehaviors;
    /** The size of the widget */
    size?: WidgetSize;
    /**
     * The runtime dependencies array to declare the widget packages.
     * @maxSize 50
     */
    dependencies?: WixDependency[];
    /**
     * The array of this widget's presets
     * @maxSize 50
     */
    presets?: Preset[];
}
interface WidgetData {
    /**
     * The script url that should render on the widget
     * @format WEB_URL
     */
    scriptUrl?: string;
    /**
     * Unique tag name to use in order to connect your JS script to your web component
     * @minLength 2
     * @maxLength 64
     */
    tagName?: string;
    /** Type of JavaScript modularization approach used in the custom element */
    scriptType?: CustomElementScriptTypeWithLiterals;
}
declare enum CustomElementScriptType {
    NONE = "NONE",
    /** CommonJS modularization approach */
    COMMON_JS = "COMMON_JS",
    /** ES Module modularization approach */
    ES_MODULE = "ES_MODULE"
}
/** @enumType */
type CustomElementScriptTypeWithLiterals = CustomElementScriptType | 'NONE' | 'COMMON_JS' | 'ES_MODULE';
interface EditorBehaviors {
    /** The settings behavior definition for the widget */
    settings?: SettingsPanel;
    /** The dashboard behavior definition for the widget */
    dashboard?: Dashboard;
}
interface SettingsPanel {
    /**
     * The settings panel URL for this component
     * @format WEB_URL
     */
    settingsUrl?: string | null;
}
interface Dashboard {
    /**
     * The dashboard page guid for the widget manage of the widget
     * @format GUID
     */
    dashboardPageComponentId?: string;
}
interface WidgetSize {
    /** define the size of the widget's height */
    height?: WidgetSizeHeight;
    /** define the size of the widget's width */
    width?: WidgetSizeWidth;
}
declare enum HeightMode {
    UNKNOWN = "UNKNOWN",
    /** Height is calculated by content */
    AUTO = "AUTO",
    /** Height is fixed require size in px */
    FIXED = "FIXED"
}
/** @enumType */
type HeightModeWithLiterals = HeightMode | 'UNKNOWN' | 'AUTO' | 'FIXED';
interface WidgetSizeHeight {
    /** Height calculation mode */
    heightMode?: HeightModeWithLiterals;
    /**
     * Default height in pixels
     * @max 9999
     */
    defaultHeight?: number;
}
interface WidgetSizeWidth {
    /** Boolean to set stretch, will place the widget stretched to the full width of the container */
    allowStretch?: boolean;
    /**
     * Default width in pixels
     * @max 9999
     */
    defaultWidth?: number;
    /** Boolean to set stretch by default on installation, if true will place the widget stretched to the full width of the container */
    stretchByDefault?: boolean;
}
interface Preset {
    /**
     * The id of the preset
     * @minLength 1
     * @maxLength 50
     */
    _id?: string;
    /**
     * Display name of the preset
     * @minLength 1
     * @maxLength 30
     */
    name?: string;
    /** Defines data for screen size for the preset */
    breakpoints?: Breakpoints;
    /**
     * URL of an image to show as the preset's thumbnail in the editor
     * @format WEB_URL
     */
    thumbnailUrl?: string | null;
}
interface Breakpoints {
    /** Defines data for small screen size */
    small?: Breakpoint;
    /** Defines data for medium screen size */
    medium?: Breakpoint;
    /** Defines data for large screen size */
    large?: Breakpoint;
}
interface Breakpoint {
    /** The size of the preset */
    size?: WidgetSize;
    /**
     * A different preset id to be used according to breakpoint
     * @maxLength 50
     */
    presetId?: string;
}
/** A component that enables extending Wix dashboard functionality. */
interface BackOfficeExtensionWidget extends BackOfficeExtensionWidgetAssetOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
    /**
     * Platform that hosts the widget.
     *
     * Must be `"BUSINESS_MANAGER"`.
     */
    hostingPlatform?: BackOfficeHostingPlatformsWithLiterals;
    /**
     * Slot ID for the plugin's container.
     * @format GUID
     */
    extends?: string;
    /** Extension description. */
    description?: string | null;
    /** Extension title. */
    title?: string;
    /**
     * Initial height of the widget while loading, in pixels.
     * Height may be adjusted dynamically based on the content of the widget or limited by the size of the widget's container.
     * @max 9999
     */
    height?: number | null;
}
/** @oneof */
interface BackOfficeExtensionWidgetAssetOneOf {
    /**
     * Iframe URL that hosts the widget's content.
     * @format WEB_URL
     */
    iframeUrl?: string;
}
/** A component that enables extending a Wix dashboard menu. */
interface BackOfficeExtensionMenuItem {
    /**
     * Platform that hosts the modal.
     *
     * Must be `"BUSINESS_MANAGER"`.
     */
    hostingPlatform?: BackOfficeHostingPlatformsWithLiterals;
    /**
     * Slot ID for the plugin's container.
     * @format GUID
     */
    extends?: string;
    /** Extension description. */
    description?: string | null;
    /** Extension title. */
    title?: string;
    /**
     * Menu item subtitle.
     * @maxLength 200
     */
    subtitle?: string | null;
    /**
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
    /** Action that takes places when the menu item is clicked. */
    action?: MenuAction;
}
interface NavigateToPageAction {
    /**
     * ID for the target [page](https://dev.wix.com/docs/sdk/host-modules/dashboard/page-ids).
     * @format GUID
     */
    pageId?: string;
    /** Relative URL to append to the base page URL. May include path segments, search params, and hash. */
    relativeUrl?: string | null;
}
interface OpenModalAction {
    /**
     * ID of the modal to open.
     * @format GUID
     */
    componentId?: string;
    /** Modal parameters. */
    componentParams?: Record<string, string>;
}
interface MenuAction extends MenuActionActionOneOf {
    navigateToPage?: NavigateToPageAction;
    openModal?: OpenModalAction;
}
/** @oneof */
interface MenuActionActionOneOf {
    navigateToPage?: NavigateToPageAction;
    openModal?: OpenModalAction;
}
/**
 * Form templates represent an entity that can be used as a source when creating a new form,
 * as well as used as common, extendable form.
 */
interface FormTemplate extends FormTemplateTemplateTypeOptionsOneOf {
    /** Extension configuration.. */
    extendableOptions?: ExtensionDetails;
    /**
     * Form template ID.
     * @format GUID
     */
    _id?: string;
    /**
     * Namespace under which all forms from this template are created.
     * Namespaces can be used to aggregate multiple forms into single set according to use case / business rules / product.
     * @minLength 10
     * @maxLength 50
     * @immutable
     */
    namespace?: string;
    /**
     * List of form fields.
     * @maxSize 100
     */
    fields?: Field[];
    /**
     * Fields which were soft deleted, but can be restored by user.
     * @maxSize 100
     */
    deletedFields?: Field[];
    /**
     * Steps of the form, determinating layout of the form
     * @maxSize 100
     */
    steps?: Step[];
    /**
     * Form rules, can be applied to layout and items properties.
     * @maxSize 100
     */
    rules?: V2Rule[];
    /**
     * Name that will be assigned to a created template.
     * @minLength 1
     * @maxLength 200
     */
    name?: string | null;
    /** Settings for actions to be taken after form submission. */
    submitSettings?: SubmitSettings;
    /**
     * Specifies the template purpose
     * @immutable
     */
    templateType?: TemplateTypeWithLiterals;
    /**
     * Date of creation.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date of last update.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Settings for field groups.
     * @maxSize 50
     */
    fieldGroups?: FieldGroup[];
    /** Required indicator properties. */
    requiredIndicatorProperties?: RequiredIndicatorProperties;
}
/** @oneof */
interface FormTemplateTemplateTypeOptionsOneOf {
    /** Extension configuration.. */
    extendableOptions?: ExtensionDetails;
}
interface Field extends FieldFieldTypeOptionsOneOf {
    /** Field accept input of data */
    inputOptions?: InputField;
    /** Field for displaying information such as header or text paragraph */
    displayOptions?: DisplayField;
    /**
     * Field id.
     * @format GUID
     * @immutable
     */
    _id?: string;
    /**
     * Whether the field is hidden.
     * Default: false
     */
    hidden?: boolean;
    /**
     * Custom identification of field, can be used to specify exceptional behaviour of client for specific field
     * @maxLength 50
     */
    identifier?: string | null;
    /**
     * Type of the field
     * @readonly
     */
    fieldType?: FieldTypeWithLiterals;
}
/** @oneof */
interface FieldFieldTypeOptionsOneOf {
    /** Field accept input of data */
    inputOptions?: InputField;
    /** Field for displaying information such as header or text paragraph */
    displayOptions?: DisplayField;
}
declare enum FieldType {
    UNKNOWN_FIELD_TYPE = "UNKNOWN_FIELD_TYPE",
    INPUT = "INPUT",
    DISPLAY = "DISPLAY"
}
/** @enumType */
type FieldTypeWithLiterals = FieldType | 'UNKNOWN_FIELD_TYPE' | 'INPUT' | 'DISPLAY';
interface InputField extends InputFieldInputTypeOptionsOneOf {
    /** Input return string as value */
    stringOptions?: _String;
    /** Input return number as value */
    numberOptions?: InputField_Number;
    /** Input return boolean as value */
    booleanOptions?: _Boolean;
    /** Input return array as value */
    arrayOptions?: _Array;
    /** Input return object as value */
    objectOptions?: _Object;
    /** Input return "Wix file" as value */
    wixFileOptions?: WixFile;
    /** Input returns selected products as value. */
    paymentOptions?: Payment;
    /** Input returns multiline address as value. */
    multilineAddressOptions?: MultilineAddress;
    /**
     * Definition of a target where the value of field belongs.
     * @minLength 1
     * @maxLength 200
     * @immutable
     */
    target?: string;
    /**
     * Mark the field as containing personal information. This will encrypt user data when storing it.
     * Default: false
     */
    pii?: boolean;
    /**
     * Whether the field is required.
     * Default: false
     */
    required?: boolean;
    /**
     * Type of the input field
     * @readonly
     */
    inputType?: InputTypeWithLiterals;
    /** Mapping to contacts, telling to what contact property field input value should be saved. */
    contactMapping?: FormFieldContactInfo;
    /**
     * Whether the field is read only.
     * Default: false
     */
    readOnly?: boolean;
}
/** @oneof */
interface InputFieldInputTypeOptionsOneOf {
    /** Input return string as value */
    stringOptions?: _String;
    /** Input return number as value */
    numberOptions?: InputField_Number;
    /** Input return boolean as value */
    booleanOptions?: _Boolean;
    /** Input return array as value */
    arrayOptions?: _Array;
    /** Input return object as value */
    objectOptions?: _Object;
    /** Input return "Wix file" as value */
    wixFileOptions?: WixFile;
    /** Input returns selected products as value. */
    paymentOptions?: Payment;
    /** Input returns multiline address as value. */
    multilineAddressOptions?: MultilineAddress;
}
interface StringType extends StringTypeFormatOptionsOneOf {
    /** DATE format options */
    dateOptions?: DateTimeConstraints;
    /** DATE_TIME format options */
    dateTimeOptions?: DateTimeConstraints;
    /** TIME format options */
    timeOptions?: DateTimeConstraints;
    /** DATE_OPTIONAL_TIME format options */
    dateOptionalTimeOptions?: DateTimeConstraints;
    /** PHONE format options */
    phoneOptions?: PhoneConstraints;
    /**
     * Minimum length.
     * @max 20000
     */
    minLength?: number | null;
    /**
     * Maximum length.
     * @max 20000
     */
    maxLength?: number | null;
    /**
     * Pattern for a regular expression match.
     * @maxLength 500
     */
    pattern?: string | null;
    /** Format of a string. */
    format?: FormatWithLiterals;
    /**
     * List of allowed values.
     * @maxSize 500
     * @maxLength 20000
     */
    enum?: string[] | null;
}
/** @oneof */
interface StringTypeFormatOptionsOneOf {
    /** DATE format options */
    dateOptions?: DateTimeConstraints;
    /** DATE_TIME format options */
    dateTimeOptions?: DateTimeConstraints;
    /** TIME format options */
    timeOptions?: DateTimeConstraints;
    /** DATE_OPTIONAL_TIME format options */
    dateOptionalTimeOptions?: DateTimeConstraints;
    /** PHONE format options */
    phoneOptions?: PhoneConstraints;
}
declare enum Format {
    UNKNOWN_FORMAT = "UNKNOWN_FORMAT",
    DATE = "DATE",
    TIME = "TIME",
    DATE_TIME = "DATE_TIME",
    EMAIL = "EMAIL",
    URL = "URL",
    UUID = "UUID",
    PHONE = "PHONE",
    URI = "URI",
    HOSTNAME = "HOSTNAME",
    COLOR_HEX = "COLOR_HEX",
    CURRENCY = "CURRENCY",
    LANGUAGE = "LANGUAGE",
    DATE_OPTIONAL_TIME = "DATE_OPTIONAL_TIME"
}
/** @enumType */
type FormatWithLiterals = Format | 'UNKNOWN_FORMAT' | 'DATE' | 'TIME' | 'DATE_TIME' | 'EMAIL' | 'URL' | 'UUID' | 'PHONE' | 'URI' | 'HOSTNAME' | 'COLOR_HEX' | 'CURRENCY' | 'LANGUAGE' | 'DATE_OPTIONAL_TIME';
interface DateTimeConstraints {
    /**
     * Support static constrains defined as ISO date/time format, as well as
     * dynamic calculations can be performed using special keywords such as "$now" to represent the current date and time.
     * The dynamic calculation supports expressions like "$now+2d" (2 days in the future), "$now-1h" (1 hour in the past), etc.
     * The regex pattern for dynamic calculations is: \$now([+-]\d{1,2})([yMdmh])
     * @maxLength 50
     */
    minimum?: string | null;
    /**
     * Support static constrains defined as ISO date/time format, as well as
     * dynamic calculations can be performed using special keywords such as "$now" to represent the current date and time.
     * The dynamic calculation supports expressions like "$now+2d" (2 days in the future), "$now-1h" (1 hour in the past), etc.
     * The regex pattern for dynamic calculations is: \$now([+-]\d{1,2})([yMdmh])
     * @maxLength 50
     */
    maximum?: string | null;
}
interface PhoneConstraints {
    /**
     * Country codes for phone number that are allowed
     * @maxSize 250
     * @maxLength 2
     */
    allowedCountryCodes?: string[];
}
declare enum StringComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    TEXT_INPUT = "TEXT_INPUT",
    RADIO_GROUP = "RADIO_GROUP",
    DROPDOWN = "DROPDOWN",
    DATE_TIME = "DATE_TIME",
    PHONE_INPUT = "PHONE_INPUT",
    DATE_INPUT = "DATE_INPUT",
    TIME_INPUT = "TIME_INPUT",
    DATE_PICKER = "DATE_PICKER"
}
/** @enumType */
type StringComponentTypeWithLiterals = StringComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'TEXT_INPUT' | 'RADIO_GROUP' | 'DROPDOWN' | 'DATE_TIME' | 'PHONE_INPUT' | 'DATE_INPUT' | 'TIME_INPUT' | 'DATE_PICKER';
interface TextInput {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Placeholder for the value input
     * @maxLength 100
     */
    placeholder?: string | null;
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Default value for the text input
     * @maxLength 20000
     */
    default?: string | null;
}
interface RadioGroup {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Flag identifying to show option allowing input custom value
     * List of options to select from
     * @maxSize 400
     */
    options?: RadioGroupOption[];
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /** Option which can be specified by UoU, enabled when this object is specified. */
    customOption?: RadioGroupCustomOption;
    /**
     * Specifies the number of columns used to display the selections within the component.
     * Default: ONE
     */
    numberOfColumns?: NumberOfColumnsWithLiterals;
}
interface RadioGroupOption {
    /**
     * Selectable option label
     * @maxLength 400
     */
    label?: string | null;
    /**
     * Selectable option value, which is saved to DB.
     * @maxLength 20000
     */
    value?: string | null;
    /** Flag identifying that option should be selected by default */
    default?: boolean;
    /**
     * Option id. Used as binding for translations
     * @format GUID
     * @immutable
     */
    _id?: string;
}
interface RadioGroupCustomOption {
    /**
     * Label of custom option input
     * @maxLength 350
     */
    label?: string | null;
    /**
     * Placeholder of custom option input
     * @maxLength 100
     */
    placeholder?: string | null;
}
declare enum NumberOfColumns {
    /** Undefined number of columns. */
    UNKNOWN = "UNKNOWN",
    /** Zero columns. */
    ZERO = "ZERO",
    /** One column. */
    ONE = "ONE",
    /** Two columns. */
    TWO = "TWO",
    /** Three columns. */
    THREE = "THREE"
}
/** @enumType */
type NumberOfColumnsWithLiterals = NumberOfColumns | 'UNKNOWN' | 'ZERO' | 'ONE' | 'TWO' | 'THREE';
interface Dropdown {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * List of options to select from
     * @maxSize 400
     */
    options?: DropdownOption[];
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /** Option which can be specified by UoU, enabled when this object is specified. */
    customOption?: DropdownCustomOption;
    /**
     * Placeholder of dropdown input
     * @maxLength 100
     */
    placeholder?: string | null;
}
interface DropdownOption {
    /**
     * Selectable option label
     * @maxLength 400
     */
    label?: string | null;
    /**
     * Selectable option value, which is saved to DB.
     * @maxLength 20000
     */
    value?: string | null;
    /** Flag identifying that option should be selected by default */
    default?: boolean;
    /**
     * Option id. Used as binding for translations
     * @format GUID
     * @immutable
     */
    _id?: string;
}
interface DropdownCustomOption {
    /**
     * Label of custom option input
     * @maxLength 350
     */
    label?: string | null;
    /**
     * Placeholder of custom option input
     * @maxLength 100
     */
    placeholder?: string | null;
}
interface DateTimeInput {
    /**
     * Label of the field. Displayed text for the date/time input.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. Additional information about the date/time input. */
    description?: RichContent;
    /**
     * Flag identifying whether to show or hide the label.
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Flag identifying whether to show or hide the placeholder.
     * Default: true
     */
    showPlaceholder?: boolean | null;
    /**
     * Flag indicating whether to use the 24-hour time format.
     * Default: false.
     */
    use24HourFormat?: boolean;
    /**
     * Default value for the date time input.
     * @format LOCAL_DATE_TIME
     */
    default?: string | null;
}
interface PhoneInput {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Placeholder for the value input
     * @maxLength 100
     */
    placeholder?: string | null;
    /**
     * Flag identifying to show label or not
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Default value of the country code
     * @minLength 1
     * @maxLength 5
     */
    defaultCountryCode?: string | null;
    /**
     * Flag identifying to show country flag or not
     * Default: false
     */
    showCountryFlag?: boolean;
}
interface DateInput {
    /**
     * Label of the field. Displayed text for the date/time input.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. Additional information about the date/time input. */
    description?: RichContent;
    /**
     * Flag identifying whether to show or hide the label.
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Flag identifying whether to show or hide the placeholder.
     * Default: true
     */
    showPlaceholder?: boolean | null;
    /**
     * Default value for the date input.
     * @format LOCAL_DATE
     */
    default?: string | null;
}
interface TimeInput {
    /**
     * Label of the field. Displayed text for the date/time input.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. Additional information about the date/time input. */
    description?: RichContent;
    /**
     * Flag identifying whether to show or hide the label.
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Flag identifying whether to show or hide the placeholder.
     * Default: true
     */
    showPlaceholder?: boolean | null;
    /**
     * Flag indicating whether to use the 24-hour time format.
     * Default: false.
     */
    use24HourFormat?: boolean;
    /**
     * Default value for the time input.
     * @format LOCAL_TIME
     */
    default?: string | null;
}
interface DatePicker {
    /**
     * Label of the field. Displayed text for the date/time input.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. Additional information about the date/time input. */
    description?: RichContent;
    /**
     * Flag identifying whether to show or hide the label.
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Placeholder of date picker input
     * @maxLength 100
     */
    placeholder?: string | null;
    /** First day of the week displayed on date picker. */
    firstDayOfWeek?: FirstDayOfWeekWithLiterals;
    /**
     * Default value for the date picker.
     * @format LOCAL_DATE
     */
    default?: string | null;
}
declare enum FirstDayOfWeek {
    /** First day of the week is Monday. */
    MONDAY = "MONDAY",
    /** First day of the week is Sunday. */
    SUNDAY = "SUNDAY"
}
/** @enumType */
type FirstDayOfWeekWithLiterals = FirstDayOfWeek | 'MONDAY' | 'SUNDAY';
interface NumberType {
    /** Inclusive maximum value. */
    maximum?: number | null;
    /** Inclusive minimum value. */
    minimum?: number | null;
    /** Multiple of value. */
    multipleOf?: number | null;
    /**
     * List of allowed values.
     * @maxSize 500
     */
    enum?: number[] | null;
}
declare enum NumberComponentType {
    UNKNOWN = "UNKNOWN",
    NUMBER_INPUT = "NUMBER_INPUT",
    RATING_INPUT = "RATING_INPUT"
}
/** @enumType */
type NumberComponentTypeWithLiterals = NumberComponentType | 'UNKNOWN' | 'NUMBER_INPUT' | 'RATING_INPUT';
interface NumberInput {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Placeholder for the value input
     * @maxLength 100
     */
    placeholder?: string | null;
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /** Default value for the number input */
    default?: number | null;
}
interface RatingInput {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Default rating
     * @min 1
     * @max 5
     */
    defaultValue?: number | null;
    /**
     * Flag identifying to hide label or not
     * Default: true
     */
    showLabel?: boolean | null;
}
interface BooleanType {
    /**
     * List of allowed values.
     * @maxSize 2
     */
    enum?: boolean[];
}
declare enum BooleanComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    CHECKBOX = "CHECKBOX"
}
/** @enumType */
type BooleanComponentTypeWithLiterals = BooleanComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'CHECKBOX';
interface Checkbox {
    /** Label of the field */
    label?: RichContent;
    /**
     * Flag identifying if checked by default
     * Default: false
     */
    checked?: boolean;
}
interface ArrayType {
    /**
     * Maximum amount of array elements.
     * @max 1000
     */
    maxItems?: number | null;
    /**
     * Minimum amount of array elements.
     * @max 1000
     */
    minItems?: number | null;
    /** Type of items allowed in array. */
    items?: ArrayTypeArrayItems;
}
declare enum ItemType {
    UNKNOWN_ITEM_TYPE = "UNKNOWN_ITEM_TYPE",
    STRING = "STRING",
    NUMBER = "NUMBER",
    BOOLEAN = "BOOLEAN",
    INTEGER = "INTEGER",
    OBJECT = "OBJECT"
}
/** @enumType */
type ItemTypeWithLiterals = ItemType | 'UNKNOWN_ITEM_TYPE' | 'STRING' | 'NUMBER' | 'BOOLEAN' | 'INTEGER' | 'OBJECT';
interface IntegerType {
    /** Maximum value. */
    maximum?: number | null;
    /** Minimum value. */
    minimum?: number | null;
    /** Multiple of value. */
    multipleOf?: number | null;
    /**
     * List of allowed values.
     * @maxSize 500
     */
    enum?: number[] | null;
}
interface ObjectType {
    /** Description of object properties. */
    properties?: Record<string, PropertiesType>;
}
declare enum PropertiesTypeEnum {
    UNKNOWN_PROPERTY_TYPE = "UNKNOWN_PROPERTY_TYPE",
    STRING = "STRING",
    NUMBER = "NUMBER",
    BOOLEAN = "BOOLEAN",
    INTEGER = "INTEGER",
    ARRAY = "ARRAY"
}
/** @enumType */
type PropertiesTypeEnumWithLiterals = PropertiesTypeEnum | 'UNKNOWN_PROPERTY_TYPE' | 'STRING' | 'NUMBER' | 'BOOLEAN' | 'INTEGER' | 'ARRAY';
interface PropertiesType extends PropertiesTypePropertiesTypeOptionsOneOf {
    /** String type validation for property. */
    stringOptions?: StringType;
    /** Number type validation for property. */
    numberOptions?: NumberType;
    /** Boolean type validation for property. */
    booleanOptions?: BooleanType;
    /** Integer type validation for property. */
    integerOptions?: IntegerType;
    /** Array type validation for property. */
    arrayOptions?: ArrayType;
    /**
     * Type of object properties
     * @readonly
     */
    propertiesType?: PropertiesTypeEnumWithLiterals;
    /** Whether the property is required. */
    required?: boolean;
}
/** @oneof */
interface PropertiesTypePropertiesTypeOptionsOneOf {
    /** String type validation for property. */
    stringOptions?: StringType;
    /** Number type validation for property. */
    numberOptions?: NumberType;
    /** Boolean type validation for property. */
    booleanOptions?: BooleanType;
    /** Integer type validation for property. */
    integerOptions?: IntegerType;
    /** Array type validation for property. */
    arrayOptions?: ArrayType;
}
interface ArrayTypeArrayItems extends ArrayTypeArrayItemsItemTypeOptionsOneOf {
    /** String type validation for items. */
    stringOptions?: StringType;
    /** Number type validation for items. */
    numberOptions?: NumberType;
    /** Boolean type validation for items. */
    booleanOptions?: BooleanType;
    /** Integer type validation for items. */
    integerOptions?: IntegerType;
    /** Object type validation for items */
    objectOptions?: ObjectType;
    /**
     * Type of array items
     * @readonly
     */
    itemType?: ItemTypeWithLiterals;
}
/** @oneof */
interface ArrayTypeArrayItemsItemTypeOptionsOneOf {
    /** String type validation for items. */
    stringOptions?: StringType;
    /** Number type validation for items. */
    numberOptions?: NumberType;
    /** Boolean type validation for items. */
    booleanOptions?: BooleanType;
    /** Integer type validation for items. */
    integerOptions?: IntegerType;
    /** Object type validation for items */
    objectOptions?: ObjectType;
}
declare enum ArrayComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    CHECKBOX_GROUP = "CHECKBOX_GROUP"
}
/** @enumType */
type ArrayComponentTypeWithLiterals = ArrayComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'CHECKBOX_GROUP';
interface CheckboxGroup {
    /**
     * Label of the field
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * List of options to select from
     * @maxSize 400
     */
    options?: CheckboxGroupOption[];
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /** Option which can be specified by UoU, enabled when this object is specified. */
    customOption?: CustomOption;
    /**
     * Specifies the number of columns used to display the selections within the component.
     * Default: ONE
     */
    numberOfColumns?: NumberOfColumnsWithLiterals;
}
interface MediaItem extends MediaItemMediaOneOf {
    /** WixMedia image. */
    image?: CommonImage;
}
/** @oneof */
interface MediaItemMediaOneOf {
    /** WixMedia image. */
    image?: CommonImage;
}
interface CommonImage {
    /**
     * WixMedia image ID.
     * @maxLength 100
     */
    _id?: string;
    /**
     * Image URL.
     * @maxLength 2000
     */
    url?: string;
    /**
     * Original image height.
     * @readonly
     */
    height?: number;
    /**
     * Original image width.
     * @readonly
     */
    width?: number;
    /**
     * Image alt text.
     * @maxLength 1000
     */
    altText?: string | null;
    /**
     * Image filename.
     * @readonly
     * @maxLength 1000
     */
    filename?: string | null;
}
interface CheckboxGroupOption {
    /**
     * Selectable option label
     * @maxLength 400
     */
    label?: string | null;
    /** Selectable option value, which is saved to DB. */
    value?: any;
    /** Flag identifying that option should be selected by default */
    default?: boolean;
    /**
     * Option id. Used as binding for translations
     * @format GUID
     * @immutable
     */
    _id?: string;
    /** Media item. Media, associated with option, like image. */
    media?: MediaItem;
}
interface CustomOption {
    /**
     * Label of custom option input
     * @maxLength 350
     */
    label?: string | null;
    /**
     * Placeholder of custom option input
     * @maxLength 100
     */
    placeholder?: string | null;
}
declare enum WixFileComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    FILE_UPLOAD = "FILE_UPLOAD",
    SIGNATURE = "SIGNATURE"
}
/** @enumType */
type WixFileComponentTypeWithLiterals = WixFileComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'FILE_UPLOAD' | 'SIGNATURE';
interface FileUpload {
    /**
     * Selectable option label
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field */
    description?: RichContent;
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Text on upload button
     * @maxLength 500
     */
    buttonText?: string | null;
    /**
     * Amount of files allowed to upload
     * @min 1
     * @max 30
     */
    fileLimit?: number;
    /**
     * Supported file formats for upload
     * @maxSize 5
     */
    uploadFileFormats?: UploadFileFormatWithLiterals[];
    /**
     * Custom text which appears when file is uploaded, if missing file name will be shown
     * @maxLength 255
     */
    explanationText?: string | null;
}
declare enum UploadFileFormat {
    /** Undefined upload file format. */
    UNDEFINED = "UNDEFINED",
    /** Video files. */
    VIDEO = "VIDEO",
    /** Image files. */
    IMAGE = "IMAGE",
    /** Audio files. */
    AUDIO = "AUDIO",
    /** Document files. */
    DOCUMENT = "DOCUMENT",
    /** Archive files. */
    ARCHIVE = "ARCHIVE"
}
/** @enumType */
type UploadFileFormatWithLiterals = UploadFileFormat | 'UNDEFINED' | 'VIDEO' | 'IMAGE' | 'AUDIO' | 'DOCUMENT' | 'ARCHIVE';
interface Signature {
    /**
     * Selectable option label
     * @maxLength 350
     */
    label?: string | null;
    /**
     * Flag identifying to hide label or not
     * Default: true
     */
    showLabel?: boolean | null;
    /** Description of the field */
    description?: RichContent;
    /** Is image upload enabled */
    imageUploadEnabled?: boolean;
}
declare enum PaymentComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    CHECKBOX_GROUP = "CHECKBOX_GROUP",
    DONATION_INPUT = "DONATION_INPUT"
}
/** @enumType */
type PaymentComponentTypeWithLiterals = PaymentComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'CHECKBOX_GROUP' | 'DONATION_INPUT';
interface PaymentType {
    /**
     * Field mapped to products.
     * @minSize 1
     * @maxSize 100
     */
    products?: Product[];
    /**
     * Minimum amount of different products.
     * @max 100
     */
    minItems?: number | null;
    /**
     * Maximum amount of different products.
     * @max 100
     */
    maxItems?: number | null;
}
declare enum ProductType {
    UNKNOWN = "UNKNOWN",
    /** Shippable (physical). */
    SHIPPABLE = "SHIPPABLE",
    /** Digital. */
    DIGITAL = "DIGITAL"
}
/** @enumType */
type ProductTypeWithLiterals = ProductType | 'UNKNOWN' | 'SHIPPABLE' | 'DIGITAL';
declare enum PriceType {
    UNKNOWN = "UNKNOWN",
    /** Fixed price. */
    FIXED_PRICE = "FIXED_PRICE",
    /** Dynamic price from price range. */
    DYNAMIC_PRICE = "DYNAMIC_PRICE"
}
/** @enumType */
type PriceTypeWithLiterals = PriceType | 'UNKNOWN' | 'FIXED_PRICE' | 'DYNAMIC_PRICE';
interface QuantityLimit {
    /**
     * Minimum quantity.
     * @min 1
     * @max 100000
     */
    minimum?: number | null;
    /**
     * Maximum quantity.
     * @min 1
     * @max 100000
     */
    maximum?: number | null;
}
interface FixedPriceOptions {
    /**
     * Fixed price monetary amount. Decimal string with a period as a decimal separator (e.g., 3.99).
     * @decimalValue options { gte:0.00, maxScale:2 }
     */
    price?: string;
}
interface DynamicPriceOptions {
    /**
     * Minimal price monetary amount.
     * @decimalValue options { gte:0.00, maxScale:2 }
     */
    minPrice?: string;
    /**
     * Maximal price monetary amount.
     * @decimalValue options { gte:0.00, maxScale:2 }
     */
    maxPrice?: string | null;
}
interface Product extends ProductPriceOptionsOneOf {
    /** Fixed price options. */
    fixedPriceOptions?: FixedPriceOptions;
    /** Dynamic price options. */
    dynamicPriceOptions?: DynamicPriceOptions;
    /**
     * Product ID.
     * @format GUID
     * @readonly
     */
    _id?: string;
    /** Product type. */
    productType?: ProductTypeWithLiterals;
    /** Price type. */
    priceType?: PriceTypeWithLiterals;
    /** Quantity limit. */
    quantityLimit?: QuantityLimit;
}
/** @oneof */
interface ProductPriceOptionsOneOf {
    /** Fixed price options. */
    fixedPriceOptions?: FixedPriceOptions;
    /** Dynamic price options. */
    dynamicPriceOptions?: DynamicPriceOptions;
}
interface ProductCheckboxGroup {
    /**
     * Label of the field.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. */
    description?: RichContent;
    /**
     * List of options to select from.
     * @maxSize 400
     */
    options?: ProductCheckboxGroupOption[];
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
    /**
     * Defines how an image should be resized to fit within its option.
     * Default: COVER
     */
    imageFit?: ImageFitWithLiterals;
}
interface ProductCheckboxGroupOption {
    /**
     * Selectable option label.
     * @maxLength 400
     */
    label?: string | null;
    /** Selectable option value, which is saved to DB. Corresponds to product id, found in field's products list. */
    value?: any;
    /**
     * Option id. Used as binding for translations.
     * @format GUID
     * @immutable
     */
    _id?: string;
    /** Media item. Media, associated with option, like image. */
    media?: MediaItem;
    /** Flag identifying that option should be selected by default */
    default?: boolean;
}
declare enum ImageFit {
    UNKNOWN_IMAGE_FIT = "UNKNOWN_IMAGE_FIT",
    /** Image is scaled to maintain its aspect ratio while filling the element's entire content box. Portions of the image may be clipped if the aspect ratios do not match. */
    COVER = "COVER",
    /** Image is resized to fill the element's content box. Aspect ratio may not be preserved. */
    CONTAIN = "CONTAIN"
}
/** @enumType */
type ImageFitWithLiterals = ImageFit | 'UNKNOWN_IMAGE_FIT' | 'COVER' | 'CONTAIN';
interface DonationInput {
    /**
     * Label of the field.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. */
    description?: RichContent;
    /**
     * List of options to select from.
     * @maxSize 400
     */
    options?: DonationInputOption[];
    /** Option which can be specified by UoU, enabled when this object is specified. */
    customOption?: CommonCustomOption;
    /**
     * Specifies the number of columns used to display the selections within the component.
     * Default: ONE
     */
    numberOfColumns?: NumberOfColumnsWithLiterals;
    /**
     * Flag identifying to hide or not label
     * Default: true
     */
    showLabel?: boolean | null;
}
interface DonationInputOption {
    /**
     * Selectable option value, which is saved to DB. Corresponds to product id, found in field's products list.
     * @format GUID
     */
    value?: string;
    /** Flag identifying that option should be selected by default */
    default?: boolean;
}
interface CommonCustomOption {
    /**
     * Label of custom option input
     * @maxLength 350
     */
    label?: string | null;
    /**
     * Placeholder of custom option input
     * @maxLength 100
     */
    placeholder?: string | null;
}
declare enum MultilineAddressComponentType {
    UNKNOWN_COMPONENT_TYPE = "UNKNOWN_COMPONENT_TYPE",
    MULTILINE_ADDRESS = "MULTILINE_ADDRESS"
}
/** @enumType */
type MultilineAddressComponentTypeWithLiterals = MultilineAddressComponentType | 'UNKNOWN_COMPONENT_TYPE' | 'MULTILINE_ADDRESS';
interface MultilineAddressValidation {
    /**
     * Allowed countries. No countries treated as all.
     * @format COUNTRY
     * @maxSize 200
     */
    allowedCountries?: string[];
    /** Fields overrides. */
    fields?: FieldsOverrides;
}
interface FieldOverrides {
    /** Whether the field is required. */
    required?: boolean;
}
interface FieldsOverrides {
    /** Subdivision. */
    subdivision?: FieldOverrides;
    /** City. */
    city?: FieldOverrides;
    /** Postal code. */
    postalCode?: FieldOverrides;
    /** Street name. */
    streetName?: FieldOverrides;
    /** Street number. */
    streetNumber?: FieldOverrides;
    /** Address line. */
    addressLine?: FieldOverrides;
    /** Address line 2. */
    addressLine2?: FieldOverrides;
    /** Country. */
    country?: FieldOverrides;
}
interface ComponentsMultilineAddress {
    /**
     * Label of the field.
     * @maxLength 350
     */
    label?: string | null;
    /** Description of the field. */
    description?: RichContent;
    /** Show country flags. */
    showCountryFlags?: boolean;
    /** Default country configuration. */
    defaultCountryConfig?: DefaultCountryConfig;
    /** Fields settings. */
    fieldSettings?: FieldsSettings;
    /** Autocomplete enabled for address line field. */
    autocompleteEnabled?: boolean;
}
declare enum DefaultCountryConfigType {
    /** Unknown default country config type. */
    UNKNOWN_DEFAULT_COUNTRY = "UNKNOWN_DEFAULT_COUNTRY",
    /** Country is determined by customer's IP address. */
    BY_IP = "BY_IP",
    /** Pre-selected default country. */
    COUNTRY = "COUNTRY"
}
/** @enumType */
type DefaultCountryConfigTypeWithLiterals = DefaultCountryConfigType | 'UNKNOWN_DEFAULT_COUNTRY' | 'BY_IP' | 'COUNTRY';
interface AddressLine2 {
    /** Show address line 2 field. */
    show?: boolean;
}
interface DefaultCountryConfig extends DefaultCountryConfigOptionsOneOf {
    /**
     * Country.
     * @format COUNTRY
     */
    countryOptions?: string;
    /** Default country type. */
    type?: DefaultCountryConfigTypeWithLiterals;
}
/** @oneof */
interface DefaultCountryConfigOptionsOneOf {
    /**
     * Country.
     * @format COUNTRY
     */
    countryOptions?: string;
}
interface FieldsSettings {
    /** Address line 2. */
    addressLine2?: AddressLine2;
}
declare enum InputType {
    UNKNOWN_INPUT_TYPE = "UNKNOWN_INPUT_TYPE",
    STRING = "STRING",
    NUMBER = "NUMBER",
    BOOLEAN = "BOOLEAN",
    ARRAY = "ARRAY",
    OBJECT = "OBJECT",
    WIX_FILE = "WIX_FILE",
    PAYMENT = "PAYMENT",
    MULTILINE_ADDRESS = "MULTILINE_ADDRESS"
}
/** @enumType */
type InputTypeWithLiterals = InputType | 'UNKNOWN_INPUT_TYPE' | 'STRING' | 'NUMBER' | 'BOOLEAN' | 'ARRAY' | 'OBJECT' | 'WIX_FILE' | 'PAYMENT' | 'MULTILINE_ADDRESS';
interface FormFieldContactInfo extends FormFieldContactInfoAdditionalInfoOneOf {
    /** Email info. */
    emailInfo?: EmailInfo;
    /** Phone info. */
    phoneInfo?: PhoneInfo;
    /** Address info. */
    addressInfo?: AddressInfo;
    /** Custom field info. */
    customFieldInfo?: CustomFieldInfo;
    /** Subscription info */
    subscriptionInfo?: SubscriptionInfo;
    /** Field mapped to contacts. */
    contactField?: ContactFieldWithLiterals;
}
/** @oneof */
interface FormFieldContactInfoAdditionalInfoOneOf {
    /** Email info. */
    emailInfo?: EmailInfo;
    /** Phone info. */
    phoneInfo?: PhoneInfo;
    /** Address info. */
    addressInfo?: AddressInfo;
    /** Custom field info. */
    customFieldInfo?: CustomFieldInfo;
    /** Subscription info */
    subscriptionInfo?: SubscriptionInfo;
}
declare enum EmailInfoTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN"
}
/** @enumType */
type EmailInfoTagWithLiterals = EmailInfoTag | 'UNTAGGED' | 'MAIN';
declare enum PhoneInfoTag {
    UNTAGGED = "UNTAGGED",
    MAIN = "MAIN"
}
/** @enumType */
type PhoneInfoTagWithLiterals = PhoneInfoTag | 'UNTAGGED' | 'MAIN';
declare enum AddressInfoTag {
    UNTAGGED = "UNTAGGED",
    HOME = "HOME"
}
/** @enumType */
type AddressInfoTagWithLiterals = AddressInfoTag | 'UNTAGGED' | 'HOME';
declare enum ConfirmationLevel {
    UNKNOWN_CONFIRMATION_LEVEL = "UNKNOWN_CONFIRMATION_LEVEL",
    SINGLE_CONFIRMATION = "SINGLE_CONFIRMATION",
    DOUBLE_CONFIRMATION = "DOUBLE_CONFIRMATION"
}
/** @enumType */
type ConfirmationLevelWithLiterals = ConfirmationLevel | 'UNKNOWN_CONFIRMATION_LEVEL' | 'SINGLE_CONFIRMATION' | 'DOUBLE_CONFIRMATION';
declare enum ContactField {
    UNKNOWN_CONTACT_FIELD = "UNKNOWN_CONTACT_FIELD",
    FIRST_NAME = "FIRST_NAME",
    LAST_NAME = "LAST_NAME",
    COMPANY = "COMPANY",
    POSITION = "POSITION",
    EMAIL = "EMAIL",
    PHONE = "PHONE",
    ADDRESS = "ADDRESS",
    BIRTHDATE = "BIRTHDATE",
    CUSTOM_FIELD = "CUSTOM_FIELD",
    SUBSCRIPTION = "SUBSCRIPTION",
    VAT_ID = "VAT_ID"
}
/** @enumType */
type ContactFieldWithLiterals = ContactField | 'UNKNOWN_CONTACT_FIELD' | 'FIRST_NAME' | 'LAST_NAME' | 'COMPANY' | 'POSITION' | 'EMAIL' | 'PHONE' | 'ADDRESS' | 'BIRTHDATE' | 'CUSTOM_FIELD' | 'SUBSCRIPTION' | 'VAT_ID';
interface EmailInfo {
    /** Email tag. */
    tag?: EmailInfoTagWithLiterals;
}
interface PhoneInfo {
    /** Phone tag. */
    tag?: PhoneInfoTagWithLiterals;
}
interface AddressInfo {
    /** Address tag. */
    tag?: AddressInfoTagWithLiterals;
}
interface CustomFieldInfo {
    /**
     * Custom field key.
     * @minLength 1
     * @maxLength 500
     */
    key?: string;
}
interface SubscriptionInfo {
    /**
     * Subscription consent opt in level, either single or double confirmation.
     * Default: SINGLE_CONFIRMATION
     */
    confirmationLevel?: ConfirmationLevelWithLiterals;
}
interface _String extends _StringComponentTypeOptionsOneOf {
    /** Text input field */
    textInputOptions?: TextInput;
    /** Selection field as radio group */
    radioGroupOptions?: RadioGroup;
    /** Selection field as drop down */
    dropdownOptions?: Dropdown;
    /** Field for selecting date and/or time */
    dateTimeOptions?: DateTimeInput;
    /** Phone input field */
    phoneInputOptions?: PhoneInput;
    /** Dropdown based component for selecting date */
    dateInputOptions?: DateInput;
    /** Field for selecting time */
    timeInputOptions?: TimeInput;
    /** Calendar type component for selecting date */
    datePickerOptions?: DatePicker;
    /** Validation of field output value. */
    validation?: StringType;
    /**
     * Component type of the string input field
     * @readonly
     */
    componentType?: StringComponentTypeWithLiterals;
}
/** @oneof */
interface _StringComponentTypeOptionsOneOf {
    /** Text input field */
    textInputOptions?: TextInput;
    /** Selection field as radio group */
    radioGroupOptions?: RadioGroup;
    /** Selection field as drop down */
    dropdownOptions?: Dropdown;
    /** Field for selecting date and/or time */
    dateTimeOptions?: DateTimeInput;
    /** Phone input field */
    phoneInputOptions?: PhoneInput;
    /** Dropdown based component for selecting date */
    dateInputOptions?: DateInput;
    /** Field for selecting time */
    timeInputOptions?: TimeInput;
    /** Calendar type component for selecting date */
    datePickerOptions?: DatePicker;
}
interface InputField_Number extends InputField_NumberComponentTypeOptionsOneOf {
    /** Number value input field */
    numberInputOptions?: NumberInput;
    /** Rating value input field */
    ratingInputOptions?: RatingInput;
    /** Validation of field output value. */
    validation?: NumberType;
    /**
     * Component type of the number input field
     * @readonly
     */
    componentType?: NumberComponentTypeWithLiterals;
}
/** @oneof */
interface InputField_NumberComponentTypeOptionsOneOf {
    /** Number value input field */
    numberInputOptions?: NumberInput;
    /** Rating value input field */
    ratingInputOptions?: RatingInput;
}
interface _Boolean extends _BooleanComponentTypeOptionsOneOf {
    /** Checkbox input field */
    checkboxOptions?: Checkbox;
    /** Validation of field output value. */
    validation?: BooleanType;
    /**
     * Component type of the boolean input field
     * @readonly
     */
    componentType?: BooleanComponentTypeWithLiterals;
}
/** @oneof */
interface _BooleanComponentTypeOptionsOneOf {
    /** Checkbox input field */
    checkboxOptions?: Checkbox;
}
interface _Array extends _ArrayComponentTypeOptionsOneOf {
    /** Checkbox group input field */
    checkboxGroupOptions?: CheckboxGroup;
    /** Validation of array type. */
    validation?: ArrayType;
    /**
     * Component type of the array input field
     * @readonly
     */
    componentType?: ArrayComponentTypeWithLiterals;
}
/** @oneof */
interface _ArrayComponentTypeOptionsOneOf {
    /** Checkbox group input field */
    checkboxGroupOptions?: CheckboxGroup;
}
interface _Object {
    /** Validation of object type. */
    validation?: ObjectType;
}
interface WixFile extends WixFileComponentTypeOptionsOneOf {
    /** File upload input field */
    fileUploadOptions?: FileUpload;
    /** Signature input field */
    signatureOptions?: Signature;
    /**
     * Component type of the array input field
     * @readonly
     */
    componentType?: WixFileComponentTypeWithLiterals;
}
/** @oneof */
interface WixFileComponentTypeOptionsOneOf {
    /** File upload input field */
    fileUploadOptions?: FileUpload;
    /** Signature input field */
    signatureOptions?: Signature;
}
interface Payment extends PaymentComponentTypeOptionsOneOf {
    /** Checkbox group input field. */
    checkboxGroupOptions?: ProductCheckboxGroup;
    /** Donation input field. */
    donationInputOptions?: DonationInput;
    /**
     * Component type of the payment input field.
     * @readonly
     */
    componentType?: PaymentComponentTypeWithLiterals;
    /** Validation of payment type. */
    validation?: PaymentType;
}
/** @oneof */
interface PaymentComponentTypeOptionsOneOf {
    /** Checkbox group input field. */
    checkboxGroupOptions?: ProductCheckboxGroup;
    /** Donation input field. */
    donationInputOptions?: DonationInput;
}
interface MultilineAddress extends MultilineAddressComponentTypeOptionsOneOf {
    /** Multiline address input field. */
    multilineAddressOptions?: ComponentsMultilineAddress;
    /**
     * Component type of the multiline address field.
     * @readonly
     */
    componentType?: MultilineAddressComponentTypeWithLiterals;
    /** Validation of multiline address field output value. */
    validation?: MultilineAddressValidation;
}
/** @oneof */
interface MultilineAddressComponentTypeOptionsOneOf {
    /** Multiline address input field. */
    multilineAddressOptions?: ComponentsMultilineAddress;
}
interface DisplayField extends DisplayFieldDisplayFieldTypeOptionsOneOf {
    /** Component displaying rich content */
    richContentOptions?: RichContentOptions;
    /** Page navigation component resolving as navigation or submit buttons */
    pageNavigationOptions?: PageNavigationOptions;
    displayFieldType?: DisplayFieldTypeWithLiterals;
}
/** @oneof */
interface DisplayFieldDisplayFieldTypeOptionsOneOf {
    /** Component displaying rich content */
    richContentOptions?: RichContentOptions;
    /** Page navigation component resolving as navigation or submit buttons */
    pageNavigationOptions?: PageNavigationOptions;
}
declare enum DisplayFieldType {
    UNKNOWN_FIELD_TYPE = "UNKNOWN_FIELD_TYPE",
    RICH_CONTENT = "RICH_CONTENT",
    PAGE_NAVIGATION = "PAGE_NAVIGATION",
    LOGIN_BAR = "LOGIN_BAR"
}
/** @enumType */
type DisplayFieldTypeWithLiterals = DisplayFieldType | 'UNKNOWN_FIELD_TYPE' | 'RICH_CONTENT' | 'PAGE_NAVIGATION' | 'LOGIN_BAR';
interface RichContentOptions {
    /** Content of the header */
    richContent?: RichContent;
    /** Number of paragraphs visible. Other part is hidden under expandable section. If not provided all text visible. */
    maxShownParagraphs?: number | null;
}
interface PageNavigationOptions {
    /**
     * When button is not on last page it behaves as switch between pages page, text of label to go to next page.
     * @maxLength 65
     */
    nextPageText?: string | null;
    /**
     * When button is not on last page it behaves as switch between pages page, text of label to go to previous page.
     * @maxLength 65
     */
    previousPageText?: string | null;
    /**
     * Text on the button when button is submitting a form
     * @maxLength 65
     */
    submitText?: string | null;
}
interface Step {
    /**
     * Step ID.
     * @format GUID
     * @immutable
     */
    _id?: string;
    /**
     * Name of the step.
     * @maxLength 200
     */
    name?: string | null;
    /** Is step hidden */
    hidden?: boolean;
    /** Form step properties */
    layout?: FormLayout;
}
interface FormLayout {
    /** Layout for large break point. */
    large?: BreakPoint;
    /** Layout for medium break point. */
    medium?: BreakPoint;
    /** Layout for small break point. */
    small?: BreakPoint;
}
interface BreakPoint {
    /**
     * Description of layouts for items.
     * @maxSize 500
     */
    items?: ItemLayout[];
    /** Amount of columns of layout grid. */
    columns?: number | null;
    /** Row height of layout grid. */
    rowHeight?: number | null;
    /** Description of elements margins. */
    margin?: Margin;
    /** Description of elements paddings. */
    padding?: Margin;
    /**
     * Sections of the layout, which allow manage fields
     * @maxSize 100
     */
    sections?: BreakPointSection[];
}
interface ItemLayout {
    /**
     * Form field reference id.
     * @format GUID
     */
    fieldId?: string;
    /** Horizontal coordinate in the grid. */
    row?: number | null;
    /** Vertical coordinate in the grid. */
    column?: number | null;
    /** Height. */
    width?: number | null;
    /** Width. */
    height?: number | null;
}
interface Margin {
    /** Horizontal value. */
    horizontal?: number | null;
    /** Vertical value. */
    vertical?: number | null;
}
interface BreakPointSection {
    /**
     * Id of the section
     * @format GUID
     * @minLength 1
     */
    _id?: string;
    /** Horizontal coordinate in the grid. */
    row?: number | null;
    /**
     * A list of field identifiers that are permitted to be placed within a section.
     * The section will only accept fields with IDs specified in this list.
     * If the section encounters the $new key within the list,
     * it allows the inclusion of fields not explicitly listed,
     * enabling dynamic addition of new fields.
     * @maxSize 100
     * @maxLength 100
     */
    allowedFieldIds?: string[];
}
interface V2Rule {
    /**
     * Id of the rule
     * @format GUID
     * @immutable
     */
    _id?: string;
    /** Rule on which item properties or layouts will be changed. */
    expression?: ConditionNode;
    /**
     * Form items with defined properties that will be
     * changed when given condition is resolved to true.
     * @maxSize 500
     */
    overrides?: FormOverride[];
    /**
     * Name of the rule
     * @maxLength 200
     */
    name?: string | null;
}
/** Enum for different types of changeable properties. */
declare enum ChangeableProperty {
    /** Unknown property type. */
    UNKNOWN = "UNKNOWN",
    /** Required property type. */
    REQUIRED = "REQUIRED",
    /** Hidden property type. */
    HIDDEN = "HIDDEN",
    /** Allowed values property type. */
    ALLOWED_VALUES = "ALLOWED_VALUES"
}
/** @enumType */
type ChangeablePropertyWithLiterals = ChangeableProperty | 'UNKNOWN' | 'REQUIRED' | 'HIDDEN' | 'ALLOWED_VALUES';
interface RequiredOptions {
    /** Value of required property */
    value?: boolean;
}
interface HiddenOptions {
    /** Value of hidden property */
    value?: boolean;
}
interface AllowedValuesOptions {
    /**
     * Allowed values
     * @maxSize 300
     * @maxLength 200
     */
    value?: string[];
}
declare enum OverrideEntityType {
    UNKNOWN = "UNKNOWN",
    FIELD = "FIELD"
}
/** @enumType */
type OverrideEntityTypeWithLiterals = OverrideEntityType | 'UNKNOWN' | 'FIELD';
interface FieldOverride extends FieldOverridePropertyTypeOptionsOneOf {
    /** Required property overrides */
    requiredOptions?: RequiredOptions;
    /** Hidden property overrides */
    hiddenOptions?: HiddenOptions;
    /** Allowed values property overrides */
    allowedValuesOptions?: AllowedValuesOptions;
    /**
     * Overridden entity id
     * @immutable
     * @format GUID
     */
    fieldId?: string;
    /** Form entity properties path with new value, that will be changed on condition. */
    propertyType?: ChangeablePropertyWithLiterals;
}
/** @oneof */
interface FieldOverridePropertyTypeOptionsOneOf {
    /** Required property overrides */
    requiredOptions?: RequiredOptions;
    /** Hidden property overrides */
    hiddenOptions?: HiddenOptions;
    /** Allowed values property overrides */
    allowedValuesOptions?: AllowedValuesOptions;
}
interface ConditionNode extends ConditionNodeNodeOneOf {
    /** A compound condition that requires all conditions to be true. */
    and?: AndCondition;
    /** A compound condition that requires at least one condition to be true. */
    or?: OrCondition;
    /** A single condition in the rule. */
    condition?: V2Condition;
}
/** @oneof */
interface ConditionNodeNodeOneOf {
    /** A compound condition that requires all conditions to be true. */
    and?: AndCondition;
    /** A compound condition that requires at least one condition to be true. */
    or?: OrCondition;
    /** A single condition in the rule. */
    condition?: V2Condition;
}
interface AndCondition {
    /**
     * The list of conditions that must all be true.
     * @minSize 1
     * @maxSize 100
     */
    conditions?: ConditionNode[];
}
interface OrCondition {
    /**
     * The list of conditions where at least one must be true.
     * @minSize 1
     * @maxSize 100
     */
    conditions?: ConditionNode[];
}
interface V2Condition {
    /**
     * The property name to be evaluated, supports dot notation for nested properties.
     * @maxLength 100
     */
    fact?: string;
    /** The operator to use for comparison. */
    operator?: OperatorWithLiterals;
    /**
     * The value to compare against.
     * @maxLength 500
     */
    value?: string;
}
declare enum Operator {
    UNKNOWN = "UNKNOWN",
    EQUAL = "EQUAL",
    NOT_EQUAL = "NOT_EQUAL",
    EMPTY = "EMPTY",
    NOT_EMPTY = "NOT_EMPTY",
    CONTAINS = "CONTAINS",
    NOT_CONTAINS = "NOT_CONTAINS",
    LESS_THAN = "LESS_THAN",
    LESS_THAN_OR_EQUALS = "LESS_THAN_OR_EQUALS",
    GREATER_THAN = "GREATER_THAN",
    GREATER_THAN_OR_EQUALS = "GREATER_THAN_OR_EQUALS",
    BEFORE = "BEFORE",
    BEFORE_OR_EQUAL = "BEFORE_OR_EQUAL",
    AFTER = "AFTER",
    AFTER_OR_EQUAL = "AFTER_OR_EQUAL",
    BETWEEN = "BETWEEN",
    ANY = "ANY",
    ARRAY_EQUAL = "ARRAY_EQUAL",
    ARRAY_NOT_EQUAL = "ARRAY_NOT_EQUAL",
    CHECKED = "CHECKED",
    NOT_CHECKED = "NOT_CHECKED",
    IN = "IN",
    NOT_IN = "NOT_IN",
    IS_DATE_OLDER_THAN = "IS_DATE_OLDER_THAN",
    IS_DATE_OLDER_THAN_OR_EQUAL = "IS_DATE_OLDER_THAN_OR_EQUAL",
    IS_DATE_NEWER_THAN = "IS_DATE_NEWER_THAN",
    IS_DATE_NEWER_THAN_OR_EQUAL = "IS_DATE_NEWER_THAN_OR_EQUAL"
}
/** @enumType */
type OperatorWithLiterals = Operator | 'UNKNOWN' | 'EQUAL' | 'NOT_EQUAL' | 'EMPTY' | 'NOT_EMPTY' | 'CONTAINS' | 'NOT_CONTAINS' | 'LESS_THAN' | 'LESS_THAN_OR_EQUALS' | 'GREATER_THAN' | 'GREATER_THAN_OR_EQUALS' | 'BEFORE' | 'BEFORE_OR_EQUAL' | 'AFTER' | 'AFTER_OR_EQUAL' | 'BETWEEN' | 'ANY' | 'ARRAY_EQUAL' | 'ARRAY_NOT_EQUAL' | 'CHECKED' | 'NOT_CHECKED' | 'IN' | 'NOT_IN' | 'IS_DATE_OLDER_THAN' | 'IS_DATE_OLDER_THAN_OR_EQUAL' | 'IS_DATE_NEWER_THAN' | 'IS_DATE_NEWER_THAN_OR_EQUAL';
interface FormOverride extends FormOverrideEntityTypeOptionsOneOf {
    /** Field override properties. */
    fieldOptions?: FieldOverride;
    /**
     * Override entity type.
     * @immutable
     */
    entityType?: OverrideEntityTypeWithLiterals;
}
/** @oneof */
interface FormOverrideEntityTypeOptionsOneOf {
    /** Field override properties. */
    fieldOptions?: FieldOverride;
}
interface SubmitSettings extends SubmitSettingsSubmitSuccessActionOptionsOneOf {
    /** Options for showing a thank you message after submission. */
    thankYouMessageOptions?: ThankYouMessageOptions;
    /** Options for redirecting to a URL after submission. */
    redirectOptions?: RedirectOptions;
    /** Action that is triggered after a successful form submission. */
    submitSuccessAction?: SubmitSuccessActionWithLiterals;
}
/** @oneof */
interface SubmitSettingsSubmitSuccessActionOptionsOneOf {
    /** Options for showing a thank you message after submission. */
    thankYouMessageOptions?: ThankYouMessageOptions;
    /** Options for redirecting to a URL after submission. */
    redirectOptions?: RedirectOptions;
}
declare enum Target {
    UNKNOWN_TARGET = "UNKNOWN_TARGET",
    /** Open in the same browser tab. */
    SELF = "SELF",
    /** Open in a new browser tab. */
    BLANK = "BLANK"
}
/** @enumType */
type TargetWithLiterals = Target | 'UNKNOWN_TARGET' | 'SELF' | 'BLANK';
declare enum SubmitSuccessAction {
    UNKNOWN_SUBMIT_SUCCESS_ACTION = "UNKNOWN_SUBMIT_SUCCESS_ACTION",
    /** No action will be taken after submission. */
    NO_ACTION = "NO_ACTION",
    /** A thank you message will be shown after submission. */
    THANK_YOU_MESSAGE = "THANK_YOU_MESSAGE",
    /** The user will be redirected to a URL after submission. */
    REDIRECT = "REDIRECT"
}
/** @enumType */
type SubmitSuccessActionWithLiterals = SubmitSuccessAction | 'UNKNOWN_SUBMIT_SUCCESS_ACTION' | 'NO_ACTION' | 'THANK_YOU_MESSAGE' | 'REDIRECT';
interface ThankYouMessageOptions {
    /** Duration in seconds after which the message should disappear. If 0, the message will stay forever. */
    durationInSeconds?: number | null;
    /** The message shown after form submission. */
    richContent?: RichContent;
}
interface RedirectOptions {
    /**
     * The URL to which the user should be redirected after a successful form submission.
     * @maxLength 2000
     */
    redirectUrl?: string | null;
    /** How the URL should be opened. */
    target?: TargetWithLiterals;
}
declare enum TemplateType {
    UNKNOWN = "UNKNOWN",
    /** a template, which can be extended by a site specific form with custom properties */
    EXTENDABLE = "EXTENDABLE",
    /** a template, from which a demo form is created */
    DEMO = "DEMO",
    /**
     * a form input, having more than one field.
     * E.g. address (country, state, street, postal code), or phone number (country code, number)
     */
    FORM_INPUT = "FORM_INPUT"
}
/** @enumType */
type TemplateTypeWithLiterals = TemplateType | 'UNKNOWN' | 'EXTENDABLE' | 'DEMO' | 'FORM_INPUT';
interface ExtensionDetails {
    /** Allow user to add/remove custom field, not present in template */
    addCustomFields?: AddCustomFields;
    /** Allow user to override properties of already existing template fields */
    overrideTemplateFields?: OverrideTemplateFields;
    /** Allow user to delete specific fields */
    deleteTemplateFields?: DeleteTemplateFields;
}
declare enum CustomFieldsType {
    /** Allow user to add/remove any custom field, not present in template */
    ANY = "ANY"
}
/** @enumType */
type CustomFieldsTypeWithLiterals = CustomFieldsType | 'ANY';
declare enum EditableProperties {
    UNKNOWN = "UNKNOWN",
    /** Change property responsible for field requirement */
    REQUIRED = "REQUIRED",
    /** Change property responsible for field visibility */
    HIDDEN = "HIDDEN",
    /** Change property of field label */
    LABEL = "LABEL",
    /** Change property of field placeholder */
    PLACEHOLDER = "PLACEHOLDER",
    /** Change property of field description */
    DESCRIPTION = "DESCRIPTION",
    /**
     * Change property of validation specifying max/min boundaries for input value
     * maxLength/minLength for string, max/min for number.
     */
    INPUT_VALUE_LIMITS = "INPUT_VALUE_LIMITS",
    /** Change property responsible for field default value */
    DEFAULT_VALUE = "DEFAULT_VALUE"
}
/** @enumType */
type EditablePropertiesWithLiterals = EditableProperties | 'UNKNOWN' | 'REQUIRED' | 'HIDDEN' | 'LABEL' | 'PLACEHOLDER' | 'DESCRIPTION' | 'INPUT_VALUE_LIMITS' | 'DEFAULT_VALUE';
interface EditableFields {
    /**
     * List of editable properties for field
     * @maxSize 10
     */
    properties?: EditablePropertiesWithLiterals[];
}
interface AddCustomFields {
    /** Field types which can be added */
    fieldType?: CustomFieldsTypeWithLiterals;
}
interface OverrideTemplateFields {
    /** Editable properties by field id. */
    editableFields?: Record<string, EditableFields>;
}
interface DeleteTemplateFields {
    /**
     * List of ids, of fields which can be deleted
     * @format GUID
     * @maxSize 100
     */
    deletableFieldIds?: string[];
}
interface FieldGroup {
    /**
     * Id of group, on layout
     * @format GUID
     */
    _id?: string;
    /**
     * Label of group
     * @maxLength 350
     */
    label?: string | null;
}
interface RequiredIndicatorProperties {
    /** Required indicator. */
    requiredIndicator?: RequiredIndicatorWithLiterals;
    /** Required indicator placement. */
    requiredIndicatorPlacement?: RequiredIndicatorPlacementWithLiterals;
}
declare enum RequiredIndicator {
    /** Unknown required indicator. */
    UNKNOWN_INDICATOR = "UNKNOWN_INDICATOR",
    /** Asterisk (*). */
    ASTERISK = "ASTERISK",
    /** Text (default: "Required"). */
    TEXT = "TEXT",
    /** None. */
    NONE = "NONE"
}
/** @enumType */
type RequiredIndicatorWithLiterals = RequiredIndicator | 'UNKNOWN_INDICATOR' | 'ASTERISK' | 'TEXT' | 'NONE';
declare enum RequiredIndicatorPlacement {
    /** Unknown required indicator placement. */
    UNKNOWN_PLACEMENT = "UNKNOWN_PLACEMENT",
    /** After field title. */
    AFTER_FIELD_TITLE = "AFTER_FIELD_TITLE",
    /** Before field title. */
    BEFORE_FIELD_TITLE = "BEFORE_FIELD_TITLE"
}
/** @enumType */
type RequiredIndicatorPlacementWithLiterals = RequiredIndicatorPlacement | 'UNKNOWN_PLACEMENT' | 'AFTER_FIELD_TITLE' | 'BEFORE_FIELD_TITLE';
/** Describes a setting group of a notification */
interface NotificationContent {
    single?: SingleContent;
    grouped?: GroupedContent;
}
/** notification content. */
interface SingleContent {
    /** Title. */
    title?: string | null;
    /** Text that appears in the nofication. */
    message?: string;
    /** Action that can be triggered in the notification. */
    action?: string | null;
}
/** notification content. */
interface GroupedContent {
    /** Title. */
    title?: string | null;
    /** Message. */
    message?: string;
    /** Action. */
    action?: string | null;
}
/** Describes topic of a notification */
interface BroadcastList {
    /** @maxSize 20 */
    params?: Param[];
}
interface Param {
    _id?: string;
    displayName?: string;
}
interface PayoutsProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
}
/** Configuration for ReviewsEntityCatalogProvider */
interface ReviewsEntityCatalogProviderConfig {
    /** URI where the SPI Implementer is deployed */
    uriConfig?: SpiBaseUri;
    /**
     * Namespace of catalog provider
     * @maxLength 100
     */
    namespace?: string;
    /** Flag that indicates if verified reviews are enabled */
    verifiedReviewsEnabled?: boolean;
}
interface VeloPublishPipelineTaskProviderConfig {
    /** URI where the SPI Implementer is deployed */
    baseUri?: SpiBaseUri;
    /**
     * The Velo Task name
     * @maxSize 100
     */
    implementerTasksNames?: WixCodePublishTaskNameWithLiterals[];
}
declare enum WixCodePublishTaskName {
    /** unknown */
    UNKNOWN = "UNKNOWN",
    /** user code bundle */
    USER_CODE_BUNDLE = "USER_CODE_BUNDLE",
    /** exported functions analysis */
    EXPORTED_FUNCTIONS_ANALYSIS = "EXPORTED_FUNCTIONS_ANALYSIS",
    /** imported namespaces analysis */
    IMPORTED_NAMESPACES_ANALYSIS = "IMPORTED_NAMESPACES_ANALYSIS",
    /** page details analysis */
    PAGE_DETAILS_ANALYSIS = "PAGE_DETAILS_ANALYSIS",
    /** user code validation */
    USER_CODE_VALIDATION = "USER_CODE_VALIDATION",
    /** code packages dependencies registration */
    CODE_PACKAGES_REGISTRATION = "CODE_PACKAGES_REGISTRATION"
}
/** @enumType */
type WixCodePublishTaskNameWithLiterals = WixCodePublishTaskName | 'UNKNOWN' | 'USER_CODE_BUNDLE' | 'EXPORTED_FUNCTIONS_ANALYSIS' | 'IMPORTED_NAMESPACES_ANALYSIS' | 'PAGE_DETAILS_ANALYSIS' | 'USER_CODE_VALIDATION' | 'CODE_PACKAGES_REGISTRATION';
interface FunctionsShopPriceSpiConfig {
    /** Uri config */
    uriConfig?: SpiBaseUri;
    /**
     * function shop id
     * @format GUID
     */
    functionShopId?: string | null;
    /** Namespace */
    namespace?: Namespace;
    /**
     * Repeated namespace case
     * @maxSize 100
     */
    namespaces?: Namespace[];
    /**
     * String name
     * @maxLength 100
     */
    shopName?: string | null;
    /** Simple double */
    shopNumber?: number | null;
}
interface Namespace {
    /**
     * Namespace name
     * @maxLength 100
     */
    name?: string | null;
    /**
     * Additional function shop id
     * @format GUID
     */
    functionShopId?: string | null;
}
/**
 * A component that describes a Function
 * Design is highly influenced by business schema api
 */
interface _Function {
    /**
     * Function method definitions
     * @maxSize 100
     */
    definitions?: FunctionDefinition[];
    /** Function configuration */
    configuration?: Configuration;
    /** Function description */
    description?: Description;
}
interface Input {
    /**
     * Schema definition: https://json-schema.org/draft/2020-12/schema
     * Protobuf does not support `$` variables -- cannot define the json-schema in protobuf
     */
    schema?: Record<string, any> | null;
    /** UI definition */
    ui?: Record<string, any> | null;
    /**
     * Input display description
     * @maxLength 100
     */
    displayDescription?: string | null;
    /** Builder SPI */
    builderSpi?: BuilderSpi;
}
interface BuilderSpi {
    /**
     * SPI url called from Function Builder
     * @maxLength 1000
     */
    baseUri?: string | null;
    /** Whether SPI supports appending Input Schema dynamically */
    dynamicSchemaFetchingEnabled?: boolean | null;
}
interface Output {
    /**
     * Schema definition: https://json-schema.org/draft/2020-12/schema
     * Protobuf does not support `$` variables -- cannot define the json-schema in protobuf
     */
    schema?: Record<string, any> | null;
    /** UI definition */
    ui?: Record<string, any> | null;
    /** Defined state */
    defined?: State;
    /** Empty state */
    empty?: State;
}
interface State {
    /**
     * State description
     * @maxLength 100
     */
    description?: string | null;
}
interface Spi {
    /**
     * SPI fqdn
     * @maxLength 200
     */
    fqdn?: string | null;
    /**
     * Configuration based on dev center SPI component configuration
     * Schema definition: https://json-schema.org/draft/2020-12/schema
     */
    schema?: Record<string, any> | null;
    /** UI definition */
    ui?: Record<string, any> | null;
}
/**
 * Function definition
 * IMPORTANT! Initial product will support only single function definition
 */
interface FunctionDefinition {
    /**
     * Method
     * @maxLength 255
     */
    method?: string;
    /** Function input. */
    input?: Input;
    /** Function output. */
    output?: Output;
    /**
     * @format GUID
     * @readonly
     */
    triggerId?: string | null;
}
interface Configuration {
    /** Function can be implemented multiple times on single site */
    multipleInstancesAllowed?: boolean | null;
    /** Spi configuration */
    spi?: Spi;
    /** Do not include the function in the functions catalog in the BM */
    hideFromFunctionsCatalog?: boolean | null;
}
interface Description {
    /** @maxLength 600 */
    aboutDescription?: string | null;
    /**
     * Description of how it works
     * @maxLength 1000
     */
    howItWorksDescription?: string | null;
    /**
     * Description of the outcome
     * @maxLength 600
     */
    outcomeDescription?: string | null;
    /** Representative image */
    representativeImage?: string;
    /**
     * Title of the builderless function template selection modal
     * @maxLength 50
     */
    builderlessTemplateSelectionModalTitle?: string | null;
    /**
     * Subtitle of the builderless function template selection modal
     * @maxLength 100
     */
    builderlessTemplateSelectionModalSubtitle?: string | null;
}
interface CheckoutContentSPIConfig {
    /**
     * Base URI where the endpoints are called. Wix eCommerce appends the endpoint path to the base URI.
     * @minLength 1
     * @maxLength 1000
     */
    deploymentUri?: string;
    /**
     * Text to display in place of the "Continue shopping" link.
     * @maxLength 30
     */
    continueShoppingLink?: string | null;
    /**
     * Text to display in place of the "Order summary" title.
     * @minLength 1
     * @maxLength 30
     */
    orderSummary?: string | null;
    /**
     * Text to display in place of the "Customer details" title.
     * @minLength 1
     * @maxLength 30
     */
    customerDetails?: string | null;
    /**
     * Text to display in place of the "Review and place order" title.
     * @minLength 1
     * @maxLength 50
     */
    reviewAndPlaceOrder?: string | null;
    /**
     * Text to display in place of the "Place order" button.
     * @minLength 1
     * @maxLength 50
     */
    placeOrderButton?: string | null;
    /**
     * Text to display in place of the "Place order & pay" button.
     * @minLength 1
     * @maxLength 50
     */
    placeOrderPayButton?: string | null;
}
interface V2CommunicationChannelConfiguration {
    /**
     * The channel provider URI that will be called in runtime
     * @maxLength 2000
     */
    deploymentUri?: string;
    /** The main configuration of the channel */
    config?: ChannelChannelConfiguration;
    /** States whether or not specific methods were implemented by the provider in order to know whether to call them in runtime */
    implementedMethods?: ChannelImplementedMethods;
}
interface ChannelChannelConfiguration extends ChannelChannelConfigurationMessagingConfigOneOf {
    /** Direct messaging configuration */
    directMessagingConfig?: DmDirectMessageConfig;
    /** Email messaging configuration */
    emailConfig?: EmailEmailMessageConfig;
    /** Sms messaging configuration */
    smsConfig?: SmsSmsMessageConfig;
    /**
     * kebab-case channel identifier. Allows the provider to register multiple channels with the same provider app.
     * @minLength 1
     * @maxLength 50
     */
    channelKey?: string;
    /** The type of the communication channel */
    type?: ChannelConfigurationChannelTypeWithLiterals;
    /** Specific provider branding parameters for the channel */
    branding?: ChannelChannelBranding;
}
/** @oneof */
interface ChannelChannelConfigurationMessagingConfigOneOf {
    /** Direct messaging configuration */
    directMessagingConfig?: DmDirectMessageConfig;
    /** Email messaging configuration */
    emailConfig?: EmailEmailMessageConfig;
    /** Sms messaging configuration */
    smsConfig?: SmsSmsMessageConfig;
}
/** The type of the communication channel */
declare enum ChannelConfigurationChannelType {
    UNKNOWN_CHANNEL_TYPE = "UNKNOWN_CHANNEL_TYPE",
    DIRECT_MESSAGING = "DIRECT_MESSAGING",
    EMAIL = "EMAIL",
    SMS = "SMS"
}
/** @enumType */
type ChannelConfigurationChannelTypeWithLiterals = ChannelConfigurationChannelType | 'UNKNOWN_CHANNEL_TYPE' | 'DIRECT_MESSAGING' | 'EMAIL' | 'SMS';
interface DmDirectMessageConfig {
    /**
     * Direct message types accepted by the provider.
     * Only supported types will be sent to the provider.
     * If the provider supports all message types, this field can be empty.
     * @maxSize 100
     */
    acceptedMessageTypes?: AcceptedMessageTypesAcceptedDirectMessageTypeWithLiterals[];
    /** Supported media types (mime types) and sizes */
    mediaCapabilities?: ChannelMediaCapabilities;
    /** Defines whether or not sending messages will be available for recipients without contact Id */
    allowAnonymousRecipients?: boolean;
    /**
     * TODO: we might consider changing/removing this field on next phases due to a strong dependency on Wix live site
     * Indicates whether or not the channel requires a live Wix website for a proper end to end channel functionality,
     * (for example, a live site is required for chat use case)
     */
    requireLiveSite?: boolean;
}
/** 'TEXT' type is assumed to be always supported, hence not explicitly annotated. */
declare enum AcceptedMessageTypesAcceptedDirectMessageType {
    UNKNOWN_DIRECT_MESSAGE_TYPE = "UNKNOWN_DIRECT_MESSAGE_TYPE",
    MEDIA = "MEDIA",
    CARD = "CARD",
    MINIMAL = "MINIMAL",
    FORM = "FORM",
    SYSTEM = "SYSTEM"
}
/** @enumType */
type AcceptedMessageTypesAcceptedDirectMessageTypeWithLiterals = AcceptedMessageTypesAcceptedDirectMessageType | 'UNKNOWN_DIRECT_MESSAGE_TYPE' | 'MEDIA' | 'CARD' | 'MINIMAL' | 'FORM' | 'SYSTEM';
interface ChannelMediaCapabilities {
    /** When marked as true, 'supported_media_types' will be ignored. */
    allMediaTypes?: boolean;
    /** Maximal file size in bytes of a single file in a message */
    maxFileSizeInBytes?: number | null;
    /**
     * List for supported media MIME types. Used when allMediaTypes is set to `false`
     * Allowed MIME types must be according to the format as described here:
     * https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Common_types
     * @maxSize 50
     * @maxLength 255
     */
    supportedMediaTypes?: string[];
}
interface EmailEmailMessageConfig {
    /** Supported media types (mime types) and sizes */
    mediaCapabilities?: ChannelMediaCapabilities;
    /** Maximal size in bytes of total media items in a message. */
    maxTotalFilesSizeInBytes?: number | null;
}
interface SmsSmsMessageConfig {
    /**
     * SMS message types accepted by the provider. Only supported types will be sent to the provider.
     * @minSize 1
     * @maxSize 100
     */
    acceptedMessageTypes?: AcceptedMessageTypesAcceptedSmsMessageTypeWithLiterals[];
    /** Supported media types (mime types) and sizes */
    mediaCapabilities?: ChannelMediaCapabilities;
    /** Optional - maximum sms message length in characters, if not given, will be unlimited */
    maxCharacters?: string | null;
}
declare enum AcceptedMessageTypesAcceptedSmsMessageType {
    UNKNOWN_SMS_MESSAGE_TYPE = "UNKNOWN_SMS_MESSAGE_TYPE",
    SMS = "SMS",
    MMS = "MMS"
}
/** @enumType */
type AcceptedMessageTypesAcceptedSmsMessageTypeWithLiterals = AcceptedMessageTypesAcceptedSmsMessageType | 'UNKNOWN_SMS_MESSAGE_TYPE' | 'SMS' | 'MMS';
interface ChannelChannelBranding {
    /**
     * The name of the channel, e.g. `Facebook` / `SMS`
     * @minLength 1
     * @maxLength 100
     */
    displayName?: string;
    /**
     * The name of the channel provider (e.g. Wix, Meta, Google)
     * @minLength 1
     * @maxLength 100
     */
    providerName?: string;
    /**
     * The description of the channel
     * @minLength 1
     * @maxLength 500
     */
    description?: string | null;
    /** Relevant brand icons */
    brandIcons?: ChannelBrandIcons;
}
/** Brand icons required for correct channel integration */
interface ChannelBrandIcons {
    /** Channel branding vector Icon */
    vectorImage?: UpstreamWixCommonImage;
    /** Channel branding Black & White Icon */
    bwOutlineVectorImage?: UpstreamWixCommonImage;
}
interface UpstreamWixCommonImage {
    /**
     * WixMedia image ID.
     * @maxLength 2000
     */
    _id?: string | null;
    /**
     * Image URL.
     * @format WEB_URL
     * @readonly
     */
    url?: string | null;
}
interface ChannelImplementedMethods {
    /** Implements getQuotaInfo */
    getQuotaInfo?: boolean;
    /** Implements validateSendingEligibility */
    validateSendingEligibility?: boolean;
    /** Implements updateMessageStatus */
    updateMessageStatus?: boolean;
}
interface WebhookComponentData {
    /**
     * The slug of the webhook, as in webhooks catalog
     * @minLength 1
     * @maxLength 128
     */
    webhookSlug?: string;
    /**
     * The callback url to be called when the webhook is triggered
     * @format WEB_URL
     */
    callbackUrl?: string;
}
/** A component that holds topology data for an application. */
interface TopologyComponentData {
    /**
     * Records of topology
     * @format WEB_URL
     */
    topology?: Record<string, string>;
}
interface CustomRewardProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * User-friendly name of the custom reward
     * @maxLength 100
     */
    rewardName?: string;
    /**
     * User-friendly description of the custom reward
     * @maxLength 500
     */
    rewardDescription?: string;
}
/** Wix Users can choose to create a "Function" component according to predefined recipes for smoother user experience */
interface FunctionRecipe {
    /**
     * Description of the function recipe
     * @maxLength 300
     */
    displayDescription?: string;
    /**
     * Meta site from which template function was taken to create a recipe
     * @format GUID
     */
    originMetaSiteId?: string;
    /**
     * Function in the meta site which was used as a template to create a recipe
     * @format GUID
     */
    originFunctionId?: string;
    /**
     * "Function" component/extension that this recipe is about
     * @format GUID
     */
    functionExtensionId?: string;
    /**
     * Created function id
     * @format GUID
     */
    functionId?: string | null;
    /**
     * Builderless flow form template id
     * @format GUID
     */
    formTemplateExtensionId?: string | null;
}
/** A backoffice component for external url`s */
interface BackOfficeExternalUrl {
    /**
     * the external url to be opened
     * @maxLength 250
     */
    url?: string | null;
    /** general component data */
    metaData?: ComponentMetaData;
    /**
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    iconKey?: string | null;
}
interface FactorConfig {
    /** the base URI where all the methods are deployed. */
    uriConfig?: SpiBaseUri;
    /** the type of the factor */
    factorType?: FactorTypeWithLiterals;
    /** whether the factor supports verify without enrolling first */
    supportsVerifyWithoutEnroll?: boolean;
}
declare enum FactorType {
    UNKNOWN_FACTOR_TYPE = "UNKNOWN_FACTOR_TYPE",
    PASSWORD = "PASSWORD",
    SMS = "SMS",
    CALL = "CALL",
    EMAIL = "EMAIL",
    TOTP = "TOTP",
    PUSH = "PUSH"
}
/** @enumType */
type FactorTypeWithLiterals = FactorType | 'UNKNOWN_FACTOR_TYPE' | 'PASSWORD' | 'SMS' | 'CALL' | 'EMAIL' | 'TOTP' | 'PUSH';
interface DiscountsSPIConfig {
    /**
     * Base URI where the endpoints are called.
     * Wix eCommerce appends the endpoint path to the base URI.
     * @minLength 1
     * @maxLength 200
     */
    deploymentUri?: string;
}
interface VeloCustomCss {
    /**
     * The grid id containing the css
     * @format GUID
     */
    gridId?: string;
    /**
     * Path to the css file in the grid
     * @minLength 2
     * @maxLength 255
     */
    filePath?: string;
}
interface AdaptiveComponentProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * identifier for SPI implementer
     * @format GUID
     */
    implementerConfigId?: string;
}
interface ActionSpiConfig {
    /**
     * The deployment uri of the assistant action
     * @maxLength 1000
     */
    deploymentUri?: string;
    /**
     * The name of the assistant action
     * @minLength 1
     * @maxLength 100
     */
    actionName?: string;
}
interface InventorySpiConfig {
    /**
     * Base URI where the endpoints are called.
     * Wix eCommerce appends the endpoint path to the base URI.
     * @minLength 1
     * @maxLength 200
     */
    deploymentUri?: string;
}
interface Monitoring extends MonitoringOptionsOneOf {
    /** Sentry provider options */
    sentryOptions?: SentryOptions;
    /** Panorama provider options */
    panoramaOptions?: PanoramaOptions;
    /** Provider type */
    type?: MonitoringTypeWithLiterals;
}
/** @oneof */
interface MonitoringOptionsOneOf {
    /** Sentry provider options */
    sentryOptions?: SentryOptions;
    /** Panorama provider options */
    panoramaOptions?: PanoramaOptions;
}
interface SentryOptions {
    /**
     * The sentry DSN
     * @minLength 1
     * @maxLength 255
     */
    dsn?: string;
}
interface Project {
    /**
     * Group id (e.g. com.wixpress)
     * @minLength 1
     * @maxLength 100
     */
    groupId?: string;
    /**
     * Short artifact id
     * @minLength 1
     * @maxLength 100
     */
    artifactId?: string;
    /**
     * Build fingerprint
     * @minLength 1
     * @maxLength 100
     */
    fingerprint?: string;
}
declare enum MonitoringType {
    UNKNOWN_PROVIDER = "UNKNOWN_PROVIDER",
    SENTRY = "SENTRY",
    PANORAMA = "PANORAMA"
}
/** @enumType */
type MonitoringTypeWithLiterals = MonitoringType | 'UNKNOWN_PROVIDER' | 'SENTRY' | 'PANORAMA';
interface PanoramaOptions {
    /** Sentry config */
    sentry?: SentryOptions;
    /** Project config */
    project?: Project;
}
interface PluginConfig {
    /** @maxLength 1000 */
    deploymentUri?: string;
    /**
     * has to be unique across all plugins
     * @maxLength 1024
     */
    pluginName?: string;
    /**
     * has to be unique across all plugins
     * @maxLength 1024
     */
    pluginDisplayName?: string;
    startingEnforcementDate?: Date | null;
    importanceLevel?: ImportanceLevelWithLiterals;
    /** @maxSize 100 */
    constraints?: Constraint[];
}
interface Consequence {
    escalation?: EscalationWithLiterals;
    /** days to resolve the violation */
    daysToResolve?: number | null;
}
declare enum Escalation {
    BREAK_BUILD = "BREAK_BUILD",
    BLOCK_ROLLOUT = "BLOCK_ROLLOUT",
    BLOCK_FUTURE_ROLLOUT = "BLOCK_FUTURE_ROLLOUT",
    OPEN_BUG_SLA = "OPEN_BUG_SLA",
    /** only shows violation in papi-dashboard */
    VISIBILITY = "VISIBILITY"
}
/** @enumType */
type EscalationWithLiterals = Escalation | 'BREAK_BUILD' | 'BLOCK_ROLLOUT' | 'BLOCK_FUTURE_ROLLOUT' | 'OPEN_BUG_SLA' | 'VISIBILITY';
declare enum ImportanceLevel {
    LOW = "LOW",
    MEDIUM = "MEDIUM",
    HIGH = "HIGH"
}
/** @enumType */
type ImportanceLevelWithLiterals = ImportanceLevel | 'LOW' | 'MEDIUM' | 'HIGH';
interface Constraint {
    /** @maxLength 1024 */
    _id?: string;
    /** @maxSize 10 */
    consequences?: Consequence[];
    /**
     * link to FAQ docs
     * @maxLength 1024
     */
    faqLink?: string;
}
interface UnifiedLightbox {
    /** Base info of component by shared logic of unified components */
    base?: BaseInfo;
    /** Settings for how the lightbox integrates with the editor */
    editorSettings?: LightboxEditorSettings;
    /** Options for how to close the lightbox component */
    closeOptions?: LightboxCloseOptions;
    /** Content of a lightbox */
    content?: LightboxContent;
}
interface LightboxEditorSettings {
    /** Basic editor settings that are relevant to all page types */
    base?: PageEditorSettings;
}
interface LightboxCloseOptions {
    /** If true or unset, the lightbox will be closed when overlay is clicked */
    closeOnOverlayClick?: boolean | null;
    /** Show an X button that closes the lightbox component */
    showXButton?: boolean | null;
}
interface LightboxContent {
    /**
     * Widgets to add as content in a lightbox
     * @maxSize 1
     */
    widgets?: PageWidgetAsContent[];
}
interface PageWidgetAsContent {
    /**
     * GUID of widget to use as content of page
     * @format GUID
     */
    widgetGuid?: string;
    /** The preset should be used */
    preset?: MainPresets;
    /** Mark widget as essential for the existence of the app (force to delete the whole app) */
    essential?: boolean;
}
interface FormSpiExtensionConfig {
    /**
     * Deployment URI where the endpoints are called. Wix Forms appends the endpoint path to the deployment URI.
     * For example, to call the Override Form endpoint at `https://my-form.com/v4/forms/override`,
     * the `deploymentUri` you provide here is `https://my-form.com/`.
     */
    deploymentUri?: SpiBaseUri;
    /**
     * The app which the form belongs to. For example, the namespace for the Wix Forms app is `wix.form_app.form`.
     *
     * Call `Get Form` to retrieve the namespace.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /**
     * The IDs of the specific forms that will trigger the defined methods when a form is requested on the API.
     * This field is optional. If empty, requests for all forms will trigger the methods.
     * @maxSize 100
     * @format GUID
     */
    formIds?: string[];
}
interface SchemaGroup {
    /**
     * SchemaGroup ID. Field is read only.
     * @format GUID
     * @readonly
     */
    _id?: string | null;
    /**
     * Date and time the SchemaGroup was created. Field is read only.
     * @readonly
     */
    _createdDate?: Date | null;
    /**
     * Date and time the SchemaGroup was last updated. Field is read only.
     * @readonly
     */
    _updatedDate?: Date | null;
    /**
     * Name of the SchemaGroup. Max symbol length is 100. Field is translatable.
     * @maxLength 100
     */
    name?: string | null;
    /**
     * List of Schemas.
     * @maxSize 50
     */
    groupElements?: SchemaGroupElement[];
}
interface SchemaGroupElement {
    /**
     * ID of the Schema. If the schema group uses an element from another existing group, the reference id to that group has to be provided here.
     * @format GUID
     */
    _id?: string | null;
    /** Position of the schema group element. */
    position?: number | null;
}
interface Panel extends PanelSelectedContentTypeOneOf {
    /**
     * The URL to the html page of the panel in case of iFrame
     * @format WEB_URL
     */
    url?: string;
    /**
     * The title of the panel
     * @minLength 1
     * @maxLength 200
     */
    displayName?: string;
    /** Optional: The size of the panel */
    size?: PanelSize;
    /** The selected panel content type */
    contentType?: PanelContentTypeWithLiterals;
}
/** @oneof */
interface PanelSelectedContentTypeOneOf {
    /**
     * The URL to the html page of the panel in case of iFrame
     * @format WEB_URL
     */
    url?: string;
}
interface PanelSize {
    /**
     * height of the panel in px
     * @min 150
     */
    height?: number | null;
    /** width of the panel */
    width?: WidthWithLiterals;
}
declare enum Width {
    SMALL = "SMALL",
    MEDIUM = "MEDIUM",
    LARGE = "LARGE"
}
/** @enumType */
type WidthWithLiterals = Width | 'SMALL' | 'MEDIUM' | 'LARGE';
/** Represents the options for panel content types */
declare enum PanelContentType {
    UNKNOWN_PanelContentType = "UNKNOWN_PanelContentType",
    url = "url"
}
/** @enumType */
type PanelContentTypeWithLiterals = PanelContentType | 'UNKNOWN_PanelContentType' | 'url';
/** Represents the information needed for code panels */
interface CodePanel {
    /**
     * The url for the panel code
     * @format WEB_URL
     */
    bundleUrl?: string;
    /**
     * The url for the panel css
     * @format WEB_URL
     */
    cssUrl?: string | null;
}
interface PurchaseValidationsConfig {
    /** deployment URI */
    uriConfig?: SpiBaseUri;
}
interface BrowserStorage {
    /** The type of browser storage used */
    type?: StorageTypeWithLiterals;
    /**
     * The name of the storage item in the browser (as can be seen in DEV Console)
     * @maxLength 100
     */
    name?: string;
    /**
     * A human friendly description of the storage item and what it is used for.
     * > This is for allowing users to display consent pages on their sites with this information.
     * @minLength 10
     * @maxLength 500
     */
    description?: string;
    /**
     * The consent category to which the storage item belongs.
     * This defines when this storage item is allowed to be used in a visitor session.
     * > This is legally important for complying with EU privacy law, so make sure to define this carefully.
     */
    consentCategory?: ConsentCategoryWithLiterals;
    /** Where this storage item will be set in the browser (User domain or the App domain) */
    domain?: StorageDomainWithLiterals;
}
/** The type of storage we are declaring */
declare enum StorageType {
    UNKNOWN_STORAGE_TYPE = "UNKNOWN_STORAGE_TYPE",
    /** A [cookie](https://developer.mozilla.org/en-US/docs/Web/API/Document/cookie) we store in the browser */
    COOKIE = "COOKIE",
    /** A [localStorage](https://developer.mozilla.org/en-US/docs/Web/API/Window/localStorage) item that persists across tabs in the domain */
    LOCALSTORAGE = "LOCALSTORAGE",
    /** A [sessionStorage](https://developer.mozilla.org/en-US/docs/Web/API/Window/sessionStorage) item for a specific tab in the domain */
    SESSIONSTORAGE = "SESSIONSTORAGE",
    /** An item in [IndexDB](https://developer.mozilla.org/en-US/docs/Web/API/IndexedDB_API) */
    INDEXDB = "INDEXDB"
}
/** @enumType */
type StorageTypeWithLiterals = StorageType | 'UNKNOWN_STORAGE_TYPE' | 'COOKIE' | 'LOCALSTORAGE' | 'SESSIONSTORAGE' | 'INDEXDB';
/** The category for EU and US Privacy Law classification */
declare enum ConsentCategory {
    /** This is an invalid value, you must classify your storage item. */
    UNKNOWN_CATEGORY = "UNKNOWN_CATEGORY",
    /** Is required for your app to function and does not use the data to do any tracking. */
    essential = "essential",
    /** Related to performanc and functional additions that are niceities but the app can work without. */
    functional = "functional",
    /** Related to analytics and may including tracking sessions and vistors to the site. */
    analytics = "analytics",
    /** Related to advertising, upselling and marketing data collected to be used. */
    advertising = "advertising"
}
/** @enumType */
type ConsentCategoryWithLiterals = ConsentCategory | 'UNKNOWN_CATEGORY' | 'essential' | 'functional' | 'analytics' | 'advertising';
declare enum StorageDomain {
    UNKNOWN_STORAGE_DOMAIN = "UNKNOWN_STORAGE_DOMAIN",
    /** Storing the values in the domain of the website the app is installed on */
    SITE_DOMAIN = "SITE_DOMAIN",
    /** Storing the values in the Wix Backoffice domain */
    WIX_DOMAIN = "WIX_DOMAIN",
    /** Storing the values as 3rd party in the application domain */
    APP_DOMAIN = "APP_DOMAIN"
}
/** @enumType */
type StorageDomainWithLiterals = StorageDomain | 'UNKNOWN_STORAGE_DOMAIN' | 'SITE_DOMAIN' | 'WIX_DOMAIN' | 'APP_DOMAIN';
/** Describe SDK module definition for an app */
interface SdkDefinition {
    /**
     * The SDK module name, for example "ecom"
     * @maxLength 100
     */
    sdkModuleName?: string;
}
/** A container (slot) that can be extended by other applications (e.g. widget plugin) */
interface SiteWidgetSlot {
    /** A container (slot) common properties. */
    slotData?: SlotData;
    /**
     * Role of the slot component, uniquely identifying it within its parent component (used by Velo).
     * @maxLength 50
     */
    slotKeyName?: string | null;
}
/** Configuration for the event validation provider. */
interface EventValidationProviderConfig {
    /** The base URI to reach the provider's service. */
    baseUri?: SpiBaseUri;
    /**
     * List of validation targets specifying the methods to validate and optional filters.
     * @minSize 1
     * @maxSize 10
     */
    validationTargets?: ValidationTarget[];
}
interface ValidationTarget {
    /** The method to validate. */
    method?: MethodWithLiterals;
    /**
     * Optional WQL filter applied to the events for validation.
     * Only events matching this filter will be validated.
     * Supported event fields:
     * - `appId`
     */
    filter?: Record<string, any> | null;
}
declare enum Method {
    /** Validate an event before creation. */
    CREATE = "CREATE",
    /** Validate an event before update. */
    UPDATE = "UPDATE",
    /** Validate an event before cancel. */
    CANCEL = "CANCEL"
}
/** @enumType */
type MethodWithLiterals = Method | 'CREATE' | 'UPDATE' | 'CANCEL';
/** Client Service is a broad category encompassing any value, function, or feature that an application needs. A service is typically a class with a narrow, well-defined purpose. A component is one type of class that can use DI. */
interface ClientSideService {
    /**
     * ID of a  UI service.
     * @format GUID
     */
    _id?: string;
    /**
     * Exported name of a service
     * @minLength 2
     * @maxLength 100
     */
    exportedName?: string;
    /** Definition of a service */
    definition?: Definition;
    /** Implementation metadata of a service, a service with no runtime definition will be considered as an atom. */
    implementation?: Implementation;
}
interface Npm {
    /**
     * Npm package name
     * @minLength 2
     * @maxLength 100
     */
    packageName?: string;
    /**
     * Npm semantic version
     * @minLength 2
     * @maxLength 100
     */
    packageVersion?: string;
    /**
     * Package entry point, default to main entry
     * @minLength 2
     * @maxLength 100
     */
    specifier?: string | null;
    /**
     * Imported name, default to default import
     * @minLength 2
     * @maxLength 100
     */
    importedName?: string | null;
}
interface Definition {
    /** Reflecting a service definition using npm package */
    npm?: Npm;
}
interface Implementation {
    /** Reflecting a service runtime using npm package */
    npm?: Npm;
    /**
     * Bundle URL
     * @format WEB_URL
     */
    bundleUrl?: string | null;
    /**
     * reference to other client side services
     * @format GUID
     * @maxSize 100
     */
    serviceDependencies?: string[];
}
interface BillingSettingsConfig {
    /**
     * name of the subscription type was it appears in relevant screens in Billing Platform
     * @minLength 1
     * @maxLength 200
     */
    subscriptionType?: string;
    /** whether subscriptions end date can be updated */
    allowSubscriptionExtension?: boolean;
    /** whether subscription can be canceled not only immediately, but also at end of billing cycle by turning off auto-renew */
    allowAutoRenewOff?: boolean;
    /** whether changes can be made to the payment schedule and under what conditions. */
    paymentDateModification?: PaymentDateModification;
}
interface PaymentDateModification {
    /**
     * Indicates whether the merchant can modify the payment date.
     * A value of true permits changes, while false means the payment date cannot be altered.
     */
    allowed?: boolean;
    /**
     * Specifies if adjustments to the price are enabled when the payment date is modified.
     * If true, changing the date to an earlier one results in proration,
     * while changing it to a later date incurs an extra charge.
     * Irrelevant if allowed is false.
     */
    priceAdjustmentEnabled?: boolean;
}
/** A component holding configuration of Patterns Wizard */
interface PatternsWizard {
    /** Configuration of the patterns wizard */
    config?: Record<string, any> | null;
}
interface ApplicationProfileProviderConfig {
    /** URI where the SPI implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /** Implemented methods */
    implementedMethods?: V1ImplementedMethods;
    /** default application profile */
    defaultApplicationProfile?: ApplicationProfile;
}
interface V1ImplementedMethods {
    /** Implement QueryApplicationProfiles */
    getMyApplicationProfile?: boolean;
}
interface ApplicationProfile {
    /**
     * name
     * @maxLength 200
     * @readonly
     */
    name?: string | null;
    /**
     * image url
     * @format WEB_URL
     * @readonly
     */
    imageUrl?: string | null;
}
/** a translated TextToSpeech payload sent to UOU */
interface TextToSpeechActionMessage {
    /**
     * Text-to-speech message body. Should be a valid SSML as string.
     * See https://www.w3.org/TR/speech-synthesis/
     * i.e. <speak>\r\nHi, testing text to speech.\r\n</speak>
     * i.e. <speak>\r\n<audio src=\"https://storage.googleapis.com/wix-restaurants/audio/beep.mp3\"/>\r\nA new order was received.\r\n</speak>
     * @minLength 1
     * @maxLength 5000
     */
    body?: string;
}
interface AudienceProviderConfig {
    /** notification preference filter SPI configuration */
    baseUri?: SpiBaseUri;
    /**
     * Provider key
     * @minLength 1
     * @maxLength 50
     */
    key?: string;
    /**
     * The name of the audience provider, e.g. `Blog Post Subscribers` / `Contacts Labels`
     * @minLength 1
     * @maxLength 100
     */
    displayName?: string;
    /** Type of participant. Each audience provider can support only one type of recipient */
    participantType?: ParticipantTypeWithLiterals;
    /** Standard json schema which describe the json the provider should get in the Resolve end point */
    inputSchema?: Record<string, any> | null;
    /**
     * Interface configuration
     * If empty default interface configuration will be auto generated based on the input schema
     */
    interfaceConfiguration?: InterfaceConfiguration;
    /** Specifying which optional methods are implemented. */
    implementedMethods?: ImplementedMethods;
    /**
     * Define the scopes which the provider audience is relevant
     * @maxSize 10
     */
    scopes?: ScopeWithLiterals[];
}
declare enum ParticipantType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    WIX_USER = "WIX_USER",
    CONTACT = "CONTACT",
    ANONYMOUS = "ANONYMOUS"
}
/** @enumType */
type ParticipantTypeWithLiterals = ParticipantType | 'UNKNOWN_TYPE' | 'WIX_USER' | 'CONTACT' | 'ANONYMOUS';
interface InterfaceConfiguration extends InterfaceConfigurationOfTypeOneOf {
    /** Should be filled if the provider implements its own custom UI */
    widgetComponentConfiguration?: WidgetComponent;
    /** Type of interface configuration */
    type?: InterfaceConfigurationTypeWithLiterals;
}
/** @oneof */
interface InterfaceConfigurationOfTypeOneOf {
    /** Should be filled if the provider implements its own custom UI */
    widgetComponentConfiguration?: WidgetComponent;
}
declare enum InterfaceConfigurationType {
    /** Widget component built by the provider */
    WIDGET_COMPONENT = "WIDGET_COMPONENT",
    /** Item Selection, in case the provider implemented item selection component */
    ITEM_SELECTION = "ITEM_SELECTION"
}
/** @enumType */
type InterfaceConfigurationTypeWithLiterals = InterfaceConfigurationType | 'WIDGET_COMPONENT' | 'ITEM_SELECTION';
interface WidgetComponent {
    /**
     * widget component id
     * @format GUID
     */
    componentId?: string;
}
interface ItemSelection {
    /**
     * Item selection provider key
     * @minLength 1
     * @maxLength 100
     */
    providerKey?: string;
    /**
     * Mapping between item selection ids array to correlate input schema field
     * @minLength 1
     * @maxLength 25
     */
    schemaIdsFieldName?: string;
}
interface ImplementedMethods {
    /** Implements countParticipants */
    countParticipants?: boolean;
}
declare enum Scope {
    /** Provider audience is available only in scope of specific site */
    SPECIFIC_SITE = "SPECIFIC_SITE",
    /** Provider audience is available only in scope of non specific site */
    NON_SPECIFIC_SITE = "NON_SPECIFIC_SITE"
}
/** @enumType */
type ScopeWithLiterals = Scope | 'SPECIFIC_SITE' | 'NON_SPECIFIC_SITE';
/** Config for the Price SPI */
interface PriceSPIConfig {
    /**
     * Pricing plan for which the SPI method should optionally apply
     * @format GUID
     */
    planId?: string;
    /** Required. Base URI where the endpoints are called. Wix appends the endpoint path to the base URI. */
    uriConfig?: SpiBaseUri;
}
interface StartDateLimitsSPIConfig {
    /** Base URI where the endpoints are called. Wix appends the endpoint path to the base URI. */
    baseUri?: SpiBaseUri;
    /**
     * Pricing plan for which the SPI method should apply
     * @format GUID
     */
    planId?: string;
}
interface StartDateRulesSPIConfig {
    /** Base URI where the endpoints are called. Wix appends the endpoint path to the base URI. */
    baseUri?: SpiBaseUri;
    /**
     * Pricing plan for which the SPI method should apply
     * @format GUID
     */
    planId?: string;
}
interface TicketReservationsSpiConfig {
    /** URI where the SPI Implementer is deployed. */
    baseUri?: SpiBaseUri;
}
/** Configuration for the dispute service plugin implementor */
interface DisputeServicePluginConfig {
    /**
     * Base URI where the endpoints are called. Wix appends the endpoint path to the base URI.
     * For example, to call the Accept Dispute endpoint at https://my-payments.com/disputes/v1/accept-dispute, the base URI you provide here is https://my-payments.com/disputes.
     */
    baseUri?: SpiBaseUri;
}
/** Config for the Fees SPI */
interface FeesSPIConfig {
    /**
     * Pricing plan for which the SPI method should optionally apply
     * @format GUID
     */
    planId?: string;
    /** Required. Base URI where the endpoints are called. Wix appends the endpoint path to the base URI. */
    uriConfig?: SpiBaseUri;
}
/** The full model for an imported component set in DEV Center */
interface EditorReactComponent {
    /**
     * The type of component to present in the Page tree, will be prefixed with AppSlug
     * @maxLength 100
     * @minLength 5
     */
    type?: string;
    /**
     * The public description of the component do display
     * @maxLength 300
     * @minLength 3
     */
    description?: string;
    /** List of component resources. This comprises any runtime code we need to load and execute for the component. */
    resources?: Resources;
    /** The configuration describing the component abilities and behaviors on the Editor stage */
    editorElement?: EditorElement;
    /** The installation settings of the component */
    installation?: InstallationInfo;
    /**
     * The Archetype this component adheres to, to be used for classification by AI models
     * @deprecated The Archetype this component adheres to, to be used for classification by AI models
     * @replacedBy editor_element.archetype
     * @targetRemovalDate 2026-06-30
     */
    archetype?: ArchetypeWithLiterals;
}
interface Resources {
    /** The bundle we will load and render in the browser */
    client?: ClientResources;
    /** The bundle for SSR, should not include any DOM API references */
    server?: Resource;
    /** The optional component SDK to expose to Velo Users to interact with the component */
    sdk?: Resource;
    /** Details for how to load translations for the component */
    translations?: TranslationResources;
    /** The optional interactions configuration JSON file */
    interactions?: Resource;
}
interface ClientResources {
    /**
     * A URL to a UMD javascript bundle
     * @format WEB_URL
     */
    componentUrl?: string;
    /**
     * A URL to the CSS file that is the default layout and style for the component
     * @format WEB_URL
     */
    cssUrl?: string | null;
}
interface Resource {
    /**
     * A URL to a UMD javascript bundle
     * @format WEB_URL
     */
    url?: string;
}
interface TranslationResources {
    /**
     * The URL that we will add the language to for fetching translations, example: `https://somecdn.com/translations/`
     * @format WEB_URL
     */
    basePath?: string;
    /**
     * The list of supported languages according to the [ISO-639-1 specification](https://en.wikipedia.org/wiki/ISO_639-1)
     * @format LANGUAGE
     * @maxSize 37
     */
    languages?: string[];
}
interface EditorElement {
    /**
     * DOM Query selector for this element that we can use to find it when rendering it (preferably  a className)
     * @minLength 4
     * @maxLength 50
     */
    selector?: string;
    /**
     * Human friendly name on the editor stage when the component is in interaction with the user
     * @minLength 4
     * @maxLength 20
     */
    displayName?: string;
    /** style-api of this element, a map of style-items where the key is the style-item name and the value is the style-item definition. These will be manifested as CSS vars in the scope of the component and prefixed with `--` */
    style?: Record<string, StyleItem>;
    /** data-api of this element, a map of data-items where the key is the data-item name and the value is the data-item definition. These will be manifested as `props` for the component */
    data?: Record<string, DataItem>;
    /** elements-map of this element, a map of inner-elements where the key is the element name and the value is the element definition */
    elements?: Record<string, ElementItem>;
    /** Native actions specified for the component */
    actions?: Actions;
    /** Custom actions specified for the component, allowing for flexibility beyond native actions */
    customActions?: Record<string, Action>;
    /** Component presets definition. Canonically useful for different layout or theming */
    presets?: Record<string, PresetItem>;
    /** The default preset, styles and data of inner elements */
    elementsDefaults?: Record<string, ElementDefaults>;
    /** Layout capabilities of the component */
    layout?: EditorElementLayout;
    /** The Archetype this component adheres to, to be used for classification by AI models */
    archetype?: ArchetypeWithLiterals;
}
interface StyleItem extends StyleItemSelectedItemTypeOneOf, StyleItemSelectedCssPropertyTypeOneOf, StyleItemSelectedCssVariableTypeOneOf {
    /** type selection key for css-properties */
    cssPropertyType?: CssPropertyTypeWithLiterals;
    /** type selection key for css-data-types */
    cssVariableType?: CssDataTypeWithLiterals;
    /** Additional options to refine the filter variable */
    filter?: Filter;
    /** Additional options to refine the backdropFilter variable */
    backdropFilter?: BackdropFilter;
    /** Additional options to refine the display variable */
    display?: Display;
    /** Additional options to refine the writingMode variable */
    writingMode?: WritingMode;
    /** Additional options to refine the customEnum variable */
    customEnum?: CustomEnum;
    /** Additional options to refine the number variable */
    number?: CssNumber;
    /** default value for the style item */
    defaultValue?: any;
    /**
     * Will be used as displayName of this style item
     * @maxLength 100
     */
    displayName?: string | null;
}
/** @oneof */
interface StyleItemSelectedItemTypeOneOf {
    /** type selection key for css-properties */
    cssPropertyType?: CssPropertyTypeWithLiterals;
    /** type selection key for css-data-types */
    cssVariableType?: CssDataTypeWithLiterals;
}
/** @oneof */
interface StyleItemSelectedCssPropertyTypeOneOf {
    /** Additional options to refine the filter variable */
    filter?: Filter;
    /** Additional options to refine the backdropFilter variable */
    backdropFilter?: BackdropFilter;
    /** Additional options to refine the display variable */
    display?: Display;
    /** Additional options to refine the writingMode variable */
    writingMode?: WritingMode;
}
/** @oneof */
interface StyleItemSelectedCssVariableTypeOneOf {
    /** Additional options to refine the customEnum variable */
    customEnum?: CustomEnum;
    /** Additional options to refine the number variable */
    number?: CssNumber;
}
/** The supported [CSS Property Types](https://developer.mozilla.org/en-US/docs/Web/CSS/Reference#index) in Javascript naming format */
declare enum CssPropertyType {
    UNKNOWN_CssPropertyType = "UNKNOWN_CssPropertyType",
    /** background properties */
    background = "background",
    backgroundSize = "backgroundSize",
    backgroundColor = "backgroundColor",
    backgroundImage = "backgroundImage",
    backgroundClip = "backgroundClip",
    backgroundOrigin = "backgroundOrigin",
    backgroundPosition = "backgroundPosition",
    backgroundRepeat = "backgroundRepeat",
    backgroundAttachment = "backgroundAttachment",
    fill = "fill",
    /** margin properties */
    margin = "margin",
    marginTop = "marginTop",
    marginRight = "marginRight",
    marginBottom = "marginBottom",
    marginLeft = "marginLeft",
    marginInlineStart = "marginInlineStart",
    marginInlineEnd = "marginInlineEnd",
    /** padding properties */
    padding = "padding",
    paddingTop = "paddingTop",
    paddingRight = "paddingRight",
    paddingBottom = "paddingBottom",
    paddingLeft = "paddingLeft",
    paddingInlineStart = "paddingInlineStart",
    paddingInlineEnd = "paddingInlineEnd",
    /** border properties */
    border = "border",
    borderWidth = "borderWidth",
    borderStyle = "borderStyle",
    borderColor = "borderColor",
    borderTop = "borderTop",
    borderTopColor = "borderTopColor",
    borderTopWidth = "borderTopWidth",
    borderTopStyle = "borderTopStyle",
    borderRight = "borderRight",
    borderRightColor = "borderRightColor",
    borderRightWidth = "borderRightWidth",
    borderRightStyle = "borderRightStyle",
    borderBottom = "borderBottom",
    borderBottomColor = "borderBottomColor",
    borderBottomWidth = "borderBottomWidth",
    borderBottomStyle = "borderBottomStyle",
    borderLeft = "borderLeft",
    borderLeftColor = "borderLeftColor",
    borderLeftWidth = "borderLeftWidth",
    borderLeftStyle = "borderLeftStyle",
    borderInlineStart = "borderInlineStart",
    borderInlineStartColor = "borderInlineStartColor",
    borderInlineStartWidth = "borderInlineStartWidth",
    borderInlineStartStyle = "borderInlineStartStyle",
    borderInlineEnd = "borderInlineEnd",
    borderInlineEndColor = "borderInlineEndColor",
    borderInlineEndWidth = "borderInlineEndWidth",
    borderInlineEndStyle = "borderInlineEndStyle",
    borderRadius = "borderRadius",
    borderTopLeftRadius = "borderTopLeftRadius",
    borderTopRightRadius = "borderTopRightRadius",
    borderBottomRightRadius = "borderBottomRightRadius",
    borderBottomLeftRadius = "borderBottomLeftRadius",
    borderStartStartRadius = "borderStartStartRadius",
    borderStartEndRadius = "borderStartEndRadius",
    borderEndStartRadius = "borderEndStartRadius",
    borderEndEndRadius = "borderEndEndRadius",
    /** text properties */
    font = "font",
    fontFamily = "fontFamily",
    fontSize = "fontSize",
    fontStretch = "fontStretch",
    fontStyle = "fontStyle",
    fontVariant = "fontVariant",
    fontWeight = "fontWeight",
    lineHeight = "lineHeight",
    color = "color",
    letterSpacing = "letterSpacing",
    writingMode = "writingMode",
    textAlign = "textAlign",
    textTransform = "textTransform",
    textShadow = "textShadow",
    textOverflow = "textOverflow",
    textDecoration = "textDecoration",
    textDecorationColor = "textDecorationColor",
    textDecorationLine = "textDecorationLine",
    textDecorationStyle = "textDecorationStyle",
    textDecorationThickness = "textDecorationThickness",
    /** general box properties */
    boxShadow = "boxShadow",
    opacity = "opacity",
    overflow = "overflow",
    /** layout properties */
    display = "display",
    alignSelf = "alignSelf",
    justifyContent = "justifyContent",
    alignItems = "alignItems",
    flexDirection = "flexDirection",
    gap = "gap",
    height = "height",
    width = "width",
    columnGap = "columnGap",
    rowGap = "rowGap",
    /** filters */
    filter = "filter",
    backdropFilter = "backdropFilter",
    /** media sizing & alignment */
    objectFit = "objectFit",
    objectPosition = "objectPosition",
    /** blending & compositing */
    mixBlendMode = "mixBlendMode",
    isolation = "isolation"
}
/** @enumType */
type CssPropertyTypeWithLiterals = CssPropertyType | 'UNKNOWN_CssPropertyType' | 'background' | 'backgroundSize' | 'backgroundColor' | 'backgroundImage' | 'backgroundClip' | 'backgroundOrigin' | 'backgroundPosition' | 'backgroundRepeat' | 'backgroundAttachment' | 'fill' | 'margin' | 'marginTop' | 'marginRight' | 'marginBottom' | 'marginLeft' | 'marginInlineStart' | 'marginInlineEnd' | 'padding' | 'paddingTop' | 'paddingRight' | 'paddingBottom' | 'paddingLeft' | 'paddingInlineStart' | 'paddingInlineEnd' | 'border' | 'borderWidth' | 'borderStyle' | 'borderColor' | 'borderTop' | 'borderTopColor' | 'borderTopWidth' | 'borderTopStyle' | 'borderRight' | 'borderRightColor' | 'borderRightWidth' | 'borderRightStyle' | 'borderBottom' | 'borderBottomColor' | 'borderBottomWidth' | 'borderBottomStyle' | 'borderLeft' | 'borderLeftColor' | 'borderLeftWidth' | 'borderLeftStyle' | 'borderInlineStart' | 'borderInlineStartColor' | 'borderInlineStartWidth' | 'borderInlineStartStyle' | 'borderInlineEnd' | 'borderInlineEndColor' | 'borderInlineEndWidth' | 'borderInlineEndStyle' | 'borderRadius' | 'borderTopLeftRadius' | 'borderTopRightRadius' | 'borderBottomRightRadius' | 'borderBottomLeftRadius' | 'borderStartStartRadius' | 'borderStartEndRadius' | 'borderEndStartRadius' | 'borderEndEndRadius' | 'font' | 'fontFamily' | 'fontSize' | 'fontStretch' | 'fontStyle' | 'fontVariant' | 'fontWeight' | 'lineHeight' | 'color' | 'letterSpacing' | 'writingMode' | 'textAlign' | 'textTransform' | 'textShadow' | 'textOverflow' | 'textDecoration' | 'textDecorationColor' | 'textDecorationLine' | 'textDecorationStyle' | 'textDecorationThickness' | 'boxShadow' | 'opacity' | 'overflow' | 'display' | 'alignSelf' | 'justifyContent' | 'alignItems' | 'flexDirection' | 'gap' | 'height' | 'width' | 'columnGap' | 'rowGap' | 'filter' | 'backdropFilter' | 'objectFit' | 'objectPosition' | 'mixBlendMode' | 'isolation';
/** The supported [CSS Data Types](https://developer.mozilla.org/en-US/docs/Web/CSS/CSS_Types) in Javascript naming format */
declare enum CssDataType {
    UNKNOWN_CssDataType = "UNKNOWN_CssDataType",
    number = "number",
    length = "length",
    color = "color",
    angle = "angle",
    percentage = "percentage",
    lengthPercentage = "lengthPercentage",
    blendMode = "blendMode",
    customEnum = "customEnum",
    string = "string",
    time = "time"
}
/** @enumType */
type CssDataTypeWithLiterals = CssDataType | 'UNKNOWN_CssDataType' | 'number' | 'length' | 'color' | 'angle' | 'percentage' | 'lengthPercentage' | 'blendMode' | 'customEnum' | 'string' | 'time';
interface Filter {
    /**
     * List of filter functions in case of reducing the abilities exposed to the User
     * @maxSize 100
     */
    filterFunctions?: FilterFunctionWithLiterals[];
}
declare enum FilterFunction {
    UNKNOWN_FilterFunctions = "UNKNOWN_FilterFunctions",
    /** The value used for blur filter */
    blur = "blur",
    /** The value used for brightness filter */
    brightness = "brightness",
    /** The value used for contrast filter */
    contrast = "contrast",
    /** The value used for drop-shadow filter */
    drop_shadow = "drop_shadow",
    /** The value used for grayscale filter */
    grayscale = "grayscale",
    /** The value used for hue-rotate filter */
    hue_rotate = "hue_rotate",
    /** The value used for invert filter */
    invert = "invert",
    /** The value used for opacity filter */
    opacity = "opacity",
    /** The value used for sepia filter */
    sepia = "sepia",
    /** The value used for saturate filter */
    saturate = "saturate"
}
/** @enumType */
type FilterFunctionWithLiterals = FilterFunction | 'UNKNOWN_FilterFunctions' | 'blur' | 'brightness' | 'contrast' | 'drop_shadow' | 'grayscale' | 'hue_rotate' | 'invert' | 'opacity' | 'sepia' | 'saturate';
interface BackdropFilter {
    /**
     * List of filter functions in case of reducing the abilities exposed to the User
     * @maxSize 100
     */
    filterFunctions?: FilterFunctionWithLiterals[];
}
interface Display {
    /**
     * list of display values in case we want to reduce the abilities exposed to the User
     * @maxSize 20
     */
    displayValues?: DisplayValueEnumDisplayValueWithLiterals[];
}
declare enum DisplayValueEnumDisplayValue {
    UNKNOWN_DisplayValue = "UNKNOWN_DisplayValue",
    none = "none",
    block = "block",
    inline = "inline",
    flow = "flow",
    flowRoot = "flowRoot",
    table = "table",
    flex = "flex",
    grid = "grid",
    list_item = "list_item",
    contents = "contents",
    inline_block = "inline_block",
    inline_table = "inline_table",
    inline_flex = "inline_flex",
    inline_grid = "inline_grid"
}
/** @enumType */
type DisplayValueEnumDisplayValueWithLiterals = DisplayValueEnumDisplayValue | 'UNKNOWN_DisplayValue' | 'none' | 'block' | 'inline' | 'flow' | 'flowRoot' | 'table' | 'flex' | 'grid' | 'list_item' | 'contents' | 'inline_block' | 'inline_table' | 'inline_flex' | 'inline_grid';
interface WritingMode {
    /**
     * list of writing-mode values in case we want to reduce the abilities exposed to the User
     * @maxSize 20
     */
    writingModeValues?: WritingModeValueWithLiterals[];
}
declare enum WritingModeValue {
    UNKNOWN_WritingModeValue = "UNKNOWN_WritingModeValue",
    horizontalTb = "horizontalTb",
    verticalRl = "verticalRl",
    verticalLr = "verticalLr",
    sidewaysRl = "sidewaysRl",
    sidewaysLr = "sidewaysLr"
}
/** @enumType */
type WritingModeValueWithLiterals = WritingModeValue | 'UNKNOWN_WritingModeValue' | 'horizontalTb' | 'verticalRl' | 'verticalLr' | 'sidewaysRl' | 'sidewaysLr';
interface CustomEnum {
    /** the type of enum values */
    cssVariableType?: CssDataTypeWithLiterals;
    /**
     * Editor-only: defines allowed values
     * @maxSize 100
     */
    options?: CustomEnumOption[];
}
interface CustomEnumOption {
    /**
     * the enum value
     * @maxLength 100
     */
    value?: string;
    /** @maxLength 100 */
    displayName?: string;
}
interface CustomEnumOptionCssProperty {
    /**
     * the css property
     * @maxLength 100
     */
    property?: string;
    /**
     * the css value
     * @maxLength 100
     */
    value?: string;
}
interface CssNumber {
    /** Indicates minimum value required for the number */
    minimum?: number | null;
    /** Indicates maximum value allowed for the number */
    maximum?: number | null;
    /** The multiplier for the number value */
    multipleOf?: number | null;
}
interface DataItem extends DataItemSelectedDataTypeOneOf {
    /** An optional object to define limitations on the text input */
    text?: Text;
    /** A required list of options to supply to the users to choose from */
    textEnum?: TextEnum;
    /** An optional set of restrictions to apply to the number */
    number?: _Number;
    /** A required list of types we want to user to be able to specify, empty means all possible A11Y values */
    a11y?: A11y;
    /** A definition of what links should be supported */
    link?: Link;
    /** The [JSON Schema definition](https://json-schema.org/specification) the developer understands in his code (useful for complex props). Some limitation may apply */
    schema?: Record<string, any> | null;
    /** An array of a data type */
    arrayItems?: ArrayItems;
    /** A container in which to render another component */
    container?: ReactElementContainer;
    /** Defines the type of data we are configuring */
    dataType?: DataTypeWithLiterals;
    /**
     * Display name of this data item
     * @maxLength 100
     */
    displayName?: string | null;
    /** The default value of this data item (only for display purposes). */
    defaultValue?: any;
}
/** @oneof */
interface DataItemSelectedDataTypeOneOf {
    /** An optional object to define limitations on the text input */
    text?: Text;
    /** A required list of options to supply to the users to choose from */
    textEnum?: TextEnum;
    /** An optional set of restrictions to apply to the number */
    number?: _Number;
    /** A required list of types we want to user to be able to specify, empty means all possible A11Y values */
    a11y?: A11y;
    /** A definition of what links should be supported */
    link?: Link;
    /** The [JSON Schema definition](https://json-schema.org/specification) the developer understands in his code (useful for complex props). Some limitation may apply */
    schema?: Record<string, any> | null;
    /** An array of a data type */
    arrayItems?: ArrayItems;
    /** A container in which to render another component */
    container?: ReactElementContainer;
}
declare enum DataType {
    UNKNOWN_DataType = "UNKNOWN_DataType",
    /** A simple text value */
    text = "text",
    /** A list of predefined textual values to choose from */
    textEnum = "textEnum",
    /** Any number */
    number = "number",
    /** true / false value */
    booleanValue = "booleanValue",
    /** An object containing the selected A11Y fields chosen */
    a11y = "a11y",
    /** A Wix Link object type */
    link = "link",
    /** A Wix Image object type */
    image = "image",
    /** A Wix Video object type */
    video = "video",
    /** A Wix Sanitized Vector Art object */
    vectorArt = "vectorArt",
    /** A Wix Audio object */
    audio = "audio",
    /** A [JSON Schema definition](https://json-schema.org/specification) the developer understands in his code (useful for complex props). Some limitation may apply. */
    schema = "schema",
    /** Local date output ISO-8601 extended local date format (YYYY-MM-DD) */
    localDate = "localDate",
    /** Local time output ISO-8601 extended local time format (hh:mm[:ss][.sss]) */
    localTime = "localTime",
    /** Local Date Time output  ISO-8601 extended local date-time format (YYYY-MM-DDThh:mm[:ss][.sss]) */
    localDateTime = "localDateTime",
    /** a URL with scheme http or https */
    webUrl = "webUrl",
    /** standard email address according to [RFC 5321, section 4.1.2](https://datatracker.ietf.org/doc/html/rfc5321#section-4.1.2) */
    email = "email",
    /** a validation format designed to match phone numbers with a variety of common characters, including digits (0-9), spaces, parentheses, plus sign, hyphens, and periods */
    phone = "phone",
    /** hostname according to IANA */
    hostname = "hostname",
    /** A valid `regex` pattern supplied by the User */
    regex = "regex",
    /** A unique identifier */
    guid = "guid",
    /** a HTML text with css inline styling */
    richText = "richText",
    /** A container place in the component that will be passed in as {children} or a function prop, depending on the case */
    container = "container",
    /** An array type of data */
    arrayItems = "arrayItems",
    /** selected `direction` for the component according to (HTML `dir` attribute)[https://developer.mozilla.org/en-US/docs/Web/HTML/Global_attributes/dir] */
    direction = "direction",
    /** A list of menu-items */
    menuItems = "menuItems"
}
/** @enumType */
type DataTypeWithLiterals = DataType | 'UNKNOWN_DataType' | 'text' | 'textEnum' | 'number' | 'booleanValue' | 'a11y' | 'link' | 'image' | 'video' | 'vectorArt' | 'audio' | 'schema' | 'localDate' | 'localTime' | 'localDateTime' | 'webUrl' | 'email' | 'phone' | 'hostname' | 'regex' | 'guid' | 'richText' | 'container' | 'arrayItems' | 'direction' | 'menuItems';
interface Text {
    /** Indicates maximum length allowed for the text */
    maxLength?: number | null;
    /** Indicates minimum length required for the text */
    minLength?: number | null;
    /**
     * @maxLength 100
     * @deprecated
     * @replacedBy pattern
     * @targetRemovalDate 2026-06-30
     */
    regexPattern?: string | null;
    /**
     * A regex pattern that the text must comply with
     * @maxLength 100
     */
    pattern?: string | null;
}
interface TextEnum {
    /**
     * list of valid enum items
     * @maxSize 100
     */
    options?: Option[];
}
interface Option {
    /**
     * actual text value for this item
     * @maxLength 100
     */
    value?: string;
    /**
     * display name for this text item
     * @maxLength 100
     */
    displayName?: string;
}
interface _Number {
    /** Indicates minimum value required for the number */
    minimum?: number | null;
    /** Indicates maximum value allowed for the number */
    maximum?: number | null;
    /** The multiplier for the number value */
    multipleOf?: number | null;
}
interface A11y {
    /**
     * A collection of attributes that will be stated in the manifest
     * @maxSize 100
     */
    attributes?: A11yAttributesWithLiterals[];
}
declare enum A11yAttributes {
    Unknown_AriaAttributes = "Unknown_AriaAttributes",
    /** The value used for tabIndex attribute */
    tabIndex = "tabIndex",
    /** The value used for aria-level */
    ariaLevel = "ariaLevel",
    /** The value used for aria-expanded */
    ariaExpanded = "ariaExpanded",
    /** The value used for aria-disabled */
    ariaDisabled = "ariaDisabled",
    /** The value used for aria-atomic */
    ariaAtomic = "ariaAtomic",
    /** The value used for aria-hidden */
    ariaHidden = "ariaHidden",
    /** The value used for aria-busy */
    ariaBusy = "ariaBusy",
    /** Indicates if should add Multiline instructions to aria-label */
    multiline = "multiline",
    /** Indicates if should add Autocomplete instructions to aria-label */
    ariaAutocomplete = "ariaAutocomplete",
    /** The value used for aria-pressed */
    ariaPressed = "ariaPressed",
    /** The value used for aria-haspopup */
    ariaHaspopup = "ariaHaspopup",
    /** The value used for aria-relevant */
    ariaRelevant = "ariaRelevant",
    /** The value used for role attribute */
    role = "role",
    /** The value used for aria-live */
    ariaLive = "ariaLive",
    /** The value used for aria-current */
    ariaCurrent = "ariaCurrent",
    /** The text used for aria-label */
    ariaLabel = "ariaLabel",
    /** The text used for aria-roledescription */
    ariaRoledescription = "ariaRoledescription",
    /** The value used for aria-describedby */
    ariaDescribedby = "ariaDescribedby",
    /** The value used for aria-labelledby */
    ariaLabelledby = "ariaLabelledby",
    /** The text used for aria-errormessage */
    ariaErrormessage = "ariaErrormessage",
    /** The text used for aria-owns */
    ariaOwns = "ariaOwns",
    /** The text used for aria-controls */
    ariaControls = "ariaControls",
    /** The HTML tag to use for the element */
    tag = "tag",
    /** The value used for aria-multiline */
    ariaMultiline = "ariaMultiline",
    /** The value used for aria-invalid */
    ariaInvalid = "ariaInvalid"
}
/** @enumType */
type A11yAttributesWithLiterals = A11yAttributes | 'Unknown_AriaAttributes' | 'tabIndex' | 'ariaLevel' | 'ariaExpanded' | 'ariaDisabled' | 'ariaAtomic' | 'ariaHidden' | 'ariaBusy' | 'multiline' | 'ariaAutocomplete' | 'ariaPressed' | 'ariaHaspopup' | 'ariaRelevant' | 'role' | 'ariaLive' | 'ariaCurrent' | 'ariaLabel' | 'ariaRoledescription' | 'ariaDescribedby' | 'ariaLabelledby' | 'ariaErrormessage' | 'ariaOwns' | 'ariaControls' | 'tag' | 'ariaMultiline' | 'ariaInvalid';
interface Link {
    /**
     * A collection of possible link types that the component supports. Only one of the types will make it to the component after input.
     * @maxSize 12
     */
    linkTypes?: LinkTypeWithLiterals[];
}
declare enum LinkType {
    UNKNOWN_LinkType = "UNKNOWN_LinkType",
    /** A link to another website */
    externalLink = "externalLink",
    /** A link to an item on the current page */
    anchorLink = "anchorLink",
    /** A valid email link (`mailto:example@example.com`) */
    emailLink = "emailLink",
    /** A valid phone link (`phone:11111111111`) */
    phoneLink = "phoneLink",
    /** A link to a page in Wix that needs to be selected dynamically */
    dynamicPageLink = "dynamicPageLink",
    /** A link to another page on the site */
    pageLink = "pageLink",
    /** A link to open a whatsapp conversation */
    whatsAppLink = "whatsAppLink",
    /** A link to a PDF file hosted by Wix */
    documentLink = "documentLink",
    /** A link that opens a lightbox */
    popupLink = "popupLink",
    /** A link that directs the user to an address on google maps */
    addressLink = "addressLink",
    /** A link that scrolls to the top/bottom of the page */
    edgeAnchorLinks = "edgeAnchorLinks",
    /** A link that directs the user to wix login dialog */
    loginToWixLink = "loginToWixLink"
}
/** @enumType */
type LinkTypeWithLiterals = LinkType | 'UNKNOWN_LinkType' | 'externalLink' | 'anchorLink' | 'emailLink' | 'phoneLink' | 'dynamicPageLink' | 'pageLink' | 'whatsAppLink' | 'documentLink' | 'popupLink' | 'addressLink' | 'edgeAnchorLinks' | 'loginToWixLink';
/** An array of data items or complex data types */
interface ArrayItems extends ArrayItemsArrayDataOneOf {
    /** The definition of multiple data items in each item of the Array */
    data?: DataItems;
    /** For a single data type in the array */
    dataItem?: DataItem;
    /** The maximum size of the Array (there will be a size limit in the Storage as well) */
    maxSize?: number | null;
}
/** @oneof */
interface ArrayItemsArrayDataOneOf {
    /** The definition of multiple data items in each item of the Array */
    data?: DataItems;
    /** For a single data type in the array */
    dataItem?: DataItem;
}
interface DataItems {
    /**
     * For an array of complex object types
     * Each item in the array, will contain all this data structure
     */
    items?: Record<string, DataItem>;
}
/**
 * A container is a place to add components to in the editor
 * There are a few different types of containers supported
 */
interface ReactElementContainer extends ReactElementContainerSelectedContainerTypeOneOf {
    /** A container element that will be passed in as children, it is composed in the editor */
    simple?: SimpleContainer;
    /** A Slot for targeting slot implementors, gets the API implementation by the host (definition in DEV Center for both) */
    slot?: Slot;
    /** Placeholder for components targeting a specific area (definition in DEV Center) */
    placeholder?: PlaceHolder;
    /**
     * A DOM Selector that will allow us to target it in the editor
     * @minLength 2
     * @maxLength 100
     */
    selector?: string;
    /** The type of Container to be rendered */
    containerType?: ContainerTypeWithLiterals;
}
/** @oneof */
interface ReactElementContainerSelectedContainerTypeOneOf {
    /** A container element that will be passed in as children, it is composed in the editor */
    simple?: SimpleContainer;
    /** A Slot for targeting slot implementors, gets the API implementation by the host (definition in DEV Center for both) */
    slot?: Slot;
    /** Placeholder for components targeting a specific area (definition in DEV Center) */
    placeholder?: PlaceHolder;
}
declare enum ContainerType {
    /** An undefined container type, is invalid */
    UNKNOWN_CONTAINER_TYPE = "UNKNOWN_CONTAINER_TYPE",
    /** A simple container that can support adding and layouting elements in the editor */
    simple = "simple",
    /** A slot declared by a component in DEV Center that allows integrations with a Props API from the host */
    slot = "slot",
    /** A container to add elements targeting a specific product use case, exposed in DEV Center */
    placeholder = "placeholder"
}
/** @enumType */
type ContainerTypeWithLiterals = ContainerType | 'UNKNOWN_CONTAINER_TYPE' | 'simple' | 'slot' | 'placeholder';
/** Currently doesn't have any properties defined */
interface SimpleContainer {
}
interface Slot {
    /**
     * The slot definition that this container should accept as defined in DEV Center
     * @format GUID
     */
    slotId?: string;
}
interface PlaceHolder {
    /**
     * The placeholder definition that this container should accept as defined in DEV Center
     * @format GUID
     */
    placeholderId?: string;
}
interface ElementItem extends ElementItemSelectedElementTypeOneOf {
    /** An new element definition */
    inlineElement?: InlineElement;
    /** A reference to the used element with overrides */
    refElement?: RefElement;
    /** Defines the type of element we are configuring */
    elementType?: ElementTypeWithLiterals;
}
/** @oneof */
interface ElementItemSelectedElementTypeOneOf {
    /** An new element definition */
    inlineElement?: InlineElement;
    /** A reference to the used element with overrides */
    refElement?: RefElement;
}
declare enum ElementType {
    UNKNOWN_ElementType = "UNKNOWN_ElementType",
    /** An element that was written as part of the component */
    inlineElement = "inlineElement",
    /** An element provided by the Wix ecosystem that we are reusing. These elements must exist in the Wix DEV Center. */
    refElement = "refElement"
}
/** @enumType */
type ElementTypeWithLiterals = ElementType | 'UNKNOWN_ElementType' | 'inlineElement' | 'refElement';
interface InlineElement {
    /**
     * Relative DOM Query selector for this element. We assume nesting by it's parent elements for CSS Vars scoping.
     * @minLength 4
     * @maxLength 50
     */
    selector?: string;
    /**
     * Human friendly name on the editor stage when the component is in interaction with the user
     * @minLength 4
     * @maxLength 20
     */
    displayName?: string;
    /** style-api of this element, a map of style-items where the key is the style-item name and the value is the style-item definition. These will be manifested as CSS vars in the scope of the component and prefixed with `--` */
    style?: Record<string, StyleItem>;
    /** data-api of this element, a map of data-items where the key is the data-item name and the value is the data-item definition */
    data?: Record<string, DataItem>;
    /** elements-map of this element, a map of inner-elements where the key is the element name and the value is the element definition */
    elements?: Record<string, ElementItem>;
    /** editor-behaviors-api of this inner-element, will determine which type of editor experiences this inner-element should support */
    behaviors?: Behaviors;
    /** Collection of the native actions specified for the concrete component */
    actions?: Actions;
    /** Custom actions specified for the component, allowing for flexibility beyond native actions */
    customActions?: Record<string, Action>;
    /** Component presets definition. Canonically useful for different layout or theming */
    presets?: Record<string, PresetItem>;
    /** The default preset, styles and data of inner elements */
    elementsDefaults?: Record<string, ElementDefaults>;
    /** The Archetype this component adheres to, to be used for classification by AI models */
    archetype?: ArchetypeWithLiterals;
}
interface Behaviors {
    /** Determines if the inner-element can be selectable in the editor */
    selectable?: boolean | null;
    /** Determines if the inner-element can be removed from the component */
    removable?: boolean | null;
}
/** List of the native actions */
interface Actions {
    /** Allows enabling / disabling and overriding the settings action */
    settings?: Action;
    /** Allows enabling / disabling and overriding the design action */
    design?: Action;
    /** Allows enabling / disabling and overriding the media action */
    media?: Action;
    /** Allows enabling / disabling and overriding the manageItems action */
    manageItems?: Action;
    /** Allows enabling / disabling and overriding the dashboard action */
    dashboard?: DashboardAction;
}
interface Action {
    /** Defines whether the action is being displayed */
    hidden?: boolean | null;
    /**
     * The public human-readable name given to the  action by the developer.
     * @minLength 4
     * @maxLength 20
     */
    displayName?: string;
    /** A model definition for declaring a concrete instructions action will perform */
    execution?: Execution;
}
interface Execution extends ExecutionActionExecuteOneOf {
    /** Executes an action that manipulates component's data */
    data?: DataAction;
    /** Executes an action that manipulates component's style */
    style?: StyleAction;
    /** Executes an event-based action. Triggered event should be intercepted in the editor script */
    event?: EventAction;
    /** Opens a URL inside an iframe panel */
    panel?: PanelAction;
    /** Executes an action on a target element (based on path) */
    forward?: ForwardAction;
    /** The action type allows to determine the return type of the execution function */
    actionType?: ActionTypeWithLiterals;
}
/** @oneof */
interface ExecutionActionExecuteOneOf {
    /** Executes an action that manipulates component's data */
    data?: DataAction;
    /** Executes an action that manipulates component's style */
    style?: StyleAction;
    /** Executes an event-based action. Triggered event should be intercepted in the editor script */
    event?: EventAction;
    /** Opens a URL inside an iframe panel */
    panel?: PanelAction;
    /** Executes an action on a target element (based on path) */
    forward?: ForwardAction;
}
declare enum ActionType {
    UNKNOWN_ActionType = "UNKNOWN_ActionType",
    data = "data",
    event = "event",
    panel = "panel",
    forward = "forward",
    style = "style"
}
/** @enumType */
type ActionTypeWithLiterals = ActionType | 'UNKNOWN_ActionType' | 'data' | 'event' | 'panel' | 'forward' | 'style';
/** Represents an action that interacts with a specific data item */
interface DataAction {
    /**
     * Points to the data item within the component’s data structure
     * @minLength 1
     * @maxLength 50
     */
    dataItemKey?: string;
}
/** Represents an action that interacts with a specific style item */
interface StyleAction {
    /**
     * Points to the style item within the component’s style structure
     * @minLength 1
     * @maxLength 50
     */
    styleItemKey?: string;
}
/** Executes an event-based action. Triggered event should be intercepted in the editor script */
interface EventAction {
    /**
     * Name of the event to be handled by the editor script
     * @minLength 1
     * @maxLength 50
     */
    event?: string;
}
/** Represents a URL-based action that opens a panel */
interface PanelAction extends PanelActionSelectedPanelTypeOneOf {
    /**
     * For using a panel defined in dev-center
     * @format GUID
     */
    panelId?: string;
    /** The selected panel reference type */
    panelType?: PanelTypeWithLiterals;
}
/** @oneof */
interface PanelActionSelectedPanelTypeOneOf {
    /**
     * For using a panel defined in dev-center
     * @format GUID
     */
    panelId?: string;
}
/** list of possible panel types */
declare enum PanelType {
    UNKNOWN_PanelType = "UNKNOWN_PanelType",
    panelId = "panelId"
}
/** @enumType */
type PanelTypeWithLiterals = PanelType | 'UNKNOWN_PanelType' | 'panelId';
/** Represents an action that targets another element within the component */
interface ForwardAction extends ForwardActionActionOneOf {
    /**
     * Used when actionType is custom
     * @minLength 1
     * @maxLength 50
     */
    custom?: string;
    /** Specifies the action names (one of the natives or custom) */
    actionName?: ActionNameWithLiterals;
    /**
     * Path to the target element
     * @minLength 1
     * @maxLength 500
     */
    elementPath?: string;
}
/** @oneof */
interface ForwardActionActionOneOf {
    /**
     * Used when actionType is custom
     * @minLength 1
     * @maxLength 50
     */
    custom?: string;
}
declare enum ActionName {
    UNKNOWN_ActionName = "UNKNOWN_ActionName",
    /** Manage the component settings, this usually aligns with component data */
    settings = "settings",
    /** Manage the `style` information */
    design = "design",
    /** Manage any media type `data` defined in the component */
    media = "media",
    /** Manage items in the component data */
    manageItems = "manageItems",
    /** Open the apps default dashboard page, or select one if there is more than one */
    dashboard = "dashboard",
    /** actionName to be triggered from the defined custom actions */
    custom = "custom"
}
/** @enumType */
type ActionNameWithLiterals = ActionName | 'UNKNOWN_ActionName' | 'settings' | 'design' | 'media' | 'manageItems' | 'dashboard' | 'custom';
interface DashboardAction {
    /** Defines whether the action is being displayed */
    hidden?: boolean | null;
    /**
     * The public human-readable name given to the  action by the developer.
     * @minLength 4
     * @maxLength 20
     */
    displayName?: string;
    /**
     * Optional pageId of the dashboard in case there is more than one
     * @minLength 4
     * @maxLength 50
     */
    dashboardPageId?: string;
    /** A model definition for declaring a concrete instructions action will perform */
    execution?: Execution;
}
interface PresetItem {
    /**
     * A URL to the CSS file of this preset
     * @format WEB_URL
     * @minLength 13
     * @maxLength 500
     */
    cssUrl?: string;
    /**
     * Preset name for displaying purposes in the editor
     * @maxLength 100
     */
    displayName?: string;
    /**
     * A URL to the CSS preset thumbnail file
     * @format WEB_URL
     * @minLength 13
     * @maxLength 500
     */
    thumbnailUrl?: string | null;
    /** The default styles for this preset */
    defaultStyles?: Record<string, any>;
    /** The default preset and styles of inner elements for this preset */
    elementsStyleDefaults?: Record<string, ElementStyleDefaults>;
    /** Optional initial size of the component when switching into this preset */
    initialSize?: ComponentInitialSize;
}
interface ElementStyleDefaults {
    /**
     * The default preset for an element
     * @maxLength 100
     */
    presetKey?: string;
    /** The default styles for an element */
    style?: Record<string, any>;
    /** The default preset and styles for inner elements */
    elementsStyleDefaults?: Record<string, ElementStyleDefaults>;
}
interface ComponentInitialSize {
    /** The component initial width setting */
    width?: InitialSizeSetting;
    /** The component initial height setting */
    height?: InitialSizeSetting;
}
interface InitialSizeSetting extends InitialSizeSettingSelectedSizingTypeOneOf {
    /**
     * The value we should set as initial size in pixels
     * @min 1
     */
    pixels?: number;
    /** The initial size type */
    sizingType?: SizingTypeWithLiterals;
}
/** @oneof */
interface InitialSizeSettingSelectedSizingTypeOneOf {
    /**
     * The value we should set as initial size in pixels
     * @min 1
     */
    pixels?: number;
}
declare enum SizingType {
    UNKNOWN_SizingType = "UNKNOWN_SizingType",
    /** Initial size should fit to the [content size](https://developer.mozilla.org/en-US/docs/Web/CSS/fit-content) */
    content = "content",
    /** Initial size should stretch to the parent size and will keep tracking it unless a user changes it */
    stretched = "stretched",
    /** Initial size should be set in pixels */
    pixels = "pixels"
}
/** @enumType */
type SizingTypeWithLiterals = SizingType | 'UNKNOWN_SizingType' | 'content' | 'stretched' | 'pixels';
interface ElementDefaults {
    /**
     * The default preset for an element
     * @maxLength 100
     */
    presetKey?: string;
    /** The default styles for an element */
    style?: Record<string, any>;
    /** The default data for an element */
    data?: Record<string, any>;
    /** The default preset and styles for inner elements */
    elementsDefaults?: Record<string, ElementDefaults>;
}
declare enum Archetype {
    UNKNOWN_Archetype = "UNKNOWN_Archetype",
    Button = "Button",
    LoginButton = "LoginButton",
    Image = "Image",
    Gallery = "Gallery",
    Video = "Video",
    Audio = "Audio",
    Text = "Text",
    TextInput = "TextInput",
    RichTextEditor = "RichTextEditor",
    SignatureInput = "SignatureInput",
    Checkbox = "Checkbox",
    RadioGroup = "RadioGroup",
    Switch = "Switch",
    Dropdown = "Dropdown",
    DatePicker = "DatePicker",
    TimePicker = "TimePicker",
    Ratings = "Ratings",
    RatingInput = "RatingInput",
    Menu = "Menu",
    Pagination = "Pagination",
    Slider = "Slider",
    Container = "Container",
    Carousel = "Carousel",
    Accordion = "Accordion",
    Tabs = "Tabs",
    ProgressBar = "ProgressBar",
    Upload = "Upload",
    Social = "Social",
    Breadcrumbs = "Breadcrumbs",
    SearchBox = "SearchBox",
    Map = "Map",
    Line = "Line",
    Logo = "Logo",
    Avatar = "Avatar",
    Captcha = "Captcha",
    VectorArt = "VectorArt",
    AnimatedGraphic = "AnimatedGraphic"
}
/** @enumType */
type ArchetypeWithLiterals = Archetype | 'UNKNOWN_Archetype' | 'Button' | 'LoginButton' | 'Image' | 'Gallery' | 'Video' | 'Audio' | 'Text' | 'TextInput' | 'RichTextEditor' | 'SignatureInput' | 'Checkbox' | 'RadioGroup' | 'Switch' | 'Dropdown' | 'DatePicker' | 'TimePicker' | 'Ratings' | 'RatingInput' | 'Menu' | 'Pagination' | 'Slider' | 'Container' | 'Carousel' | 'Accordion' | 'Tabs' | 'ProgressBar' | 'Upload' | 'Social' | 'Breadcrumbs' | 'SearchBox' | 'Map' | 'Line' | 'Logo' | 'Avatar' | 'Captcha' | 'VectorArt' | 'AnimatedGraphic';
interface RefElement {
    /**
     * The type of the referenced element. Must exist in the Wix Dev Center and be fullly typed (`appSlug.componentType`).
     * @minLength 4
     * @maxLength 100
     */
    type?: string;
    /**
     * The override of the used element selector
     * @minLength 4
     * @maxLength 50
     */
    selector?: string;
    /**
     * The override of the used element displayName
     * @minLength 4
     * @maxLength 20
     */
    displayName?: string;
    /** The override of the used element style */
    style?: Record<string, StyleItemOverrides>;
    /** The override of the used element data */
    data?: Record<string, DataItemOverrides>;
    /** The override of the used element behaviors */
    behaviors?: Behaviors;
    /** The override of the used element native actions */
    actions?: Actions;
    /** The override of the used element custom actions */
    customActions?: Record<string, Action>;
}
interface StyleItemOverrides {
    /** Disables the ability to edit this style-item */
    disableEditing?: boolean | null;
    /**
     * Overrides Display displayName of this style item
     * @maxLength 100
     */
    displayName?: string | null;
}
interface DataItemOverrides {
    /** Disables the ability to edit this data-item */
    disableEditing?: boolean | null;
    /**
     * Overrides the display name of this data-item
     * @maxLength 100
     */
    displayName?: string | null;
}
/** Top-level message containing all layout capabilities */
interface EditorElementLayout {
    /** The resizing capabilities this component can supports */
    resizeDirection?: ResizeDirectionWithLiterals;
    /** Describes the ability of content to impact on the size of this component */
    contentResizeDirection?: ContentResizeDirectionWithLiterals;
    /** Will control the availability of the stretch capability for this component */
    disableStretching?: boolean | null;
    /** Will control the availability of freely positioning this component */
    disablePositioning?: boolean | null;
}
declare enum ResizeDirection {
    /** Default value when direction is not specified */
    UNKNOWN_ResizeDirection = "UNKNOWN_ResizeDirection",
    /** Component can only be resized horizontally */
    horizontal = "horizontal",
    /** Component can only be resized vertically */
    vertical = "vertical",
    /** Component can be resized both horizontally and vertically */
    horizontalAndVertical = "horizontalAndVertical",
    /** Component maintains its aspect ratio while resizing */
    aspectRatio = "aspectRatio",
    /** Component cannot be resized in any direction */
    none = "none"
}
/** @enumType */
type ResizeDirectionWithLiterals = ResizeDirection | 'UNKNOWN_ResizeDirection' | 'horizontal' | 'vertical' | 'horizontalAndVertical' | 'aspectRatio' | 'none';
declare enum ContentResizeDirection {
    /** Default value when content resize behavior is not specified */
    UNKNOWN_ContentResizeDirection = "UNKNOWN_ContentResizeDirection",
    /** Component's width will automatically adjust based on its content */
    horizontal = "horizontal",
    /** Component's height will automatically adjust based on its content */
    vertical = "vertical",
    /** Component's width and height will automatically adjust based on its content */
    horizontalAndVertical = "horizontalAndVertical",
    /** Component's size will not be affected by its content */
    none = "none"
}
/** @enumType */
type ContentResizeDirectionWithLiterals = ContentResizeDirection | 'UNKNOWN_ContentResizeDirection' | 'horizontal' | 'vertical' | 'horizontalAndVertical' | 'none';
interface InstallationInfo extends InstallationInfoTargetContainerOneOf {
    /** Which static container should the component be installed at */
    staticContainer?: StaticContainerWithLiterals;
    /** Default presets per breakpoint with which the component should be installed */
    presets?: DefaultPresets;
    /** Initial size with which the component should be added to the stage */
    initialSize?: ComponentInitialSize;
}
/** @oneof */
interface InstallationInfoTargetContainerOneOf {
    /** Which static container should the component be installed at */
    staticContainer?: StaticContainerWithLiterals;
}
interface MarketplaceSPIConfig {
    /** URI where the SPI implementer is deployed */
    deploymentUri?: SpiBaseUri;
}
interface FormSchemaDynamicValuesSpiConfig {
    /** URI where the SPI Implementer is deployed. */
    uriConfig?: SpiBaseUri;
    /**
     * Form ID which contains dynamic fields.
     * @format GUID
     */
    formId?: string;
    /**
     * Field IDs which trigger loading of dynamic values.
     * @maxSize 100
     * @format GUID
     */
    fieldsIds?: string[];
}
interface BlogPaywallProviderConfig {
    /** Uri config */
    uriConfig?: SpiBaseUri;
}
interface RewardProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * Name of the reward that will be visible to the end users
     * @maxLength 100
     */
    rewardName?: string;
    /**
     * Description of the reward that will be visible to the end users, describing how the reward works
     * @maxLength 500
     */
    rewardDescription?: string;
}
interface ProductRestrictionsConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /** Product restrictions configuration. */
    productRestrictionsConfig?: RestrictionsConfig;
}
interface RestrictionsConfig {
    /**
     * Prices restrictions.
     *
     * Affected fields:
     * * `variantsInfo.variants.price.actualPrice.amount`
     * * `variantsInfo.variants.price.compareAtPrice.amount`
     * * `inventory.trackingMethod.quantity`
     */
    prices?: Restriction;
    /**
     * Options restrictions.
     *
     * Affected field: `options` (all nested fields except `linkedMedia`)
     */
    options?: Restriction;
    /**
     * Modifier restrictions.
     *
     * Affected field: `modifiers` (all nested fields except `linkedMedia`)
     */
    modifiers?: Restriction;
    /**
     * Inventory restrictions.
     *
     * Affected fields:
     * * `variantsInfo.variants.sku`
     * * `variantsInfo.variants.barcode`
     * * `inventory.trackingMethod.quantity`
     */
    inventory?: Restriction;
    /**
     * Pre order restrictions.
     *
     * Affected field: `inventory.preorderInfo`
     */
    preOrder?: Restriction;
    /** Whether to disallow product duplication or display a warning when duplicating a product. */
    duplicateProduct?: Restriction;
}
interface Restriction {
    /** Restriction level. */
    restrictionLevel?: RestrictionLevelWithLiterals;
}
declare enum RestrictionLevel {
    UNKNOWN_RESTRICTION_TYPE = "UNKNOWN_RESTRICTION_TYPE",
    /** Users can edit the product field after acknowledging a warning modal. */
    WARNING = "WARNING",
    /** Users **cannot** edit the product field. */
    LOCKED = "LOCKED"
}
/** @enumType */
type RestrictionLevelWithLiterals = RestrictionLevel | 'UNKNOWN_RESTRICTION_TYPE' | 'WARNING' | 'LOCKED';
interface FormSubmissionModerationSpiConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * Namespace names.
     * @maxSize 10
     */
    namespaceConfigs?: FormSubmissionModerationSpiNamespaceConfig[];
}
interface FormSubmissionModerationSpiNamespaceConfig {
    /**
     * The app which the form submissions belong to. For example, the namespace for the Wix Forms app is `wix.form_app.form`.
     *
     * Call `Get Submission` to retrieve the namespace.
     * @minLength 10
     * @maxLength 50
     */
    namespace?: string;
    /**
     * The ID of the specific form that will trigger form moderation.
     * This field is optional. If not provided, submissions from all forms will trigger the moderation.
     * @format GUID
     */
    formId?: string | null;
    /** Enable submission moderation. */
    submissionModerationEnabled?: boolean;
}
interface EventBadgesSpiConfig {
    /** URI where the SPI Implementer is deployed. */
    baseUri?: SpiBaseUri;
    /**
     * Events for which the SPI method should apply. If empty, applies to all events.
     * @maxSize 100
     * @format GUID
     */
    eventId?: string[];
}
interface OperationExecutorConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
}
/** Back-office Customization */
interface BackOfficeCustomization {
    /** Optional Header customization, if not provided the default header will be used */
    header?: Header;
    /** Optional sidebar customization, if not provided the default sidebar will be used */
    sidebar?: Sidebar;
}
interface Header extends HeaderConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: HeaderConfig;
    displayOption?: ElementDisplayOptionWithLiterals;
}
/** @oneof */
interface HeaderConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: HeaderConfig;
}
declare enum ElementDisplayOption {
    UNKNOWN_OPTION = "UNKNOWN_OPTION",
    REMOVE = "REMOVE",
    CUSTOMIZED = "CUSTOMIZED"
}
/** @enumType */
type ElementDisplayOptionWithLiterals = ElementDisplayOption | 'UNKNOWN_OPTION' | 'REMOVE' | 'CUSTOMIZED';
/** Header configuration, you can provide extensionId or using our platform header */
interface HeaderConfig extends HeaderConfigHeaderConfigOneOf {
    platform?: PlatformHeaderConfig;
    widget?: HeaderWidgetConfig;
}
/** @oneof */
interface HeaderConfigHeaderConfigOneOf {
    platform?: PlatformHeaderConfig;
    widget?: HeaderWidgetConfig;
}
/** Platform header customization option */
interface PlatformHeaderConfig {
    /**
     * Sidebar skin from WDS, dark, light.
     * @maxLength 20
     */
    theme?: string | null;
    /** Header logo */
    logo?: Logo;
    /**
     * Header menuItems / Popovers
     * @maxSize 10
     */
    menuDropdowns?: MenuDropdown[];
    /** Header platformized search configuration */
    searchConfig?: SearchConfig;
}
/** MenuItems links */
interface MenuLink {
    /**
     * Link title
     * @minLength 2
     * @maxLength 100
     */
    title?: string;
    /**
     * Link url
     * @format WEB_URL
     */
    url?: string;
}
/** option to customize your header logo */
interface Logo {
    /**
     * Logo image url
     * @format WEB_URL
     */
    imageUrl?: string;
    /**
     * Target url, choose where to navigate when clicking on the logo
     * @format WEB_URL
     */
    targetUrl?: string | null;
}
/** Header menu dropdown, (popover) */
interface MenuDropdown {
    /**
     * MenuItem title
     * @minLength 2
     * @maxLength 50
     */
    title?: string;
    /**
     * Menu dropdown links
     * @maxSize 20
     */
    links?: MenuLink[];
}
interface SearchConfig {
    /** Weather include platformized search in header or not */
    visible?: boolean;
}
/** Header widget configuration, provide extensionId */
interface HeaderWidgetConfig {
    /** @format GUID */
    extensionId?: string;
}
interface Sidebar extends SidebarConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: SidebarConfig;
    displayOption?: ElementDisplayOptionWithLiterals;
}
/** @oneof */
interface SidebarConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: SidebarConfig;
}
/** Backoffice sidebar castomization options */
interface SidebarConfig {
    /**
     * List of root sidebar items, categories or separators, if empty default sidebar will be shown
     * @maxSize 100
     */
    sidebarItems?: SidebarRootItem[];
    /**
     * Sidebar skin from WDS, dark, light.
     * @maxLength 20
     */
    theme?: string | null;
    /** Option to override sidebar header with customize extension */
    sidebarHeader?: SidebarWidget;
    /** Option to override sidebar footer with customize extension */
    sidebarFooter?: SidebarWidget;
    /**
     * List of sidebar entities that cannot be hidden by a restricted customization extension
     * @maxSize 200
     */
    nonRemovableSidebarEntities?: BackOfficeCustomizationSidebarEntity[];
    /**
     * ID of the top-level category where pages of private apps will be added
     * @maxLength 50
     */
    categoryIdForPrivateAppPages?: string | null;
}
/**
 * First Inner level of sidebar item, can contain pages or separators or categories
 * For separator no need to set item
 */
interface SidebarChildItem extends SidebarChildItemItemOneOf {
    category?: SecondLevelCategory;
    page?: Page;
    type?: SidebarDataTypeWithLiterals;
}
/** @oneof */
interface SidebarChildItemItemOneOf {
    category?: SecondLevelCategory;
    page?: Page;
}
declare enum SidebarDataType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    CATEGORY = "CATEGORY",
    PAGE = "PAGE",
    SEPARATOR = "SEPARATOR"
}
/** @enumType */
type SidebarDataTypeWithLiterals = SidebarDataType | 'UNKNOWN_TYPE' | 'CATEGORY' | 'PAGE' | 'SEPARATOR';
/** Represents sidebar category of second level */
interface SecondLevelCategory {
    /**
     * Category id, should be unique
     * @format GUID
     */
    categoryId?: string;
    /**
     * Category label
     * @minLength 2
     * @maxLength 50
     */
    label?: string;
    /**
     * Category children, consist of pages, separators or categories, categories can be a child only on root level
     * @maxSize 100
     */
    children?: SidebarSecondLevelChildItem[];
}
/**
 * Second Inner level of sidebar item, can contain pages or separators
 * For separator no need to set item
 */
interface SidebarSecondLevelChildItem extends SidebarSecondLevelChildItemItemOneOf {
    page?: Page;
    type?: SidebarDataTypeWithLiterals;
}
/** @oneof */
interface SidebarSecondLevelChildItemItemOneOf {
    page?: Page;
}
/** Represents page item in the sidebar */
interface Page {
    /** @format GUID */
    pageId?: string;
}
/** Represents sidebar category of root level */
interface FirstLevelCategory {
    /**
     * Category id, should be unique
     * @format GUID
     */
    categoryId?: string;
    /**
     * Category label
     * @minLength 2
     * @maxLength 50
     */
    label?: string;
    /**
     * Category icon, supported only on root level, will be ignores otherwise
     * [Wix Design System icon](https://www.wix-pages.com/wix-design-system-employees/?path=/story/foundations-icons--icons).
     * Use the full size key. The icon will be rendered in an appropriate size.
     * @minLength 3
     * @maxLength 50
     */
    icon?: string | null;
    /**
     * Category children, consist of pages, separators or categories, categories can be a child only on root level
     * @maxSize 100
     */
    children?: SidebarChildItem[];
}
/** Option to supply extension that will be shown in the sidebar */
interface SidebarWidgetConfig {
    /** @format GUID */
    extensionId?: string | null;
}
/** Root level sidebar item, can be category or separator (when not setting category) */
interface SidebarRootItem extends SidebarRootItemItemOneOf {
    category?: FirstLevelCategory;
    type?: SidebarDataTypeWithLiterals;
}
/** @oneof */
interface SidebarRootItemItemOneOf {
    category?: FirstLevelCategory;
}
/** Sidebar widget configuration */
interface SidebarWidget extends SidebarWidgetConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: SidebarWidgetConfig;
    /** Widget display option */
    displayOption?: ElementDisplayOptionWithLiterals;
}
/** @oneof */
interface SidebarWidgetConfigOneOf {
    /** Only set if option == CUSTOMIZED */
    customized?: SidebarWidgetConfig;
}
/** Represents a sidebar entity in a back office sidebar, used to configure required/hidden entities */
interface BackOfficeCustomizationSidebarEntity extends BackOfficeCustomizationSidebarEntityItemOneOf {
    /**
     * Category id
     * @minLength 1
     * @maxLength 50
     */
    categoryId?: string | null;
    /**
     * Page id
     * @format GUID
     */
    pageId?: string | null;
    /**
     * App id
     * @format GUID
     */
    appId?: string | null;
    /** Sidebar entity type */
    type?: SidebarEntityTypeWithLiterals;
}
/** @oneof */
interface BackOfficeCustomizationSidebarEntityItemOneOf {
    /**
     * Category id
     * @minLength 1
     * @maxLength 50
     */
    categoryId?: string | null;
    /**
     * Page id
     * @format GUID
     */
    pageId?: string | null;
    /**
     * App id
     * @format GUID
     */
    appId?: string | null;
}
/** Type of sidebar entity in a back office sidebar (cluster/category/page) */
declare enum SidebarEntityType {
    UNKNOWN_TYPE = "UNKNOWN_TYPE",
    CATEGORY = "CATEGORY",
    PAGE = "PAGE",
    APP = "APP"
}
/** @enumType */
type SidebarEntityTypeWithLiterals = SidebarEntityType | 'UNKNOWN_TYPE' | 'CATEGORY' | 'PAGE' | 'APP';
interface CoreApps {
    /**
     * List of core appIds to include in the dashboard. Only appIds present in the host's coreAppId list are allowed.
     * @maxSize 500
     * @format GUID
     */
    coreAppIds?: string[];
}
/** SPI config - defines the relation between implementer URL and which types it is validates */
interface ComponentEnricherConfig {
    /**
     * URI where the SPI Implementer is deployed
     * @maxLength 400
     */
    deploymentUri?: string;
    /**
     * Component types that will be enriched
     * @minSize 1
     * @maxSize 100
     */
    componentEnrichmentTypes?: ComponentTypeWithLiterals[];
}
/** Back-office Restricted Customization */
interface BackOfficeRestrictedCustomization {
    /**
     * List of entities to hide from sidebar
     * @maxSize 200
     */
    sidebarEntitiesToHide?: BackOfficeCustomizationSidebarEntity[];
}
interface AppPreviewProviderConfig {
    /** URI where the SPI Implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * Used to redirect to app overview
     * @maxLength 50
     */
    slug?: string | null;
}
interface LegendsSpiConfig {
    /**
     * URI where the SPI Implementer is deployed.
     * @maxLength 1000
     */
    deploymentUri?: string;
    /**
     * Configuration of namespaces known by implementer.
     * @maxSize 5
     */
    namespaceConfigs?: NamespaceConfig[];
}
interface NamespaceConfig {
    /**
     * Namespace name.
     * @maxLength 100
     */
    namespace?: string;
    /** PersonaService permissions associated with this namespace. */
    personaPermissions?: Permissions;
    /** KnowledgeService permissions associated with this namespace. */
    knowledgePermissions?: Permissions;
    /** MediaService permissions associated with this namespace. */
    mediaPermissions?: Permissions;
    /** PersonaChatService permissions associated with this namespace. */
    chatPermissions?: Permissions;
}
interface Permissions {
    /**
     * Create permission.
     * @maxLength 50
     */
    create?: string;
    /**
     * Read permission.
     * @maxLength 50
     */
    read?: string;
    /**
     * Update permission.
     * @maxLength 50
     */
    update?: string;
    /**
     * Delete permission.
     * @maxLength 50
     */
    delete?: string;
}
interface AppDeploymentProviderConfig {
    /** URI where the SPI implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * `true` if SPI implementer provides custom permission checks API calls
     *
     * Default: `false`
     */
    toggleIsPermitted?: boolean;
    /**
     * `true` if SPI implementer provides override cloud provider logic for CreateAppDeployment API calls
     *
     * Default: `false`
     */
    toggleOverrideCloudProvider?: boolean;
}
interface BackendWorker {
    /**
     * BAAS deployment ID
     * @format GUID
     */
    deploymentId?: string;
    /**
     * BAAS deployment URL
     * @format WEB_URL
     */
    deploymentUrl?: string | null;
    /**
     * User assigned label
     * @maxLength 200
     */
    label?: string | null;
    /**
     * Deployment git commit hash
     * @maxLength 40
     */
    commitHash?: string | null;
}
interface EventTimeSlotsProviderConfig {
    /** Reserved. */
    deploymentUri?: SpiBaseUri;
    /**
     * Filter to base retrieved events on, for bookings it could be `{"type": "CLASS"}`. See the *supported filters article*
     * ([SDK](https://dev.wix.com/docs/sdk/backend-modules/bookings/staff-members/supported-filters) | [REST](https://dev.wix.com/docs/rest/business-solutions/bookings/staff-members/filtering-and-sorting))
     * for a complete list of supported filters.
     */
    eventFilter?: Record<string, any> | null;
    /**
     * event service id field, that will be used to map the event.
     * i.e. "externalScheduleId", "extendedFields["@amit"].myServiceId"
     * @maxLength 100
     */
    eventServiceIdField?: string | null;
}
interface AppEnvironmentProviderConfig {
    /** URI where the SPI implementer is deployed */
    deploymentUri?: SpiBaseUri;
    /**
     * `true` if SPI implementer provides custom permission checks API calls
     *
     * Default: `false`
     */
    toggleIsAppEnvironmentPermitted?: boolean;
}
/** SDK exports specify the metadata of a module. */
interface SDKExports {
    /** Npm data that */
    importMetadata?: SDKExportsNpm;
    /** The export definition of a module */
    exportMetadata?: ExportMetadata;
    /** The maturity of the SDK exports */
    exposureAndMaturity?: ExtensionExposure;
}
interface SDKExportsNpm {
    /**
     * Npm package name
     * @minLength 2
     * @maxLength 100
     */
    packageName?: string;
    /**
     * Npm semantic version
     * @minLength 2
     * @maxLength 100
     */
    packageVersion?: string;
    /**
     * Package entry point, default to main entry
     * @minLength 2
     * @maxLength 100
     */
    specifier?: string | null;
    /**
     * Imported name, default to default import
     * @minLength 2
     * @maxLength 100
     */
    importedName?: string | null;
}
interface ExportMetadata {
    /**
     * Exported name of a module
     * @minLength 2
     * @maxLength 100
     */
    exportedName?: string;
    /**
     * Package entry point, default to main entry
     * @minLength 2
     * @maxLength 100
     */
    relativeSpecifier?: string | null;
}
interface RuntimeComponentCacheEntityExperiment extends RuntimeComponentCacheEntityExperimentExperimentOneOf {
    gradualRollout?: GradualRolloutCacheEntity;
    gradualUpdate?: GradualUpdateCacheEntity;
    gradualDelete?: GradualDeleteCacheEntity;
    partialUpdate?: PartialUpdateCacheEntity;
    /**
     * Spec to conduct on the component
     * @maxLength 128
     */
    spec?: string;
    /**
     * Value the spec should return in order to return the newer component version
     * @maxLength 128
     */
    variantValue?: string;
}
/** @oneof */
interface RuntimeComponentCacheEntityExperimentExperimentOneOf {
    gradualRollout?: GradualRolloutCacheEntity;
    gradualUpdate?: GradualUpdateCacheEntity;
    gradualDelete?: GradualDeleteCacheEntity;
    partialUpdate?: PartialUpdateCacheEntity;
}
interface GradualRolloutCacheEntity {
    experimentComponent?: RuntimeComponentCacheEntityComponent;
}
interface GradualUpdateCacheEntity {
    experimentComponent?: RuntimeComponentCacheEntityComponent;
    fallbackComponent?: RuntimeComponentCacheEntityComponent;
}
interface GradualDeleteCacheEntity {
    experimentComponent?: RuntimeComponentCacheEntityComponent;
}
interface PartialUpdateCacheEntity {
    experimentComponent?: RuntimeComponentCacheEntityComponent;
}
interface CreatedByCacheEntity {
    /**
     * The id of the entity which created the App
     * @format GUID
     */
    _id?: string;
    /** The type of the entity which created the App (User, App, etc.) */
    type?: string;
}
interface AppPermissions {
    /**
     * List of the permissions of the app version
     * @maxSize 700
     * @maxLength 164
     */
    permissions?: string[];
}
interface AppData {
    /**
     * Represents the ID of the Application
     * @format GUID
     */
    appId?: string;
    /**
     * Represents the Version of the Application
     * @maxLength 50
     */
    version?: string;
    /**
     * Represents the name of the Application
     * @maxLength 50
     */
    name?: string;
    /**
     * Represents the account id of the Application
     * @format GUID
     */
    accountId?: string;
    /**
     * Represents the namespace of the application
     * @minLength 1
     * @maxLength 150
     */
    namespace?: string | null;
    /** Is Wix application? */
    wixApp?: boolean;
    /**
     * The state of the application
     * @maxLength 50
     */
    status?: string;
    /**
     * The type of application
     * @maxLength 50
     */
    appType?: string;
    /**
     * Represents the Component data enriched with translations and overrides
     * @maxSize 300
     */
    components?: RuntimeComponentCacheEntity[];
    /**
     * The slug of the app. A human readable identifier of the app
     * @minLength 1
     * @maxLength 200
     */
    slug?: string | null;
    /** Indicates if the app is private */
    privateApp?: boolean;
    /** The id and type of the entity which created the App (User, App, etc.) */
    createdBy?: CreatedByCacheEntity;
    /** Represents the time this AppRuntimeData was created */
    _createdDate?: Date | null;
    /** Represents the time this AppRuntimeData was last updated */
    _updatedDate?: Date | null;
    /** Indicates if this app's version is not in draft state */
    draft?: boolean;
    /** The app permissions */
    permissions?: AppPermissions;
    /**
     * Represents the full version (major.minor.build) of the version. Only applicable for State = LOCKED_DRAFT / PRODUCTION
     * @minLength 1
     * @maxLength 50
     */
    fullVersion?: string | null;
}
interface TranslatedData {
    name?: string | null;
    components?: RuntimeComponentCacheEntityComponent[];
}
interface DeleteUserDefinedFieldsRequest {
    /**
     * id
     * @format GUID
     */
    dataExtensionSchemaId?: string | null;
    /**
     * List of fields paths to delete
     * @minSize 1
     * @maxSize 10
     * @maxLength 1000
     */
    fieldsToDelete?: string[];
}
interface DeleteUserDefinedFieldsResponse {
    /** Updated schema. */
    dataExtensionSchema?: DataExtensionSchema;
}
interface BaseEventMetadata {
    /**
     * App instance ID.
     * @format GUID
     */
    instanceId?: string | null;
    /**
     * Event type.
     * @maxLength 150
     */
    eventType?: string;
    /** The identification type and identity data. */
    identity?: IdentificationData;
}
interface EventMetadata extends BaseEventMetadata {
    /** Event ID. With this ID you can easily spot duplicated events and ignore them. */
    _id?: string;
    /**
     * Fully Qualified Domain Name of an entity. This is a unique identifier assigned to the API main business entities.
     * For example, `wix.stores.catalog.product`, `wix.bookings.session`, `wix.payments.transaction`.
     */
    entityFqdn?: string;
    /**
     * Event action name, placed at the top level to make it easier for users to dispatch messages.
     * For example: `created`/`updated`/`deleted`/`started`/`completed`/`email_opened`.
     */
    slug?: string;
    /** ID of the entity associated with the event. */
    entityId?: string;
    /** Event timestamp in [ISO-8601](https://en.wikipedia.org/wiki/ISO_8601) format and UTC time. For example, `2020-04-26T13:57:50.699Z`. */
    eventTime?: Date | null;
    /**
     * Whether the event was triggered as a result of a privacy regulation application
     * (for example, GDPR).
     */
    triggeredByAnonymizeRequest?: boolean | null;
    /** If present, indicates the action that triggered the event. */
    originatedFrom?: string | null;
    /**
     * A sequence number that indicates the order of updates to an entity. For example, if an entity was updated at 16:00 and then again at 16:01, the second update will always have a higher sequence number.
     * You can use this number to make sure you're handling updates in the right order. Just save the latest sequence number on your end and compare it to the one in each new message. If the new message has an older (lower) number, you can safely ignore it.
     */
    entityEventSequence?: string | null;
}
interface DataExtensionSchemaCreatedEnvelope {
    entity: DataExtensionSchema;
    metadata: EventMetadata;
}
interface DataExtensionSchemaDeletedEnvelope {
    metadata: EventMetadata;
}
interface DataExtensionSchemaUpdatedEnvelope {
    entity: DataExtensionSchema;
    metadata: EventMetadata;
}
interface ListDataExtensionSchemasOptions {
    /**
     * Namespaces within the given entity.
     * @maxSize 100
     * @maxLength 164
     */
    namespaces?: string[];
    /**
     * Additional fields that are hidden by default. For example, fields with `"x-wix-archived": true`.
     * @maxSize 5
     */
    fields?: RequestedFieldWithLiterals[];
    /**
     * Extension points within the given entity.
     * @maxSize 20
     * @maxLength 10
     */
    extensionPoints?: string[];
}

export { BackOfficeScriptAssetType as $, HostContainerId as A, BarAlignmentSelected as B, ComponentType as C, type DataExtensionSchema as D, Exposure as E, MandatoryField as F, MeasurementSystem as G, HorizontalDocking as H, InstallPage as I, Default as J, HookType as K, type ListDataExtensionSchemasOptions as L, Maturity as M, ActionSPIConfigInterfaceConfigurationType as N, SourceType as O, PluginInterface as P, ExecutionType as Q, RequestedField as R, StaticContainer as S, TemplateDefaultColor as T, type UpdateDataExtensionSchemaResponse as U, VerticalDocking as V, WebhookIdentityType as W, ExtendingComponentType as X, BackOfficeHostingPlatforms as Y, DtsDefinitionType as Z, SlotDataType as _, type ListDataExtensionSchemasResponse as a, PlanPeriodUnit as a$, ViewMode as a0, AlgorithmType as a1, LockableOperation as a2, RestrictedOperation as a3, BlockType as a4, Domain as a5, Status as a6, TextInputDisplayType as a7, ThumbnailType as a8, ImageShape as a9, StylesPosition as aA, MapType as aB, ViewRole as aC, VoteRole as aD, PollLayoutType as aE, PollLayoutDirection as aF, BackgroundType as aG, DecorationType as aH, FontType as aI, AppType as aJ, InitialExpandedItems as aK, Direction as aL, VerticalAlignment as aM, NullValue as aN, CalendarType as aO, ConnectMethod as aP, ListEventFromCalendars as aQ, SyncToCalendar as aR, OAuthAppType as aS, OAuthTechnologies as aT, NavigationType as aU, PingSettingsGroupComponentDataState as aV, NotificationTopicState as aW, NotificationTopicType as aX, RecipientType as aY, PlanFormPricingOption as aZ, PlanFormDefaultSection as a_, AvatarShape as aa, Tag as ab, FilterSelectionType as ac, FilterOptionsType as ad, PaginationMode as ae, ChannelType as af, AcceptedDirectMessageType as ag, MediaMimeType as ah, AcceptedSmsMessageType as ai, InitDirection as aj, NodeType as ak, WidthType as al, PluginContainerDataAlignment as am, ButtonDataType as an, LinkTarget as ao, TextAlignment as ap, LineStyle as aq, DividerDataWidth as ar, Alignment as as, PDFSettingsViewMode as at, LayoutType as au, Orientation as av, Crop as aw, ThumbnailsAlignment as ax, GIFType as ay, HTMLDataSource as az, type DeleteByWhiteListedMetaSiteResponse as b, ConsentCategory as b$, TypedDynamicParamType as b0, UserNotificationDataRecipientFilterType as b1, InitiatorType as b2, Level as b3, IconType as b4, MobileApplication as b5, AndroidStyle as b6, ExposureRuleType as b7, Intent as b8, UserNotificationDataType as b9, EmailInfoTag as bA, PhoneInfoTag as bB, AddressInfoTag as bC, ConfirmationLevel as bD, ContactField as bE, DisplayFieldType as bF, ChangeableProperty as bG, OverrideEntityType as bH, Operator as bI, Target as bJ, SubmitSuccessAction as bK, TemplateType as bL, CustomFieldsType as bM, EditableProperties as bN, RequiredIndicator as bO, RequiredIndicatorPlacement as bP, WixCodePublishTaskName as bQ, ChannelConfigurationChannelType as bR, AcceptedMessageTypesAcceptedDirectMessageType as bS, AcceptedMessageTypesAcceptedSmsMessageType as bT, FactorType as bU, MonitoringType as bV, Escalation as bW, ImportanceLevel as bX, Width as bY, PanelContentType as bZ, StorageType as b_, RecipientFilterType as ba, Type as bb, Environment as bc, SchemaScope as bd, SchemaFieldFieldType as be, CustomElementScriptType as bf, HeightMode as bg, FieldType as bh, Format as bi, StringComponentType as bj, NumberOfColumns as bk, FirstDayOfWeek as bl, NumberComponentType as bm, BooleanComponentType as bn, ItemType as bo, PropertiesTypeEnum as bp, ArrayComponentType as bq, WixFileComponentType as br, UploadFileFormat as bs, PaymentComponentType as bt, ProductType as bu, PriceType as bv, ImageFit as bw, MultilineAddressComponentType as bx, DefaultCountryConfigType as by, InputType as bz, type DataExtensionSchemaCreatedEnvelope as c, type DisplayValue as c$, StorageDomain as c0, Method as c1, ParticipantType as c2, InterfaceConfigurationType as c3, Scope as c4, CssPropertyType as c5, CssDataType as c6, FilterFunction as c7, DisplayValueEnumDisplayValue as c8, WritingModeValue as c9, type ReindexEvent as cA, type ReindexField as cB, type CreateDataExtensionSchemaRequest as cC, type CreateDataExtensionSchemaResponse as cD, type UpdateDataExtensionSchemaRequest as cE, type ListDataExtensionSchemasRequest as cF, type DeleteDemoDataExtensionSchemaRequest as cG, type DeleteDemoDataExtensionSchemaResponse as cH, type DeleteGlobalExtensionSchemaRequest as cI, type DeleteGlobalExtensionSchemaResponse as cJ, type DeleteByWhiteListedMetaSiteRequest as cK, type Empty as cL, type AppRuntimeDataEvent as cM, type AppRuntimeDataCacheEntity as cN, type RuntimeComponentCacheEntity as cO, type RuntimeComponentCacheEntityComponentOneOf as cP, type RuntimeComponentCacheEntityComponent as cQ, type ComponentData as cR, type ComponentDataDataOneOf as cS, type WidgetComponentData as cT, type FixedPositionOptions as cU, type WidgetDisplay as cV, type Position as cW, type SubPage as cX, type IsStretched as cY, type Margins as cZ, type DisplayProperties as c_, DataType as ca, A11yAttributes as cb, LinkType as cc, ContainerType as cd, ElementType as ce, ActionType as cf, PanelType as cg, ActionName as ch, SizingType as ci, Archetype as cj, ResizeDirection as ck, ContentResizeDirection as cl, RestrictionLevel as cm, ElementDisplayOption as cn, SidebarDataType as co, SidebarEntityType as cp, type DomainEvent as cq, type DomainEventBodyOneOf as cr, type EntityCreatedEvent as cs, type RestoreInfo as ct, type EntityUpdatedEvent as cu, type EntityDeletedEvent as cv, type ActionEvent as cw, type MessageEnvelope as cx, type IdentificationData as cy, type IdentificationDataIdOneOf as cz, type DataExtensionSchemaDeletedEnvelope as d, type DrillItem as d$, type Docking as d0, type DockingProperties as d1, type Height as d2, type ApiWidth as d3, type PageComponentData as d4, type Padding as d5, type PageReplaceOptions as d6, type PageReplaceOptionsOptionsOneOf as d7, type PageReplace as d8, type ReplacingOptions as d9, type EditorPresence as dA, type PresetEditorPresence as dB, type FocalPoint as dC, type BaseInfo as dD, type HelpResources as dE, type WidgetInstallationSettings as dF, type WidgetInstallationSettingsTargetContainerOneOf as dG, type BaseInstallation as dH, type WidgetInstallation as dI, type DefaultPresets as dJ, type ComponentModel as dK, type CodePackageComponentData as dL, type DashboardPlatfromComponentData as dM, type EmbeddedScriptComponentData as dN, type WixDependency as dO, type WebComponentData as dP, type Size as dQ, type Settings as dR, type Tab as dS, type Container as dT, type ContainerDataOneOf as dU, type Main as dV, type MainPropsData as dW, type DashboardButton as dX, type RichTextWithIllustrationVertical as dY, type Section as dZ, type DrillInListItem as d_, type ReplaceableOptions as da, type WidgetOutOfIframeComponentData as db, type OutOfIframeData as dc, type SettingsUrl as dd, type ErrorReporting as de, type ErrorReportingArtifact as df, type ApiSlot as dg, type ExtensionExposure as dh, type PageOutOfIframeComponentData as di, type PlatfromComponentData as dj, type DashboardComponentData as dk, type WorkerComponentData as dl, type StudioComponentData as dm, type StudioWidgetComponentData as dn, type StudioWidgetVariation as dp, type CustomElement as dq, type CustomElementConsentCategoryOneOf as dr, type NestedWidgets as ds, type PresetInfo as dt, type PresetSize as du, type InstallationSettings as dv, type InstallationSettingsOptionsOneOf as dw, type MainPresets as dx, type PageOptions as dy, type LightboxOptions as dz, type DataExtensionSchemaUpdatedEnvelope as e, type CheckboxField as e$, type DrillItemDataOneOf as e0, type RadioButtonLabeled as e1, type Condition as e2, type SingleKeyCondition as e3, type ColorSelectLabeled as e4, type ColorSelectLabeledDataOneOf as e5, type ColorDefinition as e6, type Thumbnails as e7, type ThumbnailData as e8, type SliderLabeled as e9, type _Date as eA, type SchemaFieldType as eB, type SchemaFieldTypeFieldTypeOneOf as eC, type InvoicesActionsComponentData as eD, type DashboardApplicationData as eE, type Bundle as eF, type ExperimentGroupWrapper as eG, type PageDashboardApplicationComponent as eH, type AppConfiguration as eI, type HostedComponent as eJ, type ContactLabelsComponentData as eK, type PredefinedLabel as eL, type WidgetPluginComponentData as eM, type PluginMarketData as eN, type PluginPlacement as eO, type PluginInstallationSettings as eP, type CrossSellConfig as eQ, type LocalDeliveryComponentData as eR, type PaymentServiceProviderConfig as eS, type PaymentMethod as eT, type PaymentMethodMethodOneOf as eU, type HostedPage as eV, type Logos as eW, type Color as eX, type PaymentServiceProviderCredentialsField as eY, type PaymentServiceProviderCredentialsFieldFieldOneOf as eZ, type SimpleField as e_, type DropDownLabeled as ea, type ToggleLabeled as eb, type BarAlignment as ec, type TextInputLabeled as ed, type FontFamilyWithColorPicker as ee, type FontDefinition as ef, type TextStyle as eg, type TextStyleDefaultColorOneOf as eh, type ResetButton as ei, type WidgetDetails as ej, type WidgetBehavior as ek, type ExtensionData as el, type SnippetSolutionData as em, type DataComponent as en, type DCConfigData as eo, type StaticFileComponentData as ep, type AppConfig as eq, type SiteConfig as er, type MultipleDashboardsComponentData as es, type DashboardItem as et, type PaymentsGatewayComponentData as eu, type AutomationTrigger as ev, type SchemaConfig as ew, type SchemaField as ex, type Primitive as ey, type Simple as ez, DataExtensionSchemaState as f, type CustomTriggerConfig as f$, type DropdownField as f0, type DropdownFieldOption as f1, type MembershipsSPIConfig as f2, type LineItemsEnricherConfig as f3, type ShippingRatesConfig as f4, type ShippingLabelCarrierSpiConfig as f5, type PackageType as f6, type PackageDimension as f7, type Image as f8, type RestaurantsPOSComponentData as f9, type DtsDefinitionReferenceDtsDefinitionOneOf as fA, type DtsHttpLink as fB, type DtsContent as fC, type BlocksData as fD, type Dimension as fE, type SlotParams as fF, type WidgetSlot as fG, type MenuSlot as fH, type BackOfficeExtension as fI, type BackOfficeExtensionExtensionOneOf as fJ, type LegacyBackOfficeExtensionWidget as fK, type LegacyBackOfficeExtensionWidgetAssetOneOf as fL, type BackOfficeScriptAsset as fM, type LegacyBackOfficeMenuItem as fN, type OpenComponent as fO, type LegacyBackOfficeMenuItemAction as fP, type TriggerProviderSPIConfig as fQ, type PreRegisterConfig as fR, type ProductsPathsConfig as fS, type CustomScopeConfig as fT, type GiftCardProviderConfig as fU, type ExternalFilterProviderConfig as fV, type RecommendationsProviderConfig as fW, type AlgorithmConfig as fX, type DropshippingProviderSPIConfig as fY, type InvoicesConfig as fZ, type SeoKeywordsSuggestionsSPIConfig as f_, type CatalogSyncConfiguration as fa, type ShippingProviderConfig as fb, type SpiBaseUri as fc, type AlternativeUri as fd, type AlertEnricherSpiConfiguration as fe, type DataExtensionsComponentData as ff, type GenericHooksConfig as fg, type GenericHookConfig as fh, type ActionProviderSPIConfig as fi, type ActionSPIConfig as fj, type WidgetComponentOptions as fk, type GenericOptions as fl, type WixApiOptions as fm, type ActionSPIConfigImplementedMethods as fn, type Metadata as fo, type ActionSPIConfigInterfaceConfiguration as fp, type ActionSPIConfigInterfaceConfigurationOptionsOneOf as fq, type Source as fr, type SourceOptionsOneOf as fs, type CatalogSPIConfig as ft, type DiscountConfig as fu, type BackOfficeExtensionContainer as fv, type Extendable as fw, type SlotData as fx, type SlotDataSlotTypeOneOf as fy, type DtsDefinitionReference as fz, WidgetVertical as g, type ChannelIcon as g$, type ContentProviderConfig as g0, type ApplicationAutomationComponent as g1, type Rule as g2, type Trigger as g3, type TriggerFilter as g4, type Debounce as g5, type ServiceAction as g6, type ConditionBlock as g7, type Offset as g8, type OffsetValueOneOf as g9, type IDPConnectionConfig as gA, type ItemsSelectionProviderConfig as gB, type LearnMore as gC, type ImageConfig as gD, type AvatarConfig as gE, type SearchField as gF, type FilterInfo as gG, type FilterInfoOptionsOneOf as gH, type StaticFilterOptions as gI, type StaticFilterOption as gJ, type ProviderFilterOptions as gK, type SearchParams as gL, type ContentData as gM, type AdditionalStepInfo as gN, type CreateNewItemInfo as gO, type ItemThumbnail as gP, type ItemThumbnailOptionsOneOf as gQ, type SyncedProjectsProviderConfig as gR, type CommunicationChannelConfiguration as gS, type ChannelConfiguration as gT, type ChannelConfigurationMessagingConfigOneOf as gU, type DirectMessageConfig as gV, type MediaCapabilities as gW, type EmailMessageConfig as gX, type SmsMessageConfig as gY, type ChannelBranding as gZ, type BrandIcons as g_, type Until as ga, type Delay as gb, type DelayTypeOneOf as gc, type RateLimit as gd, type ActionCondition as ge, type Conditions as gf, type AutomationMetadata as gg, type OriginInfo as gh, type BackOfficeSidebarCategory as gi, type BackOfficePage as gj, type BackOfficePageAssetOneOf as gk, type ComponentMetaData as gl, type Keywords as gm, type PageAnchor as gn, type AnchorMetaData as go, type UrlParam as gp, type AdditionalFeesSPIConfig as gq, type PingNotificationComponentData as gr, type BookingsPricingProviderConfig as gs, type AuthenticatorConfig as gt, type ExpectedInputs as gu, type PredefinedExpectedInput as gv, type PredefinedExpectedInputConfiguration as gw, type PredefinedExpectedInputConfigurationTypeOneOf as gx, type AdminConfigurableTextInput as gy, type TextInputSettings as gz, WidgetHorizontal as h, type PollSettings as h$, type ConversationLimitations as h0, type PostLoginConfig as h1, type BackOfficeWidget as h2, type BackOfficeWidgetContentOneOf as h3, type SocialMarketingDesignSPIConfig as h4, type FormSubmissionSpiConfig as h5, type FormsSubmissionsNamespaceConfig as h6, type FormsPermissions as h7, type WixOfferingComponentData as h8, type WixOfferingComponentDataOfferingOneOf as h9, type PDFSettings as hA, type GalleryData as hB, type Media as hC, type ItemImage as hD, type Video as hE, type Item as hF, type ItemDataOneOf as hG, type GalleryOptions as hH, type Layout as hI, type ItemStyle as hJ, type GalleryOptionsThumbnails as hK, type GIFData as hL, type GIF as hM, type HeadingData as hN, type HTMLData as hO, type HTMLDataDataOneOf as hP, type ImageData as hQ, type StylesBorder as hR, type ImageDataStyles as hS, type LinkPreviewData as hT, type LinkPreviewDataStyles as hU, type MapData as hV, type MapSettings as hW, type ParagraphData as hX, type PollData as hY, type SettingsPermissions as hZ, type PollOption as h_, type BusinessManagerPage as ha, type DevCenterTestingComponentData as hb, type DevCenterTestingComponentDataTranslatableOneOfOneOf as hc, type MessageContainingTranslatables as hd, type RichContent as he, type Node as hf, type NodeDataOneOf as hg, type NodeStyle as hh, type ButtonData as hi, type Border as hj, type Colors as hk, type PluginContainerData as hl, type PluginContainerDataWidth as hm, type PluginContainerDataWidthDataOneOf as hn, type Spoiler as ho, type PluginContainerDataHeight as hp, type Styles as hq, type V1Link as hr, type V1LinkDataOneOf as hs, type Rel as ht, type CodeBlockData as hu, type V1TextStyle as hv, type DividerData as hw, type FileData as hx, type FileSource as hy, type FileSourceDataOneOf as hz, WidgetWidthType as i, type CommentModerationProviderConfig as i$, type PollLayout as i0, type OptionLayout as i1, type Gradient as i2, type Background as i3, type BackgroundBackgroundOneOf as i4, type PollDesign as i5, type OptionDesign as i6, type Poll as i7, type PollDataLayout as i8, type Design as i9, type AudioData as iA, type OrderedListData as iB, type BulletedListData as iC, type BlockquoteData as iD, type CaptionData as iE, type LayoutCellData as iF, type V1Metadata as iG, type DocumentStyle as iH, type TextNodeStyle as iI, type CustomRefData as iJ, type TranslatedMessageWithUniqueFieldRepeated as iK, type TranslatedMessageWithIdRepeated as iL, type DiscoveryMetaData as iM, type InternalComponentMetadata as iN, type ComponentsValidatorConfig as iO, type ComponentTranslationAdditionalFieldsConfig as iP, type FormSchemaSpiConfig as iQ, type FormsSchemaNamespaceConfig as iR, type Restrictions as iS, type ProviderConfig as iT, type DefaultTaxGroupProviderConfig as iU, type TaxationCategoryProvider as iV, type DynamicSiteStructureProviderConfig as iW, type HeadlessOAuth as iX, type WixPagesDomainMapping as iY, type TaxCalculatorSpiConfig as iZ, type TaxCountriesConfig as i_, type TextData as ia, type Decoration as ib, type DecorationDataOneOf as ic, type AnchorData as id, type ColorData as ie, type LinkData as ig, type MentionData as ih, type FontSizeData as ii, type SpoilerData as ij, type AppEmbedData as ik, type AppEmbedDataAppDataOneOf as il, type BookingData as im, type EventData as io, type VideoData as ip, type PlaybackOptions as iq, type EmbedData as ir, type Oembed as is, type CollapsibleListData as it, type TableData as iu, type Dimensions as iv, type TableCellData as iw, type CellStyle as ix, type BorderColors as iy, type ListValue as iz, Region as j, type PlanFormPlanSettingsSection as j$, type GridAppFilesTransformerConfig as j0, type PolicyConfig as j1, type CustomChargesConfig as j2, type ValidationsSPIConfig as j3, type ComponentReferenceDataConfig as j4, type ReviewsProductCatalogProviderConfig as j5, type SocialMarketingDesignsProviderConfig as j6, type GbpFeatureConfig as j7, type CommentFilterProviderConfig as j8, type TaxIdValidatorConfig as j9, type PreviewConfiguration as jA, type TermsModalConfiguration as jB, type ThankYouPageInputConfig as jC, type ThankYouPageRedirectsConfiguration as jD, type ThankYouPagePreviewConfiguration as jE, type ThankYouPageModalConfiguration as jF, type PlanSettingsRowConfiguration as jG, type TermsAndConditionsConfiguration as jH, type ThankYouPageConfiguration as jI, type DurationInputConfiguration as jJ, type DurationRenameOptions as jK, type InputConfiguration as jL, type SetupFeeConfiguration as jM, type FreeTrialConfiguration as jN, type FreeOptionConfiguration as jO, type OneTimeOptionConfiguration as jP, type RecurringOptionConfiguration as jQ, type Illustration as jR, type IllustrationIllustrationOneOf as jS, type PlanDuration as jT, type PlanPriceData as jU, type PricingRecurring as jV, type PerkValues as jW, type PlanPricing as jX, type PlanPricingPricingModelOneOf as jY, type PlanFormPreviewSection as jZ, type PlanFormInfoSection as j_, type TaxTypesConfig as ja, type PingSettingsGroupComponentData as jb, type FormSpamSubmissionSpiConfig as jc, type FormsSpamSubmissionsNamespaceConfig as jd, type SpamSubmissionPermissions as je, type EditorAddon as jf, type InitialPosition as jg, type ToolPanelConfig as jh, type AddonMarketData as ji, type ExternalDatabaseSpiConfig as jj, type PaymentSettingsSPIConfig as jk, type NotificationTopic as jl, type NotificationPreferencesFilterConfig as jm, type BookingsResourceTypesProviderConfig as jn, type BookingsResourceType as jo, type PricingPlansFormConfiguration as jp, type TextWithTooltip as jq, type TooltipSuffix as jr, type TextWithSuffix as js, type TextWithSuffixSuffixOneOf as jt, type LinkSuffix as ju, type PreviewCardPlaceholders as jv, type InputWithPlaceholder as jw, type CoverImageConfiguration as jx, type PerksConfiguration as jy, type CheckboxConfiguration as jz, UnitType as k, type SiteMemberData as k$, type PlanFormBenefitsSection as k0, type PlanFormPricingAndDurationSection as k1, type PlanFormCustomSection as k2, type PlanFormSection as k3, type PlanFormSectionSectionOneOf as k4, type PlanFormTypeMetadata as k5, type PlanFormPagePermissionsSection as k6, type PlanFormInitialValue as k7, type UserNotification as k8, type UserNotificationData as k9, type MobilePushChannelConfig as kA, type MobilePushContentKeys as kB, type ExposureRule as kC, type ExposureRuleRuleOneOf as kD, type BooleanExperimentExposureRule as kE, type CustomExperimentExposureRule as kF, type VoiceContentKeys as kG, type SmsContentKeys as kH, type BrowserPushContentKeys as kI, type EmailChannel as kJ, type FeedChannels as kK, type MobilePushChannel as kL, type VoiceChannel as kM, type SmsChannel as kN, type BrowserPushChannel as kO, type LimiterField as kP, type UserNotificationDataRecipientFilter as kQ, type UserNotificationDataRecipientFilterDataOneOf as kR, type UserNotificationDataInitiator as kS, type UserNotificationDataInitiatorDataOneOf as kT, type UserNotificationDataDeeplink as kU, type UserNotificationDataDeeplinkOfOneOf as kV, type UserNotificationDataContext as kW, type ContactNotification as kX, type ContactsNotificationData as kY, type ContactsData as kZ, type ContactData as k_, type TypedDynamicParam as ka, type WixUsersData as kb, type SiteContributorsData as kc, type WixUserData as kd, type ConstOrDynamicParam as ke, type ConstOrDynamicParamValueOneOf as kf, type Url as kg, type BackofficeActionDeeplink as kh, type OrderValue as ki, type NotificationChannels as kj, type ResponsysEmail as kk, type VelocityEmail as kl, type ShoutoutEmail as km, type EmailTemplateConfig as kn, type EmailTemplateConfigProviderOneOf as ko, type WebFeedContentKeys as kp, type MobileFeedContentKeys as kq, type FeedAggregation as kr, type Icon as ks, type IconDataOneOf as kt, type UrlData as ku, type WebFeedChannel as kv, type MobileFeedChannel as kw, type FeedChannelsConfig as kx, type SharedPlatformMobilePushConfig as ky, type AndroidMobilePushConfig as kz, ReplacementType as l, type Field as l$, type LiveSiteActionDeeplink as l0, type RecipientFilter as l1, type RecipientFilterDataOneOf as l2, type Initiator as l3, type InitiatorDataOneOf as l4, type Deeplink as l5, type DeeplinkOfOneOf as l6, type Context as l7, type UnifiedPage as l8, type PageInstallationSettings as l9, type TaxGroupsProviderConfig as lA, type AdditionalTaxGroup as lB, type TaxCalculationConfig as lC, type BackOfficeModal as lD, type BackOfficeModalContentOneOf as lE, type ModalParams as lF, type DeploymentPipelineProviderConfig as lG, type CustomElementWidget as lH, type WidgetData as lI, type EditorBehaviors as lJ, type SettingsPanel as lK, type Dashboard as lL, type WidgetSize as lM, type WidgetSizeHeight as lN, type WidgetSizeWidth as lO, type Preset as lP, type Breakpoints as lQ, type Breakpoint as lR, type BackOfficeExtensionWidget as lS, type BackOfficeExtensionWidgetAssetOneOf as lT, type BackOfficeExtensionMenuItem as lU, type NavigateToPageAction as lV, type OpenModalAction as lW, type MenuAction as lX, type MenuActionActionOneOf as lY, type FormTemplate as lZ, type FormTemplateTemplateTypeOptionsOneOf as l_, type PageInstallation as la, type PageContent as lb, type WidgetAsContent as lc, type UnifiedPageEditorSettings as ld, type PageEditorSettings as le, type AvailabilityTimeSlotsProviderConfig as lf, type ProposalEditorProviderConfig as lg, type CustomReservationsApprovalConfig as lh, type CommentsContextProviderConfig as li, type FormSpamSubmissionReportSpiConfig as lj, type FormSpamSubmissionReportsNamespaceConfig as lk, type FormSpamSubmissionReportPermissions as ll, type VeloActionConfig as lm, type EventTypeProviderConfig as ln, type ServiceAvailabilityPolicyProviderConfig as lo, type SmsActionMessage as lp, type BookingPolicyProviderConfig as lq, type MultiServiceBookingPolicyProviderConfig as lr, type FormSubmissionSpiExtensionConfig as ls, type FormsSubmissionsExtensionNamespaceConfig as lt, type AssistantSpiConfig as lu, type MultilingualTranslationSchema as lv, type Schema as lw, type SchemaKey as lx, type V1SchemaField as ly, type PreviewFields as lz, HTTPMethod as m, type CustomFieldInfo as m$, type FieldFieldTypeOptionsOneOf as m0, type InputField as m1, type InputFieldInputTypeOptionsOneOf as m2, type StringType as m3, type StringTypeFormatOptionsOneOf as m4, type DateTimeConstraints as m5, type PhoneConstraints as m6, type TextInput as m7, type RadioGroup as m8, type RadioGroupOption as m9, type CustomOption as mA, type FileUpload as mB, type Signature as mC, type PaymentType as mD, type QuantityLimit as mE, type FixedPriceOptions as mF, type DynamicPriceOptions as mG, type Product as mH, type ProductPriceOptionsOneOf as mI, type ProductCheckboxGroup as mJ, type ProductCheckboxGroupOption as mK, type DonationInput as mL, type DonationInputOption as mM, type CommonCustomOption as mN, type MultilineAddressValidation as mO, type FieldOverrides as mP, type FieldsOverrides as mQ, type ComponentsMultilineAddress as mR, type AddressLine2 as mS, type DefaultCountryConfig as mT, type DefaultCountryConfigOptionsOneOf as mU, type FieldsSettings as mV, type FormFieldContactInfo as mW, type FormFieldContactInfoAdditionalInfoOneOf as mX, type EmailInfo as mY, type PhoneInfo as mZ, type AddressInfo as m_, type RadioGroupCustomOption as ma, type Dropdown as mb, type DropdownOption as mc, type DropdownCustomOption as md, type DateTimeInput as me, type PhoneInput as mf, type DateInput as mg, type TimeInput as mh, type DatePicker as mi, type NumberType as mj, type NumberInput as mk, type RatingInput as ml, type BooleanType as mm, type Checkbox as mn, type ArrayType as mo, type IntegerType as mp, type ObjectType as mq, type PropertiesType as mr, type PropertiesTypePropertiesTypeOptionsOneOf as ms, type ArrayTypeArrayItems as mt, type ArrayTypeArrayItemsItemTypeOptionsOneOf as mu, type CheckboxGroup as mv, type MediaItem as mw, type MediaItemMediaOneOf as mx, type CommonImage as my, type CheckboxGroupOption as mz, RegionType as n, type Output as n$, type SubscriptionInfo as n0, type _String as n1, type _StringComponentTypeOptionsOneOf as n2, type InputField_Number as n3, type InputField_NumberComponentTypeOptionsOneOf as n4, type _Boolean as n5, type _BooleanComponentTypeOptionsOneOf as n6, type _Array as n7, type _ArrayComponentTypeOptionsOneOf as n8, type _Object as n9, type V2Condition as nA, type FormOverride as nB, type FormOverrideEntityTypeOptionsOneOf as nC, type SubmitSettings as nD, type SubmitSettingsSubmitSuccessActionOptionsOneOf as nE, type ThankYouMessageOptions as nF, type RedirectOptions as nG, type ExtensionDetails as nH, type EditableFields as nI, type AddCustomFields as nJ, type OverrideTemplateFields as nK, type DeleteTemplateFields as nL, type FieldGroup as nM, type RequiredIndicatorProperties as nN, type NotificationContent as nO, type SingleContent as nP, type GroupedContent as nQ, type BroadcastList as nR, type Param as nS, type PayoutsProviderConfig as nT, type ReviewsEntityCatalogProviderConfig as nU, type VeloPublishPipelineTaskProviderConfig as nV, type FunctionsShopPriceSpiConfig as nW, type Namespace as nX, type _Function as nY, type Input as nZ, type BuilderSpi as n_, type WixFile as na, type WixFileComponentTypeOptionsOneOf as nb, type Payment as nc, type PaymentComponentTypeOptionsOneOf as nd, type MultilineAddress as ne, type MultilineAddressComponentTypeOptionsOneOf as nf, type DisplayField as ng, type DisplayFieldDisplayFieldTypeOptionsOneOf as nh, type RichContentOptions as ni, type PageNavigationOptions as nj, type Step as nk, type FormLayout as nl, type BreakPoint as nm, type ItemLayout as nn, type Margin as no, type BreakPointSection as np, type V2Rule as nq, type RequiredOptions as nr, type HiddenOptions as ns, type AllowedValuesOptions as nt, type FieldOverride as nu, type FieldOverridePropertyTypeOptionsOneOf as nv, type ConditionNode as nw, type ConditionNodeNodeOneOf as nx, type AndCondition as ny, type OrCondition as nz, EmbeddedScriptPages as o, type ApplicationProfile as o$, type State as o0, type Spi as o1, type FunctionDefinition as o2, type Configuration as o3, type Description as o4, type CheckoutContentSPIConfig as o5, type V2CommunicationChannelConfiguration as o6, type ChannelChannelConfiguration as o7, type ChannelChannelConfigurationMessagingConfigOneOf as o8, type DmDirectMessageConfig as o9, type UnifiedLightbox as oA, type LightboxEditorSettings as oB, type LightboxCloseOptions as oC, type LightboxContent as oD, type PageWidgetAsContent as oE, type FormSpiExtensionConfig as oF, type SchemaGroup as oG, type SchemaGroupElement as oH, type Panel as oI, type PanelSelectedContentTypeOneOf as oJ, type PanelSize as oK, type CodePanel as oL, type PurchaseValidationsConfig as oM, type BrowserStorage as oN, type SdkDefinition as oO, type SiteWidgetSlot as oP, type EventValidationProviderConfig as oQ, type ValidationTarget as oR, type ClientSideService as oS, type Npm as oT, type Definition as oU, type Implementation as oV, type BillingSettingsConfig as oW, type PaymentDateModification as oX, type PatternsWizard as oY, type ApplicationProfileProviderConfig as oZ, type V1ImplementedMethods as o_, type ChannelMediaCapabilities as oa, type EmailEmailMessageConfig as ob, type SmsSmsMessageConfig as oc, type ChannelChannelBranding as od, type ChannelBrandIcons as oe, type UpstreamWixCommonImage as of, type ChannelImplementedMethods as og, type WebhookComponentData as oh, type TopologyComponentData as oi, type CustomRewardProviderConfig as oj, type FunctionRecipe as ok, type BackOfficeExternalUrl as ol, type FactorConfig as om, type DiscountsSPIConfig as on, type VeloCustomCss as oo, type AdaptiveComponentProviderConfig as op, type ActionSpiConfig as oq, type InventorySpiConfig as or, type Monitoring as os, type MonitoringOptionsOneOf as ot, type SentryOptions as ou, type Project as ov, type PanoramaOptions as ow, type PluginConfig as ox, type Consequence as oy, type Constraint as oz, EmbeddedScriptPlacement as p, type PresetItem as p$, type TextToSpeechActionMessage as p0, type AudienceProviderConfig as p1, type InterfaceConfiguration as p2, type InterfaceConfigurationOfTypeOneOf as p3, type WidgetComponent as p4, type ItemSelection as p5, type ImplementedMethods as p6, type PriceSPIConfig as p7, type StartDateLimitsSPIConfig as p8, type StartDateRulesSPIConfig as p9, type _Number as pA, type A11y as pB, type Link as pC, type ArrayItems as pD, type ArrayItemsArrayDataOneOf as pE, type DataItems as pF, type ReactElementContainer as pG, type ReactElementContainerSelectedContainerTypeOneOf as pH, type SimpleContainer as pI, type Slot as pJ, type PlaceHolder as pK, type ElementItem as pL, type ElementItemSelectedElementTypeOneOf as pM, type InlineElement as pN, type Behaviors as pO, type Actions as pP, type Action as pQ, type Execution as pR, type ExecutionActionExecuteOneOf as pS, type DataAction as pT, type StyleAction as pU, type EventAction as pV, type PanelAction as pW, type PanelActionSelectedPanelTypeOneOf as pX, type ForwardAction as pY, type ForwardActionActionOneOf as pZ, type DashboardAction as p_, type TicketReservationsSpiConfig as pa, type DisputeServicePluginConfig as pb, type FeesSPIConfig as pc, type EditorReactComponent as pd, type Resources as pe, type ClientResources as pf, type Resource as pg, type TranslationResources as ph, type EditorElement as pi, type StyleItem as pj, type StyleItemSelectedItemTypeOneOf as pk, type StyleItemSelectedCssPropertyTypeOneOf as pl, type StyleItemSelectedCssVariableTypeOneOf as pm, type Filter as pn, type BackdropFilter as po, type Display as pp, type WritingMode as pq, type CustomEnum as pr, type CustomEnumOption as ps, type CustomEnumOptionCssProperty as pt, type CssNumber as pu, type DataItem as pv, type DataItemSelectedDataTypeOneOf as pw, type Text as px, type TextEnum as py, type Option as pz, EmbedCategory as q, type ExportMetadata as q$, type ElementStyleDefaults as q0, type ComponentInitialSize as q1, type InitialSizeSetting as q2, type InitialSizeSettingSelectedSizingTypeOneOf as q3, type ElementDefaults as q4, type RefElement as q5, type StyleItemOverrides as q6, type DataItemOverrides as q7, type EditorElementLayout as q8, type InstallationInfo as q9, type SidebarChildItem as qA, type SidebarChildItemItemOneOf as qB, type SecondLevelCategory as qC, type SidebarSecondLevelChildItem as qD, type SidebarSecondLevelChildItemItemOneOf as qE, type Page as qF, type FirstLevelCategory as qG, type SidebarWidgetConfig as qH, type SidebarRootItem as qI, type SidebarRootItemItemOneOf as qJ, type SidebarWidget as qK, type SidebarWidgetConfigOneOf as qL, type BackOfficeCustomizationSidebarEntity as qM, type BackOfficeCustomizationSidebarEntityItemOneOf as qN, type CoreApps as qO, type ComponentEnricherConfig as qP, type BackOfficeRestrictedCustomization as qQ, type AppPreviewProviderConfig as qR, type LegendsSpiConfig as qS, type NamespaceConfig as qT, type Permissions as qU, type AppDeploymentProviderConfig as qV, type BackendWorker as qW, type EventTimeSlotsProviderConfig as qX, type AppEnvironmentProviderConfig as qY, type SDKExports as qZ, type SDKExportsNpm as q_, type InstallationInfoTargetContainerOneOf as qa, type MarketplaceSPIConfig as qb, type FormSchemaDynamicValuesSpiConfig as qc, type BlogPaywallProviderConfig as qd, type RewardProviderConfig as qe, type ProductRestrictionsConfig as qf, type RestrictionsConfig as qg, type Restriction as qh, type FormSubmissionModerationSpiConfig as qi, type FormSubmissionModerationSpiNamespaceConfig as qj, type EventBadgesSpiConfig as qk, type OperationExecutorConfig as ql, type BackOfficeCustomization as qm, type Header as qn, type HeaderConfigOneOf as qo, type HeaderConfig as qp, type HeaderConfigHeaderConfigOneOf as qq, type PlatformHeaderConfig as qr, type MenuLink as qs, type Logo as qt, type MenuDropdown as qu, type SearchConfig as qv, type HeaderWidgetConfig as qw, type Sidebar as qx, type SidebarConfigOneOf as qy, type SidebarConfig as qz, ThumbnailsSize as r, type RuntimeComponentCacheEntityExperiment as r0, type RuntimeComponentCacheEntityExperimentExperimentOneOf as r1, type GradualRolloutCacheEntity as r2, type GradualUpdateCacheEntity as r3, type GradualDeleteCacheEntity as r4, type PartialUpdateCacheEntity as r5, type CreatedByCacheEntity as r6, type AppPermissions as r7, type AppData as r8, type TranslatedData as r9, type DeleteUserDefinedFieldsRequest as ra, type DeleteUserDefinedFieldsResponse as rb, type BaseEventMetadata as rc, type EventMetadata as rd, DefaultTextStyle as s, WebComponentDataElementType as t, ScriptType as u, ExtensionType as v, PrimitiveType as w, SimpleType as x, SchemaFieldExposure as y, PartialPaymentRestriction as z };
